"""This module contains the general information for ComputeServerUnitFsmStage ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ComputeServerUnitFsmStageConsts:
    LAST_UPDATE_TIME_ = ""
    NAME_ACTIVATE_ADAPTOR_ACTIVATE_LOCAL = "ActivateAdaptorActivateLocal"
    NAME_ACTIVATE_ADAPTOR_ACTIVATE_PEER = "ActivateAdaptorActivatePeer"
    NAME_ACTIVATE_ADAPTOR_ASSERT_BYPASS_WAIT = "ActivateAdaptorAssertBypassWait"
    NAME_ACTIVATE_ADAPTOR_BEGIN = "ActivateAdaptorBegin"
    NAME_ACTIVATE_ADAPTOR_CHECK_POWER_AVAILABILITY = "ActivateAdaptorCheckPowerAvailability"
    NAME_ACTIVATE_ADAPTOR_DEASSERT_RESET_BYPASS = "ActivateAdaptorDeassertResetBypass"
    NAME_ACTIVATE_ADAPTOR_FAIL = "ActivateAdaptorFail"
    NAME_ACTIVATE_ADAPTOR_POWER_DEPLOY_WAIT = "ActivateAdaptorPowerDeployWait"
    NAME_ACTIVATE_ADAPTOR_POWER_ON = "ActivateAdaptorPowerOn"
    NAME_ACTIVATE_ADAPTOR_RESET = "ActivateAdaptorReset"
    NAME_ACTIVATE_ADAPTOR_SUCCESS = "ActivateAdaptorSuccess"
    NAME_ACTIVATE_BIOSACTIVATE = "ActivateBIOSActivate"
    NAME_ACTIVATE_BIOSBEGIN = "ActivateBIOSBegin"
    NAME_ACTIVATE_BIOSCHECK_POWER_AVAILABILITY = "ActivateBIOSCheckPowerAvailability"
    NAME_ACTIVATE_BIOSCLEAR = "ActivateBIOSClear"
    NAME_ACTIVATE_BIOSFAIL = "ActivateBIOSFail"
    NAME_ACTIVATE_BIOSPOLL_ACTIVATE_STATUS = "ActivateBIOSPollActivateStatus"
    NAME_ACTIVATE_BIOSPOLL_CLEAR_STATUS = "ActivateBIOSPollClearStatus"
    NAME_ACTIVATE_BIOSPOWER_DEPLOY_WAIT = "ActivateBIOSPowerDeployWait"
    NAME_ACTIVATE_BIOSPOWER_OFF = "ActivateBIOSPowerOff"
    NAME_ACTIVATE_BIOSPOWER_ON = "ActivateBIOSPowerOn"
    NAME_ACTIVATE_BIOSSUCCESS = "ActivateBIOSSuccess"
    NAME_ACTIVATE_BIOSUPDATE_TOKENS = "ActivateBIOSUpdateTokens"
    NAME_ASSOCIATE_ACTIVATE_ADAPTOR_NW_FW_LOCAL = "AssociateActivateAdaptorNwFwLocal"
    NAME_ASSOCIATE_ACTIVATE_ADAPTOR_NW_FW_PEER = "AssociateActivateAdaptorNwFwPeer"
    NAME_ASSOCIATE_ACTIVATE_BIOS = "AssociateActivateBios"
    NAME_ASSOCIATE_ACTIVATE_IBMCFW = "AssociateActivateIBMCFw"
    NAME_ASSOCIATE_ASSERT_BYPASS_WAIT = "AssociateAssertBypassWait"
    NAME_ASSOCIATE_BEGIN = "AssociateBegin"
    NAME_ASSOCIATE_BIOS_IMG_UPDATE = "AssociateBiosImgUpdate"
    NAME_ASSOCIATE_BIOS_POST_COMPLETION = "AssociateBiosPostCompletion"
    NAME_ASSOCIATE_BLADE_POWER_OFF = "AssociateBladePowerOff"
    NAME_ASSOCIATE_BMC_CONFIG_PNU_OS = "AssociateBmcConfigPnuOS"
    NAME_ASSOCIATE_BMC_PRECONFIG_PNU_OSLOCAL = "AssociateBmcPreconfigPnuOSLocal"
    NAME_ASSOCIATE_BMC_PRECONFIG_PNU_OSPEER = "AssociateBmcPreconfigPnuOSPeer"
    NAME_ASSOCIATE_BMC_UNCONFIG_PNU_OS = "AssociateBmcUnconfigPnuOS"
    NAME_ASSOCIATE_BOOT_HOST = "AssociateBootHost"
    NAME_ASSOCIATE_BOOT_PNUOS = "AssociateBootPnuos"
    NAME_ASSOCIATE_BOOT_WAIT = "AssociateBootWait"
    NAME_ASSOCIATE_CALCULATE_VLAN_GROUP_FOR_HOST_OSLOCAL = "AssociateCalculateVlanGroupForHostOSLocal"
    NAME_ASSOCIATE_CALCULATE_VLAN_GROUP_FOR_HOST_OSPEER = "AssociateCalculateVlanGroupForHostOSPeer"
    NAME_ASSOCIATE_CHECK_POWER_AVAILABILITY = "AssociateCheckPowerAvailability"
    NAME_ASSOCIATE_CISCO_OSOPEN_GATE = "AssociateCiscoOSOpenGate"
    NAME_ASSOCIATE_CLEAR_BIOS_UPDATE = "AssociateClearBiosUpdate"
    NAME_ASSOCIATE_CONFIG_CIMC_VMEDIA = "AssociateConfigCimcVMedia"
    NAME_ASSOCIATE_CONFIG_EXT_MGMT_GW = "AssociateConfigExtMgmtGw"
    NAME_ASSOCIATE_CONFIG_EXT_MGMT_RULES = "AssociateConfigExtMgmtRules"
    NAME_ASSOCIATE_CONFIG_FAN_SPEED = "AssociateConfigFanSpeed"
    NAME_ASSOCIATE_CONFIG_FLEX_FLASH = "AssociateConfigFlexFlash"
    NAME_ASSOCIATE_CONFIG_HOST_OS_ANNOTATIONS = "AssociateConfigHostOsAnnotations"
    NAME_ASSOCIATE_CONFIG_MGMT_IP_RULES = "AssociateConfigMgmtIpRules"
    NAME_ASSOCIATE_CONFIG_SERVER_IDENTITY = "AssociateConfigServerIdentity"
    NAME_ASSOCIATE_CONFIG_SO_L = "AssociateConfigSoL"
    NAME_ASSOCIATE_CONFIG_USER_ACCESS = "AssociateConfigUserAccess"
    NAME_ASSOCIATE_CONFIG_UUID = "AssociateConfigUuid"
    NAME_ASSOCIATE_COPY_REMOTE = "AssociateCopyRemote"
    NAME_ASSOCIATE_DEASSERT_RESET_BYPASS = "AssociateDeassertResetBypass"
    NAME_ASSOCIATE_DELETE_CURL_DOWNLOADED_IMAGES = "AssociateDeleteCurlDownloadedImages"
    NAME_ASSOCIATE_DELETE_IMAGES_REMOTE = "AssociateDeleteImagesRemote"
    NAME_ASSOCIATE_DOWNLOAD_IMAGES = "AssociateDownloadImages"
    NAME_ASSOCIATE_FAIL = "AssociateFail"
    NAME_ASSOCIATE_GRAPHICS_IMAGE_UPDATE = "AssociateGraphicsImageUpdate"
    NAME_ASSOCIATE_HAG_HOST_OSCONNECT = "AssociateHagHostOSConnect"
    NAME_ASSOCIATE_HAG_PNU_OSCONNECT = "AssociateHagPnuOSConnect"
    NAME_ASSOCIATE_HAG_PNU_OSDISCONNECT = "AssociateHagPnuOSDisconnect"
    NAME_ASSOCIATE_HBA_IMG_UPDATE = "AssociateHbaImgUpdate"
    NAME_ASSOCIATE_HOST_OSCONFIG = "AssociateHostOSConfig"
    NAME_ASSOCIATE_HOST_OSCONNECT = "AssociateHostOSConnect"
    NAME_ASSOCIATE_HOST_OSIDENT = "AssociateHostOSIdent"
    NAME_ASSOCIATE_HOST_OSPOLICY = "AssociateHostOSPolicy"
    NAME_ASSOCIATE_HOST_OSVALIDATE = "AssociateHostOSValidate"
    NAME_ASSOCIATE_LOCAL_DISK_FW_UPDATE = "AssociateLocalDiskFwUpdate"
    NAME_ASSOCIATE_MARK_ADAPTER_FOR_REBOOT = "AssociateMarkAdapterForReboot"
    NAME_ASSOCIATE_MSWITCH_IMG_UPDATE = "AssociateMswitchImgUpdate"
    NAME_ASSOCIATE_NIC_CONFIG_HOST_OSLOCAL = "AssociateNicConfigHostOSLocal"
    NAME_ASSOCIATE_NIC_CONFIG_HOST_OSPEER = "AssociateNicConfigHostOSPeer"
    NAME_ASSOCIATE_NIC_CONFIG_PARAMS_HOST_OSLOCAL = "AssociateNicConfigParamsHostOSLocal"
    NAME_ASSOCIATE_NIC_CONFIG_PARAMS_HOST_OSPEER = "AssociateNicConfigParamsHostOSPeer"
    NAME_ASSOCIATE_NIC_CONFIG_PNU_OSLOCAL = "AssociateNicConfigPnuOSLocal"
    NAME_ASSOCIATE_NIC_CONFIG_PNU_OSPEER = "AssociateNicConfigPnuOSPeer"
    NAME_ASSOCIATE_NIC_CONFIG_SERVICE_INFRA_LOCAL = "AssociateNicConfigServiceInfraLocal"
    NAME_ASSOCIATE_NIC_CONFIG_SERVICE_INFRA_PEER = "AssociateNicConfigServiceInfraPeer"
    NAME_ASSOCIATE_NIC_IMG_UPDATE = "AssociateNicImgUpdate"
    NAME_ASSOCIATE_NIC_UNCONFIG_PNU_OSLOCAL = "AssociateNicUnconfigPnuOSLocal"
    NAME_ASSOCIATE_NIC_UNCONFIG_PNU_OSPEER = "AssociateNicUnconfigPnuOSPeer"
    NAME_ASSOCIATE_OOB_POLL_SAS_EXPANDER_ACTIVATE_STATUS = "AssociateOobPollSasExpanderActivateStatus"
    NAME_ASSOCIATE_OOB_POLL_SAS_EXPANDER_BOOT_IMG_ACTIVATE_STATUS = "AssociateOobPollSasExpanderBootImgActivateStatus"
    NAME_ASSOCIATE_OOB_POLL_SAS_EXPANDER_UPDATE_STATUS = "AssociateOobPollSasExpanderUpdateStatus"
    NAME_ASSOCIATE_OOB_SAS_EXPANDER_BOOT_IMG_ACTIVATE = "AssociateOobSasExpanderBootImgActivate"
    NAME_ASSOCIATE_OOB_SAS_EXPANDER_IMG_ACTIVATE = "AssociateOobSasExpanderImgActivate"
    NAME_ASSOCIATE_OOB_SAS_EXPANDER_IMG_UPDATE = "AssociateOobSasExpanderImgUpdate"
    NAME_ASSOCIATE_OOB_STORAGE_CONFIG = "AssociateOobStorageConfig"
    NAME_ASSOCIATE_OOB_STORAGE_INVENTORY = "AssociateOobStorageInventory"
    NAME_ASSOCIATE_PCI_SWITCH_IMAGE_UPDATE = "AssociatePciSwitchImageUpdate"
    NAME_ASSOCIATE_PERSISTENT_MEMORY_DIMM_FW_UPDATE = "AssociatePersistentMemoryDimmFwUpdate"
    NAME_ASSOCIATE_PNU_OSCATALOG = "AssociatePnuOSCatalog"
    NAME_ASSOCIATE_PNU_OSCONFIG = "AssociatePnuOSConfig"
    NAME_ASSOCIATE_PNU_OSIDENT = "AssociatePnuOSIdent"
    NAME_ASSOCIATE_PNU_OSINVENTORY = "AssociatePnuOSInventory"
    NAME_ASSOCIATE_PNU_OSLOCAL_DISK_CONFIG = "AssociatePnuOSLocalDiskConfig"
    NAME_ASSOCIATE_PNU_OSPERIPHERAL_COMPONENT_CONFIG = "AssociatePnuOSPeripheralComponentConfig"
    NAME_ASSOCIATE_PNU_OSPOLICY = "AssociatePnuOSPolicy"
    NAME_ASSOCIATE_PNU_OSSELF_TEST = "AssociatePnuOSSelfTest"
    NAME_ASSOCIATE_PNU_OSUNLOAD_DRIVERS = "AssociatePnuOSUnloadDrivers"
    NAME_ASSOCIATE_PNU_OSVALIDATE = "AssociatePnuOSValidate"
    NAME_ASSOCIATE_POLL_BIOS_ACTIVATE_STATUS = "AssociatePollBiosActivateStatus"
    NAME_ASSOCIATE_POLL_BIOS_UPDATE_STATUS = "AssociatePollBiosUpdateStatus"
    NAME_ASSOCIATE_POLL_BOARD_CTRL_POWER_CYCLE = "AssociatePollBoardCtrlPowerCycle"
    NAME_ASSOCIATE_POLL_BOARD_CTRL_UPDATE_STATUS = "AssociatePollBoardCtrlUpdateStatus"
    NAME_ASSOCIATE_POLL_CLEAR_BIOS_UPDATE_STATUS = "AssociatePollClearBiosUpdateStatus"
    NAME_ASSOCIATE_POWER_CYCLE_BOARD = "AssociatePowerCycleBoard"
    NAME_ASSOCIATE_POWER_DEPLOY_WAIT = "AssociatePowerDeployWait"
    NAME_ASSOCIATE_POWER_ON = "AssociatePowerOn"
    NAME_ASSOCIATE_POWER_ON_PRE_CONFIG = "AssociatePowerOnPreConfig"
    NAME_ASSOCIATE_PRE_SANITIZE = "AssociatePreSanitize"
    NAME_ASSOCIATE_PREPARE_FOR_BOOT = "AssociatePrepareForBoot"
    NAME_ASSOCIATE_RESET_IBMC = "AssociateResetIBMC"
    NAME_ASSOCIATE_RESTORE_VD_STATUS = "AssociateRestoreVdStatus"
    NAME_ASSOCIATE_SANITIZE = "AssociateSanitize"
    NAME_ASSOCIATE_SAS_EXPANDER_IMG_UPDATE = "AssociateSasExpanderImgUpdate"
    NAME_ASSOCIATE_SERIAL_DEBUG_PNU_OSCONNECT = "AssociateSerialDebugPnuOSConnect"
    NAME_ASSOCIATE_SERIAL_DEBUG_PNU_OSDISCONNECT = "AssociateSerialDebugPnuOSDisconnect"
    NAME_ASSOCIATE_SHARED_COMPONENTS_OOB_INVENTORY = "AssociateSharedComponentsOobInventory"
    NAME_ASSOCIATE_SHARED_COMPONENTS_OOB_INVENTORY_PEER = "AssociateSharedComponentsOobInventoryPeer"
    NAME_ASSOCIATE_SOL_REDIRECT_DISABLE = "AssociateSolRedirectDisable"
    NAME_ASSOCIATE_SOL_REDIRECT_ENABLE = "AssociateSolRedirectEnable"
    NAME_ASSOCIATE_STORAGE_CTLR_IMG_UPDATE = "AssociateStorageCtlrImgUpdate"
    NAME_ASSOCIATE_SUCCESS = "AssociateSuccess"
    NAME_ASSOCIATE_SW_CONFIG_HOST_OSLOCAL = "AssociateSwConfigHostOSLocal"
    NAME_ASSOCIATE_SW_CONFIG_HOST_OSPEER = "AssociateSwConfigHostOSPeer"
    NAME_ASSOCIATE_SW_CONFIG_PNU_OSLOCAL = "AssociateSwConfigPnuOSLocal"
    NAME_ASSOCIATE_SW_CONFIG_PNU_OSPEER = "AssociateSwConfigPnuOSPeer"
    NAME_ASSOCIATE_SW_CONFIG_PORT_NIV_LOCAL = "AssociateSwConfigPortNivLocal"
    NAME_ASSOCIATE_SW_CONFIG_PORT_NIV_PEER = "AssociateSwConfigPortNivPeer"
    NAME_ASSOCIATE_SW_CONFIG_SERVICE_INFRA_LOCAL = "AssociateSwConfigServiceInfraLocal"
    NAME_ASSOCIATE_SW_CONFIG_SERVICE_INFRA_PEER = "AssociateSwConfigServiceInfraPeer"
    NAME_ASSOCIATE_SW_UNCONFIG_PNU_OSLOCAL = "AssociateSwUnconfigPnuOSLocal"
    NAME_ASSOCIATE_SW_UNCONFIG_PNU_OSPEER = "AssociateSwUnconfigPnuOSPeer"
    NAME_ASSOCIATE_SYNC_POWER_STATE = "AssociateSyncPowerState"
    NAME_ASSOCIATE_UNCONFIG_CIMC_VMEDIA = "AssociateUnconfigCimcVMedia"
    NAME_ASSOCIATE_UNCONFIG_EXT_MGMT_GW = "AssociateUnconfigExtMgmtGw"
    NAME_ASSOCIATE_UNCONFIG_EXT_MGMT_RULES = "AssociateUnconfigExtMgmtRules"
    NAME_ASSOCIATE_UNLOCK_FIRMWARE_IMAGE = "AssociateUnlockFirmwareImage"
    NAME_ASSOCIATE_UPDATE_ADAPTOR_NW_FW_LOCAL = "AssociateUpdateAdaptorNwFwLocal"
    NAME_ASSOCIATE_UPDATE_ADAPTOR_NW_FW_PEER = "AssociateUpdateAdaptorNwFwPeer"
    NAME_ASSOCIATE_UPDATE_BIOS_REQUEST = "AssociateUpdateBiosRequest"
    NAME_ASSOCIATE_UPDATE_BOARD_CTRL_REQUEST = "AssociateUpdateBoardCtrlRequest"
    NAME_ASSOCIATE_UPDATE_IBMCFW = "AssociateUpdateIBMCFw"
    NAME_ASSOCIATE_VERIFY_FC_ZONE_CONFIG = "AssociateVerifyFcZoneConfig"
    NAME_ASSOCIATE_WAIT_FOR_ADAPTOR_NW_FW_UPDATE_LOCAL = "AssociateWaitForAdaptorNwFwUpdateLocal"
    NAME_ASSOCIATE_WAIT_FOR_ADAPTOR_NW_FW_UPDATE_PEER = "AssociateWaitForAdaptorNwFwUpdatePeer"
    NAME_ASSOCIATE_WAIT_FOR_BORDER_CONFIG_COMPLETION_LOCAL = "AssociateWaitForBorderConfigCompletionLocal"
    NAME_ASSOCIATE_WAIT_FOR_BORDER_CONFIG_COMPLETION_PEER = "AssociateWaitForBorderConfigCompletionPeer"
    NAME_ASSOCIATE_WAIT_FOR_IBMCFW_UPDATE = "AssociateWaitForIBMCFwUpdate"
    NAME_BIOS_RECOVERY_BEGIN = "BiosRecoveryBegin"
    NAME_BIOS_RECOVERY_CHECK_POWER_AVAILABILITY = "BiosRecoveryCheckPowerAvailability"
    NAME_BIOS_RECOVERY_CLEANUP = "BiosRecoveryCleanup"
    NAME_BIOS_RECOVERY_FAIL = "BiosRecoveryFail"
    NAME_BIOS_RECOVERY_POWER_DEPLOY_WAIT = "BiosRecoveryPowerDeployWait"
    NAME_BIOS_RECOVERY_PRE_SANITIZE = "BiosRecoveryPreSanitize"
    NAME_BIOS_RECOVERY_RESET = "BiosRecoveryReset"
    NAME_BIOS_RECOVERY_SANITIZE = "BiosRecoverySanitize"
    NAME_BIOS_RECOVERY_SETUP_VMEDIA_LOCAL = "BiosRecoverySetupVmediaLocal"
    NAME_BIOS_RECOVERY_SETUP_VMEDIA_PEER = "BiosRecoverySetupVmediaPeer"
    NAME_BIOS_RECOVERY_SHUTDOWN = "BiosRecoveryShutdown"
    NAME_BIOS_RECOVERY_START = "BiosRecoveryStart"
    NAME_BIOS_RECOVERY_STOP_VMEDIA_LOCAL = "BiosRecoveryStopVMediaLocal"
    NAME_BIOS_RECOVERY_STOP_VMEDIA_PEER = "BiosRecoveryStopVMediaPeer"
    NAME_BIOS_RECOVERY_SUCCESS = "BiosRecoverySuccess"
    NAME_BIOS_RECOVERY_TEARDOWN_VMEDIA_LOCAL = "BiosRecoveryTeardownVmediaLocal"
    NAME_BIOS_RECOVERY_TEARDOWN_VMEDIA_PEER = "BiosRecoveryTeardownVmediaPeer"
    NAME_BIOS_RECOVERY_WAIT = "BiosRecoveryWait"
    NAME_CIMC_SECURITY_CONFIG_BEGIN = "CimcSecurityConfigBegin"
    NAME_CIMC_SECURITY_CONFIG_FAIL = "CimcSecurityConfigFail"
    NAME_CIMC_SECURITY_CONFIG_KMIP_CERT_CONFIG = "CimcSecurityConfigKmipCertConfig"
    NAME_CIMC_SECURITY_CONFIG_KMIP_SAVE_CERT = "CimcSecurityConfigKmipSaveCert"
    NAME_CIMC_SECURITY_CONFIG_SUCCESS = "CimcSecurityConfigSuccess"
    NAME_CIMC_SESSION_DELETE_BEGIN = "CimcSessionDeleteBegin"
    NAME_CIMC_SESSION_DELETE_EXECUTE = "CimcSessionDeleteExecute"
    NAME_CIMC_SESSION_DELETE_FAIL = "CimcSessionDeleteFail"
    NAME_CIMC_SESSION_DELETE_SUCCESS = "CimcSessionDeleteSuccess"
    NAME_CMOS_RESET_BEGIN = "CmosResetBegin"
    NAME_CMOS_RESET_BLADE_POWER_ON = "CmosResetBladePowerOn"
    NAME_CMOS_RESET_CHECK_POWER_AVAILABILITY = "CmosResetCheckPowerAvailability"
    NAME_CMOS_RESET_EXECUTE = "CmosResetExecute"
    NAME_CMOS_RESET_FAIL = "CmosResetFail"
    NAME_CMOS_RESET_POWER_DEPLOY_WAIT = "CmosResetPowerDeployWait"
    NAME_CMOS_RESET_PRE_SANITIZE = "CmosResetPreSanitize"
    NAME_CMOS_RESET_RECONFIG_BIOS = "CmosResetReconfigBios"
    NAME_CMOS_RESET_RECONFIG_UUID = "CmosResetReconfigUuid"
    NAME_CMOS_RESET_SANITIZE = "CmosResetSanitize"
    NAME_CMOS_RESET_SUCCESS = "CmosResetSuccess"
    NAME_CONFIG_BOARD_BEGIN = "ConfigBoardBegin"
    NAME_CONFIG_BOARD_CONFIG_MEMORY_POLICY = "ConfigBoardConfigMemoryPolicy"
    NAME_CONFIG_BOARD_FAIL = "ConfigBoardFail"
    NAME_CONFIG_BOARD_SUCCESS = "ConfigBoardSuccess"
    NAME_CONFIG_SO_LBEGIN = "ConfigSoLBegin"
    NAME_CONFIG_SO_LEXECUTE = "ConfigSoLExecute"
    NAME_CONFIG_SO_LFAIL = "ConfigSoLFail"
    NAME_CONFIG_SO_LSUCCESS = "ConfigSoLSuccess"
    NAME_CONFIGURE_SERVER_PERSONALITY_BEGIN = "ConfigureServerPersonalityBegin"
    NAME_CONFIGURE_SERVER_PERSONALITY_EXECUTE = "ConfigureServerPersonalityExecute"
    NAME_CONFIGURE_SERVER_PERSONALITY_FAIL = "ConfigureServerPersonalityFail"
    NAME_CONFIGURE_SERVER_PERSONALITY_SUCCESS = "ConfigureServerPersonalitySuccess"
    NAME_DECOMMISSION_BEGIN = "DecommissionBegin"
    NAME_DECOMMISSION_CLEANUP_CIMC = "DecommissionCleanupCIMC"
    NAME_DECOMMISSION_CLEANUP_PORT_CONFIG_LOCAL = "DecommissionCleanupPortConfigLocal"
    NAME_DECOMMISSION_CLEANUP_PORT_CONFIG_PEER = "DecommissionCleanupPortConfigPeer"
    NAME_DECOMMISSION_EXECUTE = "DecommissionExecute"
    NAME_DECOMMISSION_FAIL = "DecommissionFail"
    NAME_DECOMMISSION_PRECLEANUP_PORT_CONFIG = "DecommissionPrecleanupPortConfig"
    NAME_DECOMMISSION_STOP_VMEDIA_LOCAL = "DecommissionStopVMediaLocal"
    NAME_DECOMMISSION_STOP_VMEDIA_PEER = "DecommissionStopVMediaPeer"
    NAME_DECOMMISSION_SUCCESS = "DecommissionSuccess"
    NAME_DECOMMISSION_UNCONFIG_EXT_MGMT_GW = "DecommissionUnconfigExtMgmtGw"
    NAME_DECOMMISSION_UNCONFIG_EXT_MGMT_RULES = "DecommissionUnconfigExtMgmtRules"
    NAME_DIAG_BEGIN = "DiagBegin"
    NAME_DIAG_BIOS_POST_COMPLETION = "DiagBiosPostCompletion"
    NAME_DIAG_CHECK_POWER_AVAILABILITY = "DiagCheckPowerAvailability"
    NAME_DIAG_DISABLE_SCRIPTABLE_VMEDIA = "DiagDisableScriptableVMedia"
    NAME_DIAG_FAIL = "DiagFail"
    NAME_DIAG_HAG_CONNECT = "DiagHagConnect"
    NAME_DIAG_HAG_DISCONNECT = "DiagHagDisconnect"
    NAME_DIAG_LOG_TRANSFER = "DiagLogTransfer"
    NAME_DIAG_PNU_OSIDENT = "DiagPnuOSIdent"
    NAME_DIAG_POWER_ON = "DiagPowerOn"
    NAME_DIAG_POWER_ON_WAIT = "DiagPowerOnWait"
    NAME_DIAG_PRE_SANITIZE = "DiagPreSanitize"
    NAME_DIAG_PRECONFIG_VMEDIA_LOCAL = "DiagPreconfigVmediaLocal"
    NAME_DIAG_PRECONFIG_VMEDIA_PEER = "DiagPreconfigVmediaPeer"
    NAME_DIAG_RUN_TESTS = "DiagRunTests"
    NAME_DIAG_SANITIZE = "DiagSanitize"
    NAME_DIAG_SERIAL_DEBUG_CONNECT = "DiagSerialDebugConnect"
    NAME_DIAG_SERIAL_DEBUG_DISCONNECT = "DiagSerialDebugDisconnect"
    NAME_DIAG_SETUP_BOOT_ENVIRONMENT = "DiagSetupBootEnvironment"
    NAME_DIAG_SETUP_VMEDIA_LOCAL = "DiagSetupVmediaLocal"
    NAME_DIAG_SETUP_VMEDIA_PEER = "DiagSetupVmediaPeer"
    NAME_DIAG_SHUTDOWN = "DiagShutdown"
    NAME_DIAG_SUCCESS = "DiagSuccess"
    NAME_DIAG_TEAR_DOWN_BOOT_ENVIRONMENT = "DiagTearDownBootEnvironment"
    NAME_DIAG_TEARDOWN_VMEDIA_LOCAL = "DiagTeardownVmediaLocal"
    NAME_DIAG_TEARDOWN_VMEDIA_PEER = "DiagTeardownVmediaPeer"
    NAME_DIAG_WAIT_FOR_DEBUG = "DiagWaitForDebug"
    NAME_DIAGNOSTIC_INTERRUPT_BEGIN = "DiagnosticInterruptBegin"
    NAME_DIAGNOSTIC_INTERRUPT_EXECUTE = "DiagnosticInterruptExecute"
    NAME_DIAGNOSTIC_INTERRUPT_FAIL = "DiagnosticInterruptFail"
    NAME_DIAGNOSTIC_INTERRUPT_SUCCESS = "DiagnosticInterruptSuccess"
    NAME_DISASSOCIATE_BEGIN = "DisassociateBegin"
    NAME_DISASSOCIATE_BIOS_POST_COMPLETION = "DisassociateBiosPostCompletion"
    NAME_DISASSOCIATE_BMC_CONFIG_PNU_OS = "DisassociateBmcConfigPnuOS"
    NAME_DISASSOCIATE_BMC_PRECONFIG_PNU_OSLOCAL = "DisassociateBmcPreconfigPnuOSLocal"
    NAME_DISASSOCIATE_BMC_PRECONFIG_PNU_OSPEER = "DisassociateBmcPreconfigPnuOSPeer"
    NAME_DISASSOCIATE_BMC_UNCONFIG_PNU_OS = "DisassociateBmcUnconfigPnuOS"
    NAME_DISASSOCIATE_BOOT_PNUOS = "DisassociateBootPnuos"
    NAME_DISASSOCIATE_BOOT_WAIT = "DisassociateBootWait"
    NAME_DISASSOCIATE_CHECK_POWER_AVAILABILITY = "DisassociateCheckPowerAvailability"
    NAME_DISASSOCIATE_CONFIG_BIOS = "DisassociateConfigBios"
    NAME_DISASSOCIATE_CONFIG_FLEX_FLASH_SCRUB = "DisassociateConfigFlexFlashScrub"
    NAME_DISASSOCIATE_CONFIG_KVM_MGMT_DEFAULT_SETTING = "DisassociateConfigKvmMgmtDefaultSetting"
    NAME_DISASSOCIATE_CONFIG_USER_ACCESS = "DisassociateConfigUserAccess"
    NAME_DISASSOCIATE_DEASSERT_RESET_BYPASS = "DisassociateDeassertResetBypass"
    NAME_DISASSOCIATE_FAIL = "DisassociateFail"
    NAME_DISASSOCIATE_HAG_PNU_OSCONNECT = "DisassociateHagPnuOSConnect"
    NAME_DISASSOCIATE_HAG_PNU_OSDISCONNECT = "DisassociateHagPnuOSDisconnect"
    NAME_DISASSOCIATE_HANDLE_POOLING = "DisassociateHandlePooling"
    NAME_DISASSOCIATE_NIC_CONFIG_PNU_OSLOCAL = "DisassociateNicConfigPnuOSLocal"
    NAME_DISASSOCIATE_NIC_CONFIG_PNU_OSPEER = "DisassociateNicConfigPnuOSPeer"
    NAME_DISASSOCIATE_NIC_UNCONFIG_HOST_OSLOCAL = "DisassociateNicUnconfigHostOSLocal"
    NAME_DISASSOCIATE_NIC_UNCONFIG_HOST_OSPEER = "DisassociateNicUnconfigHostOSPeer"
    NAME_DISASSOCIATE_NIC_UNCONFIG_PNU_OSLOCAL = "DisassociateNicUnconfigPnuOSLocal"
    NAME_DISASSOCIATE_NIC_UNCONFIG_PNU_OSPEER = "DisassociateNicUnconfigPnuOSPeer"
    NAME_DISASSOCIATE_NIC_UNCONFIG_SERVICE_INFRA_LOCAL = "DisassociateNicUnconfigServiceInfraLocal"
    NAME_DISASSOCIATE_NIC_UNCONFIG_SERVICE_INFRA_PEER = "DisassociateNicUnconfigServiceInfraPeer"
    NAME_DISASSOCIATE_OOB_DISK_SCRUB = "DisassociateOobDiskScrub"
    NAME_DISASSOCIATE_PNU_OSCATALOG = "DisassociatePnuOSCatalog"
    NAME_DISASSOCIATE_PNU_OSIDENT = "DisassociatePnuOSIdent"
    NAME_DISASSOCIATE_PNU_OSPOLICY = "DisassociatePnuOSPolicy"
    NAME_DISASSOCIATE_PNU_OSSCRUB = "DisassociatePnuOSScrub"
    NAME_DISASSOCIATE_PNU_OSSELF_TEST = "DisassociatePnuOSSelfTest"
    NAME_DISASSOCIATE_PNU_OSUNCONFIG = "DisassociatePnuOSUnconfig"
    NAME_DISASSOCIATE_PNU_OSVALIDATE = "DisassociatePnuOSValidate"
    NAME_DISASSOCIATE_POWER_DEPLOY_WAIT = "DisassociatePowerDeployWait"
    NAME_DISASSOCIATE_POWER_ON = "DisassociatePowerOn"
    NAME_DISASSOCIATE_PRE_SANITIZE = "DisassociatePreSanitize"
    NAME_DISASSOCIATE_RESET_SECURE_BOOT_CONFIG = "DisassociateResetSecureBootConfig"
    NAME_DISASSOCIATE_SANITIZE = "DisassociateSanitize"
    NAME_DISASSOCIATE_SERIAL_DEBUG_PNU_OSCONNECT = "DisassociateSerialDebugPnuOSConnect"
    NAME_DISASSOCIATE_SERIAL_DEBUG_PNU_OSDISCONNECT = "DisassociateSerialDebugPnuOSDisconnect"
    NAME_DISASSOCIATE_SHUTDOWN = "DisassociateShutdown"
    NAME_DISASSOCIATE_SOL_REDIRECT_DISABLE = "DisassociateSolRedirectDisable"
    NAME_DISASSOCIATE_SOL_REDIRECT_ENABLE = "DisassociateSolRedirectEnable"
    NAME_DISASSOCIATE_SUCCESS = "DisassociateSuccess"
    NAME_DISASSOCIATE_SW_CONFIG_PNU_OSLOCAL = "DisassociateSwConfigPnuOSLocal"
    NAME_DISASSOCIATE_SW_CONFIG_PNU_OSPEER = "DisassociateSwConfigPnuOSPeer"
    NAME_DISASSOCIATE_SW_CONFIG_PORT_NIV_LOCAL = "DisassociateSwConfigPortNivLocal"
    NAME_DISASSOCIATE_SW_CONFIG_PORT_NIV_PEER = "DisassociateSwConfigPortNivPeer"
    NAME_DISASSOCIATE_SW_UNCONFIG_HOST_OSLOCAL = "DisassociateSwUnconfigHostOSLocal"
    NAME_DISASSOCIATE_SW_UNCONFIG_HOST_OSPEER = "DisassociateSwUnconfigHostOSPeer"
    NAME_DISASSOCIATE_SW_UNCONFIG_PNU_OSLOCAL = "DisassociateSwUnconfigPnuOSLocal"
    NAME_DISASSOCIATE_SW_UNCONFIG_PNU_OSPEER = "DisassociateSwUnconfigPnuOSPeer"
    NAME_DISASSOCIATE_UNCONFIG_BIOS = "DisassociateUnconfigBios"
    NAME_DISASSOCIATE_UNCONFIG_CIMC_VMEDIA = "DisassociateUnconfigCimcVMedia"
    NAME_DISASSOCIATE_UNCONFIG_EXT_MGMT_GW = "DisassociateUnconfigExtMgmtGw"
    NAME_DISASSOCIATE_UNCONFIG_EXT_MGMT_RULES = "DisassociateUnconfigExtMgmtRules"
    NAME_DISASSOCIATE_UNCONFIG_FLEX_FLASH = "DisassociateUnconfigFlexFlash"
    NAME_DISASSOCIATE_UNCONFIG_SERVER_IDENTITY = "DisassociateUnconfigServerIdentity"
    NAME_DISASSOCIATE_UNCONFIG_SO_L = "DisassociateUnconfigSoL"
    NAME_DISASSOCIATE_UNCONFIG_UUID = "DisassociateUnconfigUuid"
    NAME_DISASSOCIATE_VERIFY_FC_ZONE_CONFIG = "DisassociateVerifyFcZoneConfig"
    NAME_DISCOVER_BEGIN = "DiscoverBegin"
    NAME_DISCOVER_BIOS_POST_COMPLETION = "DiscoverBiosPostCompletion"
    NAME_DISCOVER_BLADE_BOOT_WAIT = "DiscoverBladeBootWait"
    NAME_DISCOVER_BMC_CONFIG_PNU_OS = "DiscoverBmcConfigPnuOS"
    NAME_DISCOVER_BMC_FACTORY_RESET = "DiscoverBmcFactoryReset"
    NAME_DISCOVER_BMC_INVENTORY = "DiscoverBmcInventory"
    NAME_DISCOVER_BMC_SHUTDOWN_DISCOVERED = "DiscoverBmcShutdownDiscovered"
    NAME_DISCOVER_BOOT_PNUOS = "DiscoverBootPnuos"
    NAME_DISCOVER_CIMC_PRESENCE = "DiscoverCimcPresence"
    NAME_DISCOVER_CLEANUP_NIC_CONFIG_LOCAL = "DiscoverCleanupNicConfigLocal"
    NAME_DISCOVER_CLEANUP_NIC_CONFIG_PEER = "DiscoverCleanupNicConfigPeer"
    NAME_DISCOVER_CONFIG_USER_ACCESS = "DiscoverConfigUserAccess"
    NAME_DISCOVER_FAIL = "DiscoverFail"
    NAME_DISCOVER_HANDLE_POOLING = "DiscoverHandlePooling"
    NAME_DISCOVER_PRE_SANITIZE = "DiscoverPreSanitize"
    NAME_DISCOVER_READ_SMBIOS = "DiscoverReadSmbios"
    NAME_DISCOVER_SANITIZE = "DiscoverSanitize"
    NAME_DISCOVER_SUCCESS = "DiscoverSuccess"
    NAME_DISCOVER_UNCONFIG_CIMC_VMEDIA = "DiscoverUnconfigCimcVMedia"
    NAME_DISCOVER_UNCONFIG_EXT_MGMT_GW = "DiscoverUnconfigExtMgmtGw"
    NAME_DISCOVER_UNCONFIG_EXT_MGMT_RULES = "DiscoverUnconfigExtMgmtRules"
    NAME_DISK_ZONING_INVENTORY_BEGIN = "DiskZoningInventoryBegin"
    NAME_DISK_ZONING_INVENTORY_BOOT_HOST = "DiskZoningInventoryBootHost"
    NAME_DISK_ZONING_INVENTORY_BOOT_WAIT = "DiskZoningInventoryBootWait"
    NAME_DISK_ZONING_INVENTORY_FAIL = "DiskZoningInventoryFail"
    NAME_DISK_ZONING_INVENTORY_PRE_SANITIZE = "DiskZoningInventoryPreSanitize"
    NAME_DISK_ZONING_INVENTORY_SANITIZE = "DiskZoningInventorySanitize"
    NAME_DISK_ZONING_INVENTORY_SHUTDOWN = "DiskZoningInventoryShutdown"
    NAME_DISK_ZONING_INVENTORY_STORAGE_INVENTORY = "DiskZoningInventoryStorageInventory"
    NAME_DISK_ZONING_INVENTORY_SUCCESS = "DiskZoningInventorySuccess"
    NAME_ENABLE_CIMC_SECURE_BOOT_ACTIVATE = "EnableCimcSecureBootActivate"
    NAME_ENABLE_CIMC_SECURE_BOOT_BEGIN = "EnableCimcSecureBootBegin"
    NAME_ENABLE_CIMC_SECURE_BOOT_FAIL = "EnableCimcSecureBootFail"
    NAME_ENABLE_CIMC_SECURE_BOOT_POLL_UPDATE_STATUS = "EnableCimcSecureBootPollUpdateStatus"
    NAME_ENABLE_CIMC_SECURE_BOOT_RESET = "EnableCimcSecureBootReset"
    NAME_ENABLE_CIMC_SECURE_BOOT_SUCCESS = "EnableCimcSecureBootSuccess"
    NAME_ENABLE_CIMC_SECURE_BOOT_UPDATE_REQUEST = "EnableCimcSecureBootUpdateRequest"
    NAME_EXECUTE_ACTIONS_BEGIN = "ExecuteActionsBegin"
    NAME_EXECUTE_ACTIONS_BIOS_POST_COMPLETION = "ExecuteActionsBiosPostCompletion"
    NAME_EXECUTE_ACTIONS_EXECUTE_PMACTION = "ExecuteActionsExecutePMAction"
    NAME_EXECUTE_ACTIONS_FAIL = "ExecuteActionsFail"
    NAME_EXECUTE_ACTIONS_POWER_ON = "ExecuteActionsPowerOn"
    NAME_EXECUTE_ACTIONS_SOFT_SHUTDOWN = "ExecuteActionsSoftShutdown"
    NAME_EXECUTE_ACTIONS_SUCCESS = "ExecuteActionsSuccess"
    NAME_FLASH_CONTROLLER_BEGIN = "FlashControllerBegin"
    NAME_FLASH_CONTROLLER_FAIL = "FlashControllerFail"
    NAME_FLASH_CONTROLLER_SUCCESS = "FlashControllerSuccess"
    NAME_FLASH_CONTROLLER_UPDATE_FLASH_LIFE = "FlashControllerUpdateFlashLife"
    NAME_FW_UPGRADE_ACTIVATE_ADAPTOR_NW_FW_LOCAL = "FwUpgradeActivateAdaptorNwFwLocal"
    NAME_FW_UPGRADE_ACTIVATE_ADAPTOR_NW_FW_PEER = "FwUpgradeActivateAdaptorNwFwPeer"
    NAME_FW_UPGRADE_ACTIVATE_BIOS = "FwUpgradeActivateBios"
    NAME_FW_UPGRADE_ACTIVATE_IBMCFW = "FwUpgradeActivateIBMCFw"
    NAME_FW_UPGRADE_ASSERT_BYPASS_WAIT = "FwUpgradeAssertBypassWait"
    NAME_FW_UPGRADE_BEGIN = "FwUpgradeBegin"
    NAME_FW_UPGRADE_BIOS_IMG_UPDATE = "FwUpgradeBiosImgUpdate"
    NAME_FW_UPGRADE_BIOS_POST_COMPLETION = "FwUpgradeBiosPostCompletion"
    NAME_FW_UPGRADE_BLADE_POWER_OFF = "FwUpgradeBladePowerOff"
    NAME_FW_UPGRADE_BMC_CONFIG_PNU_OS = "FwUpgradeBmcConfigPnuOS"
    NAME_FW_UPGRADE_BMC_PRECONFIG_PNU_OSLOCAL = "FwUpgradeBmcPreconfigPnuOSLocal"
    NAME_FW_UPGRADE_BMC_PRECONFIG_PNU_OSPEER = "FwUpgradeBmcPreconfigPnuOSPeer"
    NAME_FW_UPGRADE_BMC_UNCONFIG_PNU_OS = "FwUpgradeBmcUnconfigPnuOS"
    NAME_FW_UPGRADE_BOOT_PNUOS = "FwUpgradeBootPnuos"
    NAME_FW_UPGRADE_BOOT_WAIT = "FwUpgradeBootWait"
    NAME_FW_UPGRADE_CHECK_POWER_AVAILABILITY = "FwUpgradeCheckPowerAvailability"
    NAME_FW_UPGRADE_CISCO_OSOPEN_GATE = "FwUpgradeCiscoOSOpenGate"
    NAME_FW_UPGRADE_CLEAR_BIOS_UPDATE = "FwUpgradeClearBiosUpdate"
    NAME_FW_UPGRADE_COPY_REMOTE = "FwUpgradeCopyRemote"
    NAME_FW_UPGRADE_DEASSERT_RESET_BYPASS = "FwUpgradeDeassertResetBypass"
    NAME_FW_UPGRADE_DELETE_CURL_DOWNLOADED_IMAGES = "FwUpgradeDeleteCurlDownloadedImages"
    NAME_FW_UPGRADE_DELETE_IMAGES_REMOTE = "FwUpgradeDeleteImagesRemote"
    NAME_FW_UPGRADE_DOWNLOAD_IMAGES = "FwUpgradeDownloadImages"
    NAME_FW_UPGRADE_FAIL = "FwUpgradeFail"
    NAME_FW_UPGRADE_GRAPHICS_IMAGE_UPDATE = "FwUpgradeGraphicsImageUpdate"
    NAME_FW_UPGRADE_HAG_PNU_OSCONNECT = "FwUpgradeHagPnuOSConnect"
    NAME_FW_UPGRADE_HAG_PNU_OSDISCONNECT = "FwUpgradeHagPnuOSDisconnect"
    NAME_FW_UPGRADE_HBA_IMG_UPDATE = "FwUpgradeHbaImgUpdate"
    NAME_FW_UPGRADE_LOCAL_DISK_FW_UPDATE = "FwUpgradeLocalDiskFwUpdate"
    NAME_FW_UPGRADE_MSWITCH_IMG_UPDATE = "FwUpgradeMswitchImgUpdate"
    NAME_FW_UPGRADE_NIC_CONFIG_PNU_OSLOCAL = "FwUpgradeNicConfigPnuOSLocal"
    NAME_FW_UPGRADE_NIC_CONFIG_PNU_OSPEER = "FwUpgradeNicConfigPnuOSPeer"
    NAME_FW_UPGRADE_NIC_IMG_UPDATE = "FwUpgradeNicImgUpdate"
    NAME_FW_UPGRADE_NIC_UNCONFIG_PNU_OSLOCAL = "FwUpgradeNicUnconfigPnuOSLocal"
    NAME_FW_UPGRADE_NIC_UNCONFIG_PNU_OSPEER = "FwUpgradeNicUnconfigPnuOSPeer"
    NAME_FW_UPGRADE_OOB_POLL_SAS_EXPANDER_ACTIVATE_STATUS = "FwUpgradeOobPollSasExpanderActivateStatus"
    NAME_FW_UPGRADE_OOB_POLL_SAS_EXPANDER_BOOT_IMG_ACTIVATE_STATUS = "FwUpgradeOobPollSasExpanderBootImgActivateStatus"
    NAME_FW_UPGRADE_OOB_POLL_SAS_EXPANDER_UPDATE_STATUS = "FwUpgradeOobPollSasExpanderUpdateStatus"
    NAME_FW_UPGRADE_OOB_SAS_EXPANDER_BOOT_IMG_ACTIVATE = "FwUpgradeOobSasExpanderBootImgActivate"
    NAME_FW_UPGRADE_OOB_SAS_EXPANDER_IMG_ACTIVATE = "FwUpgradeOobSasExpanderImgActivate"
    NAME_FW_UPGRADE_OOB_SAS_EXPANDER_IMG_UPDATE = "FwUpgradeOobSasExpanderImgUpdate"
    NAME_FW_UPGRADE_OOB_STORAGE_INVENTORY = "FwUpgradeOobStorageInventory"
    NAME_FW_UPGRADE_PCI_SWITCH_IMAGE_UPDATE = "FwUpgradePciSwitchImageUpdate"
    NAME_FW_UPGRADE_PERSISTENT_MEMORY_DIMM_FW_UPDATE = "FwUpgradePersistentMemoryDimmFwUpdate"
    NAME_FW_UPGRADE_PNU_OSCATALOG = "FwUpgradePnuOSCatalog"
    NAME_FW_UPGRADE_PNU_OSCONFIG = "FwUpgradePnuOSConfig"
    NAME_FW_UPGRADE_PNU_OSIDENT = "FwUpgradePnuOSIdent"
    NAME_FW_UPGRADE_PNU_OSINVENTORY = "FwUpgradePnuOSInventory"
    NAME_FW_UPGRADE_PNU_OSPOLICY = "FwUpgradePnuOSPolicy"
    NAME_FW_UPGRADE_PNU_OSSELF_TEST = "FwUpgradePnuOSSelfTest"
    NAME_FW_UPGRADE_PNU_OSUNLOAD_DRIVERS = "FwUpgradePnuOSUnloadDrivers"
    NAME_FW_UPGRADE_PNU_OSVALIDATE = "FwUpgradePnuOSValidate"
    NAME_FW_UPGRADE_POLL_BIOS_ACTIVATE_STATUS = "FwUpgradePollBiosActivateStatus"
    NAME_FW_UPGRADE_POLL_BIOS_UPDATE_STATUS = "FwUpgradePollBiosUpdateStatus"
    NAME_FW_UPGRADE_POLL_BOARD_CTRL_POWER_CYCLE = "FwUpgradePollBoardCtrlPowerCycle"
    NAME_FW_UPGRADE_POLL_BOARD_CTRL_UPDATE_STATUS = "FwUpgradePollBoardCtrlUpdateStatus"
    NAME_FW_UPGRADE_POLL_CLEAR_BIOS_UPDATE_STATUS = "FwUpgradePollClearBiosUpdateStatus"
    NAME_FW_UPGRADE_POWER_CYCLE_BOARD = "FwUpgradePowerCycleBoard"
    NAME_FW_UPGRADE_POWER_DEPLOY_WAIT = "FwUpgradePowerDeployWait"
    NAME_FW_UPGRADE_POWER_ON = "FwUpgradePowerOn"
    NAME_FW_UPGRADE_PRE_SANITIZE = "FwUpgradePreSanitize"
    NAME_FW_UPGRADE_RESET_IBMC = "FwUpgradeResetIBMC"
    NAME_FW_UPGRADE_SANITIZE = "FwUpgradeSanitize"
    NAME_FW_UPGRADE_SAS_EXPANDER_IMG_UPDATE = "FwUpgradeSasExpanderImgUpdate"
    NAME_FW_UPGRADE_SERIAL_DEBUG_PNU_OSCONNECT = "FwUpgradeSerialDebugPnuOSConnect"
    NAME_FW_UPGRADE_SERIAL_DEBUG_PNU_OSDISCONNECT = "FwUpgradeSerialDebugPnuOSDisconnect"
    NAME_FW_UPGRADE_SHUTDOWN = "FwUpgradeShutdown"
    NAME_FW_UPGRADE_SOL_REDIRECT_DISABLE = "FwUpgradeSolRedirectDisable"
    NAME_FW_UPGRADE_SOL_REDIRECT_ENABLE = "FwUpgradeSolRedirectEnable"
    NAME_FW_UPGRADE_STORAGE_CTLR_IMG_UPDATE = "FwUpgradeStorageCtlrImgUpdate"
    NAME_FW_UPGRADE_SUCCESS = "FwUpgradeSuccess"
    NAME_FW_UPGRADE_SW_CONFIG_PNU_OSLOCAL = "FwUpgradeSwConfigPnuOSLocal"
    NAME_FW_UPGRADE_SW_CONFIG_PNU_OSPEER = "FwUpgradeSwConfigPnuOSPeer"
    NAME_FW_UPGRADE_SW_CONFIG_PORT_NIV_LOCAL = "FwUpgradeSwConfigPortNivLocal"
    NAME_FW_UPGRADE_SW_CONFIG_PORT_NIV_PEER = "FwUpgradeSwConfigPortNivPeer"
    NAME_FW_UPGRADE_SW_UNCONFIG_PNU_OSLOCAL = "FwUpgradeSwUnconfigPnuOSLocal"
    NAME_FW_UPGRADE_SW_UNCONFIG_PNU_OSPEER = "FwUpgradeSwUnconfigPnuOSPeer"
    NAME_FW_UPGRADE_UNCONFIG_CIMC_VMEDIA = "FwUpgradeUnconfigCimcVMedia"
    NAME_FW_UPGRADE_UNCONFIG_EXT_MGMT_GW = "FwUpgradeUnconfigExtMgmtGw"
    NAME_FW_UPGRADE_UNCONFIG_EXT_MGMT_RULES = "FwUpgradeUnconfigExtMgmtRules"
    NAME_FW_UPGRADE_UNLOCK_FIRMWARE_IMAGE = "FwUpgradeUnlockFirmwareImage"
    NAME_FW_UPGRADE_UPDATE_ADAPTOR_NW_FW_LOCAL = "FwUpgradeUpdateAdaptorNwFwLocal"
    NAME_FW_UPGRADE_UPDATE_ADAPTOR_NW_FW_PEER = "FwUpgradeUpdateAdaptorNwFwPeer"
    NAME_FW_UPGRADE_UPDATE_BIOS_REQUEST = "FwUpgradeUpdateBiosRequest"
    NAME_FW_UPGRADE_UPDATE_BOARD_CTRL_REQUEST = "FwUpgradeUpdateBoardCtrlRequest"
    NAME_FW_UPGRADE_UPDATE_IBMCFW = "FwUpgradeUpdateIBMCFw"
    NAME_FW_UPGRADE_WAIT_FOR_ADAPTOR_NW_FW_UPDATE_LOCAL = "FwUpgradeWaitForAdaptorNwFwUpdateLocal"
    NAME_FW_UPGRADE_WAIT_FOR_ADAPTOR_NW_FW_UPDATE_PEER = "FwUpgradeWaitForAdaptorNwFwUpdatePeer"
    NAME_FW_UPGRADE_WAIT_FOR_IBMCFW_UPDATE = "FwUpgradeWaitForIBMCFwUpdate"
    NAME_HARD_SHUTDOWN_BEGIN = "HardShutdownBegin"
    NAME_HARD_SHUTDOWN_EXECUTE = "HardShutdownExecute"
    NAME_HARD_SHUTDOWN_FAIL = "HardShutdownFail"
    NAME_HARD_SHUTDOWN_SUCCESS = "HardShutdownSuccess"
    NAME_HARDRESET_BEGIN = "HardresetBegin"
    NAME_HARDRESET_CHECK_POWER_AVAILABILITY = "HardresetCheckPowerAvailability"
    NAME_HARDRESET_EXECUTE = "HardresetExecute"
    NAME_HARDRESET_FAIL = "HardresetFail"
    NAME_HARDRESET_POWER_DEPLOY_WAIT = "HardresetPowerDeployWait"
    NAME_HARDRESET_PRE_SANITIZE = "HardresetPreSanitize"
    NAME_HARDRESET_SANITIZE = "HardresetSanitize"
    NAME_HARDRESET_SUCCESS = "HardresetSuccess"
    NAME_NVME_SWITCH_RECOVERY_BEGIN = "NvmeSwitchRecoveryBegin"
    NAME_NVME_SWITCH_RECOVERY_CHECK_STATUS = "NvmeSwitchRecoveryCheckStatus"
    NAME_NVME_SWITCH_RECOVERY_EXECUTE = "NvmeSwitchRecoveryExecute"
    NAME_NVME_SWITCH_RECOVERY_FAIL = "NvmeSwitchRecoveryFail"
    NAME_NVME_SWITCH_RECOVERY_SUCCESS = "NvmeSwitchRecoverySuccess"
    NAME_NVME_SWITCH_RECOVERY_WAIT_FOR_ACK = "NvmeSwitchRecoveryWaitForAck"
    NAME_OOB_STORAGE_ADMIN_CONFIG_BEGIN = "OobStorageAdminConfigBegin"
    NAME_OOB_STORAGE_ADMIN_CONFIG_BOOT_HOST = "OobStorageAdminConfigBootHost"
    NAME_OOB_STORAGE_ADMIN_CONFIG_BOOT_WAIT = "OobStorageAdminConfigBootWait"
    NAME_OOB_STORAGE_ADMIN_CONFIG_CHECK_POWER_AVAILABILITY = "OobStorageAdminConfigCheckPowerAvailability"
    NAME_OOB_STORAGE_ADMIN_CONFIG_FAIL = "OobStorageAdminConfigFail"
    NAME_OOB_STORAGE_ADMIN_CONFIG_OOB_STORAGE_CONFIG = "OobStorageAdminConfigOobStorageConfig"
    NAME_OOB_STORAGE_ADMIN_CONFIG_OOB_STORAGE_INVENTORY = "OobStorageAdminConfigOobStorageInventory"
    NAME_OOB_STORAGE_ADMIN_CONFIG_POWER_DEPLOY_WAIT = "OobStorageAdminConfigPowerDeployWait"
    NAME_OOB_STORAGE_ADMIN_CONFIG_PRE_SANITIZE = "OobStorageAdminConfigPreSanitize"
    NAME_OOB_STORAGE_ADMIN_CONFIG_SANITIZE = "OobStorageAdminConfigSanitize"
    NAME_OOB_STORAGE_ADMIN_CONFIG_SHUTDOWN = "OobStorageAdminConfigShutdown"
    NAME_OOB_STORAGE_ADMIN_CONFIG_SUCCESS = "OobStorageAdminConfigSuccess"
    NAME_OOB_STORAGE_ADMIN_CONFIG_TEAR_DOWN_VMEDIA_LOCAL = "OobStorageAdminConfigTearDownVMediaLocal"
    NAME_OOB_STORAGE_ADMIN_CONFIG_TEAR_DOWN_VMEDIA_PEER = "OobStorageAdminConfigTearDownVMediaPeer"
    NAME_POWER_CAP_BEGIN = "PowerCapBegin"
    NAME_POWER_CAP_CONFIG = "PowerCapConfig"
    NAME_POWER_CAP_FAIL = "PowerCapFail"
    NAME_POWER_CAP_SUCCESS = "PowerCapSuccess"
    NAME_POWERCYCLE_BEGIN = "PowercycleBegin"
    NAME_POWERCYCLE_CHECK_POWER_AVAILABILITY = "PowercycleCheckPowerAvailability"
    NAME_POWERCYCLE_EXECUTE = "PowercycleExecute"
    NAME_POWERCYCLE_FAIL = "PowercycleFail"
    NAME_POWERCYCLE_POWER_DEPLOY_WAIT = "PowercyclePowerDeployWait"
    NAME_POWERCYCLE_PRE_SANITIZE = "PowercyclePreSanitize"
    NAME_POWERCYCLE_SANITIZE = "PowercycleSanitize"
    NAME_POWERCYCLE_SUCCESS = "PowercycleSuccess"
    NAME_REINITIALIZE_VIRTUAL_DRIVE_BEGIN = "ReinitializeVirtualDriveBegin"
    NAME_REINITIALIZE_VIRTUAL_DRIVE_EXECUTE_VDACTION = "ReinitializeVirtualDriveExecuteVDAction"
    NAME_REINITIALIZE_VIRTUAL_DRIVE_FAIL = "ReinitializeVirtualDriveFail"
    NAME_REINITIALIZE_VIRTUAL_DRIVE_SUCCESS = "ReinitializeVirtualDriveSuccess"
    NAME_RESET_BMC_BEGIN = "ResetBmcBegin"
    NAME_RESET_BMC_EXECUTE = "ResetBmcExecute"
    NAME_RESET_BMC_FAIL = "ResetBmcFail"
    NAME_RESET_BMC_SUCCESS = "ResetBmcSuccess"
    NAME_RESET_IPMI_BEGIN = "ResetIpmiBegin"
    NAME_RESET_IPMI_EXECUTE = "ResetIpmiExecute"
    NAME_RESET_IPMI_FAIL = "ResetIpmiFail"
    NAME_RESET_IPMI_SUCCESS = "ResetIpmiSuccess"
    NAME_RESET_KVM_BEGIN = "ResetKvmBegin"
    NAME_RESET_KVM_EXECUTE = "ResetKvmExecute"
    NAME_RESET_KVM_FAIL = "ResetKvmFail"
    NAME_RESET_KVM_SUCCESS = "ResetKvmSuccess"
    NAME_RESET_MEMORY_ERRORS_BEGIN = "ResetMemoryErrorsBegin"
    NAME_RESET_MEMORY_ERRORS_EXECUTE = "ResetMemoryErrorsExecute"
    NAME_RESET_MEMORY_ERRORS_FAIL = "ResetMemoryErrorsFail"
    NAME_RESET_MEMORY_ERRORS_SUCCESS = "ResetMemoryErrorsSuccess"
    NAME_SERVICE_INFRA_DEPLOY_BEGIN = "ServiceInfraDeployBegin"
    NAME_SERVICE_INFRA_DEPLOY_FAIL = "ServiceInfraDeployFail"
    NAME_SERVICE_INFRA_DEPLOY_NIC_CONFIG_LOCAL = "ServiceInfraDeployNicConfigLocal"
    NAME_SERVICE_INFRA_DEPLOY_NIC_CONFIG_PEER = "ServiceInfraDeployNicConfigPeer"
    NAME_SERVICE_INFRA_DEPLOY_SUCCESS = "ServiceInfraDeploySuccess"
    NAME_SERVICE_INFRA_DEPLOY_SW_CONFIG_LOCAL = "ServiceInfraDeploySwConfigLocal"
    NAME_SERVICE_INFRA_DEPLOY_SW_CONFIG_PEER = "ServiceInfraDeploySwConfigPeer"
    NAME_SERVICE_INFRA_WITHDRAW_BEGIN = "ServiceInfraWithdrawBegin"
    NAME_SERVICE_INFRA_WITHDRAW_FAIL = "ServiceInfraWithdrawFail"
    NAME_SERVICE_INFRA_WITHDRAW_NIC_UN_CONFIG_LOCAL = "ServiceInfraWithdrawNicUnConfigLocal"
    NAME_SERVICE_INFRA_WITHDRAW_NIC_UN_CONFIG_PEER = "ServiceInfraWithdrawNicUnConfigPeer"
    NAME_SERVICE_INFRA_WITHDRAW_SUCCESS = "ServiceInfraWithdrawSuccess"
    NAME_SERVICE_INFRA_WITHDRAW_SW_UN_CONFIG_LOCAL = "ServiceInfraWithdrawSwUnConfigLocal"
    NAME_SERVICE_INFRA_WITHDRAW_SW_UN_CONFIG_PEER = "ServiceInfraWithdrawSwUnConfigPeer"
    NAME_SOFT_SHUTDOWN_BEGIN = "SoftShutdownBegin"
    NAME_SOFT_SHUTDOWN_EXECUTE = "SoftShutdownExecute"
    NAME_SOFT_SHUTDOWN_FAIL = "SoftShutdownFail"
    NAME_SOFT_SHUTDOWN_SUCCESS = "SoftShutdownSuccess"
    NAME_SOFTRESET_BEGIN = "SoftresetBegin"
    NAME_SOFTRESET_CHECK_POWER_AVAILABILITY = "SoftresetCheckPowerAvailability"
    NAME_SOFTRESET_EXECUTE = "SoftresetExecute"
    NAME_SOFTRESET_FAIL = "SoftresetFail"
    NAME_SOFTRESET_POWER_DEPLOY_WAIT = "SoftresetPowerDeployWait"
    NAME_SOFTRESET_PRE_SANITIZE = "SoftresetPreSanitize"
    NAME_SOFTRESET_SANITIZE = "SoftresetSanitize"
    NAME_SOFTRESET_SUCCESS = "SoftresetSuccess"
    NAME_SW_CONN_UPD_A = "SwConnUpdA"
    NAME_SW_CONN_UPD_B = "SwConnUpdB"
    NAME_SW_CONN_UPD_BEGIN = "SwConnUpdBegin"
    NAME_SW_CONN_UPD_FAIL = "SwConnUpdFail"
    NAME_SW_CONN_UPD_SUCCESS = "SwConnUpdSuccess"
    NAME_TURNUP_BEGIN = "TurnupBegin"
    NAME_TURNUP_CHECK_POWER_AVAILABILITY = "TurnupCheckPowerAvailability"
    NAME_TURNUP_EXECUTE = "TurnupExecute"
    NAME_TURNUP_FAIL = "TurnupFail"
    NAME_TURNUP_POWER_DEPLOY_WAIT = "TurnupPowerDeployWait"
    NAME_TURNUP_SUCCESS = "TurnupSuccess"
    NAME_UNCONFIG_SO_LBEGIN = "UnconfigSoLBegin"
    NAME_UNCONFIG_SO_LEXECUTE = "UnconfigSoLExecute"
    NAME_UNCONFIG_SO_LFAIL = "UnconfigSoLFail"
    NAME_UNCONFIG_SO_LSUCCESS = "UnconfigSoLSuccess"
    NAME_UPDATE_ADAPTOR_BEGIN = "UpdateAdaptorBegin"
    NAME_UPDATE_ADAPTOR_CHECK_POWER_AVAILABILITY = "UpdateAdaptorCheckPowerAvailability"
    NAME_UPDATE_ADAPTOR_FAIL = "UpdateAdaptorFail"
    NAME_UPDATE_ADAPTOR_POLL_UPDATE_STATUS_LOCAL = "UpdateAdaptorPollUpdateStatusLocal"
    NAME_UPDATE_ADAPTOR_POLL_UPDATE_STATUS_PEER = "UpdateAdaptorPollUpdateStatusPeer"
    NAME_UPDATE_ADAPTOR_POWER_DEPLOY_WAIT = "UpdateAdaptorPowerDeployWait"
    NAME_UPDATE_ADAPTOR_POWER_OFF = "UpdateAdaptorPowerOff"
    NAME_UPDATE_ADAPTOR_POWER_ON = "UpdateAdaptorPowerOn"
    NAME_UPDATE_ADAPTOR_SUCCESS = "UpdateAdaptorSuccess"
    NAME_UPDATE_ADAPTOR_UPDATE_REQUEST_LOCAL = "UpdateAdaptorUpdateRequestLocal"
    NAME_UPDATE_ADAPTOR_UPDATE_REQUEST_PEER = "UpdateAdaptorUpdateRequestPeer"
    NAME_UPDATE_BIOSBEGIN = "UpdateBIOSBegin"
    NAME_UPDATE_BIOSCLEAR = "UpdateBIOSClear"
    NAME_UPDATE_BIOSFAIL = "UpdateBIOSFail"
    NAME_UPDATE_BIOSPOLL_CLEAR_STATUS = "UpdateBIOSPollClearStatus"
    NAME_UPDATE_BIOSPOLL_UPDATE_STATUS = "UpdateBIOSPollUpdateStatus"
    NAME_UPDATE_BIOSSUCCESS = "UpdateBIOSSuccess"
    NAME_UPDATE_BIOSUPDATE_REQUEST = "UpdateBIOSUpdateRequest"
    NAME_UPDATE_BOARD_CONTROLLER_BEGIN = "UpdateBoardControllerBegin"
    NAME_UPDATE_BOARD_CONTROLLER_CHECK_POWER_AVAILABILITY = "UpdateBoardControllerCheckPowerAvailability"
    NAME_UPDATE_BOARD_CONTROLLER_FAIL = "UpdateBoardControllerFail"
    NAME_UPDATE_BOARD_CONTROLLER_POLL_BOARD_CTRL_POWER_CYCLE = "UpdateBoardControllerPollBoardCtrlPowerCycle"
    NAME_UPDATE_BOARD_CONTROLLER_POLL_UPDATE_STATUS = "UpdateBoardControllerPollUpdateStatus"
    NAME_UPDATE_BOARD_CONTROLLER_POWER_CYCLE_BOARD = "UpdateBoardControllerPowerCycleBoard"
    NAME_UPDATE_BOARD_CONTROLLER_POWER_DEPLOY_WAIT = "UpdateBoardControllerPowerDeployWait"
    NAME_UPDATE_BOARD_CONTROLLER_PREPARE_FOR_UPDATE = "UpdateBoardControllerPrepareForUpdate"
    NAME_UPDATE_BOARD_CONTROLLER_SERVER_POWER_OFF = "UpdateBoardControllerServerPowerOff"
    NAME_UPDATE_BOARD_CONTROLLER_SERVER_POWER_ON = "UpdateBoardControllerServerPowerOn"
    NAME_UPDATE_BOARD_CONTROLLER_SUCCESS = "UpdateBoardControllerSuccess"
    NAME_UPDATE_BOARD_CONTROLLER_UPDATE_REQUEST = "UpdateBoardControllerUpdateRequest"
    NAME_CLEAR_TPMBEGIN = "clearTPMBegin"
    NAME_CLEAR_TPMBIOS_POST_COMPLETION = "clearTPMBiosPostCompletion"
    NAME_CLEAR_TPMBLADE_POWER_OFF = "clearTPMBladePowerOff"
    NAME_CLEAR_TPMBLADE_POWER_ON = "clearTPMBladePowerOn"
    NAME_CLEAR_TPMBOOT_HOST = "clearTPMBootHost"
    NAME_CLEAR_TPMCLEAR = "clearTPMClear"
    NAME_CLEAR_TPMFAIL = "clearTPMFail"
    NAME_CLEAR_TPMPRE_SANITIZE = "clearTPMPreSanitize"
    NAME_CLEAR_TPMREAD_SM_BIOS = "clearTPMReadSmBios"
    NAME_CLEAR_TPMRECONFIG_BIOS = "clearTPMReconfigBios"
    NAME_CLEAR_TPMSANITIZE = "clearTPMSanitize"
    NAME_CLEAR_TPMSETUP_VMEDIA = "clearTPMSetupVmedia"
    NAME_CLEAR_TPMSTOP_VMEDIA_LOCAL = "clearTPMStopVMediaLocal"
    NAME_CLEAR_TPMSTOP_VMEDIA_PEER = "clearTPMStopVMediaPeer"
    NAME_CLEAR_TPMSUCCESS = "clearTPMSuccess"
    NAME_CLEAR_TPMUNCONFIG_VMEDIA = "clearTPMUnconfigVmedia"
    NAME_NOP = "nop"
    NAME_UPDATE_EXT_USERS_BEGIN = "updateExtUsersBegin"
    NAME_UPDATE_EXT_USERS_DEPLOY = "updateExtUsersDeploy"
    NAME_UPDATE_EXT_USERS_FAIL = "updateExtUsersFail"
    NAME_UPDATE_EXT_USERS_SUCCESS = "updateExtUsersSuccess"
    STAGE_STATUS_FAIL = "fail"
    STAGE_STATUS_IN_PROGRESS = "inProgress"
    STAGE_STATUS_NOP = "nop"
    STAGE_STATUS_PENDING = "pending"
    STAGE_STATUS_SKIP = "skip"
    STAGE_STATUS_SUCCESS = "success"
    STAGE_STATUS_THROTTLED = "throttled"


class ComputeServerUnitFsmStage(ManagedObject):
    """This is ComputeServerUnitFsmStage class."""

    consts = ComputeServerUnitFsmStageConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("ComputeServerUnitFsmStage", "computeServerUnitFsmStage", "stage-[name]", VersionMeta.Version251a, "OutputOnly", 0xf, [], [""], ['computeServerUnitFsm'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version251a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "last_update_time": MoPropertyMeta("last_update_time", "lastUpdateTime", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version251a, MoPropertyMeta.NAMING, None, None, None, None, ["ActivateAdaptorActivateLocal", "ActivateAdaptorActivatePeer", "ActivateAdaptorAssertBypassWait", "ActivateAdaptorBegin", "ActivateAdaptorCheckPowerAvailability", "ActivateAdaptorDeassertResetBypass", "ActivateAdaptorFail", "ActivateAdaptorPowerDeployWait", "ActivateAdaptorPowerOn", "ActivateAdaptorReset", "ActivateAdaptorSuccess", "ActivateBIOSActivate", "ActivateBIOSBegin", "ActivateBIOSCheckPowerAvailability", "ActivateBIOSClear", "ActivateBIOSFail", "ActivateBIOSPollActivateStatus", "ActivateBIOSPollClearStatus", "ActivateBIOSPowerDeployWait", "ActivateBIOSPowerOff", "ActivateBIOSPowerOn", "ActivateBIOSSuccess", "ActivateBIOSUpdateTokens", "AssociateActivateAdaptorNwFwLocal", "AssociateActivateAdaptorNwFwPeer", "AssociateActivateBios", "AssociateActivateIBMCFw", "AssociateAssertBypassWait", "AssociateBegin", "AssociateBiosImgUpdate", "AssociateBiosPostCompletion", "AssociateBladePowerOff", "AssociateBmcConfigPnuOS", "AssociateBmcPreconfigPnuOSLocal", "AssociateBmcPreconfigPnuOSPeer", "AssociateBmcUnconfigPnuOS", "AssociateBootHost", "AssociateBootPnuos", "AssociateBootWait", "AssociateCalculateVlanGroupForHostOSLocal", "AssociateCalculateVlanGroupForHostOSPeer", "AssociateCheckPowerAvailability", "AssociateCiscoOSOpenGate", "AssociateClearBiosUpdate", "AssociateConfigCimcVMedia", "AssociateConfigExtMgmtGw", "AssociateConfigExtMgmtRules", "AssociateConfigFanSpeed", "AssociateConfigFlexFlash", "AssociateConfigHostOsAnnotations", "AssociateConfigMgmtIpRules", "AssociateConfigServerIdentity", "AssociateConfigSoL", "AssociateConfigUserAccess", "AssociateConfigUuid", "AssociateCopyRemote", "AssociateDeassertResetBypass", "AssociateDeleteCurlDownloadedImages", "AssociateDeleteImagesRemote", "AssociateDownloadImages", "AssociateFail", "AssociateGraphicsImageUpdate", "AssociateHagHostOSConnect", "AssociateHagPnuOSConnect", "AssociateHagPnuOSDisconnect", "AssociateHbaImgUpdate", "AssociateHostOSConfig", "AssociateHostOSConnect", "AssociateHostOSIdent", "AssociateHostOSPolicy", "AssociateHostOSValidate", "AssociateLocalDiskFwUpdate", "AssociateMarkAdapterForReboot", "AssociateMswitchImgUpdate", "AssociateNicConfigHostOSLocal", "AssociateNicConfigHostOSPeer", "AssociateNicConfigParamsHostOSLocal", "AssociateNicConfigParamsHostOSPeer", "AssociateNicConfigPnuOSLocal", "AssociateNicConfigPnuOSPeer", "AssociateNicConfigServiceInfraLocal", "AssociateNicConfigServiceInfraPeer", "AssociateNicImgUpdate", "AssociateNicUnconfigPnuOSLocal", "AssociateNicUnconfigPnuOSPeer", "AssociateOobPollSasExpanderActivateStatus", "AssociateOobPollSasExpanderBootImgActivateStatus", "AssociateOobPollSasExpanderUpdateStatus", "AssociateOobSasExpanderBootImgActivate", "AssociateOobSasExpanderImgActivate", "AssociateOobSasExpanderImgUpdate", "AssociateOobStorageConfig", "AssociateOobStorageInventory", "AssociatePciSwitchImageUpdate", "AssociatePersistentMemoryDimmFwUpdate", "AssociatePnuOSCatalog", "AssociatePnuOSConfig", "AssociatePnuOSIdent", "AssociatePnuOSInventory", "AssociatePnuOSLocalDiskConfig", "AssociatePnuOSPeripheralComponentConfig", "AssociatePnuOSPolicy", "AssociatePnuOSSelfTest", "AssociatePnuOSUnloadDrivers", "AssociatePnuOSValidate", "AssociatePollBiosActivateStatus", "AssociatePollBiosUpdateStatus", "AssociatePollBoardCtrlPowerCycle", "AssociatePollBoardCtrlUpdateStatus", "AssociatePollClearBiosUpdateStatus", "AssociatePowerCycleBoard", "AssociatePowerDeployWait", "AssociatePowerOn", "AssociatePowerOnPreConfig", "AssociatePreSanitize", "AssociatePrepareForBoot", "AssociateResetIBMC", "AssociateRestoreVdStatus", "AssociateSanitize", "AssociateSasExpanderImgUpdate", "AssociateSerialDebugPnuOSConnect", "AssociateSerialDebugPnuOSDisconnect", "AssociateSharedComponentsOobInventory", "AssociateSharedComponentsOobInventoryPeer", "AssociateSolRedirectDisable", "AssociateSolRedirectEnable", "AssociateStorageCtlrImgUpdate", "AssociateSuccess", "AssociateSwConfigHostOSLocal", "AssociateSwConfigHostOSPeer", "AssociateSwConfigPnuOSLocal", "AssociateSwConfigPnuOSPeer", "AssociateSwConfigPortNivLocal", "AssociateSwConfigPortNivPeer", "AssociateSwConfigServiceInfraLocal", "AssociateSwConfigServiceInfraPeer", "AssociateSwUnconfigPnuOSLocal", "AssociateSwUnconfigPnuOSPeer", "AssociateSyncPowerState", "AssociateUnconfigCimcVMedia", "AssociateUnconfigExtMgmtGw", "AssociateUnconfigExtMgmtRules", "AssociateUnlockFirmwareImage", "AssociateUpdateAdaptorNwFwLocal", "AssociateUpdateAdaptorNwFwPeer", "AssociateUpdateBiosRequest", "AssociateUpdateBoardCtrlRequest", "AssociateUpdateIBMCFw", "AssociateVerifyFcZoneConfig", "AssociateWaitForAdaptorNwFwUpdateLocal", "AssociateWaitForAdaptorNwFwUpdatePeer", "AssociateWaitForBorderConfigCompletionLocal", "AssociateWaitForBorderConfigCompletionPeer", "AssociateWaitForIBMCFwUpdate", "BiosRecoveryBegin", "BiosRecoveryCheckPowerAvailability", "BiosRecoveryCleanup", "BiosRecoveryFail", "BiosRecoveryPowerDeployWait", "BiosRecoveryPreSanitize", "BiosRecoveryReset", "BiosRecoverySanitize", "BiosRecoverySetupVmediaLocal", "BiosRecoverySetupVmediaPeer", "BiosRecoveryShutdown", "BiosRecoveryStart", "BiosRecoveryStopVMediaLocal", "BiosRecoveryStopVMediaPeer", "BiosRecoverySuccess", "BiosRecoveryTeardownVmediaLocal", "BiosRecoveryTeardownVmediaPeer", "BiosRecoveryWait", "CimcSecurityConfigBegin", "CimcSecurityConfigFail", "CimcSecurityConfigKmipCertConfig", "CimcSecurityConfigKmipSaveCert", "CimcSecurityConfigSuccess", "CimcSessionDeleteBegin", "CimcSessionDeleteExecute", "CimcSessionDeleteFail", "CimcSessionDeleteSuccess", "CmosResetBegin", "CmosResetBladePowerOn", "CmosResetCheckPowerAvailability", "CmosResetExecute", "CmosResetFail", "CmosResetPowerDeployWait", "CmosResetPreSanitize", "CmosResetReconfigBios", "CmosResetReconfigUuid", "CmosResetSanitize", "CmosResetSuccess", "ConfigBoardBegin", "ConfigBoardConfigMemoryPolicy", "ConfigBoardFail", "ConfigBoardSuccess", "ConfigSoLBegin", "ConfigSoLExecute", "ConfigSoLFail", "ConfigSoLSuccess", "ConfigureServerPersonalityBegin", "ConfigureServerPersonalityExecute", "ConfigureServerPersonalityFail", "ConfigureServerPersonalitySuccess", "DecommissionBegin", "DecommissionCleanupCIMC", "DecommissionCleanupPortConfigLocal", "DecommissionCleanupPortConfigPeer", "DecommissionExecute", "DecommissionFail", "DecommissionPrecleanupPortConfig", "DecommissionStopVMediaLocal", "DecommissionStopVMediaPeer", "DecommissionSuccess", "DecommissionUnconfigExtMgmtGw", "DecommissionUnconfigExtMgmtRules", "DiagBegin", "DiagBiosPostCompletion", "DiagCheckPowerAvailability", "DiagDisableScriptableVMedia", "DiagFail", "DiagHagConnect", "DiagHagDisconnect", "DiagLogTransfer", "DiagPnuOSIdent", "DiagPowerOn", "DiagPowerOnWait", "DiagPreSanitize", "DiagPreconfigVmediaLocal", "DiagPreconfigVmediaPeer", "DiagRunTests", "DiagSanitize", "DiagSerialDebugConnect", "DiagSerialDebugDisconnect", "DiagSetupBootEnvironment", "DiagSetupVmediaLocal", "DiagSetupVmediaPeer", "DiagShutdown", "DiagSuccess", "DiagTearDownBootEnvironment", "DiagTeardownVmediaLocal", "DiagTeardownVmediaPeer", "DiagWaitForDebug", "DiagnosticInterruptBegin", "DiagnosticInterruptExecute", "DiagnosticInterruptFail", "DiagnosticInterruptSuccess", "DisassociateBegin", "DisassociateBiosPostCompletion", "DisassociateBmcConfigPnuOS", "DisassociateBmcPreconfigPnuOSLocal", "DisassociateBmcPreconfigPnuOSPeer", "DisassociateBmcUnconfigPnuOS", "DisassociateBootPnuos", "DisassociateBootWait", "DisassociateCheckPowerAvailability", "DisassociateConfigBios", "DisassociateConfigFlexFlashScrub", "DisassociateConfigKvmMgmtDefaultSetting", "DisassociateConfigUserAccess", "DisassociateDeassertResetBypass", "DisassociateFail", "DisassociateHagPnuOSConnect", "DisassociateHagPnuOSDisconnect", "DisassociateHandlePooling", "DisassociateNicConfigPnuOSLocal", "DisassociateNicConfigPnuOSPeer", "DisassociateNicUnconfigHostOSLocal", "DisassociateNicUnconfigHostOSPeer", "DisassociateNicUnconfigPnuOSLocal", "DisassociateNicUnconfigPnuOSPeer", "DisassociateNicUnconfigServiceInfraLocal", "DisassociateNicUnconfigServiceInfraPeer", "DisassociateOobDiskScrub", "DisassociatePnuOSCatalog", "DisassociatePnuOSIdent", "DisassociatePnuOSPolicy", "DisassociatePnuOSScrub", "DisassociatePnuOSSelfTest", "DisassociatePnuOSUnconfig", "DisassociatePnuOSValidate", "DisassociatePowerDeployWait", "DisassociatePowerOn", "DisassociatePreSanitize", "DisassociateResetSecureBootConfig", "DisassociateSanitize", "DisassociateSerialDebugPnuOSConnect", "DisassociateSerialDebugPnuOSDisconnect", "DisassociateShutdown", "DisassociateSolRedirectDisable", "DisassociateSolRedirectEnable", "DisassociateSuccess", "DisassociateSwConfigPnuOSLocal", "DisassociateSwConfigPnuOSPeer", "DisassociateSwConfigPortNivLocal", "DisassociateSwConfigPortNivPeer", "DisassociateSwUnconfigHostOSLocal", "DisassociateSwUnconfigHostOSPeer", "DisassociateSwUnconfigPnuOSLocal", "DisassociateSwUnconfigPnuOSPeer", "DisassociateUnconfigBios", "DisassociateUnconfigCimcVMedia", "DisassociateUnconfigExtMgmtGw", "DisassociateUnconfigExtMgmtRules", "DisassociateUnconfigFlexFlash", "DisassociateUnconfigServerIdentity", "DisassociateUnconfigSoL", "DisassociateUnconfigUuid", "DisassociateVerifyFcZoneConfig", "DiscoverBegin", "DiscoverBiosPostCompletion", "DiscoverBladeBootWait", "DiscoverBmcConfigPnuOS", "DiscoverBmcFactoryReset", "DiscoverBmcInventory", "DiscoverBmcShutdownDiscovered", "DiscoverBootPnuos", "DiscoverCimcPresence", "DiscoverCleanupNicConfigLocal", "DiscoverCleanupNicConfigPeer", "DiscoverConfigUserAccess", "DiscoverFail", "DiscoverHandlePooling", "DiscoverPreSanitize", "DiscoverReadSmbios", "DiscoverSanitize", "DiscoverSuccess", "DiscoverUnconfigCimcVMedia", "DiscoverUnconfigExtMgmtGw", "DiscoverUnconfigExtMgmtRules", "DiskZoningInventoryBegin", "DiskZoningInventoryBootHost", "DiskZoningInventoryBootWait", "DiskZoningInventoryFail", "DiskZoningInventoryPreSanitize", "DiskZoningInventorySanitize", "DiskZoningInventoryShutdown", "DiskZoningInventoryStorageInventory", "DiskZoningInventorySuccess", "EnableCimcSecureBootActivate", "EnableCimcSecureBootBegin", "EnableCimcSecureBootFail", "EnableCimcSecureBootPollUpdateStatus", "EnableCimcSecureBootReset", "EnableCimcSecureBootSuccess", "EnableCimcSecureBootUpdateRequest", "ExecuteActionsBegin", "ExecuteActionsBiosPostCompletion", "ExecuteActionsExecutePMAction", "ExecuteActionsFail", "ExecuteActionsPowerOn", "ExecuteActionsSoftShutdown", "ExecuteActionsSuccess", "FlashControllerBegin", "FlashControllerFail", "FlashControllerSuccess", "FlashControllerUpdateFlashLife", "FwUpgradeActivateAdaptorNwFwLocal", "FwUpgradeActivateAdaptorNwFwPeer", "FwUpgradeActivateBios", "FwUpgradeActivateIBMCFw", "FwUpgradeAssertBypassWait", "FwUpgradeBegin", "FwUpgradeBiosImgUpdate", "FwUpgradeBiosPostCompletion", "FwUpgradeBladePowerOff", "FwUpgradeBmcConfigPnuOS", "FwUpgradeBmcPreconfigPnuOSLocal", "FwUpgradeBmcPreconfigPnuOSPeer", "FwUpgradeBmcUnconfigPnuOS", "FwUpgradeBootPnuos", "FwUpgradeBootWait", "FwUpgradeCheckPowerAvailability", "FwUpgradeCiscoOSOpenGate", "FwUpgradeClearBiosUpdate", "FwUpgradeCopyRemote", "FwUpgradeDeassertResetBypass", "FwUpgradeDeleteCurlDownloadedImages", "FwUpgradeDeleteImagesRemote", "FwUpgradeDownloadImages", "FwUpgradeFail", "FwUpgradeGraphicsImageUpdate", "FwUpgradeHagPnuOSConnect", "FwUpgradeHagPnuOSDisconnect", "FwUpgradeHbaImgUpdate", "FwUpgradeLocalDiskFwUpdate", "FwUpgradeMswitchImgUpdate", "FwUpgradeNicConfigPnuOSLocal", "FwUpgradeNicConfigPnuOSPeer", "FwUpgradeNicImgUpdate", "FwUpgradeNicUnconfigPnuOSLocal", "FwUpgradeNicUnconfigPnuOSPeer", "FwUpgradeOobPollSasExpanderActivateStatus", "FwUpgradeOobPollSasExpanderBootImgActivateStatus", "FwUpgradeOobPollSasExpanderUpdateStatus", "FwUpgradeOobSasExpanderBootImgActivate", "FwUpgradeOobSasExpanderImgActivate", "FwUpgradeOobSasExpanderImgUpdate", "FwUpgradeOobStorageInventory", "FwUpgradePciSwitchImageUpdate", "FwUpgradePersistentMemoryDimmFwUpdate", "FwUpgradePnuOSCatalog", "FwUpgradePnuOSConfig", "FwUpgradePnuOSIdent", "FwUpgradePnuOSInventory", "FwUpgradePnuOSPolicy", "FwUpgradePnuOSSelfTest", "FwUpgradePnuOSUnloadDrivers", "FwUpgradePnuOSValidate", "FwUpgradePollBiosActivateStatus", "FwUpgradePollBiosUpdateStatus", "FwUpgradePollBoardCtrlPowerCycle", "FwUpgradePollBoardCtrlUpdateStatus", "FwUpgradePollClearBiosUpdateStatus", "FwUpgradePowerCycleBoard", "FwUpgradePowerDeployWait", "FwUpgradePowerOn", "FwUpgradePreSanitize", "FwUpgradeResetIBMC", "FwUpgradeSanitize", "FwUpgradeSasExpanderImgUpdate", "FwUpgradeSerialDebugPnuOSConnect", "FwUpgradeSerialDebugPnuOSDisconnect", "FwUpgradeShutdown", "FwUpgradeSolRedirectDisable", "FwUpgradeSolRedirectEnable", "FwUpgradeStorageCtlrImgUpdate", "FwUpgradeSuccess", "FwUpgradeSwConfigPnuOSLocal", "FwUpgradeSwConfigPnuOSPeer", "FwUpgradeSwConfigPortNivLocal", "FwUpgradeSwConfigPortNivPeer", "FwUpgradeSwUnconfigPnuOSLocal", "FwUpgradeSwUnconfigPnuOSPeer", "FwUpgradeUnconfigCimcVMedia", "FwUpgradeUnconfigExtMgmtGw", "FwUpgradeUnconfigExtMgmtRules", "FwUpgradeUnlockFirmwareImage", "FwUpgradeUpdateAdaptorNwFwLocal", "FwUpgradeUpdateAdaptorNwFwPeer", "FwUpgradeUpdateBiosRequest", "FwUpgradeUpdateBoardCtrlRequest", "FwUpgradeUpdateIBMCFw", "FwUpgradeWaitForAdaptorNwFwUpdateLocal", "FwUpgradeWaitForAdaptorNwFwUpdatePeer", "FwUpgradeWaitForIBMCFwUpdate", "HardShutdownBegin", "HardShutdownExecute", "HardShutdownFail", "HardShutdownSuccess", "HardresetBegin", "HardresetCheckPowerAvailability", "HardresetExecute", "HardresetFail", "HardresetPowerDeployWait", "HardresetPreSanitize", "HardresetSanitize", "HardresetSuccess", "NvmeSwitchRecoveryBegin", "NvmeSwitchRecoveryCheckStatus", "NvmeSwitchRecoveryExecute", "NvmeSwitchRecoveryFail", "NvmeSwitchRecoverySuccess", "NvmeSwitchRecoveryWaitForAck", "OobStorageAdminConfigBegin", "OobStorageAdminConfigBootHost", "OobStorageAdminConfigBootWait", "OobStorageAdminConfigCheckPowerAvailability", "OobStorageAdminConfigFail", "OobStorageAdminConfigOobStorageConfig", "OobStorageAdminConfigOobStorageInventory", "OobStorageAdminConfigPowerDeployWait", "OobStorageAdminConfigPreSanitize", "OobStorageAdminConfigSanitize", "OobStorageAdminConfigShutdown", "OobStorageAdminConfigSuccess", "OobStorageAdminConfigTearDownVMediaLocal", "OobStorageAdminConfigTearDownVMediaPeer", "PowerCapBegin", "PowerCapConfig", "PowerCapFail", "PowerCapSuccess", "PowercycleBegin", "PowercycleCheckPowerAvailability", "PowercycleExecute", "PowercycleFail", "PowercyclePowerDeployWait", "PowercyclePreSanitize", "PowercycleSanitize", "PowercycleSuccess", "ReinitializeVirtualDriveBegin", "ReinitializeVirtualDriveExecuteVDAction", "ReinitializeVirtualDriveFail", "ReinitializeVirtualDriveSuccess", "ResetBmcBegin", "ResetBmcExecute", "ResetBmcFail", "ResetBmcSuccess", "ResetIpmiBegin", "ResetIpmiExecute", "ResetIpmiFail", "ResetIpmiSuccess", "ResetKvmBegin", "ResetKvmExecute", "ResetKvmFail", "ResetKvmSuccess", "ResetMemoryErrorsBegin", "ResetMemoryErrorsExecute", "ResetMemoryErrorsFail", "ResetMemoryErrorsSuccess", "ServiceInfraDeployBegin", "ServiceInfraDeployFail", "ServiceInfraDeployNicConfigLocal", "ServiceInfraDeployNicConfigPeer", "ServiceInfraDeploySuccess", "ServiceInfraDeploySwConfigLocal", "ServiceInfraDeploySwConfigPeer", "ServiceInfraWithdrawBegin", "ServiceInfraWithdrawFail", "ServiceInfraWithdrawNicUnConfigLocal", "ServiceInfraWithdrawNicUnConfigPeer", "ServiceInfraWithdrawSuccess", "ServiceInfraWithdrawSwUnConfigLocal", "ServiceInfraWithdrawSwUnConfigPeer", "SoftShutdownBegin", "SoftShutdownExecute", "SoftShutdownFail", "SoftShutdownSuccess", "SoftresetBegin", "SoftresetCheckPowerAvailability", "SoftresetExecute", "SoftresetFail", "SoftresetPowerDeployWait", "SoftresetPreSanitize", "SoftresetSanitize", "SoftresetSuccess", "SwConnUpdA", "SwConnUpdB", "SwConnUpdBegin", "SwConnUpdFail", "SwConnUpdSuccess", "TurnupBegin", "TurnupCheckPowerAvailability", "TurnupExecute", "TurnupFail", "TurnupPowerDeployWait", "TurnupSuccess", "UnconfigSoLBegin", "UnconfigSoLExecute", "UnconfigSoLFail", "UnconfigSoLSuccess", "UpdateAdaptorBegin", "UpdateAdaptorCheckPowerAvailability", "UpdateAdaptorFail", "UpdateAdaptorPollUpdateStatusLocal", "UpdateAdaptorPollUpdateStatusPeer", "UpdateAdaptorPowerDeployWait", "UpdateAdaptorPowerOff", "UpdateAdaptorPowerOn", "UpdateAdaptorSuccess", "UpdateAdaptorUpdateRequestLocal", "UpdateAdaptorUpdateRequestPeer", "UpdateBIOSBegin", "UpdateBIOSClear", "UpdateBIOSFail", "UpdateBIOSPollClearStatus", "UpdateBIOSPollUpdateStatus", "UpdateBIOSSuccess", "UpdateBIOSUpdateRequest", "UpdateBoardControllerBegin", "UpdateBoardControllerCheckPowerAvailability", "UpdateBoardControllerFail", "UpdateBoardControllerPollBoardCtrlPowerCycle", "UpdateBoardControllerPollUpdateStatus", "UpdateBoardControllerPowerCycleBoard", "UpdateBoardControllerPowerDeployWait", "UpdateBoardControllerPrepareForUpdate", "UpdateBoardControllerServerPowerOff", "UpdateBoardControllerServerPowerOn", "UpdateBoardControllerSuccess", "UpdateBoardControllerUpdateRequest", "clearTPMBegin", "clearTPMBiosPostCompletion", "clearTPMBladePowerOff", "clearTPMBladePowerOn", "clearTPMBootHost", "clearTPMClear", "clearTPMFail", "clearTPMPreSanitize", "clearTPMReadSmBios", "clearTPMReconfigBios", "clearTPMSanitize", "clearTPMSetupVmedia", "clearTPMStopVMediaLocal", "clearTPMStopVMediaPeer", "clearTPMSuccess", "clearTPMUnconfigVmedia", "nop", "updateExtUsersBegin", "updateExtUsersDeploy", "updateExtUsersFail", "updateExtUsersSuccess"], []),
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "retry": MoPropertyMeta("retry", "retry", "byte", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "stage_status": MoPropertyMeta("stage_status", "stageStatus", "string", VersionMeta.Version251a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version251a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "lastUpdateTime": "last_update_time", 
        "name": "name", 
        "order": "order", 
        "retry": "retry", 
        "rn": "rn", 
        "sacl": "sacl", 
        "stageStatus": "stage_status", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.last_update_time = None
        self.order = None
        self.retry = None
        self.sacl = None
        self.stage_status = None
        self.status = None

        ManagedObject.__init__(self, "ComputeServerUnitFsmStage", parent_mo_or_dn, **kwargs)
