# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose.tools import *


def test_import_ucsmsdk():
    import ucsmsdk


def test_import_ucsbasetype():
    from ucsmsdk import ucsbasetype


def test_import_ucsconstants():
    from ucsmsdk import ucsconstants


def test_import_ucscore():
    from ucsmsdk import ucscore


def test_import_ucscoremeta():
    from ucsmsdk import ucscoremeta


def test_import_ucscoreutils():
    from ucsmsdk import ucscoreutils


def test_import_ucsdriver():
    from ucsmsdk import ucsdriver


def test_import_ucseventhandler():
    from ucsmsdk import ucseventhandler


def test_import_ucsexception():
    from ucsmsdk import ucsexception


def test_import_ucsfilter():
    from ucsmsdk import ucsfilter


def test_import_ucsfiltertype():
    from ucsmsdk import ucsfiltertype


def test_import_ucsgenutils():
    from ucsmsdk import ucsgenutils


def test_import_ucshandle():
    from ucsmsdk import ucshandle


def test_import_ucsmeta():
    from ucsmsdk import ucsmeta


def test_import_ucsmethod():
    from ucsmsdk import ucsmethod


def test_import_ucsmethodfactory():
    from ucsmsdk import ucsmethodfactory


def test_import_ucsmo():
    from ucsmsdk import ucsmo


def test_import_ucssession():
    from ucsmsdk import ucssession


def test_import_ucsxmlcodec():
    from ucsmsdk import ucsxmlcodec


def test_import_utils():
    import ucsmsdk.utils


def test_import_ccoimage():
    from ucsmsdk.utils import ccoimage


def test_import_comparesyncmo():
    from ucsmsdk.utils import comparesyncmo


def test_import_converttopython():
    from ucsmsdk.utils import converttopython


def test_import_ucsbackup():
    from ucsmsdk.utils import ucsbackup


def test_import_ucsguilaunch():
    from ucsmsdk.utils import ucsguilaunch


def test_import_ucskvmlaunch():
    from ucsmsdk.utils import ucskvmlaunch


def test_import_ucstechsupport():
    from ucsmsdk.utils import ucstechsupport


