# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

""" This is auto-generated module containing Constants information. """


class NamingId:
    METHOD = "method"
    METHOD_SET = "methodSet"
    AAA_AUTH_REALM = "aaaAuthRealm"
    AAA_AUTH_REALM_FSM = "aaaAuthRealmFsm"
    AAA_AUTH_REALM_FSM_STAGE = "aaaAuthRealmFsmStage"
    AAA_CHANGE_SELF_PASSWORD = "aaaChangeSelfPassword"
    AAA_CHECK_COMPUTE_AUTH_TOKEN = "aaaCheckComputeAuthToken"
    AAA_CHECK_COMPUTE_EXT_ACCESS = "aaaCheckComputeExtAccess"
    AAA_CIMC_SESSION = "aaaCimcSession"
    AAA_CONSOLE_AUTH = "aaaConsoleAuth"
    AAA_DEFAULT_AUTH = "aaaDefaultAuth"
    AAA_DOMAIN = "aaaDomain"
    AAA_DOMAIN_AUTH = "aaaDomainAuth"
    AAA_EP_AUTH_PROFILE = "aaaEpAuthProfile"
    AAA_EP_FSM = "aaaEpFsm"
    AAA_EP_FSM_STAGE = "aaaEpFsmStage"
    AAA_EP_FSM_TASK = "aaaEpFsmTask"
    AAA_EP_LOGIN = "aaaEpLogin"
    AAA_EP_USER = "aaaEpUser"
    AAA_EXT_MGMT_CUT_THRU_TKN = "aaaExtMgmtCutThruTkn"
    AAA_GET_AUTH_TOKEN_CLIENT = "aaaGetAuthTokenClient"
    AAA_GET_AUTH_TOKEN_INTERNAL = "aaaGetAuthTokenInternal"
    AAA_GET_KVMLAUNCH_URL = "aaaGetKVMLaunchUrl"
    AAA_GET_KVMLAUNCH_URL_INTERNAL = "aaaGetKVMLaunchUrlInternal"
    AAA_GET_NCOMPUTE_AUTH_TOKEN_BY_DN = "aaaGetNComputeAuthTokenByDn"
    AAA_GET_NCOMPUTE_AUTH_TOKEN_INTERNAL_BY_DN = "aaaGetNComputeAuthTokenInternalByDn"
    AAA_KEEP_ALIVE = "aaaKeepAlive"
    AAA_LDAP_EP = "aaaLdapEp"
    AAA_LDAP_EP_FSM = "aaaLdapEpFsm"
    AAA_LDAP_EP_FSM_STAGE = "aaaLdapEpFsmStage"
    AAA_LDAP_GROUP = "aaaLdapGroup"
    AAA_LDAP_GROUP_RULE = "aaaLdapGroupRule"
    AAA_LDAP_PROVIDER = "aaaLdapProvider"
    AAA_LOCAL_MGMT_CMD_LOG = "aaaLocalMgmtCmdLog"
    AAA_LOCALE = "aaaLocale"
    AAA_LOG = "aaaLog"
    AAA_LOGIN = "aaaLogin"
    AAA_LOGIN_PROFILE = "aaaLoginProfile"
    AAA_LOGOUT = "aaaLogout"
    AAA_MOD_LR = "aaaModLR"
    AAA_ORG = "aaaOrg"
    AAA_PRE_LOGIN_BANNER = "aaaPreLoginBanner"
    AAA_PROVIDER_GROUP = "aaaProviderGroup"
    AAA_PROVIDER_REF = "aaaProviderRef"
    AAA_PWD_PROFILE = "aaaPwdProfile"
    AAA_RADIUS_EP = "aaaRadiusEp"
    AAA_RADIUS_EP_FSM = "aaaRadiusEpFsm"
    AAA_RADIUS_EP_FSM_STAGE = "aaaRadiusEpFsmStage"
    AAA_RADIUS_PROVIDER = "aaaRadiusProvider"
    AAA_REALM_FSM = "aaaRealmFsm"
    AAA_REALM_FSM_STAGE = "aaaRealmFsmStage"
    AAA_REALM_FSM_TASK = "aaaRealmFsmTask"
    AAA_REFRESH = "aaaRefresh"
    AAA_REMOTE_USER = "aaaRemoteUser"
    AAA_ROLE = "aaaRole"
    AAA_SESSION = "aaaSession"
    AAA_SESSION_INFO = "aaaSessionInfo"
    AAA_SESSION_INFO_TABLE = "aaaSessionInfoTable"
    AAA_SESSION_LR = "aaaSessionLR"
    AAA_SETUP_SHELL_ACCESS_INTERNAL = "aaaSetupShellAccessInternal"
    AAA_SHELL_LOGIN = "aaaShellLogin"
    AAA_SSH_AUTH = "aaaSshAuth"
    AAA_TACACS_PLUS_EP = "aaaTacacsPlusEp"
    AAA_TACACS_PLUS_EP_FSM = "aaaTacacsPlusEpFsm"
    AAA_TACACS_PLUS_EP_FSM_STAGE = "aaaTacacsPlusEpFsmStage"
    AAA_TACACS_PLUS_PROVIDER = "aaaTacacsPlusProvider"
    AAA_TOKEN_LOGIN = "aaaTokenLogin"
    AAA_TOKEN_REFRESH = "aaaTokenRefresh"
    AAA_USER = "aaaUser"
    AAA_USER_DATA = "aaaUserData"
    AAA_USER_EP = "aaaUserEp"
    AAA_USER_EP_FSM = "aaaUserEpFsm"
    AAA_USER_EP_FSM_STAGE = "aaaUserEpFsmStage"
    AAA_USER_EP_FSM_TASK = "aaaUserEpFsmTask"
    AAA_USER_LOCALE = "aaaUserLocale"
    AAA_USER_ROLE = "aaaUserRole"
    AAA_WEB_LOGIN = "aaaWebLogin"
    ADAPTOR_AZURE_QOS_PROFILE = "adaptorAzureQosProfile"
    ADAPTOR_CAP_QUAL = "adaptorCapQual"
    ADAPTOR_CAP_SPEC = "adaptorCapSpec"
    ADAPTOR_DIAG_CAP = "adaptorDiagCap"
    ADAPTOR_DYNAMIC_CONFIG_CAP = "adaptorDynamicConfigCap"
    ADAPTOR_ETH_ADV_FILTER_PROFILE = "adaptorEthAdvFilterProfile"
    ADAPTOR_ETH_ARFS_PROFILE = "adaptorEthArfsProfile"
    ADAPTOR_ETH_COMP_QUEUE_PROFILE = "adaptorEthCompQueueProfile"
    ADAPTOR_ETH_FAILOVER_PROFILE = "adaptorEthFailoverProfile"
    ADAPTOR_ETH_GENEVEPROFILE = "adaptorEthGENEVEProfile"
    ADAPTOR_ETH_INTERRUPT_PROFILE = "adaptorEthInterruptProfile"
    ADAPTOR_ETH_INTERRUPT_SCALING_PROFILE = "adaptorEthInterruptScalingProfile"
    ADAPTOR_ETH_NVGREPROFILE = "adaptorEthNVGREProfile"
    ADAPTOR_ETH_OFFLOAD_PROFILE = "adaptorEthOffloadProfile"
    ADAPTOR_ETH_PORT_BY_SIZE_LARGE_STATS = "adaptorEthPortBySizeLargeStats"
    ADAPTOR_ETH_PORT_BY_SIZE_LARGE_STATS_HIST = "adaptorEthPortBySizeLargeStatsHist"
    ADAPTOR_ETH_PORT_BY_SIZE_SMALL_STATS = "adaptorEthPortBySizeSmallStats"
    ADAPTOR_ETH_PORT_BY_SIZE_SMALL_STATS_HIST = "adaptorEthPortBySizeSmallStatsHist"
    ADAPTOR_ETH_PORT_ERR_STATS = "adaptorEthPortErrStats"
    ADAPTOR_ETH_PORT_ERR_STATS_HIST = "adaptorEthPortErrStatsHist"
    ADAPTOR_ETH_PORT_MCAST_STATS = "adaptorEthPortMcastStats"
    ADAPTOR_ETH_PORT_MCAST_STATS_HIST = "adaptorEthPortMcastStatsHist"
    ADAPTOR_ETH_PORT_OUTSIZED_STATS = "adaptorEthPortOutsizedStats"
    ADAPTOR_ETH_PORT_OUTSIZED_STATS_HIST = "adaptorEthPortOutsizedStatsHist"
    ADAPTOR_ETH_PORT_STATS = "adaptorEthPortStats"
    ADAPTOR_ETH_PORT_STATS_HIST = "adaptorEthPortStatsHist"
    ADAPTOR_ETH_RECV_QUEUE_PROFILE = "adaptorEthRecvQueueProfile"
    ADAPTOR_ETH_RO_CEPROFILE = "adaptorEthRoCEProfile"
    ADAPTOR_ETH_VX_LANPROFILE = "adaptorEthVxLANProfile"
    ADAPTOR_ETH_WORK_QUEUE_PROFILE = "adaptorEthWorkQueueProfile"
    ADAPTOR_ETHER_IF_STATS = "adaptorEtherIfStats"
    ADAPTOR_ETHER_IF_STATS_HIST = "adaptorEtherIfStatsHist"
    ADAPTOR_EXT_ETH_IF = "adaptorExtEthIf"
    ADAPTOR_EXT_ETH_IF_FSM = "adaptorExtEthIfFsm"
    ADAPTOR_EXT_ETH_IF_FSM_STAGE = "adaptorExtEthIfFsmStage"
    ADAPTOR_EXT_ETH_IF_FSM_TASK = "adaptorExtEthIfFsmTask"
    ADAPTOR_EXT_ETH_IF_PC = "adaptorExtEthIfPc"
    ADAPTOR_EXT_ETH_IF_PC_EP = "adaptorExtEthIfPcEp"
    ADAPTOR_EXT_IP_V6_RSS_HASH_PROFILE = "adaptorExtIpV6RssHashProfile"
    ADAPTOR_FAMILY_TYPE_DEF = "adaptorFamilyTypeDef"
    ADAPTOR_FC_CDB_WORK_QUEUE_PROFILE = "adaptorFcCdbWorkQueueProfile"
    ADAPTOR_FC_ERROR_RECOVERY_PROFILE = "adaptorFcErrorRecoveryProfile"
    ADAPTOR_FC_FNIC_PROFILE = "adaptorFcFnicProfile"
    ADAPTOR_FC_IF_EVENT_STATS = "adaptorFcIfEventStats"
    ADAPTOR_FC_IF_EVENT_STATS_HIST = "adaptorFcIfEventStatsHist"
    ADAPTOR_FC_IF_FC4_STATS = "adaptorFcIfFC4Stats"
    ADAPTOR_FC_IF_FC4_STATS_HIST = "adaptorFcIfFC4StatsHist"
    ADAPTOR_FC_IF_FRAME_STATS = "adaptorFcIfFrameStats"
    ADAPTOR_FC_IF_FRAME_STATS_HIST = "adaptorFcIfFrameStatsHist"
    ADAPTOR_FC_INTERRUPT_PROFILE = "adaptorFcInterruptProfile"
    ADAPTOR_FC_OEIF = "adaptorFcOEIf"
    ADAPTOR_FC_PORT_FLOGI_PROFILE = "adaptorFcPortFLogiProfile"
    ADAPTOR_FC_PORT_PLOGI_PROFILE = "adaptorFcPortPLogiProfile"
    ADAPTOR_FC_PORT_PROFILE = "adaptorFcPortProfile"
    ADAPTOR_FC_PORT_STATS = "adaptorFcPortStats"
    ADAPTOR_FC_PORT_STATS_HIST = "adaptorFcPortStatsHist"
    ADAPTOR_FC_RECV_QUEUE_PROFILE = "adaptorFcRecvQueueProfile"
    ADAPTOR_FC_VHBA_TYPE_PROFILE = "adaptorFcVhbaTypeProfile"
    ADAPTOR_FC_WORK_QUEUE_PROFILE = "adaptorFcWorkQueueProfile"
    ADAPTOR_FRU_CAP_PROVIDER = "adaptorFruCapProvider"
    ADAPTOR_FRU_CAP_REF = "adaptorFruCapRef"
    ADAPTOR_FW_CAP_PROVIDER = "adaptorFwCapProvider"
    ADAPTOR_HOST_ETH_IF = "adaptorHostEthIf"
    ADAPTOR_HOST_ETH_IF_FSM = "adaptorHostEthIfFsm"
    ADAPTOR_HOST_ETH_IF_FSM_STAGE = "adaptorHostEthIfFsmStage"
    ADAPTOR_HOST_ETH_IF_FSM_TASK = "adaptorHostEthIfFsmTask"
    ADAPTOR_HOST_ETH_IF_PROFILE = "adaptorHostEthIfProfile"
    ADAPTOR_HOST_FC_IF = "adaptorHostFcIf"
    ADAPTOR_HOST_FC_IF_FSM = "adaptorHostFcIfFsm"
    ADAPTOR_HOST_FC_IF_FSM_STAGE = "adaptorHostFcIfFsmStage"
    ADAPTOR_HOST_FC_IF_FSM_TASK = "adaptorHostFcIfFsmTask"
    ADAPTOR_HOST_FC_IF_PROFILE = "adaptorHostFcIfProfile"
    ADAPTOR_HOST_IF_CONFIG = "adaptorHostIfConfig"
    ADAPTOR_HOST_ISCSI_IF = "adaptorHostIscsiIf"
    ADAPTOR_HOST_ISCSI_IF_PROFILE = "adaptorHostIscsiIfProfile"
    ADAPTOR_HOST_MGMT_CAP = "adaptorHostMgmtCap"
    ADAPTOR_HOST_PORT = "adaptorHostPort"
    ADAPTOR_HOST_PORT_CAP = "adaptorHostPortCap"
    ADAPTOR_HOST_SCSI_IF = "adaptorHostScsiIf"
    ADAPTOR_HOST_SCSI_LUN_REF = "adaptorHostScsiLunRef"
    ADAPTOR_HOST_SERVICE_ETH_IF = "adaptorHostServiceEthIf"
    ADAPTOR_HOST_VNIC_HW_ADDR_CAP = "adaptorHostVnicHwAddrCap"
    ADAPTOR_HOSTETH_HW_ADDR_CAP = "adaptorHostethHwAddrCap"
    ADAPTOR_HOSTFC_HW_ADDR_CAP = "adaptorHostfcHwAddrCap"
    ADAPTOR_ISCSI_CAP = "adaptorIScsiCap"
    ADAPTOR_IP_V4_RSS_HASH_PROFILE = "adaptorIpV4RssHashProfile"
    ADAPTOR_IP_V6_RSS_HASH_PROFILE = "adaptorIpV6RssHashProfile"
    ADAPTOR_ISCSI_AUTH = "adaptorIscsiAuth"
    ADAPTOR_ISCSI_PROT = "adaptorIscsiProt"
    ADAPTOR_ISCSI_TARGET_IF = "adaptorIscsiTargetIf"
    ADAPTOR_LAN_CAP = "adaptorLanCap"
    ADAPTOR_LLDP_CAP = "adaptorLldpCap"
    ADAPTOR_MENLO_BASE_ERROR_STATS = "adaptorMenloBaseErrorStats"
    ADAPTOR_MENLO_BASE_ERROR_STATS_HIST = "adaptorMenloBaseErrorStatsHist"
    ADAPTOR_MENLO_DCE_PORT_STATS = "adaptorMenloDcePortStats"
    ADAPTOR_MENLO_DCE_PORT_STATS_HIST = "adaptorMenloDcePortStatsHist"
    ADAPTOR_MENLO_ETH_ERROR_STATS = "adaptorMenloEthErrorStats"
    ADAPTOR_MENLO_ETH_ERROR_STATS_HIST = "adaptorMenloEthErrorStatsHist"
    ADAPTOR_MENLO_ETH_STATS = "adaptorMenloEthStats"
    ADAPTOR_MENLO_ETH_STATS_HIST = "adaptorMenloEthStatsHist"
    ADAPTOR_MENLO_FC_ERROR_STATS = "adaptorMenloFcErrorStats"
    ADAPTOR_MENLO_FC_ERROR_STATS_HIST = "adaptorMenloFcErrorStatsHist"
    ADAPTOR_MENLO_FC_STATS = "adaptorMenloFcStats"
    ADAPTOR_MENLO_FC_STATS_HIST = "adaptorMenloFcStatsHist"
    ADAPTOR_MENLO_HOST_PORT_STATS = "adaptorMenloHostPortStats"
    ADAPTOR_MENLO_HOST_PORT_STATS_HIST = "adaptorMenloHostPortStatsHist"
    ADAPTOR_MENLO_MCPU_ERROR_STATS = "adaptorMenloMcpuErrorStats"
    ADAPTOR_MENLO_MCPU_ERROR_STATS_HIST = "adaptorMenloMcpuErrorStatsHist"
    ADAPTOR_MENLO_MCPU_STATS = "adaptorMenloMcpuStats"
    ADAPTOR_MENLO_MCPU_STATS_HIST = "adaptorMenloMcpuStatsHist"
    ADAPTOR_MENLO_NET_EG_STATS = "adaptorMenloNetEgStats"
    ADAPTOR_MENLO_NET_EG_STATS_HIST = "adaptorMenloNetEgStatsHist"
    ADAPTOR_MENLO_NET_IN_STATS = "adaptorMenloNetInStats"
    ADAPTOR_MENLO_NET_IN_STATS_HIST = "adaptorMenloNetInStatsHist"
    ADAPTOR_MENLO_QERROR_STATS = "adaptorMenloQErrorStats"
    ADAPTOR_MENLO_QERROR_STATS_HIST = "adaptorMenloQErrorStatsHist"
    ADAPTOR_MENLO_QSTATS = "adaptorMenloQStats"
    ADAPTOR_MENLO_QSTATS_HIST = "adaptorMenloQStatsHist"
    ADAPTOR_MGMT_VNIC_ETH_CONFIG = "adaptorMgmtVnicEthConfig"
    ADAPTOR_NW_MGMT_CAP = "adaptorNwMgmtCap"
    ADAPTOR_NW_STATS_MGMT_CAP = "adaptorNwStatsMgmtCap"
    ADAPTOR_PROTOCOL_PROFILE = "adaptorProtocolProfile"
    ADAPTOR_QUAL = "adaptorQual"
    ADAPTOR_RNIC_CAP_SPEC = "adaptorRnicCapSpec"
    ADAPTOR_RSS_PROFILE = "adaptorRssProfile"
    ADAPTOR_SAN_CAP = "adaptorSanCap"
    ADAPTOR_UNIT = "adaptorUnit"
    ADAPTOR_UNIT_ASSOC_CTX = "adaptorUnitAssocCtx"
    ADAPTOR_UNIT_EXTN = "adaptorUnitExtn"
    ADAPTOR_UPLINK_HW_ADDR_CAP = "adaptorUplinkHwAddrCap"
    ADAPTOR_UPLINK_PORT_STATS = "adaptorUplinkPortStats"
    ADAPTOR_USNIC_CONN_DEF = "adaptorUsnicConnDef"
    ADAPTOR_VLAN = "adaptorVlan"
    ADAPTOR_VMMQ_CONN_DEF = "adaptorVmmqConnDef"
    ADAPTOR_VNIC_STATS = "adaptorVnicStats"
    ADAPTOR_VNIC_STATS_HIST = "adaptorVnicStatsHist"
    ADAPTOR_VSAN = "adaptorVsan"
    ALLBITS_FILTER = "allbitsFilter"
    AND_FILTER = "andFilter"
    ANYBIT_FILTER = "anybitFilter"
    APE_ATTRIBUTE = "apeAttribute"
    APE_BOOT_PNU_OS = "apeBootPnuOs"
    APE_CONFIGURE_CMCLIF = "apeConfigureCMCLIF"
    APE_CONTROLLER_CHASSIS = "apeControllerChassis"
    APE_CONTROLLER_EEPROM = "apeControllerEeprom"
    APE_CONTROLLER_MANAGER = "apeControllerManager"
    APE_CREATE_HVVNIC = "apeCreateHVVnic"
    APE_CREATE_SFISH = "apeCreateSfish"
    APE_CREATE_VMVNIC = "apeCreateVMVnic"
    APE_DCOS_AG_MANAGER = "apeDcosAgManager"
    APE_DELETE_HVVNIC = "apeDeleteHVVnic"
    APE_DELETE_SFISH = "apeDeleteSfish"
    APE_DELETE_VMVNIC = "apeDeleteVMVnic"
    APE_FRU = "apeFru"
    APE_GET_ADAPTOR_CONNECTIVITY = "apeGetAdaptorConnectivity"
    APE_GET_APE_FIRMWARE_ACTIVE_SIDE = "apeGetApeFirmwareActiveSide"
    APE_GET_INVENTORY_FROM_STORAGE_REGISTRAR = "apeGetInventoryFromStorageRegistrar"
    APE_GET_IP_FROM_SERIAL = "apeGetIpFromSerial"
    APE_GET_MC_STATS = "apeGetMcStats"
    APE_GET_NEXT_ID = "apeGetNextId"
    APE_GET_PNU_OSINVENTORY = "apeGetPnuOSInventory"
    APE_GET_SERVER_FROM_IP = "apeGetServerFromIp"
    APE_GET_SWITCH_APE_FRU = "apeGetSwitchApeFru"
    APE_HOST_AGENT = "apeHostAgent"
    APE_INJECT_STIMULI = "apeInjectStimuli"
    APE_INSERT_NEW_CHASSIS = "apeInsertNewChassis"
    APE_INSERT_NEW_FEX = "apeInsertNewFex"
    APE_INSERT_NEW_RACK = "apeInsertNewRack"
    APE_ISSUE_ADAPTOR_ID = "apeIssueAdaptorId"
    APE_ISSUE_CHASSIS_ID = "apeIssueChassisId"
    APE_ISSUE_FEX_ID = "apeIssueFexId"
    APE_ISSUE_RACK_ID = "apeIssueRackId"
    APE_LANBOOT = "apeLANBoot"
    APE_LOCAL_DISK_BOOT = "apeLocalDiskBoot"
    APE_MANAGER = "apeManager"
    APE_MC = "apeMc"
    APE_MC_GET = "apeMcGet"
    APE_MC_GET_ATTRIBUTE = "apeMcGetAttribute"
    APE_MC_GET_ATTRIBUTE_DATA = "apeMcGetAttributeData"
    APE_MC_GET_BIOS_TOKENS = "apeMcGetBiosTokens"
    APE_MC_GET_FRU = "apeMcGetFru"
    APE_MC_GET_PARAM = "apeMcGetParam"
    APE_MC_GET_READING = "apeMcGetReading"
    APE_MC_GET_SDR = "apeMcGetSdr"
    APE_MC_GET_SMBIOS = "apeMcGetSmbios"
    APE_MC_SET = "apeMcSet"
    APE_MC_SET_ATTRIBUTE_DATA = "apeMcSetAttributeData"
    APE_MC_SET_PARAM = "apeMcSetParam"
    APE_MC_STATS = "apeMcStats"
    APE_MC_TABLE = "apeMcTable"
    APE_MENLO = "apeMenlo"
    APE_MENLO_VNIC = "apeMenloVnic"
    APE_MENLO_VNIC_STATS = "apeMenloVnicStats"
    APE_MUX_OFFLINE = "apeMuxOffline"
    APE_NIC_AG_MANAGER = "apeNicAgManager"
    APE_PALO = "apePalo"
    APE_PALO_VNIC = "apePaloVnic"
    APE_PALO_VNIC_STATS = "apePaloVnicStats"
    APE_PARAM = "apeParam"
    APE_READING = "apeReading"
    APE_REMOVE_DEVICE = "apeRemoveDevice"
    APE_SANBOOT = "apeSANBoot"
    APE_SDR = "apeSdr"
    APE_SET_ADAPTOR_FIRMWARE_VERSION = "apeSetAdaptorFirmwareVersion"
    APE_SET_APE_SENSOR_READING = "apeSetApeSensorReading"
    APE_SET_FLEX_FLASH_CONTROLLER_FIRMWARE_VERSION = "apeSetFlexFlashControllerFirmwareVersion"
    APE_SET_FLEX_FLASH_CONTROLLER_STATE = "apeSetFlexFlashControllerState"
    APE_SET_FLEX_FLASH_VIRTUAL_RAID_INFORMATION = "apeSetFlexFlashVirtualRaidInformation"
    APE_SET_MC_STATS = "apeSetMcStats"
    APE_SET_SERVER_LIFE_CYCLE = "apeSetServerLifeCycle"
    APE_SET_SWITCH_INVENTORY = "apeSetSwitchInventory"
    APE_SET_VMEDIA_MOUNTS = "apeSetVmediaMounts"
    APE_SWITCH_FIRMWARE_INV = "apeSwitchFirmwareInv"
    APE_TRIGGER_SW_INV = "apeTriggerSwInv"
    APE_UPDATE_APE_FIRMWARE_ACTIVE_SIDE = "apeUpdateApeFirmwareActiveSide"
    APE_UPDATE_APE_FIRMWARE_PARAM_TABLE = "apeUpdateApeFirmwareParamTable"
    APE_UPDATE_BIOSFIRMWARE_VERSION = "apeUpdateBIOSFirmwareVersion"
    APE_UPDATE_SERVER_ABSENCE = "apeUpdateServerAbsence"
    APE_UPDATE_SERVER_PRESENCE = "apeUpdateServerPresence"
    APE_UPDATE_STORAGE_CTLR_FIRMWARE_VERSION = "apeUpdateStorageCtlrFirmwareVersion"
    APE_VIRTUAL_MEDIA_BOOT = "apeVirtualMediaBoot"
    BIOS_BOT = "biosBOT"
    BIOS_BOOT_DEV = "biosBootDev"
    BIOS_BOOT_DEV_GRP = "biosBootDevGrp"
    BIOS_FEATURE_REF = "biosFeatureRef"
    BIOS_PARAMETER_REF = "biosParameterRef"
    BIOS_REF = "biosRef"
    BIOS_SETTING_REF = "biosSettingRef"
    BIOS_SETTINGS = "biosSettings"
    BIOS_TOKEN_FEATURE_GROUP = "biosTokenFeatureGroup"
    BIOS_TOKEN_PARAM = "biosTokenParam"
    BIOS_TOKEN_SETTINGS = "biosTokenSettings"
    BIOS_UNIT = "biosUnit"
    BIOS_VIDENTITY_PARAMS = "biosVIdentityParams"
    BIOS_VPROFILE = "biosVProfile"
    BIOS_VF_ACPI10_SUPPORT = "biosVfACPI10Support"
    BIOS_VF_ASPMSUPPORT = "biosVfASPMSupport"
    BIOS_VF_ALL_USBDEVICES = "biosVfAllUSBDevices"
    BIOS_VF_ALTITUDE = "biosVfAltitude"
    BIOS_VF_ASSERT_NMION_PERR = "biosVfAssertNMIOnPERR"
    BIOS_VF_ASSERT_NMION_SERR = "biosVfAssertNMIOnSERR"
    BIOS_VF_BMEDMAMITIGATION = "biosVfBMEDMAMitigation"
    BIOS_VF_BOOT_OPTION_RETRY = "biosVfBootOptionRetry"
    BIOS_VF_CPUHARDWARE_POWER_MANAGEMENT = "biosVfCPUHardwarePowerManagement"
    BIOS_VF_CPUPERFORMANCE = "biosVfCPUPerformance"
    BIOS_VF_CONSISTENT_DEVICE_NAME_CONTROL = "biosVfConsistentDeviceNameControl"
    BIOS_VF_CONSOLE_REDIRECTION = "biosVfConsoleRedirection"
    BIOS_VF_CORE_MULTI_PROCESSING = "biosVfCoreMultiProcessing"
    BIOS_VF_DDR3_VOLTAGE_SELECTION = "biosVfDDR3VoltageSelection"
    BIOS_VF_DRAMCLOCK_THROTTLING = "biosVfDRAMClockThrottling"
    BIOS_VF_DIRECT_CACHE_ACCESS = "biosVfDirectCacheAccess"
    BIOS_VF_DRAM_REFRESH_RATE = "biosVfDramRefreshRate"
    BIOS_VF_ENERGY_PERFORMANCE_TUNING = "biosVfEnergyPerformanceTuning"
    BIOS_VF_ENHANCED_INTEL_SPEED_STEP_TECH = "biosVfEnhancedIntelSpeedStepTech"
    BIOS_VF_ENHANCED_POWER_CAPPING_SUPPORT = "biosVfEnhancedPowerCappingSupport"
    BIOS_VF_EXECUTE_DISABLE_BIT = "biosVfExecuteDisableBit"
    BIOS_VF_FRB2_TIMER = "biosVfFRB2Timer"
    BIOS_VF_FREQUENCY_FLOOR_OVERRIDE = "biosVfFrequencyFloorOverride"
    BIOS_VF_FRONT_PANEL_LOCKOUT = "biosVfFrontPanelLockout"
    BIOS_VF_IOEMEZZ1_OPTION_ROM = "biosVfIOEMezz1OptionROM"
    BIOS_VF_IOENVME1_OPTION_ROM = "biosVfIOENVMe1OptionROM"
    BIOS_VF_IOENVME2_OPTION_ROM = "biosVfIOENVMe2OptionROM"
    BIOS_VF_IOESLOT1_OPTION_ROM = "biosVfIOESlot1OptionROM"
    BIOS_VF_IOESLOT2_OPTION_ROM = "biosVfIOESlot2OptionROM"
    BIOS_VF_INTEGRATED_GRAPHICS = "biosVfIntegratedGraphics"
    BIOS_VF_INTEGRATED_GRAPHICS_APERTURE_SIZE = "biosVfIntegratedGraphicsApertureSize"
    BIOS_VF_INTEL_ENTRY_SASRAIDMODULE = "biosVfIntelEntrySASRAIDModule"
    BIOS_VF_INTEL_HYPER_THREADING_TECH = "biosVfIntelHyperThreadingTech"
    BIOS_VF_INTEL_TRUSTED_EXECUTION_TECHNOLOGY = "biosVfIntelTrustedExecutionTechnology"
    BIOS_VF_INTEL_TURBO_BOOST_TECH = "biosVfIntelTurboBoostTech"
    BIOS_VF_INTEL_VTFOR_DIRECTED_IO = "biosVfIntelVTForDirectedIO"
    BIOS_VF_INTEL_VIRTUALIZATION_TECHNOLOGY = "biosVfIntelVirtualizationTechnology"
    BIOS_VF_INTERLEAVE_CONFIGURATION = "biosVfInterleaveConfiguration"
    BIOS_VF_LOCAL_X2_APIC = "biosVfLocalX2Apic"
    BIOS_VF_LV_DIMMSUPPORT = "biosVfLvDIMMSupport"
    BIOS_VF_MAX_VARIABLE_MTRRSETTING = "biosVfMaxVariableMTRRSetting"
    BIOS_VF_MAXIMUM_MEMORY_BELOW4_GB = "biosVfMaximumMemoryBelow4GB"
    BIOS_VF_MEMORY_MAPPED_IOABOVE4_GB = "biosVfMemoryMappedIOAbove4GB"
    BIOS_VF_MIRRORING_MODE = "biosVfMirroringMode"
    BIOS_VF_NUMAOPTIMIZED = "biosVfNUMAOptimized"
    BIOS_VF_OSBOOT_WATCHDOG_TIMER = "biosVfOSBootWatchdogTimer"
    BIOS_VF_OSBOOT_WATCHDOG_TIMER_POLICY = "biosVfOSBootWatchdogTimerPolicy"
    BIOS_VF_OSBOOT_WATCHDOG_TIMER_TIMEOUT = "biosVfOSBootWatchdogTimerTimeout"
    BIOS_VF_ONBOARD_GRAPHICS = "biosVfOnboardGraphics"
    BIOS_VF_ONBOARD_SATACONTROLLER = "biosVfOnboardSATAController"
    BIOS_VF_ONBOARD_STORAGE = "biosVfOnboardStorage"
    BIOS_VF_OPTION_ROMENABLE = "biosVfOptionROMEnable"
    BIOS_VF_OPTION_ROMLOAD = "biosVfOptionROMLoad"
    BIOS_VF_OUT_OF_BAND_MANAGEMENT = "biosVfOutOfBandManagement"
    BIOS_VF_PCHSATAMODE = "biosVfPCHSATAMode"
    BIOS_VF_PCILOMPORTS_CONFIGURATION = "biosVfPCILOMPortsConfiguration"
    BIOS_VF_PCIROMCLP = "biosVfPCIROMCLP"
    BIOS_VF_PCISLOT_LINK_SPEED = "biosVfPCISlotLinkSpeed"
    BIOS_VF_PCISLOT_OPTION_ROMENABLE = "biosVfPCISlotOptionROMEnable"
    BIOS_VF_POSTERROR_PAUSE = "biosVfPOSTErrorPause"
    BIOS_VF_PSTATECOORDINATION = "biosVfPSTATECoordination"
    BIOS_VF_PACKAGE_CSTATE_LIMIT = "biosVfPackageCStateLimit"
    BIOS_VF_PANIC_AND_HIGH_WATERMARK = "biosVfPanicAndHighWatermark"
    BIOS_VF_PROCESSOR_C1_E = "biosVfProcessorC1E"
    BIOS_VF_PROCESSOR_C3_REPORT = "biosVfProcessorC3Report"
    BIOS_VF_PROCESSOR_C6_REPORT = "biosVfProcessorC6Report"
    BIOS_VF_PROCESSOR_C7_REPORT = "biosVfProcessorC7Report"
    BIOS_VF_PROCESSOR_CMCI = "biosVfProcessorCMCI"
    BIOS_VF_PROCESSOR_CSTATE = "biosVfProcessorCState"
    BIOS_VF_PROCESSOR_ENERGY_CONFIGURATION = "biosVfProcessorEnergyConfiguration"
    BIOS_VF_PROCESSOR_PREFETCH_CONFIG = "biosVfProcessorPrefetchConfig"
    BIOS_VF_QPILINK_FREQUENCY_SELECT = "biosVfQPILinkFrequencySelect"
    BIOS_VF_QPISNOOP_MODE = "biosVfQPISnoopMode"
    BIOS_VF_QUIET_BOOT = "biosVfQuietBoot"
    BIOS_VF_REDIRECTION_AFTER_BIOSPOST = "biosVfRedirectionAfterBIOSPOST"
    BIOS_VF_RESUME_ON_ACPOWER_LOSS = "biosVfResumeOnACPowerLoss"
    BIOS_VF_SBMEZZ1_OPTION_ROM = "biosVfSBMezz1OptionROM"
    BIOS_VF_SBNVME1_OPTION_ROM = "biosVfSBNVMe1OptionROM"
    BIOS_VF_SIOC1_OPTION_ROM = "biosVfSIOC1OptionROM"
    BIOS_VF_SIOC2_OPTION_ROM = "biosVfSIOC2OptionROM"
    BIOS_VF_SCRUB_POLICIES = "biosVfScrubPolicies"
    BIOS_VF_SELECT_MEMORY_RASCONFIGURATION = "biosVfSelectMemoryRASConfiguration"
    BIOS_VF_SERIAL_PORT_AENABLE = "biosVfSerialPortAEnable"
    BIOS_VF_SPARING_MODE = "biosVfSparingMode"
    BIOS_VF_SRIOV_CONFIG = "biosVfSriovConfig"
    BIOS_VF_TPMPENDING_OPERATION = "biosVfTPMPendingOperation"
    BIOS_VF_TPMSUPPORT = "biosVfTPMSupport"
    BIOS_VF_TRUSTED_PLATFORM_MODULE = "biosVfTrustedPlatformModule"
    BIOS_VF_UCSMBOOT_MODE_CONTROL = "biosVfUCSMBootModeControl"
    BIOS_VF_UCSMBOOT_ORDER_RULE_CONTROL = "biosVfUCSMBootOrderRuleControl"
    BIOS_VF_UEFIOSUSE_LEGACY_VIDEO = "biosVfUEFIOSUseLegacyVideo"
    BIOS_VF_USBBOOT_CONFIG = "biosVfUSBBootConfig"
    BIOS_VF_USBCONFIGURATION = "biosVfUSBConfiguration"
    BIOS_VF_USBFRONT_PANEL_ACCESS_LOCK = "biosVfUSBFrontPanelAccessLock"
    BIOS_VF_USBPORT_CONFIGURATION = "biosVfUSBPortConfiguration"
    BIOS_VF_USBSYSTEM_IDLE_POWER_OPTIMIZING_SETTING = "biosVfUSBSystemIdlePowerOptimizingSetting"
    BIOS_VF_VGAPRIORITY = "biosVfVGAPriority"
    BIOS_VF_WORKLOAD_CONFIGURATION = "biosVfWorkloadConfiguration"
    BMC_SELCOUNTER = "bmcSELCounter"
    BW_FILTER = "bwFilter"
    CALLHOME_ANONYMOUS_REPORTING = "callhomeAnonymousReporting"
    CALLHOME_DEST = "callhomeDest"
    CALLHOME_EP = "callhomeEp"
    CALLHOME_EP_FSM = "callhomeEpFsm"
    CALLHOME_EP_FSM_STAGE = "callhomeEpFsmStage"
    CALLHOME_EP_FSM_TASK = "callhomeEpFsmTask"
    CALLHOME_PERIODIC_SYSTEM_INVENTORY = "callhomePeriodicSystemInventory"
    CALLHOME_POLICY = "callhomePolicy"
    CALLHOME_PROFILE = "callhomeProfile"
    CALLHOME_SMTP = "callhomeSmtp"
    CALLHOME_SOURCE = "callhomeSource"
    CALLHOME_TEST_ALERT = "callhomeTestAlert"
    CAPABILITY_CATALOGUE = "capabilityCatalogue"
    CAPABILITY_CATALOGUE_FSM = "capabilityCatalogueFsm"
    CAPABILITY_CATALOGUE_FSM_STAGE = "capabilityCatalogueFsmStage"
    CAPABILITY_CATALOGUE_FSM_TASK = "capabilityCatalogueFsmTask"
    CAPABILITY_EP = "capabilityEp"
    CAPABILITY_FEATURE_LIMITS = "capabilityFeatureLimits"
    CAPABILITY_MGMT_EXTENSION = "capabilityMgmtExtension"
    CAPABILITY_MGMT_EXTENSION_FSM = "capabilityMgmtExtensionFsm"
    CAPABILITY_MGMT_EXTENSION_FSM_STAGE = "capabilityMgmtExtensionFsmStage"
    CAPABILITY_MGMT_EXTENSION_FSM_TASK = "capabilityMgmtExtensionFsmTask"
    CAPABILITY_NETWORK_LIMITS = "capabilityNetworkLimits"
    CAPABILITY_STORAGE_LIMITS = "capabilityStorageLimits"
    CAPABILITY_SYSTEM_LIMITS = "capabilitySystemLimits"
    CAPABILITY_UPDATE = "capabilityUpdate"
    CAPABILITY_UPDATER = "capabilityUpdater"
    CAPABILITY_UPDATER_FSM = "capabilityUpdaterFsm"
    CAPABILITY_UPDATER_FSM_STAGE = "capabilityUpdaterFsmStage"
    CAPABILITY_UPDATER_FSM_TASK = "capabilityUpdaterFsmTask"
    CHANGE_CHANGED_OBJECT_REF = "changeChangedObjectRef"
    CIMCVMEDIA_ACTUAL_MOUNT_ENTRY = "cimcvmediaActualMountEntry"
    CIMCVMEDIA_ACTUAL_MOUNT_LIST = "cimcvmediaActualMountList"
    CIMCVMEDIA_CONFIG_MOUNT_ENTRY = "cimcvmediaConfigMountEntry"
    CIMCVMEDIA_EXT_MGMT_RULE_ENTRY = "cimcvmediaExtMgmtRuleEntry"
    CIMCVMEDIA_MOUNT_CONFIG_DEF = "cimcvmediaMountConfigDef"
    CIMCVMEDIA_MOUNT_CONFIG_POLICY = "cimcvmediaMountConfigPolicy"
    CLASS_ID = "classId"
    CLASS_ID_SET = "classIdSet"
    CLITEST_TYPE_TEST = "clitestTypeTest"
    CLITEST_TYPE_TEST2 = "clitestTypeTest2"
    CLITEST_TYPE_TEST_CHILD = "clitestTypeTestChild"
    CLOUD_DEVICE_CONNECTOR_EP = "cloudDeviceConnectorEp"
    CLOUD_MGMT_SVC = "cloudMgmtSvc"
    COMM_CIMC_WEB_SERVICE = "commCimcWebService"
    COMM_CIMXML = "commCimxml"
    COMM_DATE_TIME = "commDateTime"
    COMM_DNS = "commDns"
    COMM_DNS_PROVIDER = "commDnsProvider"
    COMM_EVT_CHANNEL = "commEvtChannel"
    COMM_HTTP = "commHttp"
    COMM_HTTPS = "commHttps"
    COMM_LOCALE = "commLocale"
    COMM_NTP_PROVIDER = "commNtpProvider"
    COMM_SHELL_SVC_LIMITS = "commShellSvcLimits"
    COMM_SMASH_CLP = "commSmashCLP"
    COMM_SNMP = "commSnmp"
    COMM_SNMP_TRAP = "commSnmpTrap"
    COMM_SNMP_USER = "commSnmpUser"
    COMM_SSH = "commSsh"
    COMM_SVC_EP = "commSvcEp"
    COMM_SVC_EP_FSM = "commSvcEpFsm"
    COMM_SVC_EP_FSM_STAGE = "commSvcEpFsmStage"
    COMM_SVC_EP_FSM_TASK = "commSvcEpFsmTask"
    COMM_SVC_POLICY = "commSvcPolicy"
    COMM_SYSLOG = "commSyslog"
    COMM_SYSLOG_CLIENT = "commSyslogClient"
    COMM_SYSLOG_CONSOLE = "commSyslogConsole"
    COMM_SYSLOG_FILE = "commSyslogFile"
    COMM_SYSLOG_MONITOR = "commSyslogMonitor"
    COMM_SYSLOG_SOURCE = "commSyslogSource"
    COMM_TELNET = "commTelnet"
    COMM_WEB_CHANNEL = "commWebChannel"
    COMM_WEB_SVC_LIMITS = "commWebSvcLimits"
    COMM_WSMAN = "commWsman"
    COMM_XML_CL_CONN_POLICY = "commXmlClConnPolicy"
    COMPUTE_ADMIN_ACK = "computeAdminAck"
    COMPUTE_AUTOCONFIG_POLICY = "computeAutoconfigPolicy"
    COMPUTE_BLADE = "computeBlade"
    COMPUTE_BLADE_DISC_POLICY = "computeBladeDiscPolicy"
    COMPUTE_BLADE_EP = "computeBladeEp"
    COMPUTE_BLADE_FSM = "computeBladeFsm"
    COMPUTE_BLADE_FSM_STAGE = "computeBladeFsmStage"
    COMPUTE_BLADE_FSM_TASK = "computeBladeFsmTask"
    COMPUTE_BLADE_INHERIT_POLICY = "computeBladeInheritPolicy"
    COMPUTE_BOARD = "computeBoard"
    COMPUTE_BOARD_CONNECTOR = "computeBoardConnector"
    COMPUTE_BOARD_CONTROLLER = "computeBoardController"
    COMPUTE_CARTRIDGE = "computeCartridge"
    COMPUTE_CHASSIS_CONN_POLICY = "computeChassisConnPolicy"
    COMPUTE_CHASSIS_DISC_POLICY = "computeChassisDiscPolicy"
    COMPUTE_CHASSIS_QUAL = "computeChassisQual"
    COMPUTE_CONSTRAINT_DEF = "computeConstraintDef"
    COMPUTE_DEFAULTS = "computeDefaults"
    COMPUTE_EXT_BOARD = "computeExtBoard"
    COMPUTE_FACTORY_RESET_OPERATION = "computeFactoryResetOperation"
    COMPUTE_FAN_POLICY = "computeFanPolicy"
    COMPUTE_FW_SYNC_ACK = "computeFwSyncAck"
    COMPUTE_GET_INVENTORY = "computeGetInventory"
    COMPUTE_GRAPHICS_CARD_POLICY = "computeGraphicsCardPolicy"
    COMPUTE_HEALTH_LED_SENSOR_ALARM = "computeHealthLedSensorAlarm"
    COMPUTE_HOST_UTILITY_OS = "computeHostUtilityOs"
    COMPUTE_HW_CHANGE_DISC_POLICY = "computeHwChangeDiscPolicy"
    COMPUTE_IOHUB = "computeIOHub"
    COMPUTE_IOHUB_ENV_STATS = "computeIOHubEnvStats"
    COMPUTE_IOHUB_ENV_STATS_HIST = "computeIOHubEnvStatsHist"
    COMPUTE_INSTANCE_ID_QUAL = "computeInstanceIdQual"
    COMPUTE_KVM_MGMT_POLICY = "computeKvmMgmtPolicy"
    COMPUTE_MB_POWER_STATS = "computeMbPowerStats"
    COMPUTE_MB_POWER_STATS_HIST = "computeMbPowerStatsHist"
    COMPUTE_MB_TEMP_STATS = "computeMbTempStats"
    COMPUTE_MB_TEMP_STATS_HIST = "computeMbTempStatsHist"
    COMPUTE_MEMORY_CONFIG_POLICY = "computeMemoryConfigPolicy"
    COMPUTE_MEMORY_CONFIGURATION = "computeMemoryConfiguration"
    COMPUTE_MEMORY_UNIT_CONSTRAINT_DEF = "computeMemoryUnitConstraintDef"
    COMPUTE_PCIE_FATAL_COMPLETION_STATS = "computePCIeFatalCompletionStats"
    COMPUTE_PCIE_FATAL_PROTOCOL_STATS = "computePCIeFatalProtocolStats"
    COMPUTE_PCIE_FATAL_RECEIVE_STATS = "computePCIeFatalReceiveStats"
    COMPUTE_PCIE_FATAL_STATS = "computePCIeFatalStats"
    COMPUTE_PCI_CAP = "computePciCap"
    COMPUTE_PCI_SLOT_SCAN_DEF = "computePciSlotScanDef"
    COMPUTE_PERSONALITY = "computePersonality"
    COMPUTE_PHYSICAL_ASSOC_CTX = "computePhysicalAssocCtx"
    COMPUTE_PHYSICAL_EXTENSION = "computePhysicalExtension"
    COMPUTE_PHYSICAL_FSM = "computePhysicalFsm"
    COMPUTE_PHYSICAL_FSM_STAGE = "computePhysicalFsmStage"
    COMPUTE_PHYSICAL_FSM_TASK = "computePhysicalFsmTask"
    COMPUTE_PHYSICAL_QUAL = "computePhysicalQual"
    COMPUTE_PLATFORM = "computePlatform"
    COMPUTE_PNU_OSIMAGE = "computePnuOSImage"
    COMPUTE_POOL = "computePool"
    COMPUTE_POOL_POLICY_REF = "computePoolPolicyRef"
    COMPUTE_POOLABLE = "computePoolable"
    COMPUTE_POOLED_ENCLOSURE_COMPUTE_SLOT = "computePooledEnclosureComputeSlot"
    COMPUTE_POOLED_RACK_UNIT = "computePooledRackUnit"
    COMPUTE_POOLED_SLOT = "computePooledSlot"
    COMPUTE_POOLING_POLICY = "computePoolingPolicy"
    COMPUTE_PORT_DISC_POLICY = "computePortDiscPolicy"
    COMPUTE_POWER_SAVE_POLICY = "computePowerSavePolicy"
    COMPUTE_POWER_SYNC_DEF = "computePowerSyncDef"
    COMPUTE_POWER_SYNC_POLICY = "computePowerSyncPolicy"
    COMPUTE_PSU_CONTROL = "computePsuControl"
    COMPUTE_PSU_POLICY = "computePsuPolicy"
    COMPUTE_QUAL = "computeQual"
    COMPUTE_RACK_CONN_LINK_POLICY = "computeRackConnLinkPolicy"
    COMPUTE_RACK_QUAL = "computeRackQual"
    COMPUTE_RACK_UNIT = "computeRackUnit"
    COMPUTE_RACK_UNIT_FSM = "computeRackUnitFsm"
    COMPUTE_RACK_UNIT_FSM_STAGE = "computeRackUnitFsmStage"
    COMPUTE_RACK_UNIT_FSM_TASK = "computeRackUnitFsmTask"
    COMPUTE_RACK_UNIT_MB_TEMP_STATS = "computeRackUnitMbTempStats"
    COMPUTE_RACK_UNIT_MB_TEMP_STATS_HIST = "computeRackUnitMbTempStatsHist"
    COMPUTE_REBOOT_LOG = "computeRebootLog"
    COMPUTE_RTC_BATTERY = "computeRtcBattery"
    COMPUTE_SCRUB_POLICY = "computeScrubPolicy"
    COMPUTE_SERVER_DISC_POLICY = "computeServerDiscPolicy"
    COMPUTE_SERVER_DISC_POLICY_FSM = "computeServerDiscPolicyFsm"
    COMPUTE_SERVER_DISC_POLICY_FSM_STAGE = "computeServerDiscPolicyFsmStage"
    COMPUTE_SERVER_DISC_POLICY_FSM_TASK = "computeServerDiscPolicyFsmTask"
    COMPUTE_SERVER_MGMT_POLICY = "computeServerMgmtPolicy"
    COMPUTE_SERVER_TYPE_CAP = "computeServerTypeCap"
    COMPUTE_SERVER_UNIT = "computeServerUnit"
    COMPUTE_SERVER_UNIT_FSM = "computeServerUnitFsm"
    COMPUTE_SERVER_UNIT_FSM_STAGE = "computeServerUnitFsmStage"
    COMPUTE_SERVER_UNIT_FSM_TASK = "computeServerUnitFsmTask"
    COMPUTE_SLOT_QUAL = "computeSlotQual"
    CONFIG_CHECK_COMPATIBILITY = "configCheckCompatibility"
    CONFIG_CHECK_CONFORMANCE = "configCheckConformance"
    CONFIG_CHECK_FIRMWARE_UPDATABLE = "configCheckFirmwareUpdatable"
    CONFIG_CONF_FILTERED = "configConfFiltered"
    CONFIG_CONF_MO = "configConfMo"
    CONFIG_CONF_MO_GROUP = "configConfMoGroup"
    CONFIG_CONF_MOS = "configConfMos"
    CONFIG_CONF_RENAME = "configConfRename"
    CONFIG_CONFIG = "configConfig"
    CONFIG_COUNT_CLASS = "configCountClass"
    CONFIG_ESTIMATE_CONF_MOS = "configEstimateConfMos"
    CONFIG_ESTIMATE_IMPACT = "configEstimateImpact"
    CONFIG_FIND_DEPENDENCIES = "configFindDependencies"
    CONFIG_FIND_DNS_BY_CLASS_ID = "configFindDnsByClassId"
    CONFIG_FIND_HOST_PACK_DEPENDENCIES = "configFindHostPackDependencies"
    CONFIG_FIND_PACK_DEPENDENCIES = "configFindPackDependencies"
    CONFIG_FIND_PERMITTED = "configFindPermitted"
    CONFIG_GET_ESTIMATE_IMPACT = "configGetEstimateImpact"
    CONFIG_GET_REMOTE_POLICIES = "configGetRemotePolicies"
    CONFIG_GET_XML_FILE = "configGetXmlFile"
    CONFIG_GET_XML_FILE_STR = "configGetXmlFileStr"
    CONFIG_IMPACT = "configImpact"
    CONFIG_INSTALL_ALL_IMPACT = "configInstallAllImpact"
    CONFIG_INSTALL_CHASSIS_IMPACT = "configInstallChassisImpact"
    CONFIG_MANAGED_EP_IMPACT_RESPONSE = "configManagedEpImpactResponse"
    CONFIG_MAP = "configMap"
    CONFIG_MO_CHANGE_EVENT = "configMoChangeEvent"
    CONFIG_REFRESH_IDENTITY = "configRefreshIdentity"
    CONFIG_RELEASE_RESOLVE_CONTEXT = "configReleaseResolveContext"
    CONFIG_RENEW_RESOLVE_CONTEXT = "configRenewResolveContext"
    CONFIG_RESOLVE_CHILDREN = "configResolveChildren"
    CONFIG_RESOLVE_CHILDREN_SORTED = "configResolveChildrenSorted"
    CONFIG_RESOLVE_CLASS = "configResolveClass"
    CONFIG_RESOLVE_CLASS_SORTED = "configResolveClassSorted"
    CONFIG_RESOLVE_CLASSES = "configResolveClasses"
    CONFIG_RESOLVE_CLASSES_SORTED = "configResolveClassesSorted"
    CONFIG_RESOLVE_CONTEXT = "configResolveContext"
    CONFIG_RESOLVE_DN = "configResolveDn"
    CONFIG_RESOLVE_DNS = "configResolveDns"
    CONFIG_RESOLVE_PARENT = "configResolveParent"
    CONFIG_SCOPE = "configScope"
    CONFIG_SET = "configSet"
    CONFIG_SORTER = "configSorter"
    CONFIG_UPDATE_ALL_IMPACT = "configUpdateAllImpact"
    CONTROLLER_HA_CONTROLLER = "controllerHaController"
    CONTROLLER_MGMT_DB_CHECK_POL = "controllerMgmtDbCheckPol"
    CONTROLLER_OPERATIONAL_VERSION_HOLDER = "controllerOperationalVersionHolder"
    CONTROLLER_PREFERED_VERSION_HOLDER = "controllerPreferedVersionHolder"
    COPROCESSOR_CARD = "coprocessorCard"
    CPMAINT_ACK = "cpmaintAck"
    CPMAINT_MAINT_POLICY = "cpmaintMaintPolicy"
    DCX_FCOE_VIF_EP = "dcxFcoeVifEp"
    DCX_NS = "dcxNs"
    DCX_UNIVERSE = "dcxUniverse"
    DCX_VIF = "dcxVIf"
    DCX_VC = "dcxVc"
    DCX_VIF_EP = "dcxVifEp"
    DHCP_ACQUIRED = "dhcpAcquired"
    DHCP_INST = "dhcpInst"
    DHCP_LEASE = "dhcpLease"
    DIAG_LOG_EP = "diagLogEp"
    DIAG_MEMORY_TEST = "diagMemoryTest"
    DIAG_RSLT = "diagRslt"
    DIAG_RUN_POLICY = "diagRunPolicy"
    DIAG_SRV_CAP_PROVIDER = "diagSrvCapProvider"
    DIAG_SRV_CTRL = "diagSrvCtrl"
    DN = "dn"
    DN_SET = "dnSet"
    DOMAIN_CHASSIS_FEATURE = "domainChassisFeature"
    DOMAIN_CHASSIS_FEATURE_CONT = "domainChassisFeatureCont"
    DOMAIN_CHASSIS_PARAM = "domainChassisParam"
    DOMAIN_ENVIRONMENT_FEATURE = "domainEnvironmentFeature"
    DOMAIN_ENVIRONMENT_FEATURE_CONT = "domainEnvironmentFeatureCont"
    DOMAIN_ENVIRONMENT_PARAM = "domainEnvironmentParam"
    DOMAIN_NETWORK_FEATURE = "domainNetworkFeature"
    DOMAIN_NETWORK_FEATURE_CONT = "domainNetworkFeatureCont"
    DOMAIN_NETWORK_PARAM = "domainNetworkParam"
    DOMAIN_SERVER_FEATURE = "domainServerFeature"
    DOMAIN_SERVER_FEATURE_CONT = "domainServerFeatureCont"
    DOMAIN_SERVER_PARAM = "domainServerParam"
    DOMAIN_STORAGE_FEATURE = "domainStorageFeature"
    DOMAIN_STORAGE_FEATURE_CONT = "domainStorageFeatureCont"
    DOMAIN_STORAGE_PARAM = "domainStorageParam"
    DPSEC_MAC = "dpsecMac"
    DUPE_SCOPE = "dupeScope"
    DUPE_SCOPE_RESULT = "dupeScopeResult"
    EPQOS_DEFINITION = "epqosDefinition"
    EPQOS_DEFINITION_DEL_TASK = "epqosDefinitionDelTask"
    EPQOS_DEFINITION_DEL_TASK_FSM = "epqosDefinitionDelTaskFsm"
    EPQOS_DEFINITION_DEL_TASK_FSM_STAGE = "epqosDefinitionDelTaskFsmStage"
    EPQOS_DEFINITION_DEL_TASK_FSM_TASK = "epqosDefinitionDelTaskFsmTask"
    EPQOS_DEFINITION_FSM = "epqosDefinitionFsm"
    EPQOS_DEFINITION_FSM_STAGE = "epqosDefinitionFsmStage"
    EPQOS_DEFINITION_FSM_TASK = "epqosDefinitionFsmTask"
    EPQOS_EGRESS = "epqosEgress"
    EQ_FILTER = "eqFilter"
    EQUIPMENT_ADAPTOR_CONN_DEF = "equipmentAdaptorConnDef"
    EQUIPMENT_ADAPTOR_DEF = "equipmentAdaptorDef"
    EQUIPMENT_ADVANCED_BOOT_ORDER = "equipmentAdvancedBootOrder"
    EQUIPMENT_AUTO_CONFIG_MODE = "equipmentAutoConfigMode"
    EQUIPMENT_AUTOCONFIG_POLICY = "equipmentAutoconfigPolicy"
    EQUIPMENT_BASE_BOARD_CAP_PROVIDER = "equipmentBaseBoardCapProvider"
    EQUIPMENT_BEACON_CAP_PROVIDER = "equipmentBeaconCapProvider"
    EQUIPMENT_BEACON_LED = "equipmentBeaconLed"
    EQUIPMENT_BEACON_LED_FSM = "equipmentBeaconLedFsm"
    EQUIPMENT_BEACON_LED_FSM_STAGE = "equipmentBeaconLedFsmStage"
    EQUIPMENT_BEACON_LED_FSM_TASK = "equipmentBeaconLedFsmTask"
    EQUIPMENT_BINDING = "equipmentBinding"
    EQUIPMENT_BIOS_DEF = "equipmentBiosDef"
    EQUIPMENT_BIOS_TOKEN_OVERRIDE = "equipmentBiosTokenOverride"
    EQUIPMENT_BLADE_AGLIBRARY = "equipmentBladeAGLibrary"
    EQUIPMENT_BLADE_AGGREGATION_CAP_REF = "equipmentBladeAggregationCapRef"
    EQUIPMENT_BLADE_BIOS_CAP_PROVIDER = "equipmentBladeBiosCapProvider"
    EQUIPMENT_BLADE_CAP_PROVIDER = "equipmentBladeCapProvider"
    EQUIPMENT_BLADE_CAP_PROVIDER_TYPE_DEF = "equipmentBladeCapProviderTypeDef"
    EQUIPMENT_BLADE_CONN_DEF = "equipmentBladeConnDef"
    EQUIPMENT_BLADE_IOMCONN_DEF = "equipmentBladeIOMConnDef"
    EQUIPMENT_BLADE_SWITCH_CONN_DEF = "equipmentBladeSwitchConnDef"
    EQUIPMENT_BOARD_CONTROLLER_DEF = "equipmentBoardControllerDef"
    EQUIPMENT_BOOT_DEVICE_CONSTRAINTS = "equipmentBootDeviceConstraints"
    EQUIPMENT_BREAKOUT_CAP = "equipmentBreakoutCap"
    EQUIPMENT_CAP_MOD_SPEC = "equipmentCapModSpec"
    EQUIPMENT_CATALOG_CAP_PROVIDER = "equipmentCatalogCapProvider"
    EQUIPMENT_CHASSIS = "equipmentChassis"
    EQUIPMENT_CHASSIS_ASSOC_CTX = "equipmentChassisAssocCtx"
    EQUIPMENT_CHASSIS_CAP_PROVIDER = "equipmentChassisCapProvider"
    EQUIPMENT_CHASSIS_FSM = "equipmentChassisFsm"
    EQUIPMENT_CHASSIS_FSM_STAGE = "equipmentChassisFsmStage"
    EQUIPMENT_CHASSIS_FSM_TASK = "equipmentChassisFsmTask"
    EQUIPMENT_CHASSIS_INHERIT_POLICY = "equipmentChassisInheritPolicy"
    EQUIPMENT_CHASSIS_ISSUES = "equipmentChassisIssues"
    EQUIPMENT_CHASSIS_PROFILE = "equipmentChassisProfile"
    EQUIPMENT_CHASSIS_PROFILE_ASSOC_CTX = "equipmentChassisProfileAssocCtx"
    EQUIPMENT_CHASSIS_PROFILE_FSM = "equipmentChassisProfileFsm"
    EQUIPMENT_CHASSIS_PROFILE_FSM_STAGE = "equipmentChassisProfileFsmStage"
    EQUIPMENT_CHASSIS_PROFILE_FSM_TASK = "equipmentChassisProfileFsmTask"
    EQUIPMENT_CHASSIS_QUAL = "equipmentChassisQual"
    EQUIPMENT_CHASSIS_STATS = "equipmentChassisStats"
    EQUIPMENT_CHASSIS_STATS_HIST = "equipmentChassisStatsHist"
    EQUIPMENT_CIMC_VMEDIA = "equipmentCimcVmedia"
    EQUIPMENT_CISCO_OS_OPEN_GATE = "equipmentCiscoOsOpenGate"
    EQUIPMENT_CLONE = "equipmentClone"
    EQUIPMENT_COMPUTE_CONN = "equipmentComputeConn"
    EQUIPMENT_COMPUTE_CONN_POLICY = "equipmentComputeConnPolicy"
    EQUIPMENT_COPROCESSOR_UNIT_CAP_PROVIDER = "equipmentCoprocessorUnitCapProvider"
    EQUIPMENT_DBG_PLUGIN_CAP_PROVIDER = "equipmentDbgPluginCapProvider"
    EQUIPMENT_DIAG_FEATURE_SUPPORT = "equipmentDiagFeatureSupport"
    EQUIPMENT_DIMM_ENTRY = "equipmentDimmEntry"
    EQUIPMENT_DIMM_MAPPING = "equipmentDimmMapping"
    EQUIPMENT_DISCOVERY_CAP = "equipmentDiscoveryCap"
    EQUIPMENT_DOWNGRADE_CONSTRAINT = "equipmentDowngradeConstraint"
    EQUIPMENT_DRIVE_SEC_CAP = "equipmentDriveSecCap"
    EQUIPMENT_EMBEDDED_CONTROLLER_CONFIG = "equipmentEmbeddedControllerConfig"
    EQUIPMENT_EMBEDDED_STORAGE_DEF = "equipmentEmbeddedStorageDef"
    EQUIPMENT_FAN = "equipmentFan"
    EQUIPMENT_FAN_AGGRESSIVE_COOLING_CAP = "equipmentFanAggressiveCoolingCap"
    EQUIPMENT_FAN_MODULE = "equipmentFanModule"
    EQUIPMENT_FAN_MODULE_CAP_PROVIDER = "equipmentFanModuleCapProvider"
    EQUIPMENT_FAN_MODULE_DEF = "equipmentFanModuleDef"
    EQUIPMENT_FAN_MODULE_STATS = "equipmentFanModuleStats"
    EQUIPMENT_FAN_MODULE_STATS_HIST = "equipmentFanModuleStatsHist"
    EQUIPMENT_FAN_PRESENCE_DEF = "equipmentFanPresenceDef"
    EQUIPMENT_FAN_STATS = "equipmentFanStats"
    EQUIPMENT_FAN_STATS_HIST = "equipmentFanStatsHist"
    EQUIPMENT_FEX = "equipmentFex"
    EQUIPMENT_FEX_CAP_PROVIDER = "equipmentFexCapProvider"
    EQUIPMENT_FEX_ENV_STATS = "equipmentFexEnvStats"
    EQUIPMENT_FEX_ENV_STATS_HIST = "equipmentFexEnvStatsHist"
    EQUIPMENT_FEX_FSM = "equipmentFexFsm"
    EQUIPMENT_FEX_FSM_STAGE = "equipmentFexFsmStage"
    EQUIPMENT_FEX_FSM_TASK = "equipmentFexFsmTask"
    EQUIPMENT_FEX_POWER_SUMMARY = "equipmentFexPowerSummary"
    EQUIPMENT_FEX_POWER_SUMMARY_HIST = "equipmentFexPowerSummaryHist"
    EQUIPMENT_FEX_PSU_INPUT_STATS = "equipmentFexPsuInputStats"
    EQUIPMENT_FEX_PSU_INPUT_STATS_HIST = "equipmentFexPsuInputStatsHist"
    EQUIPMENT_FEX_SYSTEM_STATS = "equipmentFexSystemStats"
    EQUIPMENT_FEX_SYSTEM_STATS_HIST = "equipmentFexSystemStatsHist"
    EQUIPMENT_FIRMWARE_CONSTRAINT = "equipmentFirmwareConstraint"
    EQUIPMENT_FLASH_LIFE = "equipmentFlashLife"
    EQUIPMENT_FLEX_FLASH_NON_REMOVABLE = "equipmentFlexFlashNonRemovable"
    EQUIPMENT_FRU_VARIANT = "equipmentFruVariant"
    EQUIPMENT_GEM_CAP_PROVIDER = "equipmentGemCapProvider"
    EQUIPMENT_GEM_PORT_CAP = "equipmentGemPortCap"
    EQUIPMENT_GRAPHICS_CARD_CAP_PROVIDER = "equipmentGraphicsCardCapProvider"
    EQUIPMENT_GRAPHICS_CARD_CAP_REF = "equipmentGraphicsCardCapRef"
    EQUIPMENT_HDDFAULT_MON_DEF = "equipmentHDDFaultMonDef"
    EQUIPMENT_HEALTH_LED = "equipmentHealthLed"
    EQUIPMENT_HOST_IF_CAP_PROVIDER = "equipmentHostIfCapProvider"
    EQUIPMENT_HOST_MGMT_CONTROLLER_CAP = "equipmentHostMgmtControllerCap"
    EQUIPMENT_HW_CAP_DERIVATIVE_PROVIDER = "equipmentHwCapDerivativeProvider"
    EQUIPMENT_HW_REVISION_MODIFIER = "equipmentHwRevisionModifier"
    EQUIPMENT_HX_CAP = "equipmentHxCap"
    EQUIPMENT_IOCARD = "equipmentIOCard"
    EQUIPMENT_IOCARD_BASE_FSM = "equipmentIOCardBaseFsm"
    EQUIPMENT_IOCARD_BASE_FSM_STAGE = "equipmentIOCardBaseFsmStage"
    EQUIPMENT_IOCARD_BASE_FSM_TASK = "equipmentIOCardBaseFsmTask"
    EQUIPMENT_IOCARD_CAP_PROVIDER = "equipmentIOCardCapProvider"
    EQUIPMENT_IOCARD_FSM = "equipmentIOCardFsm"
    EQUIPMENT_IOCARD_FSM_STAGE = "equipmentIOCardFsmStage"
    EQUIPMENT_IOCARD_FSM_TASK = "equipmentIOCardFsmTask"
    EQUIPMENT_IOCARD_STATS = "equipmentIOCardStats"
    EQUIPMENT_IOCARD_STATS_HIST = "equipmentIOCardStatsHist"
    EQUIPMENT_IOCARD_TYPE_DEF = "equipmentIOCardTypeDef"
    EQUIPMENT_IOEXPANDER = "equipmentIOExpander"
    EQUIPMENT_IOEXPANDER_CAP_PROVIDER = "equipmentIOExpanderCapProvider"
    EQUIPMENT_INBAND_MGMT_CAP = "equipmentInbandMgmtCap"
    EQUIPMENT_INDICATOR_LED = "equipmentIndicatorLed"
    EQUIPMENT_INSTANTIATE_NNAMED_TEMPLATE = "equipmentInstantiateNNamedTemplate"
    EQUIPMENT_INSTANTIATE_NTEMPLATE = "equipmentInstantiateNTemplate"
    EQUIPMENT_INSTANTIATE_TEMPLATE = "equipmentInstantiateTemplate"
    EQUIPMENT_INVENTORY_STATUS = "equipmentInventoryStatus"
    EQUIPMENT_KVM_MGMT_CAP = "equipmentKvmMgmtCap"
    EQUIPMENT_LOCAL_DISK_CAP_PROVIDER = "equipmentLocalDiskCapProvider"
    EQUIPMENT_LOCAL_DISK_CONTROLLER_CAP_PROVIDER = "equipmentLocalDiskControllerCapProvider"
    EQUIPMENT_LOCAL_DISK_CONTROLLER_CAP_REF = "equipmentLocalDiskControllerCapRef"
    EQUIPMENT_LOCAL_DISK_CONTROLLER_DEF = "equipmentLocalDiskControllerDef"
    EQUIPMENT_LOCAL_DISK_CONTROLLER_TYPE_DEF = "equipmentLocalDiskControllerTypeDef"
    EQUIPMENT_LOCAL_DISK_DEF = "equipmentLocalDiskDef"
    EQUIPMENT_LOCATOR_LED = "equipmentLocatorLed"
    EQUIPMENT_LOCATOR_LED_FSM = "equipmentLocatorLedFsm"
    EQUIPMENT_LOCATOR_LED_FSM_STAGE = "equipmentLocatorLedFsmStage"
    EQUIPMENT_LOCATOR_LED_FSM_TASK = "equipmentLocatorLedFsmTask"
    EQUIPMENT_MANUFACTURING_DEF = "equipmentManufacturingDef"
    EQUIPMENT_MEMORY_UNIT_CAP_PROVIDER = "equipmentMemoryUnitCapProvider"
    EQUIPMENT_MEMORY_UNIT_DISCOVERY_MODIFIER_DEF = "equipmentMemoryUnitDiscoveryModifierDef"
    EQUIPMENT_MGMT_CAP_PROVIDER = "equipmentMgmtCapProvider"
    EQUIPMENT_MGMT_EXT_CAP_PROVIDER = "equipmentMgmtExtCapProvider"
    EQUIPMENT_MINI_STORAGE_CAP_PROVIDER = "equipmentMiniStorageCapProvider"
    EQUIPMENT_NETWORK_ELEMENT_FAN_STATS = "equipmentNetworkElementFanStats"
    EQUIPMENT_NETWORK_ELEMENT_FAN_STATS_HIST = "equipmentNetworkElementFanStatsHist"
    EQUIPMENT_NON_COPPER_PASSIVE_CAP = "equipmentNonCopperPassiveCap"
    EQUIPMENT_NVME_DEF = "equipmentNvmeDef"
    EQUIPMENT_NVME_SWITCH_CONFIG = "equipmentNvmeSwitchConfig"
    EQUIPMENT_ONBOARD_DEVICE_DEF = "equipmentOnboardDeviceDef"
    EQUIPMENT_POST = "equipmentPOST"
    EQUIPMENT_POSTCODE = "equipmentPOSTCode"
    EQUIPMENT_POSTCODE_REPORTER = "equipmentPOSTCodeReporter"
    EQUIPMENT_POSTCODE_TEMPLATE = "equipmentPOSTCodeTemplate"
    EQUIPMENT_PCI_DEF = "equipmentPciDef"
    EQUIPMENT_PCI_SLOT_ID_ENTRY = "equipmentPciSlotIdEntry"
    EQUIPMENT_PCI_SLOT_ID_MAPPING = "equipmentPciSlotIdMapping"
    EQUIPMENT_PCI_SLOT_SUB_OEMID_ENTRY = "equipmentPciSlotSubOEMIdEntry"
    EQUIPMENT_PCI_SWITCH_CAP_PROVIDER = "equipmentPciSwitchCapProvider"
    EQUIPMENT_PCIE_SLOT_ORIENTATION = "equipmentPcieSlotOrientation"
    EQUIPMENT_PERSISTENT_MEMORY_UNIT_CAP_PROVIDER = "equipmentPersistentMemoryUnitCapProvider"
    EQUIPMENT_PERSONALITY = "equipmentPersonality"
    EQUIPMENT_PFC_MMU_CAP = "equipmentPfcMmuCap"
    EQUIPMENT_PHYS_DEVICES_PER_BOARD = "equipmentPhysDevicesPerBoard"
    EQUIPMENT_PHYSICAL_DEF = "equipmentPhysicalDef"
    EQUIPMENT_PHYSICAL_QUAL = "equipmentPhysicalQual"
    EQUIPMENT_PICTURE = "equipmentPicture"
    EQUIPMENT_PNUOS_BOOT_MODE = "equipmentPnuosBootMode"
    EQUIPMENT_POOL = "equipmentPool"
    EQUIPMENT_POOL_POLICY_REF = "equipmentPoolPolicyRef"
    EQUIPMENT_POOLABLE = "equipmentPoolable"
    EQUIPMENT_POOLED_CHASSIS = "equipmentPooledChassis"
    EQUIPMENT_POOLING_POLICY = "equipmentPoolingPolicy"
    EQUIPMENT_PORT_CAP = "equipmentPortCap"
    EQUIPMENT_PORT_GROUP_AGGREGATION_DEF = "equipmentPortGroupAggregationDef"
    EQUIPMENT_PORT_GROUP_DEF = "equipmentPortGroupDef"
    EQUIPMENT_PORT_GROUP_SW_COMPLEX_DEF = "equipmentPortGroupSwComplexDef"
    EQUIPMENT_PORT_SW_COMPLEX_REF = "equipmentPortSwComplexRef"
    EQUIPMENT_POWER_CAP_DEF = "equipmentPowerCapDef"
    EQUIPMENT_PROCESSOR_UNIT_CAP_PROVIDER = "equipmentProcessorUnitCapProvider"
    EQUIPMENT_PROCESSOR_UNIT_DEF = "equipmentProcessorUnitDef"
    EQUIPMENT_PSU = "equipmentPsu"
    EQUIPMENT_PSU_CAP_PROVIDER = "equipmentPsuCapProvider"
    EQUIPMENT_PSU_DEF = "equipmentPsuDef"
    EQUIPMENT_PSU_FSM = "equipmentPsuFsm"
    EQUIPMENT_PSU_FSM_STAGE = "equipmentPsuFsmStage"
    EQUIPMENT_PSU_FSM_TASK = "equipmentPsuFsmTask"
    EQUIPMENT_PSU_INPUT_STATS = "equipmentPsuInputStats"
    EQUIPMENT_PSU_INPUT_STATS_HIST = "equipmentPsuInputStatsHist"
    EQUIPMENT_PSU_OUTPUT_STATS = "equipmentPsuOutputStats"
    EQUIPMENT_PSU_OUTPUT_STATS_HIST = "equipmentPsuOutputStatsHist"
    EQUIPMENT_PSU_STATS = "equipmentPsuStats"
    EQUIPMENT_PSU_STATS_HIST = "equipmentPsuStatsHist"
    EQUIPMENT_QUAL = "equipmentQual"
    EQUIPMENT_RACK_ENCLOSURE = "equipmentRackEnclosure"
    EQUIPMENT_RACK_ENCLOSURE_CAP_PROVIDER = "equipmentRackEnclosureCapProvider"
    EQUIPMENT_RACK_FAN_MODULE_DEF = "equipmentRackFanModuleDef"
    EQUIPMENT_RACK_UNIT_CAP_PROVIDER = "equipmentRackUnitCapProvider"
    EQUIPMENT_RACK_UNIT_FAN_STATS = "equipmentRackUnitFanStats"
    EQUIPMENT_RACK_UNIT_FAN_STATS_HIST = "equipmentRackUnitFanStatsHist"
    EQUIPMENT_RACK_UNIT_PSU_STATS = "equipmentRackUnitPsuStats"
    EQUIPMENT_RACK_UNIT_PSU_STATS_HIST = "equipmentRackUnitPsuStatsHist"
    EQUIPMENT_RAID_DEF = "equipmentRaidDef"
    EQUIPMENT_REQUIREMENT = "equipmentRequirement"
    EQUIPMENT_RESOLVE_TEMPLATES = "equipmentResolveTemplates"
    EQUIPMENT_SECURE_BOOT = "equipmentSecureBoot"
    EQUIPMENT_SECURITY_UNIT_CAP_PROVIDER = "equipmentSecurityUnitCapProvider"
    EQUIPMENT_SERVER_CORRECT_UUID_BEHAVIOR = "equipmentServerCorrectUuidBehavior"
    EQUIPMENT_SERVER_FEATURE_CAP = "equipmentServerFeatureCap"
    EQUIPMENT_SERVER_PORT_CAP_PROVIDER = "equipmentServerPortCapProvider"
    EQUIPMENT_SERVER_UNIT_CAP_PROVIDER = "equipmentServerUnitCapProvider"
    EQUIPMENT_SERVICE_DEF = "equipmentServiceDef"
    EQUIPMENT_SHARED_IOMODULE = "equipmentSharedIOModule"
    EQUIPMENT_SIOC_CAP_PROVIDER = "equipmentSiocCapProvider"
    EQUIPMENT_SIOC_TEMP_STATS = "equipmentSiocTempStats"
    EQUIPMENT_SIOC_TEMP_STATS_HIST = "equipmentSiocTempStatsHist"
    EQUIPMENT_SLOT_ARRAY = "equipmentSlotArray"
    EQUIPMENT_SLOT_ARRAY_REF = "equipmentSlotArrayRef"
    EQUIPMENT_SLOT_EP = "equipmentSlotEp"
    EQUIPMENT_SPDM_CERTIFICATE_CAP = "equipmentSpdmCertificateCap"
    EQUIPMENT_SPEED_COMPATIBILITY = "equipmentSpeedCompatibility"
    EQUIPMENT_STORAGE_CONTROLLER_CONFIG = "equipmentStorageControllerConfig"
    EQUIPMENT_STORAGE_CONTROLLER_SLOT_DEF = "equipmentStorageControllerSlotDef"
    EQUIPMENT_STORAGE_ENC_CAP_PROVIDER = "equipmentStorageEncCapProvider"
    EQUIPMENT_STORAGE_LIMIT_CAP = "equipmentStorageLimitCap"
    EQUIPMENT_STORAGE_NVME_SWITCH_CAP_PROVIDER = "equipmentStorageNvmeSwitchCapProvider"
    EQUIPMENT_STORAGE_NVME_SWITCH_DEF = "equipmentStorageNvmeSwitchDef"
    EQUIPMENT_STORAGE_SAS_EXPANDER_CAP_PROVIDER = "equipmentStorageSasExpanderCapProvider"
    EQUIPMENT_STORAGE_SAS_EXPANDER_CAP_REF = "equipmentStorageSasExpanderCapRef"
    EQUIPMENT_STORAGE_SAS_EXPANDER_DEF = "equipmentStorageSasExpanderDef"
    EQUIPMENT_SWITCH_CAP = "equipmentSwitchCap"
    EQUIPMENT_SWITCH_CAP_PROVIDER = "equipmentSwitchCapProvider"
    EQUIPMENT_SWITCH_CARD = "equipmentSwitchCard"
    EQUIPMENT_SWITCH_IOCARD = "equipmentSwitchIOCard"
    EQUIPMENT_SWITCH_IOCARD_CAP_PROVIDER = "equipmentSwitchIOCardCapProvider"
    EQUIPMENT_SWITCH_IOCARD_FSM = "equipmentSwitchIOCardFsm"
    EQUIPMENT_SWITCH_IOCARD_FSM_STAGE = "equipmentSwitchIOCardFsmStage"
    EQUIPMENT_SWITCH_IOCARD_FSM_TASK = "equipmentSwitchIOCardFsmTask"
    EQUIPMENT_SWITCH_TYPE_DEF = "equipmentSwitchTypeDef"
    EQUIPMENT_SYSTEM_IOCONTROLLER = "equipmentSystemIOController"
    EQUIPMENT_SYSTEM_IOCONTROLLER_FSM = "equipmentSystemIOControllerFsm"
    EQUIPMENT_SYSTEM_IOCONTROLLER_FSM_STAGE = "equipmentSystemIOControllerFsmStage"
    EQUIPMENT_SYSTEM_IOCONTROLLER_FSM_TASK = "equipmentSystemIOControllerFsmTask"
    EQUIPMENT_TEMPLATISE = "equipmentTemplatise"
    EQUIPMENT_TIER = "equipmentTier"
    EQUIPMENT_TPM = "equipmentTpm"
    EQUIPMENT_TPM_CAP_PROVIDER = "equipmentTpmCapProvider"
    EQUIPMENT_UNIFIED_PORT_CAP_PROVIDER = "equipmentUnifiedPortCapProvider"
    EQUIPMENT_UUID_FEATURE_CAP = "equipmentUuidFeatureCap"
    EQUIPMENT_VERSION_CONSTRAINT = "equipmentVersionConstraint"
    EQUIPMENT_XCVR = "equipmentXcvr"
    ETHER_ERR_STATS = "etherErrStats"
    ETHER_ERR_STATS_HIST = "etherErrStatsHist"
    ETHER_FCOE_INTERFACE_STATS = "etherFcoeInterfaceStats"
    ETHER_FCOE_INTERFACE_STATS_HIST = "etherFcoeInterfaceStatsHist"
    ETHER_LOSS_STATS = "etherLossStats"
    ETHER_LOSS_STATS_HIST = "etherLossStatsHist"
    ETHER_NI_ERR_STATS = "etherNiErrStats"
    ETHER_NI_ERR_STATS_HIST = "etherNiErrStatsHist"
    ETHER_NIC_IF_CONFIG = "etherNicIfConfig"
    ETHER_PIO = "etherPIo"
    ETHER_PIO_END_POINT = "etherPIoEndPoint"
    ETHER_PIO_FSM = "etherPIoFsm"
    ETHER_PIO_FSM_STAGE = "etherPIoFsmStage"
    ETHER_PAUSE_STATS = "etherPauseStats"
    ETHER_PAUSE_STATS_HIST = "etherPauseStatsHist"
    ETHER_PORT_CHAN_ID_ELEM = "etherPortChanIdElem"
    ETHER_PORT_CHAN_ID_UNIVERSE = "etherPortChanIdUniverse"
    ETHER_RX_STATS = "etherRxStats"
    ETHER_RX_STATS_HIST = "etherRxStatsHist"
    ETHER_SERVER_INT_FIO = "etherServerIntFIo"
    ETHER_SERVER_INT_FIO_FSM = "etherServerIntFIoFsm"
    ETHER_SERVER_INT_FIO_FSM_STAGE = "etherServerIntFIoFsmStage"
    ETHER_SERVER_INT_FIO_FSM_TASK = "etherServerIntFIoFsmTask"
    ETHER_SERVER_INT_FIO_PC = "etherServerIntFIoPc"
    ETHER_SERVER_INT_FIO_PC_EP = "etherServerIntFIoPcEp"
    ETHER_SW_IF_CONFIG = "etherSwIfConfig"
    ETHER_SWITCH_INT_FIO = "etherSwitchIntFIo"
    ETHER_SWITCH_INT_FIO_PC = "etherSwitchIntFIoPc"
    ETHER_SWITCH_INT_FIO_PC_EP = "etherSwitchIntFIoPcEp"
    ETHER_TX_STATS = "etherTxStats"
    ETHER_TX_STATS_HIST = "etherTxStatsHist"
    EVENT_EP_CTRL = "eventEpCtrl"
    EVENT_HOLDER = "eventHolder"
    EVENT_INST = "eventInst"
    EVENT_LOG = "eventLog"
    EVENT_POLICY = "eventPolicy"
    EVENT_RECORD = "eventRecord"
    EVENT_REGISTER_EVENT_CHANNEL = "eventRegisterEventChannel"
    EVENT_REGISTER_EVENT_CHANNEL_RESP = "eventRegisterEventChannelResp"
    EVENT_SEND_EVENT = "eventSendEvent"
    EVENT_SEND_HEARTBEAT = "eventSendHeartbeat"
    EVENT_SUBSCRIBE = "eventSubscribe"
    EVENT_UN_REGISTER_EVENT_CHANNEL = "eventUnRegisterEventChannel"
    EVENT_UNSUBSCRIBE = "eventUnsubscribe"
    EXTMGMT_ARP_TARGETS = "extmgmtArpTargets"
    EXTMGMT_GATEWAY_PING = "extmgmtGatewayPing"
    EXTMGMT_IF = "extmgmtIf"
    EXTMGMT_IF_MON_POLICY = "extmgmtIfMonPolicy"
    EXTMGMT_MII_STATUS = "extmgmtMiiStatus"
    EXTMGMT_NDISC_TARGETS = "extmgmtNdiscTargets"
    EXTPOL_CLIENT = "extpolClient"
    EXTPOL_CLIENT_CONT = "extpolClientCont"
    EXTPOL_CONTROLLER = "extpolController"
    EXTPOL_CONTROLLER_CONT = "extpolControllerCont"
    EXTPOL_EP = "extpolEp"
    EXTPOL_EP_FSM = "extpolEpFsm"
    EXTPOL_EP_FSM_STAGE = "extpolEpFsmStage"
    EXTPOL_EP_FSM_TASK = "extpolEpFsmTask"
    EXTPOL_PROVIDER = "extpolProvider"
    EXTPOL_PROVIDER_CONT = "extpolProviderCont"
    EXTPOL_PROVIDER_FSM = "extpolProviderFsm"
    EXTPOL_PROVIDER_FSM_STAGE = "extpolProviderFsmStage"
    EXTPOL_PROVIDER_FSM_TASK = "extpolProviderFsmTask"
    EXTPOL_REGISTRY = "extpolRegistry"
    EXTPOL_REGISTRY_FSM = "extpolRegistryFsm"
    EXTPOL_REGISTRY_FSM_STAGE = "extpolRegistryFsmStage"
    EXTPOL_REGISTRY_FSM_TASK = "extpolRegistryFsmTask"
    EXTPOL_SYSTEM_CONTEXT = "extpolSystemContext"
    EXTVMM_EP = "extvmmEp"
    EXTVMM_EP_FSM = "extvmmEpFsm"
    EXTVMM_EP_FSM_STAGE = "extvmmEpFsmStage"
    EXTVMM_EP_FSM_TASK = "extvmmEpFsmTask"
    EXTVMM_FNDREFERENCE = "extvmmFNDReference"
    EXTVMM_FABRIC_NETWORK = "extvmmFabricNetwork"
    EXTVMM_FABRIC_NETWORK_DEFINITION = "extvmmFabricNetworkDefinition"
    EXTVMM_KEY_INST = "extvmmKeyInst"
    EXTVMM_KEY_RING = "extvmmKeyRing"
    EXTVMM_KEY_STORE = "extvmmKeyStore"
    EXTVMM_KEY_STORE_FSM = "extvmmKeyStoreFsm"
    EXTVMM_KEY_STORE_FSM_STAGE = "extvmmKeyStoreFsmStage"
    EXTVMM_KEY_STORE_FSM_TASK = "extvmmKeyStoreFsmTask"
    EXTVMM_MASTER_EXT_KEY = "extvmmMasterExtKey"
    EXTVMM_MASTER_EXT_KEY_FSM = "extvmmMasterExtKeyFsm"
    EXTVMM_MASTER_EXT_KEY_FSM_STAGE = "extvmmMasterExtKeyFsmStage"
    EXTVMM_MASTER_EXT_KEY_FSM_TASK = "extvmmMasterExtKeyFsmTask"
    EXTVMM_NETWORK_SETS = "extvmmNetworkSets"
    EXTVMM_NETWORK_SETS_FSM = "extvmmNetworkSetsFsm"
    EXTVMM_NETWORK_SETS_FSM_STAGE = "extvmmNetworkSetsFsmStage"
    EXTVMM_NETWORK_SETS_FSM_TASK = "extvmmNetworkSetsFsmTask"
    EXTVMM_PROVIDER = "extvmmProvider"
    EXTVMM_PROVIDER_FSM = "extvmmProviderFsm"
    EXTVMM_PROVIDER_FSM_STAGE = "extvmmProviderFsmStage"
    EXTVMM_PROVIDER_FSM_TASK = "extvmmProviderFsmTask"
    EXTVMM_SWITCH_DEL_TASK = "extvmmSwitchDelTask"
    EXTVMM_SWITCH_DEL_TASK_FSM = "extvmmSwitchDelTaskFsm"
    EXTVMM_SWITCH_DEL_TASK_FSM_STAGE = "extvmmSwitchDelTaskFsmStage"
    EXTVMM_SWITCH_DEL_TASK_FSM_TASK = "extvmmSwitchDelTaskFsmTask"
    EXTVMM_SWITCH_SET = "extvmmSwitchSet"
    EXTVMM_UP_LINK_PP = "extvmmUpLinkPP"
    EXTVMM_VMNDREF = "extvmmVMNDRef"
    EXTVMM_VMNETWORK = "extvmmVMNetwork"
    EXTVMM_VMNETWORK_DEFINITION = "extvmmVMNetworkDefinition"
    EXTVMM_VMNETWORK_SETS = "extvmmVMNetworkSets"
    FABRIC_BHVLAN = "fabricBHVlan"
    FABRIC_BREAKOUT = "fabricBreakout"
    FABRIC_CABLING = "fabricCabling"
    FABRIC_CABLING_SW = "fabricCablingSw"
    FABRIC_CARTRIDGE_PH_EP = "fabricCartridgePhEp"
    FABRIC_CARTRIDGE_SLOT_EP = "fabricCartridgeSlotEp"
    FABRIC_CARTRIDGE_SLOT_EP_FSM = "fabricCartridgeSlotEpFsm"
    FABRIC_CARTRIDGE_SLOT_EP_FSM_STAGE = "fabricCartridgeSlotEpFsmStage"
    FABRIC_CARTRIDGE_SLOT_EP_FSM_TASK = "fabricCartridgeSlotEpFsmTask"
    FABRIC_CDP_LINK_POLICY = "fabricCdpLinkPolicy"
    FABRIC_CHANGED_OBJECT_REF = "fabricChangedObjectRef"
    FABRIC_CHASSIS_EP = "fabricChassisEp"
    FABRIC_COMPUTE_MSLOT_EP = "fabricComputeMSlotEp"
    FABRIC_COMPUTE_MSLOT_EP_FSM = "fabricComputeMSlotEpFsm"
    FABRIC_COMPUTE_MSLOT_EP_FSM_STAGE = "fabricComputeMSlotEpFsmStage"
    FABRIC_COMPUTE_MSLOT_EP_FSM_TASK = "fabricComputeMSlotEpFsmTask"
    FABRIC_COMPUTE_PH_EP = "fabricComputePhEp"
    FABRIC_COMPUTE_SLOT_EP = "fabricComputeSlotEp"
    FABRIC_COMPUTE_SLOT_EP_FSM = "fabricComputeSlotEpFsm"
    FABRIC_COMPUTE_SLOT_EP_FSM_STAGE = "fabricComputeSlotEpFsmStage"
    FABRIC_COMPUTE_SLOT_EP_FSM_TASK = "fabricComputeSlotEpFsmTask"
    FABRIC_DCE_SRV = "fabricDceSrv"
    FABRIC_DCE_SW_SRV = "fabricDceSwSrv"
    FABRIC_DCE_SW_SRV_EP = "fabricDceSwSrvEp"
    FABRIC_DCE_SW_SRV_PC = "fabricDceSwSrvPc"
    FABRIC_DCE_SW_SRV_PC_EP = "fabricDceSwSrvPcEp"
    FABRIC_EP = "fabricEp"
    FABRIC_EP_MGR = "fabricEpMgr"
    FABRIC_EP_MGR_FSM = "fabricEpMgrFsm"
    FABRIC_EP_MGR_FSM_STAGE = "fabricEpMgrFsmStage"
    FABRIC_EP_MGR_FSM_TASK = "fabricEpMgrFsmTask"
    FABRIC_ETH_ESTC = "fabricEthEstc"
    FABRIC_ETH_ESTC_CLOUD = "fabricEthEstcCloud"
    FABRIC_ETH_ESTC_EP = "fabricEthEstcEp"
    FABRIC_ETH_ESTC_PC = "fabricEthEstcPc"
    FABRIC_ETH_ESTC_PC_EP = "fabricEthEstcPcEp"
    FABRIC_ETH_FLOW_MON_LAN = "fabricEthFlowMonLan"
    FABRIC_ETH_LAN = "fabricEthLan"
    FABRIC_ETH_LAN_EP = "fabricEthLanEp"
    FABRIC_ETH_LAN_FLOW_MONITORING = "fabricEthLanFlowMonitoring"
    FABRIC_ETH_LAN_PC = "fabricEthLanPc"
    FABRIC_ETH_LAN_PC_EP = "fabricEthLanPcEp"
    FABRIC_ETH_LINK_PROFILE = "fabricEthLinkProfile"
    FABRIC_ETH_MON = "fabricEthMon"
    FABRIC_ETH_MON_DEST_EP = "fabricEthMonDestEp"
    FABRIC_ETH_MON_FILT_EP = "fabricEthMonFiltEp"
    FABRIC_ETH_MON_FILT_REF = "fabricEthMonFiltRef"
    FABRIC_ETH_MON_LAN = "fabricEthMonLan"
    FABRIC_ETH_MON_SRC_EP = "fabricEthMonSrcEp"
    FABRIC_ETH_MON_SRC_REF = "fabricEthMonSrcRef"
    FABRIC_ETH_TARGET_EP = "fabricEthTargetEp"
    FABRIC_ETH_VLAN_PC = "fabricEthVlanPc"
    FABRIC_ETH_VLAN_PORT_EP = "fabricEthVlanPortEp"
    FABRIC_FC_ENDPOINT = "fabricFcEndpoint"
    FABRIC_FC_ESTC = "fabricFcEstc"
    FABRIC_FC_ESTC_CLOUD = "fabricFcEstcCloud"
    FABRIC_FC_ESTC_EP = "fabricFcEstcEp"
    FABRIC_FC_MON = "fabricFcMon"
    FABRIC_FC_MON_DEST_EP = "fabricFcMonDestEp"
    FABRIC_FC_MON_FILT_EP = "fabricFcMonFiltEp"
    FABRIC_FC_MON_FILT_REF = "fabricFcMonFiltRef"
    FABRIC_FC_MON_SAN = "fabricFcMonSan"
    FABRIC_FC_MON_SRC_EP = "fabricFcMonSrcEp"
    FABRIC_FC_MON_SRC_REF = "fabricFcMonSrcRef"
    FABRIC_FC_SAN = "fabricFcSan"
    FABRIC_FC_SAN_EP = "fabricFcSanEp"
    FABRIC_FC_SAN_PC = "fabricFcSanPc"
    FABRIC_FC_SAN_PC_EP = "fabricFcSanPcEp"
    FABRIC_FC_USER_ZONE = "fabricFcUserZone"
    FABRIC_FC_VSAN_PC = "fabricFcVsanPc"
    FABRIC_FC_VSAN_PORT_EP = "fabricFcVsanPortEp"
    FABRIC_FC_ZONE_PROFILE = "fabricFcZoneProfile"
    FABRIC_FCOE_ESTC_EP = "fabricFcoeEstcEp"
    FABRIC_FCOE_SAN_EP = "fabricFcoeSanEp"
    FABRIC_FCOE_SAN_PC = "fabricFcoeSanPc"
    FABRIC_FCOE_SAN_PC_EP = "fabricFcoeSanPcEp"
    FABRIC_FCOE_VSAN_PC = "fabricFcoeVsanPc"
    FABRIC_FCOE_VSAN_PORT_EP = "fabricFcoeVsanPortEp"
    FABRIC_FLOW_MON_DEFINITION = "fabricFlowMonDefinition"
    FABRIC_FLOW_MON_EXPORTER_PROFILE = "fabricFlowMonExporterProfile"
    FABRIC_IF = "fabricIf"
    FABRIC_LACP_POLICY = "fabricLacpPolicy"
    FABRIC_LAN_ACCESS_MGR = "fabricLanAccessMgr"
    FABRIC_LAN_CLOUD = "fabricLanCloud"
    FABRIC_LAN_CLOUD_FSM = "fabricLanCloudFsm"
    FABRIC_LAN_CLOUD_FSM_STAGE = "fabricLanCloudFsmStage"
    FABRIC_LAN_CLOUD_FSM_TASK = "fabricLanCloudFsmTask"
    FABRIC_LAN_CLOUD_POLICY = "fabricLanCloudPolicy"
    FABRIC_LAN_MON_CLOUD = "fabricLanMonCloud"
    FABRIC_LAN_PIN_GROUP = "fabricLanPinGroup"
    FABRIC_LAN_PIN_TARGET = "fabricLanPinTarget"
    FABRIC_LAST_ACKED_SLOT = "fabricLastAckedSlot"
    FABRIC_LOCALE = "fabricLocale"
    FABRIC_MULTICAST_POLICY = "fabricMulticastPolicy"
    FABRIC_NET_GROUP = "fabricNetGroup"
    FABRIC_NET_GROUP_REF = "fabricNetGroupRef"
    FABRIC_NETFLOW_COLLECTOR = "fabricNetflowCollector"
    FABRIC_NETFLOW_IPV4_ADDR = "fabricNetflowIPv4Addr"
    FABRIC_NETFLOW_MON_EXPORTER = "fabricNetflowMonExporter"
    FABRIC_NETFLOW_MON_EXPORTER_REF = "fabricNetflowMonExporterRef"
    FABRIC_NETFLOW_MON_SESSION = "fabricNetflowMonSession"
    FABRIC_NETFLOW_MON_SRC_EP = "fabricNetflowMonSrcEp"
    FABRIC_NETFLOW_MON_SRC_REF = "fabricNetflowMonSrcRef"
    FABRIC_NETFLOW_MONITOR = "fabricNetflowMonitor"
    FABRIC_NETFLOW_MONITOR_REF = "fabricNetflowMonitorRef"
    FABRIC_NETFLOW_TIMEOUT_POLICY = "fabricNetflowTimeoutPolicy"
    FABRIC_ORG_VLAN_POLICY = "fabricOrgVlanPolicy"
    FABRIC_PATH = "fabricPath"
    FABRIC_PATH_CONN = "fabricPathConn"
    FABRIC_PATH_EP = "fabricPathEp"
    FABRIC_POOLABLE_VLAN = "fabricPoolableVlan"
    FABRIC_POOLED_VLAN = "fabricPooledVlan"
    FABRIC_RESERVED_VLAN = "fabricReservedVlan"
    FABRIC_RESERVED_VLAN_FSM = "fabricReservedVlanFsm"
    FABRIC_RESERVED_VLAN_FSM_STAGE = "fabricReservedVlanFsmStage"
    FABRIC_RESERVED_VLAN_FSM_TASK = "fabricReservedVlanFsmTask"
    FABRIC_SAN_CLOUD = "fabricSanCloud"
    FABRIC_SAN_CLOUD_FSM = "fabricSanCloudFsm"
    FABRIC_SAN_CLOUD_FSM_STAGE = "fabricSanCloudFsmStage"
    FABRIC_SAN_CLOUD_FSM_TASK = "fabricSanCloudFsmTask"
    FABRIC_SAN_GROUP = "fabricSanGroup"
    FABRIC_SAN_GROUP_REF = "fabricSanGroupRef"
    FABRIC_SAN_MON_CLOUD = "fabricSanMonCloud"
    FABRIC_SAN_PIN_GROUP = "fabricSanPinGroup"
    FABRIC_SAN_PIN_TARGET = "fabricSanPinTarget"
    FABRIC_SUB_GROUP = "fabricSubGroup"
    FABRIC_SW_CH_PH_EP = "fabricSwChPhEp"
    FABRIC_SW_SUB_GROUP = "fabricSwSubGroup"
    FABRIC_UDLD_LINK_POLICY = "fabricUdldLinkPolicy"
    FABRIC_UDLD_POLICY = "fabricUdldPolicy"
    FABRIC_VCON = "fabricVCon"
    FABRIC_VCON_PROFILE = "fabricVConProfile"
    FABRIC_VLAN = "fabricVlan"
    FABRIC_VLAN_EP = "fabricVlanEp"
    FABRIC_VLAN_GROUP_PERMIT = "fabricVlanGroupPermit"
    FABRIC_VLAN_GROUP_REQ = "fabricVlanGroupReq"
    FABRIC_VLAN_PERMIT = "fabricVlanPermit"
    FABRIC_VLAN_REQ = "fabricVlanReq"
    FABRIC_VNET_EP_SYNC_EP = "fabricVnetEpSyncEp"
    FABRIC_VNET_EP_SYNC_EP_FSM = "fabricVnetEpSyncEpFsm"
    FABRIC_VNET_EP_SYNC_EP_FSM_STAGE = "fabricVnetEpSyncEpFsmStage"
    FABRIC_VNET_EP_SYNC_EP_FSM_TASK = "fabricVnetEpSyncEpFsmTask"
    FABRIC_VSAN = "fabricVsan"
    FABRIC_VSAN_EP = "fabricVsanEp"
    FABRIC_VSAN_MEMBERSHIP = "fabricVsanMembership"
    FABRIC_ZONE_ID_UNIVERSE = "fabricZoneIdUniverse"
    FAULT_ACK_FAULT = "faultAckFault"
    FAULT_ACK_FAULTS = "faultAckFaults"
    FAULT_AFFECTED_CLASS = "faultAffectedClass"
    FAULT_HOLDER = "faultHolder"
    FAULT_INST = "faultInst"
    FAULT_LOCAL_TYPED_HOLDER = "faultLocalTypedHolder"
    FAULT_POLICY = "faultPolicy"
    FAULT_RESOLVE_FAULT = "faultResolveFault"
    FAULT_SUPPRESS_POLICY = "faultSuppressPolicy"
    FAULT_SUPPRESS_POLICY_ITEM = "faultSuppressPolicyItem"
    FAULT_SUPPRESS_TASK = "faultSuppressTask"
    FC_ERR_STATS = "fcErrStats"
    FC_ERR_STATS_HIST = "fcErrStatsHist"
    FC_NIC_IF_CONFIG = "fcNicIfConfig"
    FC_PIO = "fcPIo"
    FC_PIO_FSM = "fcPIoFsm"
    FC_PIO_FSM_STAGE = "fcPIoFsmStage"
    FC_STATS = "fcStats"
    FC_STATS_HIST = "fcStatsHist"
    FC_SW_IF_CONFIG = "fcSwIfConfig"
    FCPOOL_ADDR = "fcpoolAddr"
    FCPOOL_BLOCK = "fcpoolBlock"
    FCPOOL_BOOT_TARGET = "fcpoolBootTarget"
    FCPOOL_FORMAT = "fcpoolFormat"
    FCPOOL_INITIATOR = "fcpoolInitiator"
    FCPOOL_INITIATOR_EP = "fcpoolInitiatorEp"
    FCPOOL_INITIATORS = "fcpoolInitiators"
    FCPOOL_OUI = "fcpoolOui"
    FCPOOL_OUIS = "fcpoolOuis"
    FCPOOL_OUIS_FSM = "fcpoolOuisFsm"
    FCPOOL_OUIS_FSM_STAGE = "fcpoolOuisFsmStage"
    FCPOOL_OUIS_FSM_TASK = "fcpoolOuisFsmTask"
    FCPOOL_POOLABLE = "fcpoolPoolable"
    FCPOOL_UNIVERSE = "fcpoolUniverse"
    FEATURE_CONTEXT_EP = "featureContextEp"
    FEATURE_DEFINITION = "featureDefinition"
    FEATURE_DEFINITION_INSTANCE = "featureDefinitionInstance"
    FEATURE_DEFINITION_REF = "featureDefinitionRef"
    FEATURE_FRU_CAP_PROVIDER_INSTANCE = "featureFruCapProviderInstance"
    FEATURE_FRU_CAP_PROVIDER_REF = "featureFruCapProviderRef"
    FEATURE_PROVIDER = "featureProvider"
    FEATURE_PROVIDER_INSTANCE = "featureProviderInstance"
    FILTER_FILTER = "filterFilter"
    FIRMWARE_ACK = "firmwareAck"
    FIRMWARE_ACTIVITY = "firmwareActivity"
    FIRMWARE_ACTIVITY_TRIGGER = "firmwareActivityTrigger"
    FIRMWARE_AUTO_SYNC_POLICY = "firmwareAutoSyncPolicy"
    FIRMWARE_BACKUP_VERSION_HOLDER = "firmwareBackupVersionHolder"
    FIRMWARE_BLADE = "firmwareBlade"
    FIRMWARE_BOOT_DEFINITION = "firmwareBootDefinition"
    FIRMWARE_BOOT_UNIT = "firmwareBootUnit"
    FIRMWARE_BUNDLE_INFO = "firmwareBundleInfo"
    FIRMWARE_BUNDLE_INFO_DIGEST = "firmwareBundleInfoDigest"
    FIRMWARE_BUNDLE_TYPE = "firmwareBundleType"
    FIRMWARE_BUNDLE_TYPE_CAP_PROVIDER = "firmwareBundleTypeCapProvider"
    FIRMWARE_CATALOG_PACK = "firmwareCatalogPack"
    FIRMWARE_CATALOGUE = "firmwareCatalogue"
    FIRMWARE_CHASSIS_COMPONENT_SPEC = "firmwareChassisComponentSpec"
    FIRMWARE_CHASSIS_PACK = "firmwareChassisPack"
    FIRMWARE_CHASSIS_PACK_MOD_IMPACT = "firmwareChassisPackModImpact"
    FIRMWARE_COMP_SOURCE = "firmwareCompSource"
    FIRMWARE_COMP_TARGET = "firmwareCompTarget"
    FIRMWARE_COMPONENT_SPEC = "firmwareComponentSpec"
    FIRMWARE_COMPUTE_HOST_PACK = "firmwareComputeHostPack"
    FIRMWARE_COMPUTE_MGMT_PACK = "firmwareComputeMgmtPack"
    FIRMWARE_CONNECTION_MANAGEMENT_CHASSIS_CONSTRAINT = "firmwareConnectionManagementChassisConstraint"
    FIRMWARE_CONSTRAINTS = "firmwareConstraints"
    FIRMWARE_DEPENDENCY = "firmwareDependency"
    FIRMWARE_DIST_IMAGE = "firmwareDistImage"
    FIRMWARE_DISTRIBUTABLE = "firmwareDistributable"
    FIRMWARE_DISTRIBUTABLE_FSM = "firmwareDistributableFsm"
    FIRMWARE_DISTRIBUTABLE_FSM_STAGE = "firmwareDistributableFsmStage"
    FIRMWARE_DISTRIBUTABLE_FSM_TASK = "firmwareDistributableFsmTask"
    FIRMWARE_DOWNLOADER = "firmwareDownloader"
    FIRMWARE_DOWNLOADER_FSM = "firmwareDownloaderFsm"
    FIRMWARE_DOWNLOADER_FSM_STAGE = "firmwareDownloaderFsmStage"
    FIRMWARE_DOWNLOADER_FSM_TASK = "firmwareDownloaderFsmTask"
    FIRMWARE_DRIVE_SECURITY_CONSTRAINT = "firmwareDriveSecurityConstraint"
    FIRMWARE_DUAL_VIC_CHASSIS_CONSTRAINT = "firmwareDualVicChassisConstraint"
    FIRMWARE_DUAL_VIC_SERVER_CONSTRAINT = "firmwareDualVicServerConstraint"
    FIRMWARE_EXCLUDE_CHASSIS_COMPONENT = "firmwareExcludeChassisComponent"
    FIRMWARE_EXCLUDE_SERVER_COMPONENT = "firmwareExcludeServerComponent"
    FIRMWARE_FILE_UNIT = "firmwareFileUnit"
    FIRMWARE_HOST = "firmwareHost"
    FIRMWARE_HOST_PACK_MOD_IMPACT = "firmwareHostPackModImpact"
    FIRMWARE_IMAGE = "firmwareImage"
    FIRMWARE_IMAGE_FSM = "firmwareImageFsm"
    FIRMWARE_IMAGE_FSM_STAGE = "firmwareImageFsmStage"
    FIRMWARE_IMAGE_FSM_TASK = "firmwareImageFsmTask"
    FIRMWARE_IMAGE_LOCK = "firmwareImageLock"
    FIRMWARE_INFRA = "firmwareInfra"
    FIRMWARE_INFRA_PACK = "firmwareInfraPack"
    FIRMWARE_INSTALL_IMPACT = "firmwareInstallImpact"
    FIRMWARE_INSTALLABLE = "firmwareInstallable"
    FIRMWARE_MODULE = "firmwareModule"
    FIRMWARE_PCHSTORAGE_CONFIG_CONSTRAINT = "firmwarePCHStorageConfigConstraint"
    FIRMWARE_PACK_ITEM = "firmwarePackItem"
    FIRMWARE_PLATFORM_BUNDLE_TYPE_CAP_PROVIDER = "firmwarePlatformBundleTypeCapProvider"
    FIRMWARE_PROCESSOR_TYPE_CONSTRAINT = "firmwareProcessorTypeConstraint"
    FIRMWARE_RACK = "firmwareRack"
    FIRMWARE_RACK_POWER_CAP_CONSTRAINT = "firmwareRackPowerCapConstraint"
    FIRMWARE_RUNNING = "firmwareRunning"
    FIRMWARE_SECOND_CONTROLLER_CHASSIS_CONSTRAINT = "firmwareSecondControllerChassisConstraint"
    FIRMWARE_SECOND_CONTROLLER_SERVER_CONSTRAINT = "firmwareSecondControllerServerConstraint"
    FIRMWARE_SECURE_FPGA = "firmwareSecureFPGA"
    FIRMWARE_SERVER_CHASSIS_CONSTRAINT = "firmwareServerChassisConstraint"
    FIRMWARE_SERVER_TYPE_CONSTRAINT = "firmwareServerTypeConstraint"
    FIRMWARE_SERVICE_PACK = "firmwareServicePack"
    FIRMWARE_SINGLE_PATH_CHASSIS_CONSTRAINT = "firmwareSinglePathChassisConstraint"
    FIRMWARE_SPEC = "firmwareSpec"
    FIRMWARE_STATUS = "firmwareStatus"
    FIRMWARE_SYSTEM = "firmwareSystem"
    FIRMWARE_SYSTEM_COMP_CHECK_RESULT = "firmwareSystemCompCheckResult"
    FIRMWARE_SYSTEM_FSM = "firmwareSystemFsm"
    FIRMWARE_SYSTEM_FSM_STAGE = "firmwareSystemFsmStage"
    FIRMWARE_SYSTEM_FSM_TASK = "firmwareSystemFsmTask"
    FIRMWARE_TPMCONSTRAINT = "firmwareTPMConstraint"
    FIRMWARE_TYPE = "firmwareType"
    FIRMWARE_UCSC_INFO = "firmwareUcscInfo"
    FIRMWARE_UPDATABLE = "firmwareUpdatable"
    FIRMWARE_UPGRADE_CONSTRAINT = "firmwareUpgradeConstraint"
    FIRMWARE_UPGRADE_DETAIL = "firmwareUpgradeDetail"
    FIRMWARE_UPGRADE_INFO = "firmwareUpgradeInfo"
    FIRMWARE_VIC_SLOT_CONSTRAINT = "firmwareVicSlotConstraint"
    FIRMWARE_VNIC_CDN_CONSTRAINT = "firmwareVnicCdnConstraint"
    FIRMWARE_WATERBAY_SIOC_SERVER_CONSTRAINT = "firmwareWaterbaySiocServerConstraint"
    FLOWCTRL_DEFINITION = "flowctrlDefinition"
    FLOWCTRL_ITEM = "flowctrlItem"
    FSM_DEBUG_ACTION = "fsmDebugAction"
    FSM_STATUS = "fsmStatus"
    GE_FILTER = "geFilter"
    GMETA_CLASS = "gmetaClass"
    GMETA_EP = "gmetaEp"
    GMETA_HOLDER = "gmetaHolder"
    GMETA_HOLDER_FSM = "gmetaHolderFsm"
    GMETA_HOLDER_FSM_STAGE = "gmetaHolderFsmStage"
    GMETA_HOLDER_FSM_TASK = "gmetaHolderFsmTask"
    GMETA_POLICY_MAP_ELEMENT = "gmetaPolicyMapElement"
    GMETA_POLICY_MAP_HOLDER = "gmetaPolicyMapHolder"
    GMETA_PROP = "gmetaProp"
    GRAPHICS_CARD = "graphicsCard"
    GRAPHICS_CONTROLLER = "graphicsController"
    GT_FILTER = "gtFilter"
    HOSTIMG_POLICY = "hostimgPolicy"
    HOSTIMG_TARGET = "hostimgTarget"
    ID = "id"
    ID_SET = "idSet"
    IDENT_IDENT_CTX = "identIdentCtx"
    IDENT_IDENT_REQUEST = "identIdentRequest"
    IDENT_IDENT_REQUEST_FSM = "identIdentRequestFsm"
    IDENT_IDENT_REQUEST_FSM_STAGE = "identIdentRequestFsmStage"
    IDENT_IDENT_REQUEST_FSM_TASK = "identIdentRequestFsmTask"
    IDENT_META_SYSTEM = "identMetaSystem"
    IDENT_META_SYSTEM_FSM = "identMetaSystemFsm"
    IDENT_META_SYSTEM_FSM_STAGE = "identMetaSystemFsmStage"
    IDENT_META_SYSTEM_FSM_TASK = "identMetaSystemFsmTask"
    IDENT_META_VERSE = "identMetaVerse"
    IDENT_REQUEST_EP = "identRequestEp"
    IDENT_SYS_INFO = "identSysInfo"
    IMGPROV_POLICY = "imgprovPolicy"
    IMGPROV_TARGET = "imgprovTarget"
    IMGSEC_KEY = "imgsecKey"
    IMGSEC_POLICY = "imgsecPolicy"
    INITIATOR_FC_INITIATOR_EP = "initiatorFcInitiatorEp"
    INITIATOR_GROUP_EP = "initiatorGroupEp"
    INITIATOR_ISCSI_INITIATOR_EP = "initiatorIScsiInitiatorEp"
    INITIATOR_LUN_EP = "initiatorLunEp"
    INITIATOR_MEMBER_EP = "initiatorMemberEp"
    INITIATOR_REQUESTOR_EP = "initiatorRequestorEp"
    INITIATOR_REQUESTOR_GRP_EP = "initiatorRequestorGrpEp"
    INITIATOR_STORE_EP = "initiatorStoreEp"
    INITIATOR_UNIT_EP = "initiatorUnitEp"
    IP_DNS_SUFFIX = "ipDnsSuffix"
    IP_IPV4_DNS = "ipIPv4Dns"
    IP_IPV4_WINS_SERVER = "ipIPv4WinsServer"
    IP_IP_V4_STATIC_ADDR = "ipIpV4StaticAddr"
    IP_IP_V4_STATIC_TARGET_ADDR = "ipIpV4StaticTargetAddr"
    IP_SERVICE_IF = "ipServiceIf"
    IPPOOL_ADDR = "ippoolAddr"
    IPPOOL_BLOCK = "ippoolBlock"
    IPPOOL_IP_V6_ADDR = "ippoolIpV6Addr"
    IPPOOL_IP_V6_BLOCK = "ippoolIpV6Block"
    IPPOOL_IP_V6_POOLED = "ippoolIpV6Pooled"
    IPPOOL_POOL = "ippoolPool"
    IPPOOL_POOLABLE = "ippoolPoolable"
    IPPOOL_POOLED = "ippoolPooled"
    IPPOOL_UNIVERSE = "ippoolUniverse"
    IQNPOOL_ADDR = "iqnpoolAddr"
    IQNPOOL_BLOCK = "iqnpoolBlock"
    IQNPOOL_FORMAT = "iqnpoolFormat"
    IQNPOOL_POOL = "iqnpoolPool"
    IQNPOOL_POOLABLE = "iqnpoolPoolable"
    IQNPOOL_POOLED = "iqnpoolPooled"
    IQNPOOL_TRANSPORT_BLOCK = "iqnpoolTransportBlock"
    IQNPOOL_UNIVERSE = "iqnpoolUniverse"
    ISCSI_AUTH_PROFILE = "iscsiAuthProfile"
    LE_FILTER = "leFilter"
    LICENSE_CONTENTS = "licenseContents"
    LICENSE_DOWNLOADER = "licenseDownloader"
    LICENSE_DOWNLOADER_FSM = "licenseDownloaderFsm"
    LICENSE_DOWNLOADER_FSM_STAGE = "licenseDownloaderFsmStage"
    LICENSE_DOWNLOADER_FSM_TASK = "licenseDownloaderFsmTask"
    LICENSE_EP = "licenseEp"
    LICENSE_FEATURE = "licenseFeature"
    LICENSE_FEATURE_CAP_PROVIDER = "licenseFeatureCapProvider"
    LICENSE_FEATURE_LINE = "licenseFeatureLine"
    LICENSE_FILE = "licenseFile"
    LICENSE_FILE_FSM = "licenseFileFsm"
    LICENSE_FILE_FSM_STAGE = "licenseFileFsmStage"
    LICENSE_FILE_FSM_TASK = "licenseFileFsmTask"
    LICENSE_INSTANCE = "licenseInstance"
    LICENSE_INSTANCE_FSM = "licenseInstanceFsm"
    LICENSE_INSTANCE_FSM_STAGE = "licenseInstanceFsmStage"
    LICENSE_INSTANCE_FSM_TASK = "licenseInstanceFsmTask"
    LICENSE_PROP = "licenseProp"
    LICENSE_SERVER_HOST_ID = "licenseServerHostId"
    LICENSE_SOURCE = "licenseSource"
    LICENSE_SOURCE_FILE = "licenseSourceFile"
    LICENSE_TARGET = "licenseTarget"
    LLDP_ACQUIRED = "lldpAcquired"
    LOGGING_SYNC_OCNS = "loggingSyncOcns"
    LS_AGENT_POLICY = "lsAgentPolicy"
    LS_BINDING = "lsBinding"
    LS_CLONE = "lsClone"
    LS_FC_LOCALE = "lsFcLocale"
    LS_FC_ZONE = "lsFcZone"
    LS_FC_ZONE_GROUP = "lsFcZoneGroup"
    LS_IDENTITY_INFO = "lsIdentityInfo"
    LS_INSTANTIATE_NNAMED_TEMPLATE = "lsInstantiateNNamedTemplate"
    LS_INSTANTIATE_NTEMPLATE = "lsInstantiateNTemplate"
    LS_INSTANTIATE_TEMPLATE = "lsInstantiateTemplate"
    LS_ISSUES = "lsIssues"
    LS_POWER = "lsPower"
    LS_REQUIREMENT = "lsRequirement"
    LS_RESOLVE_TEMPLATES = "lsResolveTemplates"
    LS_SERVER = "lsServer"
    LS_SERVER_ASSOC_CTX = "lsServerAssocCtx"
    LS_SERVER_EXTENSION = "lsServerExtension"
    LS_SERVER_FSM = "lsServerFsm"
    LS_SERVER_FSM_STAGE = "lsServerFsmStage"
    LS_SERVER_FSM_TASK = "lsServerFsmTask"
    LS_TEMPLATISE = "lsTemplatise"
    LS_TIER = "lsTier"
    LS_UUID_HISTORY = "lsUuidHistory"
    LS_VCON_ASSIGN = "lsVConAssign"
    LS_VERSION_BEH = "lsVersionBeh"
    LS_ZONE_INITIATOR_MEMBER = "lsZoneInitiatorMember"
    LS_ZONE_TARGET_MEMBER = "lsZoneTargetMember"
    LSBOOT_BOOT_SECURITY = "lsbootBootSecurity"
    LSBOOT_DEF = "lsbootDef"
    LSBOOT_DEFAULT_LOCAL_IMAGE = "lsbootDefaultLocalImage"
    LSBOOT_EFISHELL = "lsbootEFIShell"
    LSBOOT_EMBEDDED_LOCAL_DISK_IMAGE = "lsbootEmbeddedLocalDiskImage"
    LSBOOT_EMBEDDED_LOCAL_DISK_IMAGE_PATH = "lsbootEmbeddedLocalDiskImagePath"
    LSBOOT_EMBEDDED_LOCAL_LUN_IMAGE = "lsbootEmbeddedLocalLunImage"
    LSBOOT_ISCSI = "lsbootIScsi"
    LSBOOT_ISCSI_IMAGE_PATH = "lsbootIScsiImagePath"
    LSBOOT_LAN = "lsbootLan"
    LSBOOT_LAN_IMAGE_PATH = "lsbootLanImagePath"
    LSBOOT_LOCAL_DISK_IMAGE = "lsbootLocalDiskImage"
    LSBOOT_LOCAL_DISK_IMAGE_PATH = "lsbootLocalDiskImagePath"
    LSBOOT_LOCAL_HDD_IMAGE = "lsbootLocalHddImage"
    LSBOOT_LOCAL_LUN_IMAGE_PATH = "lsbootLocalLunImagePath"
    LSBOOT_LOCAL_STORAGE = "lsbootLocalStorage"
    LSBOOT_NVME = "lsbootNvme"
    LSBOOT_NVME_DISK_SSD = "lsbootNvmeDiskSsd"
    LSBOOT_NVME_PCI_SSD = "lsbootNvmePciSsd"
    LSBOOT_POLICY = "lsbootPolicy"
    LSBOOT_SAN = "lsbootSan"
    LSBOOT_SAN_CAT_SAN_IMAGE = "lsbootSanCatSanImage"
    LSBOOT_SAN_CAT_SAN_IMAGE_PATH = "lsbootSanCatSanImagePath"
    LSBOOT_SAN_IMAGE = "lsbootSanImage"
    LSBOOT_SAN_IMAGE_PATH = "lsbootSanImagePath"
    LSBOOT_STORAGE = "lsbootStorage"
    LSBOOT_UEFIBOOT_PARAM = "lsbootUEFIBootParam"
    LSBOOT_USB_EXTERNAL_IMAGE = "lsbootUsbExternalImage"
    LSBOOT_USB_FLASH_STORAGE_IMAGE = "lsbootUsbFlashStorageImage"
    LSBOOT_USB_INTERNAL_IMAGE = "lsbootUsbInternalImage"
    LSBOOT_VIRTUAL_MEDIA = "lsbootVirtualMedia"
    LSMAINT_ACK = "lsmaintAck"
    LSMAINT_MAINT_POLICY = "lsmaintMaintPolicy"
    LSTORAGE_CONTROLLER_DEF = "lstorageControllerDef"
    LSTORAGE_CONTROLLER_MODE_CONFIG = "lstorageControllerModeConfig"
    LSTORAGE_CONTROLLER_QUALIFIER = "lstorageControllerQualifier"
    LSTORAGE_CONTROLLER_REF = "lstorageControllerRef"
    LSTORAGE_CREATE_ZONING_FROM_INV = "lstorageCreateZoningFromInv"
    LSTORAGE_DAS_SCSI_LUN = "lstorageDasScsiLun"
    LSTORAGE_DISK_GROUP_CONFIG_DEF = "lstorageDiskGroupConfigDef"
    LSTORAGE_DISK_GROUP_CONFIG_POLICY = "lstorageDiskGroupConfigPolicy"
    LSTORAGE_DISK_GROUP_QUALIFIER = "lstorageDiskGroupQualifier"
    LSTORAGE_DISK_SLOT = "lstorageDiskSlot"
    LSTORAGE_DISK_ZONING_CONFIG_DEF = "lstorageDiskZoningConfigDef"
    LSTORAGE_DISK_ZONING_POLICY = "lstorageDiskZoningPolicy"
    LSTORAGE_DRIVE_SECURITY = "lstorageDriveSecurity"
    LSTORAGE_LOCAL = "lstorageLocal"
    LSTORAGE_LOCAL_DEF = "lstorageLocalDef"
    LSTORAGE_LOCAL_DISK_CONFIG_REF = "lstorageLocalDiskConfigRef"
    LSTORAGE_LOCAL_DISK_REF = "lstorageLocalDiskRef"
    LSTORAGE_LOGIN = "lstorageLogin"
    LSTORAGE_LUN_SET_CONFIG = "lstorageLunSetConfig"
    LSTORAGE_LUN_SET_DISK_SLOT = "lstorageLunSetDiskSlot"
    LSTORAGE_PROFILE = "lstorageProfile"
    LSTORAGE_PROFILE_BINDING = "lstorageProfileBinding"
    LSTORAGE_PROFILE_DEF = "lstorageProfileDef"
    LSTORAGE_REMOTE = "lstorageRemote"
    LSTORAGE_REMOTE_DEF = "lstorageRemoteDef"
    LSTORAGE_SAS_EXPANDER_CONFIG_POLICY = "lstorageSasExpanderConfigPolicy"
    LSTORAGE_SECURITY = "lstorageSecurity"
    LSTORAGE_VIRTUAL_DRIVE_DEF = "lstorageVirtualDriveDef"
    LT_FILTER = "ltFilter"
    MACPOOL_ADDR = "macpoolAddr"
    MACPOOL_BLOCK = "macpoolBlock"
    MACPOOL_FORMAT = "macpoolFormat"
    MACPOOL_POOL = "macpoolPool"
    MACPOOL_POOLABLE = "macpoolPoolable"
    MACPOOL_POOLED = "macpoolPooled"
    MACPOOL_UNIVERSE = "macpoolUniverse"
    MEMORY_ARRAY = "memoryArray"
    MEMORY_ARRAY_ENV_STATS = "memoryArrayEnvStats"
    MEMORY_ARRAY_ENV_STATS_HIST = "memoryArrayEnvStatsHist"
    MEMORY_BUFFER_UNIT = "memoryBufferUnit"
    MEMORY_BUFFER_UNIT_ENV_STATS = "memoryBufferUnitEnvStats"
    MEMORY_BUFFER_UNIT_ENV_STATS_HIST = "memoryBufferUnitEnvStatsHist"
    MEMORY_ERROR_STATS = "memoryErrorStats"
    MEMORY_PERSISTENT_MEMORY_CONFIG_RESULT = "memoryPersistentMemoryConfigResult"
    MEMORY_PERSISTENT_MEMORY_CONFIGURATION = "memoryPersistentMemoryConfiguration"
    MEMORY_PERSISTENT_MEMORY_GOAL = "memoryPersistentMemoryGoal"
    MEMORY_PERSISTENT_MEMORY_LOCAL_SECURITY = "memoryPersistentMemoryLocalSecurity"
    MEMORY_PERSISTENT_MEMORY_LOGICAL_NAMESPACE = "memoryPersistentMemoryLogicalNamespace"
    MEMORY_PERSISTENT_MEMORY_NAMESPACE = "memoryPersistentMemoryNamespace"
    MEMORY_PERSISTENT_MEMORY_NAMESPACE_CONFIG_RESULT = "memoryPersistentMemoryNamespaceConfigResult"
    MEMORY_PERSISTENT_MEMORY_POLICY = "memoryPersistentMemoryPolicy"
    MEMORY_PERSISTENT_MEMORY_REGION = "memoryPersistentMemoryRegion"
    MEMORY_PERSISTENT_MEMORY_SECURITY = "memoryPersistentMemorySecurity"
    MEMORY_PERSISTENT_MEMORY_UNIT = "memoryPersistentMemoryUnit"
    MEMORY_QUAL = "memoryQual"
    MEMORY_RUNTIME = "memoryRuntime"
    MEMORY_RUNTIME_HIST = "memoryRuntimeHist"
    MEMORY_UNIT = "memoryUnit"
    MEMORY_UNIT_ENV_STATS = "memoryUnitEnvStats"
    MEMORY_UNIT_ENV_STATS_HIST = "memoryUnitEnvStatsHist"
    METHOD_RESOLVE_VESSEL = "methodResolveVessel"
    METHOD_VESSEL = "methodVessel"
    MGMT_ACCESS_POLICY = "mgmtAccessPolicy"
    MGMT_ACCESS_POLICY_ITEM = "mgmtAccessPolicyItem"
    MGMT_ACCESS_PORT = "mgmtAccessPort"
    MGMT_BACKUP = "mgmtBackup"
    MGMT_BACKUP_EXPORT_EXT_POLICY = "mgmtBackupExportExtPolicy"
    MGMT_BACKUP_FSM = "mgmtBackupFsm"
    MGMT_BACKUP_FSM_STAGE = "mgmtBackupFsmStage"
    MGMT_BACKUP_FSM_TASK = "mgmtBackupFsmTask"
    MGMT_BACKUP_POLICY = "mgmtBackupPolicy"
    MGMT_BACKUP_POLICY_CONFIG = "mgmtBackupPolicyConfig"
    MGMT_BACKUP_POLICY_FSM = "mgmtBackupPolicyFsm"
    MGMT_BACKUP_POLICY_FSM_STAGE = "mgmtBackupPolicyFsmStage"
    MGMT_CFG_EXPORT_POLICY = "mgmtCfgExportPolicy"
    MGMT_CFG_EXPORT_POLICY_FSM = "mgmtCfgExportPolicyFsm"
    MGMT_CFG_EXPORT_POLICY_FSM_STAGE = "mgmtCfgExportPolicyFsmStage"
    MGMT_CIMC_SECURE_BOOT = "mgmtCimcSecureBoot"
    MGMT_CMC_SECURE_BOOT = "mgmtCmcSecureBoot"
    MGMT_CONNECTION = "mgmtConnection"
    MGMT_CONTROLLER = "mgmtController"
    MGMT_CONTROLLER_FSM = "mgmtControllerFsm"
    MGMT_CONTROLLER_FSM_STAGE = "mgmtControllerFsmStage"
    MGMT_CONTROLLER_FSM_TASK = "mgmtControllerFsmTask"
    MGMT_DB_STATE = "mgmtDbState"
    MGMT_ENTITY = "mgmtEntity"
    MGMT_EXPORT_POLICY_FSM = "mgmtExportPolicyFsm"
    MGMT_EXPORT_POLICY_FSM_STAGE = "mgmtExportPolicyFsmStage"
    MGMT_EXPORT_POLICY_FSM_TASK = "mgmtExportPolicyFsmTask"
    MGMT_HEALTH_ATTR = "mgmtHealthAttr"
    MGMT_HEALTH_STATUS = "mgmtHealthStatus"
    MGMT_IPV6_IF_ADDR = "mgmtIPv6IfAddr"
    MGMT_IPV6_IF_ADDR_FSM = "mgmtIPv6IfAddrFsm"
    MGMT_IPV6_IF_ADDR_FSM_STAGE = "mgmtIPv6IfAddrFsmStage"
    MGMT_IPV6_IF_ADDR_FSM_TASK = "mgmtIPv6IfAddrFsmTask"
    MGMT_IPV6_IF_CONFIG = "mgmtIPv6IfConfig"
    MGMT_IF = "mgmtIf"
    MGMT_IF_FSM = "mgmtIfFsm"
    MGMT_IF_FSM_STAGE = "mgmtIfFsmStage"
    MGMT_IF_FSM_TASK = "mgmtIfFsmTask"
    MGMT_IMPORTER = "mgmtImporter"
    MGMT_IMPORTER_FSM = "mgmtImporterFsm"
    MGMT_IMPORTER_FSM_STAGE = "mgmtImporterFsmStage"
    MGMT_IMPORTER_FSM_TASK = "mgmtImporterFsmTask"
    MGMT_INBAND_PROFILE = "mgmtInbandProfile"
    MGMT_INT_AUTH_POLICY = "mgmtIntAuthPolicy"
    MGMT_INTERFACE = "mgmtInterface"
    MGMT_KMIP = "mgmtKmip"
    MGMT_KMIP_CERT_POLICY = "mgmtKmipCertPolicy"
    MGMT_KVM_CERTIFICATE = "mgmtKvmCertificate"
    MGMT_LEADER_ENTITY = "mgmtLeaderEntity"
    MGMT_PMON_ENTRY = "mgmtPmonEntry"
    MGMT_PROF_DERIVED_INTERFACE = "mgmtProfDerivedInterface"
    MGMT_RESOLVE_BACKUP_FILENAMES = "mgmtResolveBackupFilenames"
    MGMT_SECURITY = "mgmtSecurity"
    MGMT_SPDM_CERTIFICATE = "mgmtSpdmCertificate"
    MGMT_SPDM_CERTIFICATE_DATA = "mgmtSpdmCertificateData"
    MGMT_SPDM_CERTIFICATE_INVENTORY = "mgmtSpdmCertificateInventory"
    MGMT_SPDM_CERTIFICATE_POLICY = "mgmtSpdmCertificatePolicy"
    MGMT_SW_PERSONALITIES = "mgmtSwPersonalities"
    MGMT_SW_PERSONALITIES_INVENTORY = "mgmtSwPersonalitiesInventory"
    MGMT_SW_PERSONALITY = "mgmtSwPersonality"
    MGMT_USB_NIC_MGMT_IF = "mgmtUsbNicMgmtIf"
    MGMT_VNET = "mgmtVnet"
    MO_INV_KV = "moInvKv"
    MO_IP_V4_ADDR_KV = "moIpV4AddrKv"
    MO_IP_V6_ADDR_KV = "moIpV6AddrKv"
    MO_KV = "moKv"
    MO_KV_CFG_HOLDER = "moKvCfgHolder"
    MO_KV_INV_HOLDER = "moKvInvHolder"
    MO_VNIC_KV = "moVnicKv"
    MOREF_FRU_REF = "morefFruRef"
    MOREF_IMPORT_ROOT = "morefImportRoot"
    MOREF_IMPORT_ROOT_FSM = "morefImportRootFsm"
    MOREF_IMPORT_ROOT_FSM_STAGE = "morefImportRootFsmStage"
    MOREF_IMPORT_ROOT_FSM_TASK = "morefImportRootFsmTask"
    MOREF_PROP = "morefProp"
    MOREF_REF = "morefRef"
    NE_FILTER = "neFilter"
    NETWORK_ELEMENT = "networkElement"
    NETWORK_IF_STATS = "networkIfStats"
    NETWORK_LAN_NEIGHBOR_ENTRY = "networkLanNeighborEntry"
    NETWORK_LAN_NEIGHBORS = "networkLanNeighbors"
    NETWORK_LIMIT = "networkLimit"
    NETWORK_LLDP_NEIGHBOR_ENTRY = "networkLldpNeighborEntry"
    NETWORK_LLDP_NEIGHBORS = "networkLldpNeighbors"
    NETWORK_OPER_LEVEL = "networkOperLevel"
    NETWORK_SAN_NEIGHBOR_ENTRY = "networkSanNeighborEntry"
    NETWORK_SAN_NEIGHBORS = "networkSanNeighbors"
    NFS_EP = "nfsEp"
    NFS_MOUNT_DEF = "nfsMountDef"
    NFS_MOUNT_DEF_FSM = "nfsMountDefFsm"
    NFS_MOUNT_DEF_FSM_STAGE = "nfsMountDefFsmStage"
    NFS_MOUNT_DEF_FSM_TASK = "nfsMountDefFsmTask"
    NFS_MOUNT_INST = "nfsMountInst"
    NFS_MOUNT_INST_FSM = "nfsMountInstFsm"
    NFS_MOUNT_INST_FSM_STAGE = "nfsMountInstFsmStage"
    NFS_MOUNT_INST_FSM_TASK = "nfsMountInstFsmTask"
    NOT_FILTER = "notFilter"
    NWCTRL_DEFINITION = "nwctrlDefinition"
    OBSERVE_FILTER = "observeFilter"
    OBSERVE_OBSERVED = "observeObserved"
    OBSERVE_OBSERVED_CONT = "observeObservedCont"
    OBSERVE_OBSERVED_FSM = "observeObservedFsm"
    OBSERVE_OBSERVED_FSM_STAGE = "observeObservedFsmStage"
    OBSERVE_OBSERVED_FSM_TASK = "observeObservedFsmTask"
    OR_FILTER = "orFilter"
    ORG_ORG = "orgOrg"
    ORG_RESOLVE_ELEMENTS = "orgResolveElements"
    ORG_RESOLVE_LOGICAL_PARENTS = "orgResolveLogicalParents"
    ORG_SOURCE_MASK = "orgSourceMask"
    OS_ARPLINK_MONITORING_POLICY = "osARPLinkMonitoringPolicy"
    OS_ARPTARGET = "osARPTarget"
    OS_AGENT = "osAgent"
    OS_ETH_BOND_INTF = "osEthBondIntf"
    OS_ETH_BOND_MODE_ACTIVE_BACKUP = "osEthBondModeActiveBackup"
    OS_ETH_BOND_MODE_BALANCED_ALB = "osEthBondModeBalancedALB"
    OS_ETH_BOND_MODE_BALANCED_RR = "osEthBondModeBalancedRR"
    OS_ETH_BOND_MODE_BALANCED_TLB = "osEthBondModeBalancedTLB"
    OS_ETH_BOND_MODE_BALANCED_XOR = "osEthBondModeBalancedXOR"
    OS_ETH_BOND_MODE_BROADCAST = "osEthBondModeBroadcast"
    OS_ETH_INTF = "osEthIntf"
    OS_INSTANCE = "osInstance"
    OS_MII_LINK_MONITORING_POLICY = "osMiiLinkMonitoringPolicy"
    OS_PRIMARY_SLAVE = "osPrimarySlave"
    PAIR = "pair"
    PCI_EQUIP_SLOT = "pciEquipSlot"
    PCI_LINK = "pciLink"
    PCI_SWITCH = "pciSwitch"
    PCI_UNIT = "pciUnit"
    PFC_WATCH_DOG = "pfcWatchDog"
    PFC_WATCH_DOG_FSM = "pfcWatchDogFsm"
    PFC_WATCH_DOG_FSM_STAGE = "pfcWatchDogFsmStage"
    PFC_WATCH_DOG_FSM_TASK = "pfcWatchDogFsmTask"
    PKI_CERT_REQ = "pkiCertReq"
    PKI_EP = "pkiEp"
    PKI_EP_FSM = "pkiEpFsm"
    PKI_EP_FSM_STAGE = "pkiEpFsmStage"
    PKI_EP_FSM_TASK = "pkiEpFsmTask"
    PKI_KEY_RING = "pkiKeyRing"
    PKI_TP = "pkiTP"
    POLICY_CENTRALE_SYNC = "policyCentraleSync"
    POLICY_CHILD_CLASS = "policyChildClass"
    POLICY_COMMUNICATION = "policyCommunication"
    POLICY_CONFIG_BACKUP = "policyConfigBackup"
    POLICY_CONFIG_ERROR = "policyConfigError"
    POLICY_CONTEXT = "policyContext"
    POLICY_CONTROL_EP = "policyControlEp"
    POLICY_CONTROL_EP_FSM = "policyControlEpFsm"
    POLICY_CONTROL_EP_FSM_STAGE = "policyControlEpFsmStage"
    POLICY_CONTROL_EP_FSM_TASK = "policyControlEpFsmTask"
    POLICY_CONTROLLED_INSTANCE = "policyControlledInstance"
    POLICY_CONTROLLED_TYPE = "policyControlledType"
    POLICY_CONTROLLED_TYPE_FSM = "policyControlledTypeFsm"
    POLICY_CONTROLLED_TYPE_FSM_STAGE = "policyControlledTypeFsmStage"
    POLICY_CONTROLLED_TYPE_FSM_TASK = "policyControlledTypeFsmTask"
    POLICY_DATE_TIME = "policyDateTime"
    POLICY_DEST_CLASS = "policyDestClass"
    POLICY_DEST_EP = "policyDestEp"
    POLICY_DIGEST = "policyDigest"
    POLICY_DISCOVERY = "policyDiscovery"
    POLICY_DNS = "policyDns"
    POLICY_ELEMENT = "policyElement"
    POLICY_EQUIPMENT = "policyEquipment"
    POLICY_FAULT = "policyFault"
    POLICY_ID_RESOLVE_POLICY = "policyIdResolvePolicy"
    POLICY_INFRA_FIRMWARE = "policyInfraFirmware"
    POLICY_LOCAL_MAP = "policyLocalMap"
    POLICY_MEP = "policyMEp"
    POLICY_MONITORING = "policyMonitoring"
    POLICY_POLICY_DEST_CLASS = "policyPolicyDestClass"
    POLICY_POLICY_EP = "policyPolicyEp"
    POLICY_POLICY_REQUESTOR = "policyPolicyRequestor"
    POLICY_POLICY_SCOPE = "policyPolicyScope"
    POLICY_POLICY_SCOPE_CONT = "policyPolicyScopeCont"
    POLICY_POLICY_SCOPE_CONT_FSM = "policyPolicyScopeContFsm"
    POLICY_POLICY_SCOPE_CONT_FSM_STAGE = "policyPolicyScopeContFsmStage"
    POLICY_POLICY_SCOPE_CONT_FSM_TASK = "policyPolicyScopeContFsmTask"
    POLICY_POLICY_SCOPE_CONTEXT = "policyPolicyScopeContext"
    POLICY_POLICY_SCOPE_FSM = "policyPolicyScopeFsm"
    POLICY_POLICY_SCOPE_FSM_STAGE = "policyPolicyScopeFsmStage"
    POLICY_POLICY_SCOPE_FSM_TASK = "policyPolicyScopeFsmTask"
    POLICY_PORT_CONFIG = "policyPortConfig"
    POLICY_POWER_MGMT = "policyPowerMgmt"
    POLICY_PSU = "policyPsu"
    POLICY_REF_REQ = "policyRefReq"
    POLICY_REQUESTOR = "policyRequestor"
    POLICY_REQUESTOR_FSM = "policyRequestorFsm"
    POLICY_REQUESTOR_FSM_STAGE = "policyRequestorFsmStage"
    POLICY_REQUESTOR_FSM_TASK = "policyRequestorFsmTask"
    POLICY_RESOLVE_NAMES = "policyResolveNames"
    POLICY_SCOPE = "policyScope"
    POLICY_SECURITY = "policySecurity"
    POLICY_SET_CENTRALE_STORAGE = "policySetCentraleStorage"
    POLICY_SOURCE_APP = "policySourceApp"
    POLICY_STORAGE_AUTO_CONFIG = "policyStorageAutoConfig"
    POLICY_SYSTEM_EP = "policySystemEp"
    POOL_RESOLVE_IN_SCOPE = "poolResolveInScope"
    PORT_DOMAIN_EP = "portDomainEp"
    PORT_GROUP = "portGroup"
    PORT_PIO_FSM = "portPIoFsm"
    PORT_PIO_FSM_STAGE = "portPIoFsmStage"
    PORT_PIO_FSM_TASK = "portPIoFsmTask"
    PORT_SUB_GROUP = "portSubGroup"
    PORT_TRUST_MODE = "portTrustMode"
    POWER_BUDGET = "powerBudget"
    POWER_CHASSIS_MEMBER = "powerChassisMember"
    POWER_EP = "powerEp"
    POWER_FIMEMBER = "powerFIMember"
    POWER_FEX_MEMBER = "powerFexMember"
    POWER_GROUP = "powerGroup"
    POWER_GROUP_ADDITION_POLICY = "powerGroupAdditionPolicy"
    POWER_GROUP_QUAL = "powerGroupQual"
    POWER_GROUP_STATS = "powerGroupStats"
    POWER_GROUP_STATS_HIST = "powerGroupStatsHist"
    POWER_MGMT_POLICY = "powerMgmtPolicy"
    POWER_PLACEMENT = "powerPlacement"
    POWER_POLICY = "powerPolicy"
    POWER_PRIO_WGHT = "powerPrioWght"
    POWER_PROFILED_POWER = "powerProfiledPower"
    POWER_RACK_UNIT_MEMBER = "powerRackUnitMember"
    PROC_DOER = "procDoer"
    PROC_MANAGER = "procManager"
    PROC_PRT = "procPrt"
    PROC_PRT_COUNTS = "procPrtCounts"
    PROC_STIMULUS_COUNTS = "procStimulusCounts"
    PROC_SVC = "procSvc"
    PROC_TX_COUNTS = "procTxCounts"
    PROCESSOR_CACHE_MEM_STATS = "processorCacheMemStats"
    PROCESSOR_CORE = "processorCore"
    PROCESSOR_ENV_STATS = "processorEnvStats"
    PROCESSOR_ENV_STATS_HIST = "processorEnvStatsHist"
    PROCESSOR_ERROR_STATS = "processorErrorStats"
    PROCESSOR_EXEC_STATS = "processorExecStats"
    PROCESSOR_IOSTATS = "processorIOStats"
    PROCESSOR_MISC_STATS = "processorMiscStats"
    PROCESSOR_PCIBUS_STATS = "processorPCIBusStats"
    PROCESSOR_PMUSTATS = "processorPMUStats"
    PROCESSOR_QUAL = "processorQual"
    PROCESSOR_RUNTIME = "processorRuntime"
    PROCESSOR_RUNTIME_HIST = "processorRuntimeHist"
    PROCESSOR_SECURITY_STATS = "processorSecurityStats"
    PROCESSOR_THREAD = "processorThread"
    PROCESSOR_UNIT = "processorUnit"
    PROCESSOR_UNIT_ASSOC_CTX = "processorUnitAssocCtx"
    QOSCLASS_DEFINITION = "qosclassDefinition"
    QOSCLASS_DEFINITION_FSM = "qosclassDefinitionFsm"
    QOSCLASS_DEFINITION_FSM_STAGE = "qosclassDefinitionFsmStage"
    QOSCLASS_DEFINITION_FSM_TASK = "qosclassDefinitionFsmTask"
    QOSCLASS_ETH_BE = "qosclassEthBE"
    QOSCLASS_ETH_CLASSIFIED = "qosclassEthClassified"
    QOSCLASS_FC = "qosclassFc"
    QOSCLASS_SLOW_DRAIN = "qosclassSlowDrain"
    QOSCLASS_SLOW_DRAIN_FSM = "qosclassSlowDrainFsm"
    QOSCLASS_SLOW_DRAIN_FSM_STAGE = "qosclassSlowDrainFsmStage"
    QOSCLASS_SLOW_DRAIN_FSM_TASK = "qosclassSlowDrainFsmTask"
    QUERYRESULT_DEPENDENCY = "queryresultDependency"
    QUERYRESULT_USAGE = "queryresultUsage"
    SECURITY_UNIT = "securityUnit"
    SES_DISK_SLOT_EP = "sesDiskSlotEp"
    SES_ENCLOSURE = "sesEnclosure"
    SOL_CONFIG = "solConfig"
    SOL_IF = "solIf"
    SOL_POLICY = "solPolicy"
    STATS_CLEAR_INTERVAL = "statsClearInterval"
    STATS_COLLECTION_POLICY = "statsCollectionPolicy"
    STATS_COLLECTION_POLICY_FSM = "statsCollectionPolicyFsm"
    STATS_COLLECTION_POLICY_FSM_STAGE = "statsCollectionPolicyFsmStage"
    STATS_COLLECTION_POLICY_FSM_TASK = "statsCollectionPolicyFsmTask"
    STATS_HOLDER = "statsHolder"
    STATS_RESOLVE_THRESHOLD_POLICY = "statsResolveThresholdPolicy"
    STATS_SUBSCRIBE = "statsSubscribe"
    STATS_THR32_DEFINITION = "statsThr32Definition"
    STATS_THR32_VALUE = "statsThr32Value"
    STATS_THR64_DEFINITION = "statsThr64Definition"
    STATS_THR64_VALUE = "statsThr64Value"
    STATS_THR_FLOAT_DEFINITION = "statsThrFloatDefinition"
    STATS_THR_FLOAT_VALUE = "statsThrFloatValue"
    STATS_THRESHOLD_CLASS = "statsThresholdClass"
    STATS_THRESHOLD_POLICY = "statsThresholdPolicy"
    STORAGE_AUTH_KEY = "storageAuthKey"
    STORAGE_CONNECTION_DEF = "storageConnectionDef"
    STORAGE_CONNECTION_POLICY = "storageConnectionPolicy"
    STORAGE_CONTROLLER = "storageController"
    STORAGE_CONTROLLER_EP = "storageControllerEp"
    STORAGE_CONTROLLER_REF = "storageControllerRef"
    STORAGE_CONTROLLER_REFERENCE = "storageControllerReference"
    STORAGE_DISK_ENV_STATS = "storageDiskEnvStats"
    STORAGE_DISK_ENV_STATS_HIST = "storageDiskEnvStatsHist"
    STORAGE_DOMAIN_EP = "storageDomainEp"
    STORAGE_DRIVE = "storageDrive"
    STORAGE_EMBEDDED_STORAGE = "storageEmbeddedStorage"
    STORAGE_ENCLOSURE = "storageEnclosure"
    STORAGE_ENCLOSURE_CAP = "storageEnclosureCap"
    STORAGE_ENCLOSURE_DISK_SLOT_EP = "storageEnclosureDiskSlotEp"
    STORAGE_ENCLOSURE_FSM = "storageEnclosureFsm"
    STORAGE_ENCLOSURE_FSM_STAGE = "storageEnclosureFsmStage"
    STORAGE_ENCLOSURE_FSM_TASK = "storageEnclosureFsmTask"
    STORAGE_ENCLOSURE_LOCAL_DISK_CONFIG = "storageEnclosureLocalDiskConfig"
    STORAGE_EP_USER = "storageEpUser"
    STORAGE_ETHER_IF = "storageEtherIf"
    STORAGE_FC_IF = "storageFcIf"
    STORAGE_FC_TARGET_EP = "storageFcTargetEp"
    STORAGE_FC_TARGET_IF = "storageFcTargetIf"
    STORAGE_FLEX_FLASH_CARD = "storageFlexFlashCard"
    STORAGE_FLEX_FLASH_CONTROLLER = "storageFlexFlashController"
    STORAGE_FLEX_FLASH_CONTROLLER_FSM = "storageFlexFlashControllerFsm"
    STORAGE_FLEX_FLASH_CONTROLLER_FSM_STAGE = "storageFlexFlashControllerFsmStage"
    STORAGE_FLEX_FLASH_CONTROLLER_FSM_TASK = "storageFlexFlashControllerFsmTask"
    STORAGE_FLEX_FLASH_DRIVE = "storageFlexFlashDrive"
    STORAGE_FLEX_FLASH_VIRTUAL_DRIVE = "storageFlexFlashVirtualDrive"
    STORAGE_HDD_MOTHER_BOARD_TEMP_STATS = "storageHddMotherBoardTempStats"
    STORAGE_HDD_MOTHER_BOARD_TEMP_STATS_HIST = "storageHddMotherBoardTempStatsHist"
    STORAGE_ISCSI_TARGET_IF = "storageIScsiTargetIf"
    STORAGE_INI_GROUP = "storageIniGroup"
    STORAGE_INITIATOR = "storageInitiator"
    STORAGE_ITEM = "storageItem"
    STORAGE_LOCAL_DISK = "storageLocalDisk"
    STORAGE_LOCAL_DISK_CONFIG_DEF = "storageLocalDiskConfigDef"
    STORAGE_LOCAL_DISK_CONFIG_POLICY = "storageLocalDiskConfigPolicy"
    STORAGE_LOCAL_DISK_EP = "storageLocalDiskEp"
    STORAGE_LOCAL_DISK_FSM = "storageLocalDiskFsm"
    STORAGE_LOCAL_DISK_FSM_STAGE = "storageLocalDiskFsmStage"
    STORAGE_LOCAL_DISK_FSM_TASK = "storageLocalDiskFsmTask"
    STORAGE_LOCAL_DISK_PARTITION = "storageLocalDiskPartition"
    STORAGE_LOCAL_DISK_SLOT_EP = "storageLocalDiskSlotEp"
    STORAGE_LOCAL_LUN = "storageLocalLun"
    STORAGE_LUN_DISK = "storageLunDisk"
    STORAGE_LUN_RESOURCE_SELECTION_LOG = "storageLunResourceSelectionLog"
    STORAGE_MEZZ_FLASH_LIFE = "storageMezzFlashLife"
    STORAGE_MINI_STORAGE = "storageMiniStorage"
    STORAGE_NODE_EP = "storageNodeEp"
    STORAGE_NVME_STATS = "storageNvmeStats"
    STORAGE_NVME_STATS_HIST = "storageNvmeStatsHist"
    STORAGE_NVME_STORAGE = "storageNvmeStorage"
    STORAGE_NVME_SWITCH = "storageNvmeSwitch"
    STORAGE_ONBOARD_DEVICE = "storageOnboardDevice"
    STORAGE_OPERATION = "storageOperation"
    STORAGE_QUAL = "storageQual"
    STORAGE_RAID_BATTERY = "storageRaidBattery"
    STORAGE_SAS_EXPANDER = "storageSasExpander"
    STORAGE_SAS_LINK_DESCRIPTOR = "storageSasLinkDescriptor"
    STORAGE_SAS_PORT = "storageSasPort"
    STORAGE_SAS_PORT_DESCRIPTOR = "storageSasPortDescriptor"
    STORAGE_SAS_UP_LINK = "storageSasUpLink"
    STORAGE_SCSI_LUN_REF = "storageScsiLunRef"
    STORAGE_SSD_HEALTH_STATS = "storageSsdHealthStats"
    STORAGE_SSD_HEALTH_STATS_HIST = "storageSsdHealthStatsHist"
    STORAGE_SYSTEM = "storageSystem"
    STORAGE_SYSTEM_FSM = "storageSystemFsm"
    STORAGE_SYSTEM_FSM_STAGE = "storageSystemFsmStage"
    STORAGE_SYSTEM_FSM_TASK = "storageSystemFsmTask"
    STORAGE_TRANSPORTABLE_FLASH_MODULE = "storageTransportableFlashModule"
    STORAGE_VDMEMBER_EP = "storageVDMemberEp"
    STORAGE_VIRTUAL_DRIVE = "storageVirtualDrive"
    STORAGE_VIRTUAL_DRIVE_CONTAINER = "storageVirtualDriveContainer"
    STORAGE_VIRTUAL_DRIVE_EP = "storageVirtualDriveEp"
    STORAGE_VIRTUAL_DRIVE_REF = "storageVirtualDriveRef"
    STORAGE_VSAN_REF = "storageVsanRef"
    SW_ACCESS_DOMAIN = "swAccessDomain"
    SW_ACCESS_DOMAIN_FSM = "swAccessDomainFsm"
    SW_ACCESS_DOMAIN_FSM_STAGE = "swAccessDomainFsmStage"
    SW_ACCESS_DOMAIN_FSM_TASK = "swAccessDomainFsmTask"
    SW_ACCESS_EP = "swAccessEp"
    SW_CARD_ENV_STATS = "swCardEnvStats"
    SW_CARD_ENV_STATS_HIST = "swCardEnvStatsHist"
    SW_CMCLAN = "swCmclan"
    SW_ENV_STATS = "swEnvStats"
    SW_ENV_STATS_HIST = "swEnvStatsHist"
    SW_ETH_ESTC_EP = "swEthEstcEp"
    SW_ETH_ESTC_PC = "swEthEstcPc"
    SW_ETH_LAN_BORDER = "swEthLanBorder"
    SW_ETH_LAN_BORDER_FSM = "swEthLanBorderFsm"
    SW_ETH_LAN_BORDER_FSM_STAGE = "swEthLanBorderFsmStage"
    SW_ETH_LAN_BORDER_FSM_TASK = "swEthLanBorderFsmTask"
    SW_ETH_LAN_EP = "swEthLanEp"
    SW_ETH_LAN_FLOW_MON = "swEthLanFlowMon"
    SW_ETH_LAN_FLOW_MON_FSM = "swEthLanFlowMonFsm"
    SW_ETH_LAN_FLOW_MON_FSM_STAGE = "swEthLanFlowMonFsmStage"
    SW_ETH_LAN_FLOW_MON_FSM_TASK = "swEthLanFlowMonFsmTask"
    SW_ETH_LAN_MON = "swEthLanMon"
    SW_ETH_LAN_PC = "swEthLanPc"
    SW_ETH_MON = "swEthMon"
    SW_ETH_MON_DEST_EP = "swEthMonDestEp"
    SW_ETH_MON_FSM = "swEthMonFsm"
    SW_ETH_MON_FSM_STAGE = "swEthMonFsmStage"
    SW_ETH_MON_FSM_TASK = "swEthMonFsmTask"
    SW_ETH_MON_SRC_EP = "swEthMonSrcEp"
    SW_ETH_TARGET_EP = "swEthTargetEp"
    SW_ETHER_PORT = "swEtherPort"
    SW_EXT_UTILITY = "swExtUtility"
    SW_EXT_UTILITY_FSM = "swExtUtilityFsm"
    SW_EXT_UTILITY_FSM_STAGE = "swExtUtilityFsmStage"
    SW_EXT_UTILITY_FSM_TASK = "swExtUtilityFsmTask"
    SW_FABRIC_ZONE_NS = "swFabricZoneNs"
    SW_FABRIC_ZONE_NS_OVERRIDE = "swFabricZoneNsOverride"
    SW_FC_ENDPOINT = "swFcEndpoint"
    SW_FC_ESTC_EP = "swFcEstcEp"
    SW_FC_MON = "swFcMon"
    SW_FC_MON_DEST_EP = "swFcMonDestEp"
    SW_FC_MON_FSM = "swFcMonFsm"
    SW_FC_MON_FSM_STAGE = "swFcMonFsmStage"
    SW_FC_MON_FSM_TASK = "swFcMonFsmTask"
    SW_FC_MON_SRC_EP = "swFcMonSrcEp"
    SW_FC_SAN_BORDER = "swFcSanBorder"
    SW_FC_SAN_BORDER_FSM = "swFcSanBorderFsm"
    SW_FC_SAN_BORDER_FSM_STAGE = "swFcSanBorderFsmStage"
    SW_FC_SAN_BORDER_FSM_TASK = "swFcSanBorderFsmTask"
    SW_FC_SAN_EP = "swFcSanEp"
    SW_FC_SAN_MON = "swFcSanMon"
    SW_FC_SAN_PC = "swFcSanPc"
    SW_FC_SERVER_ZONE_GROUP = "swFcServerZoneGroup"
    SW_FC_USER_ZONE = "swFcUserZone"
    SW_FC_USER_ZONE_GROUP = "swFcUserZoneGroup"
    SW_FC_ZONE = "swFcZone"
    SW_FC_ZONE_SET = "swFcZoneSet"
    SW_FCOE_ESTC_EP = "swFcoeEstcEp"
    SW_FCOE_SAN_EP = "swFcoeSanEp"
    SW_FCOE_SAN_PC = "swFcoeSanPc"
    SW_IP_ROUTE = "swIpRoute"
    SW_NFEXPORTER_REF = "swNFExporterRef"
    SW_NETFLOW_EXPORTER = "swNetflowExporter"
    SW_NETFLOW_MON_SESSION = "swNetflowMonSession"
    SW_NETFLOW_MONITOR = "swNetflowMonitor"
    SW_NETFLOW_MONITOR_REF = "swNetflowMonitorRef"
    SW_NETFLOW_RECORD_DEF = "swNetflowRecordDef"
    SW_PHYS = "swPhys"
    SW_PHYS_ETHER_EP = "swPhysEtherEp"
    SW_PHYS_FC_EP = "swPhysFcEp"
    SW_PHYS_FSM = "swPhysFsm"
    SW_PHYS_FSM_STAGE = "swPhysFsmStage"
    SW_PHYS_FSM_TASK = "swPhysFsmTask"
    SW_PORT_BREAKOUT = "swPortBreakout"
    SW_PORT_DISCOVER = "swPortDiscover"
    SW_PORT_DISCOVER_FSM = "swPortDiscoverFsm"
    SW_PORT_DISCOVER_FSM_STAGE = "swPortDiscoverFsmStage"
    SW_PORT_DISCOVER_FSM_TASK = "swPortDiscoverFsmTask"
    SW_SUB_GROUP = "swSubGroup"
    SW_SYSTEM_STATS = "swSystemStats"
    SW_SYSTEM_STATS_HIST = "swSystemStatsHist"
    SW_ULAN = "swUlan"
    SW_UTILITY_DOMAIN = "swUtilityDomain"
    SW_UTILITY_DOMAIN_FSM = "swUtilityDomainFsm"
    SW_UTILITY_DOMAIN_FSM_STAGE = "swUtilityDomainFsmStage"
    SW_UTILITY_DOMAIN_FSM_TASK = "swUtilityDomainFsmTask"
    SW_VIFREF = "swVIFRef"
    SW_VIRT_L3_INTF = "swVirtL3Intf"
    SW_VLAN = "swVlan"
    SW_VLAN_GROUP = "swVlanGroup"
    SW_VLAN_PORT_NS = "swVlanPortNs"
    SW_VLAN_PORT_NS_OVERRIDE = "swVlanPortNsOverride"
    SW_VLAN_REF = "swVlanRef"
    SW_VSAN = "swVsan"
    SW_ZONE_INITIATOR_MEMBER = "swZoneInitiatorMember"
    SW_ZONE_TARGET_MEMBER = "swZoneTargetMember"
    SWAT_ACTION = "swatAction"
    SWAT_CONDITION = "swatCondition"
    SWAT_EXAMPLE = "swatExample"
    SWAT_GETSTATS = "swatGetstats"
    SWAT_INJECT = "swatInject"
    SWAT_INJECTION = "swatInjection"
    SWAT_RESULTSTATS = "swatResultstats"
    SWAT_TARGET = "swatTarget"
    SWAT_TRIGGER = "swatTrigger"
    SYNTHETIC_DIRECTORY = "syntheticDirectory"
    SYNTHETIC_FSOBJ_INVENTORY = "syntheticFSObjInventory"
    SYNTHETIC_FSOBJ_INVENTORY_B = "syntheticFSObjInventoryB"
    SYNTHETIC_FILE = "syntheticFile"
    SYNTHETIC_FILE_SYSTEM = "syntheticFileSystem"
    SYNTHETIC_FS_OBJ = "syntheticFsObj"
    SYNTHETIC_FS_OBJ_FSM = "syntheticFsObjFsm"
    SYNTHETIC_FS_OBJ_FSM_STAGE = "syntheticFsObjFsmStage"
    SYNTHETIC_FS_OBJ_FSM_TASK = "syntheticFsObjFsmTask"
    SYNTHETIC_TEST_TX = "syntheticTestTx"
    SYNTHETIC_TIME = "syntheticTime"
    SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET = "sysdebugAutoCoreFileExportTarget"
    SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM = "sysdebugAutoCoreFileExportTargetFsm"
    SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM_STAGE = "sysdebugAutoCoreFileExportTargetFsmStage"
    SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM_TASK = "sysdebugAutoCoreFileExportTargetFsmTask"
    SYSDEBUG_BACKUP_BEHAVIOR = "sysdebugBackupBehavior"
    SYSDEBUG_CORE = "sysdebugCore"
    SYSDEBUG_CORE_FILE_REPOSITORY = "sysdebugCoreFileRepository"
    SYSDEBUG_CORE_FSM = "sysdebugCoreFsm"
    SYSDEBUG_CORE_FSM_STAGE = "sysdebugCoreFsmStage"
    SYSDEBUG_CORE_FSM_TASK = "sysdebugCoreFsmTask"
    SYSDEBUG_DIAGNOSTIC_LOG = "sysdebugDiagnosticLog"
    SYSDEBUG_DIAGNOSTIC_LOG_REPOSITORY = "sysdebugDiagnosticLogRepository"
    SYSDEBUG_EP = "sysdebugEp"
    SYSDEBUG_LOG_CONTROL_DESTINATION_FILE = "sysdebugLogControlDestinationFile"
    SYSDEBUG_LOG_CONTROL_DESTINATION_SYSLOG = "sysdebugLogControlDestinationSyslog"
    SYSDEBUG_LOG_CONTROL_DOMAIN = "sysdebugLogControlDomain"
    SYSDEBUG_LOG_CONTROL_EP = "sysdebugLogControlEp"
    SYSDEBUG_LOG_CONTROL_EP_FSM = "sysdebugLogControlEpFsm"
    SYSDEBUG_LOG_CONTROL_EP_FSM_STAGE = "sysdebugLogControlEpFsmStage"
    SYSDEBUG_LOG_CONTROL_EP_FSM_TASK = "sysdebugLogControlEpFsmTask"
    SYSDEBUG_LOG_CONTROL_MODULE = "sysdebugLogControlModule"
    SYSDEBUG_LOG_EXPORT_POLICY = "sysdebugLogExportPolicy"
    SYSDEBUG_LOG_EXPORT_POLICY_FSM = "sysdebugLogExportPolicyFsm"
    SYSDEBUG_LOG_EXPORT_POLICY_FSM_STAGE = "sysdebugLogExportPolicyFsmStage"
    SYSDEBUG_LOG_EXPORT_POLICY_FSM_TASK = "sysdebugLogExportPolicyFsmTask"
    SYSDEBUG_LOG_EXPORT_STATUS = "sysdebugLogExportStatus"
    SYSDEBUG_MEP_LOG = "sysdebugMEpLog"
    SYSDEBUG_MEP_LOG_POLICY = "sysdebugMEpLogPolicy"
    SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET = "sysdebugManualCoreFileExportTarget"
    SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM = "sysdebugManualCoreFileExportTargetFsm"
    SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM_STAGE = "sysdebugManualCoreFileExportTargetFsmStage"
    SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM_TASK = "sysdebugManualCoreFileExportTargetFsmTask"
    SYSDEBUG_TECH_SUP_FILE_REPOSITORY = "sysdebugTechSupFileRepository"
    SYSDEBUG_TECH_SUPPORT = "sysdebugTechSupport"
    SYSDEBUG_TECH_SUPPORT_CMD_OPT = "sysdebugTechSupportCmdOpt"
    SYSDEBUG_TECH_SUPPORT_FSM = "sysdebugTechSupportFsm"
    SYSDEBUG_TECH_SUPPORT_FSM_STAGE = "sysdebugTechSupportFsmStage"
    SYSDEBUG_TECH_SUPPORT_FSM_TASK = "sysdebugTechSupportFsmTask"
    SYSFILE_DIGEST = "sysfileDigest"
    SYSFILE_MUTATION = "sysfileMutation"
    SYSFILE_MUTATION_FSM = "sysfileMutationFsm"
    SYSFILE_MUTATION_FSM_STAGE = "sysfileMutationFsmStage"
    SYSFILE_MUTATION_FSM_TASK = "sysfileMutationFsmTask"
    TOP_INFO_POLICY = "topInfoPolicy"
    TOP_INFO_SYNC_POLICY = "topInfoSyncPolicy"
    TOP_META_INF = "topMetaInf"
    TOP_ROOT = "topRoot"
    TOP_SYS_DEFAULTS = "topSysDefaults"
    TOP_SYSTEM = "topSystem"
    TRIG_ABS_WINDOW = "trigAbsWindow"
    TRIG_CLIENT_TOKEN = "trigClientToken"
    TRIG_LOCAL_ABS_WINDOW = "trigLocalAbsWindow"
    TRIG_LOCAL_SCHED = "trigLocalSched"
    TRIG_META = "trigMeta"
    TRIG_PERFORM_TOKEN_ACTION = "trigPerformTokenAction"
    TRIG_RECURR_WINDOW = "trigRecurrWindow"
    TRIG_SCHED = "trigSched"
    TRIG_TEST = "trigTest"
    TRIG_TRIGGERED = "trigTriggered"
    UUIDPOOL_ADDR = "uuidpoolAddr"
    UUIDPOOL_BLOCK = "uuidpoolBlock"
    UUIDPOOL_FORMAT = "uuidpoolFormat"
    UUIDPOOL_POOL = "uuidpoolPool"
    UUIDPOOL_POOLABLE = "uuidpoolPoolable"
    UUIDPOOL_POOLED = "uuidpoolPooled"
    UUIDPOOL_UNIVERSE = "uuidpoolUniverse"
    VERSION_APPLICATION = "versionApplication"
    VERSION_EP = "versionEp"
    VM_COMPUTE_EP = "vmComputeEp"
    VM_DC = "vmDC"
    VM_DCORG = "vmDCOrg"
    VM_EP = "vmEp"
    VM_HBA = "vmHba"
    VM_HV = "vmHv"
    VM_INSTANCE = "vmInstance"
    VM_LIFE_CYCLE_POLICY = "vmLifeCyclePolicy"
    VM_LIFE_CYCLE_POLICY_FSM = "vmLifeCyclePolicyFsm"
    VM_LIFE_CYCLE_POLICY_FSM_STAGE = "vmLifeCyclePolicyFsmStage"
    VM_LIFE_CYCLE_POLICY_FSM_TASK = "vmLifeCyclePolicyFsmTask"
    VM_NIC = "vmNic"
    VM_ORG = "vmOrg"
    VM_SWITCH = "vmSwitch"
    VM_VIF = "vmVif"
    VM_VLAN = "vmVlan"
    VM_VNIC_PROF_CL = "vmVnicProfCl"
    VM_VNIC_PROF_INST = "vmVnicProfInst"
    VM_VSAN = "vmVsan"
    VNIC_BOOT_IP_POLICY = "vnicBootIpPolicy"
    VNIC_BOOT_TARGET = "vnicBootTarget"
    VNIC_CONN_DEF = "vnicConnDef"
    VNIC_DEF_BEH = "vnicDefBeh"
    VNIC_DYNAMIC_CON = "vnicDynamicCon"
    VNIC_DYNAMIC_CON_POLICY = "vnicDynamicConPolicy"
    VNIC_DYNAMIC_CON_POLICY_REF = "vnicDynamicConPolicyRef"
    VNIC_DYNAMIC_ID_UNIVERSE = "vnicDynamicIdUniverse"
    VNIC_DYNAMIC_PROVIDER = "vnicDynamicProvider"
    VNIC_DYNAMIC_PROVIDER_EP = "vnicDynamicProviderEp"
    VNIC_ETH_CONFIG = "vnicEthConfig"
    VNIC_ETH_LIF = "vnicEthLif"
    VNIC_ETHER = "vnicEther"
    VNIC_ETHER_IF = "vnicEtherIf"
    VNIC_FC = "vnicFc"
    VNIC_FC_GROUP_DEF = "vnicFcGroupDef"
    VNIC_FC_GROUP_TEMPL = "vnicFcGroupTempl"
    VNIC_FC_IF = "vnicFcIf"
    VNIC_FC_LIF = "vnicFcLif"
    VNIC_FC_NODE = "vnicFcNode"
    VNIC_FC_OEIF = "vnicFcOEIf"
    VNIC_IPV4_DHCP = "vnicIPv4Dhcp"
    VNIC_IPV4_DNS = "vnicIPv4Dns"
    VNIC_IPV4_IF = "vnicIPv4If"
    VNIC_IPV4_ISCSI_ADDR = "vnicIPv4IscsiAddr"
    VNIC_IPV4_POOLED_ISCSI_ADDR = "vnicIPv4PooledIscsiAddr"
    VNIC_IPV4_STATIC_ROUTE = "vnicIPv4StaticRoute"
    VNIC_IPV6_IF = "vnicIPv6If"
    VNIC_ISCSI = "vnicIScsi"
    VNIC_ISCSI_AUTO_TARGET_IF = "vnicIScsiAutoTargetIf"
    VNIC_ISCSI_BOOT_PARAMS = "vnicIScsiBootParams"
    VNIC_ISCSI_BOOT_VNIC = "vnicIScsiBootVnic"
    VNIC_ISCSI_CONFIG = "vnicIScsiConfig"
    VNIC_ISCSI_INIT_AUTO_CONFIG_POLICY = "vnicIScsiInitAutoConfigPolicy"
    VNIC_ISCSI_LCP = "vnicIScsiLCP"
    VNIC_ISCSI_NODE = "vnicIScsiNode"
    VNIC_ISCSI_STATIC_TARGET_IF = "vnicIScsiStaticTargetIf"
    VNIC_INTERNAL_PROFILE = "vnicInternalProfile"
    VNIC_IP_V4_HISTORY = "vnicIpV4History"
    VNIC_IP_V4_MGMT_POOLED_ADDR = "vnicIpV4MgmtPooledAddr"
    VNIC_IP_V4_POOLED_ADDR = "vnicIpV4PooledAddr"
    VNIC_IP_V4_PROF_DERIVED_ADDR = "vnicIpV4ProfDerivedAddr"
    VNIC_IP_V4_STATIC_ADDR = "vnicIpV4StaticAddr"
    VNIC_IP_V6_HISTORY = "vnicIpV6History"
    VNIC_IP_V6_MGMT_POOLED_ADDR = "vnicIpV6MgmtPooledAddr"
    VNIC_IP_V6_STATIC_ADDR = "vnicIpV6StaticAddr"
    VNIC_IPC = "vnicIpc"
    VNIC_IPC_IF = "vnicIpcIf"
    VNIC_IQN_HISTORY = "vnicIqnHistory"
    VNIC_LAN_CONN_POLICY = "vnicLanConnPolicy"
    VNIC_LAN_CONN_TEMPL = "vnicLanConnTempl"
    VNIC_LIF_VLAN = "vnicLifVlan"
    VNIC_LIF_VSAN = "vnicLifVsan"
    VNIC_LUN = "vnicLun"
    VNIC_MAC_HISTORY = "vnicMacHistory"
    VNIC_OPROFILE_ALIAS = "vnicOProfileAlias"
    VNIC_PROFILE = "vnicProfile"
    VNIC_PROFILE_ALIAS = "vnicProfileAlias"
    VNIC_PROFILE_REF = "vnicProfileRef"
    VNIC_PROFILE_SET = "vnicProfileSet"
    VNIC_PROFILE_SET_FSM = "vnicProfileSetFsm"
    VNIC_PROFILE_SET_FSM_STAGE = "vnicProfileSetFsmStage"
    VNIC_PROFILE_SET_FSM_TASK = "vnicProfileSetFsmTask"
    VNIC_RACK_SERVER_DISCOVERY_PROFILE = "vnicRackServerDiscoveryProfile"
    VNIC_SAN_CONN_POLICY = "vnicSanConnPolicy"
    VNIC_SAN_CONN_TEMPL = "vnicSanConnTempl"
    VNIC_SCSI = "vnicScsi"
    VNIC_SCSI_IF = "vnicScsiIf"
    VNIC_USNIC_CON_POLICY = "vnicUsnicConPolicy"
    VNIC_USNIC_CON_POLICY_REF = "vnicUsnicConPolicyRef"
    VNIC_VHBA_BEH_POLICY = "vnicVhbaBehPolicy"
    VNIC_VLAN = "vnicVlan"
    VNIC_VMQ_CON_POLICY = "vnicVmqConPolicy"
    VNIC_VMQ_CON_POLICY_REF = "vnicVmqConPolicyRef"
    VNIC_VNIC_BEH_POLICY = "vnicVnicBehPolicy"
    VNIC_WWNN_HISTORY = "vnicWwnnHistory"
    VNIC_WWPN_HISTORY = "vnicWwpnHistory"
    WCARD_FILTER = "wcardFilter"


class YesOrNo:
    FALSE = "false"
    NO = "no"
    TRUE = "true"
    YES = "yes"


class NamingPropertyId:
    _ABORT_ERRORS = "AbortErrors"
    _ABORT_ERRORS15_MIN = "AbortErrors15Min"
    _ABORT_ERRORS15_MIN_H = "AbortErrors15MinH"
    _ABORT_ERRORS1_DAY = "AbortErrors1Day"
    _ABORT_ERRORS1_DAY_H = "AbortErrors1DayH"
    _ABORT_ERRORS1_HOUR = "AbortErrors1Hour"
    _ABORT_ERRORS1_HOUR_H = "AbortErrors1HourH"
    _ABORT_ERRORS1_WEEK = "AbortErrors1Week"
    _ABORT_ERRORS1_WEEK_H = "AbortErrors1WeekH"
    _ABORT_ERRORS2_WEEKS = "AbortErrors2Weeks"
    _ABORT_ERRORS2_WEEKS_H = "AbortErrors2WeeksH"
    _ADDL_INFO = "AddlInfo"
    _CHASSIS_I2_CERRORS = "ChassisI2CErrors"
    _CHASSIS_I2_CERRORS_AVG = "ChassisI2CErrorsAvg"
    _CHASSIS_I2_CERRORS_MAX = "ChassisI2CErrorsMax"
    _CHASSIS_I2_CERRORS_MIN = "ChassisI2CErrorsMin"
    _CHASSIS_PROFILE_DN = "ChassisProfileDn"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS = "CoherentSlaveCorrectableErrors"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS15_MIN = "CoherentSlaveCorrectableErrors15Min"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS15_MIN_H = "CoherentSlaveCorrectableErrors15MinH"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS1_DAY = "CoherentSlaveCorrectableErrors1Day"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS1_DAY_H = "CoherentSlaveCorrectableErrors1DayH"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS1_HOUR = "CoherentSlaveCorrectableErrors1Hour"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS1_HOUR_H = "CoherentSlaveCorrectableErrors1HourH"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS1_WEEK = "CoherentSlaveCorrectableErrors1Week"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS1_WEEK_H = "CoherentSlaveCorrectableErrors1WeekH"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS2_WEEKS = "CoherentSlaveCorrectableErrors2Weeks"
    _COHERENT_SLAVE_CORRECTABLE_ERRORS2_WEEKS_H = "CoherentSlaveCorrectableErrors2WeeksH"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS = "CoherentSlaveUncorrectableErrors"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS15_MIN = "CoherentSlaveUncorrectableErrors15Min"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS15_MIN_H = "CoherentSlaveUncorrectableErrors15MinH"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS1_DAY = "CoherentSlaveUncorrectableErrors1Day"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS1_DAY_H = "CoherentSlaveUncorrectableErrors1DayH"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS1_HOUR = "CoherentSlaveUncorrectableErrors1Hour"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS1_HOUR_H = "CoherentSlaveUncorrectableErrors1HourH"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS1_WEEK = "CoherentSlaveUncorrectableErrors1Week"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS1_WEEK_H = "CoherentSlaveUncorrectableErrors1WeekH"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS2_WEEKS = "CoherentSlaveUncorrectableErrors2Weeks"
    _COHERENT_SLAVE_UNCORRECTABLE_ERRORS2_WEEKS_H = "CoherentSlaveUncorrectableErrors2WeeksH"
    _CONTROLLER_FW_VERSION = "ControllerFwVersion"
    _CONTROLLER_MODEL = "ControllerModel"
    _CORRECTABLE_LINK_CRCERRORS = "CorrectableLinkCRCErrors"
    _CORRECTABLE_LINK_CRCERRORS15_MIN = "CorrectableLinkCRCErrors15Min"
    _CORRECTABLE_LINK_CRCERRORS15_MIN_H = "CorrectableLinkCRCErrors15MinH"
    _CORRECTABLE_LINK_CRCERRORS1_DAY = "CorrectableLinkCRCErrors1Day"
    _CORRECTABLE_LINK_CRCERRORS1_DAY_H = "CorrectableLinkCRCErrors1DayH"
    _CORRECTABLE_LINK_CRCERRORS1_HOUR = "CorrectableLinkCRCErrors1Hour"
    _CORRECTABLE_LINK_CRCERRORS1_HOUR_H = "CorrectableLinkCRCErrors1HourH"
    _CORRECTABLE_LINK_CRCERRORS1_WEEK = "CorrectableLinkCRCErrors1Week"
    _CORRECTABLE_LINK_CRCERRORS1_WEEK_H = "CorrectableLinkCRCErrors1WeekH"
    _CORRECTABLE_LINK_CRCERRORS2_WEEKS = "CorrectableLinkCRCErrors2Weeks"
    _CORRECTABLE_LINK_CRCERRORS2_WEEKS_H = "CorrectableLinkCRCErrors2WeeksH"
    _CORRECTABLE_PARITY_ERROR = "CorrectableParityError"
    _CORRECTABLE_PARITY_ERROR_AVG = "CorrectableParityErrorAvg"
    _CORRECTABLE_PARITY_ERROR_MAX = "CorrectableParityErrorMax"
    _CORRECTABLE_PARITY_ERROR_MIN = "CorrectableParityErrorMin"
    _DECODE_UNIT_CORRECTABLE_ERRORS = "DecodeUnitCorrectableErrors"
    _DECODE_UNIT_CORRECTABLE_ERRORS15_MIN = "DecodeUnitCorrectableErrors15Min"
    _DECODE_UNIT_CORRECTABLE_ERRORS15_MIN_H = "DecodeUnitCorrectableErrors15MinH"
    _DECODE_UNIT_CORRECTABLE_ERRORS1_DAY = "DecodeUnitCorrectableErrors1Day"
    _DECODE_UNIT_CORRECTABLE_ERRORS1_DAY_H = "DecodeUnitCorrectableErrors1DayH"
    _DECODE_UNIT_CORRECTABLE_ERRORS1_HOUR = "DecodeUnitCorrectableErrors1Hour"
    _DECODE_UNIT_CORRECTABLE_ERRORS1_HOUR_H = "DecodeUnitCorrectableErrors1HourH"
    _DECODE_UNIT_CORRECTABLE_ERRORS1_WEEK = "DecodeUnitCorrectableErrors1Week"
    _DECODE_UNIT_CORRECTABLE_ERRORS1_WEEK_H = "DecodeUnitCorrectableErrors1WeekH"
    _DECODE_UNIT_CORRECTABLE_ERRORS2_WEEKS = "DecodeUnitCorrectableErrors2Weeks"
    _DECODE_UNIT_CORRECTABLE_ERRORS2_WEEKS_H = "DecodeUnitCorrectableErrors2WeeksH"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS = "DecodeUnitUncorrectableErrors"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS15_MIN = "DecodeUnitUncorrectableErrors15Min"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS15_MIN_H = "DecodeUnitUncorrectableErrors15MinH"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS1_DAY = "DecodeUnitUncorrectableErrors1Day"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS1_DAY_H = "DecodeUnitUncorrectableErrors1DayH"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS1_HOUR = "DecodeUnitUncorrectableErrors1Hour"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS1_HOUR_H = "DecodeUnitUncorrectableErrors1HourH"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS1_WEEK = "DecodeUnitUncorrectableErrors1Week"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS1_WEEK_H = "DecodeUnitUncorrectableErrors1WeekH"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS2_WEEKS = "DecodeUnitUncorrectableErrors2Weeks"
    _DECODE_UNIT_UNCORRECTABLE_ERRORS2_WEEKS_H = "DecodeUnitUncorrectableErrors2WeeksH"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS = "DramWriteDataCorrectableCRCErrors"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS15_MIN = "DramWriteDataCorrectableCRCErrors15Min"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS15_MIN_H = "DramWriteDataCorrectableCRCErrors15MinH"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS1_DAY = "DramWriteDataCorrectableCRCErrors1Day"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS1_DAY_H = "DramWriteDataCorrectableCRCErrors1DayH"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS1_HOUR = "DramWriteDataCorrectableCRCErrors1Hour"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS1_HOUR_H = "DramWriteDataCorrectableCRCErrors1HourH"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS1_WEEK = "DramWriteDataCorrectableCRCErrors1Week"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS1_WEEK_H = "DramWriteDataCorrectableCRCErrors1WeekH"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS2_WEEKS = "DramWriteDataCorrectableCRCErrors2Weeks"
    _DRAM_WRITE_DATA_CORRECTABLE_CRCERRORS2_WEEKS_H = "DramWriteDataCorrectableCRCErrors2WeeksH"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS = "DramWriteDataUnCorrectableCRCErrors"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS15_MIN = "DramWriteDataUnCorrectableCRCErrors15Min"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS15_MIN_H = "DramWriteDataUnCorrectableCRCErrors15MinH"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS1_DAY = "DramWriteDataUnCorrectableCRCErrors1Day"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS1_DAY_H = "DramWriteDataUnCorrectableCRCErrors1DayH"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS1_HOUR = "DramWriteDataUnCorrectableCRCErrors1Hour"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS1_HOUR_H = "DramWriteDataUnCorrectableCRCErrors1HourH"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS1_WEEK = "DramWriteDataUnCorrectableCRCErrors1Week"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS1_WEEK_H = "DramWriteDataUnCorrectableCRCErrors1WeekH"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS2_WEEKS = "DramWriteDataUnCorrectableCRCErrors2Weeks"
    _DRAM_WRITE_DATA_UN_CORRECTABLE_CRCERRORS2_WEEKS_H = "DramWriteDataUnCorrectableCRCErrors2WeeksH"
    _END_POINT_DN = "EndPointDn"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS = "ExecutionUnitCorrectableErrors"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS15_MIN = "ExecutionUnitCorrectableErrors15Min"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS15_MIN_H = "ExecutionUnitCorrectableErrors15MinH"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS1_DAY = "ExecutionUnitCorrectableErrors1Day"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS1_DAY_H = "ExecutionUnitCorrectableErrors1DayH"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS1_HOUR = "ExecutionUnitCorrectableErrors1Hour"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS1_HOUR_H = "ExecutionUnitCorrectableErrors1HourH"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS1_WEEK = "ExecutionUnitCorrectableErrors1Week"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS1_WEEK_H = "ExecutionUnitCorrectableErrors1WeekH"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS2_WEEKS = "ExecutionUnitCorrectableErrors2Weeks"
    _EXECUTION_UNIT_CORRECTABLE_ERRORS2_WEEKS_H = "ExecutionUnitCorrectableErrors2WeeksH"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS = "ExecutionUnitUncorrectableErrors"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS15_MIN = "ExecutionUnitUncorrectableErrors15Min"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS15_MIN_H = "ExecutionUnitUncorrectableErrors15MinH"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS1_DAY = "ExecutionUnitUncorrectableErrors1Day"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS1_DAY_H = "ExecutionUnitUncorrectableErrors1DayH"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS1_HOUR = "ExecutionUnitUncorrectableErrors1Hour"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS1_HOUR_H = "ExecutionUnitUncorrectableErrors1HourH"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS1_WEEK = "ExecutionUnitUncorrectableErrors1Week"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS1_WEEK_H = "ExecutionUnitUncorrectableErrors1WeekH"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS2_WEEKS = "ExecutionUnitUncorrectableErrors2Weeks"
    _EXECUTION_UNIT_UNCORRECTABLE_ERRORS2_WEEKS_H = "ExecutionUnitUncorrectableErrors2WeeksH"
    _FCHUNCORRECTABLE_ERRORS = "FCHUncorrectableErrors"
    _FCHUNCORRECTABLE_ERRORS15_MIN = "FCHUncorrectableErrors15Min"
    _FCHUNCORRECTABLE_ERRORS15_MIN_H = "FCHUncorrectableErrors15MinH"
    _FCHUNCORRECTABLE_ERRORS1_DAY = "FCHUncorrectableErrors1Day"
    _FCHUNCORRECTABLE_ERRORS1_DAY_H = "FCHUncorrectableErrors1DayH"
    _FCHUNCORRECTABLE_ERRORS1_HOUR = "FCHUncorrectableErrors1Hour"
    _FCHUNCORRECTABLE_ERRORS1_HOUR_H = "FCHUncorrectableErrors1HourH"
    _FCHUNCORRECTABLE_ERRORS1_WEEK = "FCHUncorrectableErrors1Week"
    _FCHUNCORRECTABLE_ERRORS1_WEEK_H = "FCHUncorrectableErrors1WeekH"
    _FCHUNCORRECTABLE_ERRORS2_WEEKS = "FCHUncorrectableErrors2Weeks"
    _FCHUNCORRECTABLE_ERRORS2_WEEKS_H = "FCHUncorrectableErrors2WeeksH"
    _FCHCORRECTABLE_ERRORS = "FCHcorrectableErrors"
    _FCHCORRECTABLE_ERRORS15_MIN = "FCHcorrectableErrors15Min"
    _FCHCORRECTABLE_ERRORS15_MIN_H = "FCHcorrectableErrors15MinH"
    _FCHCORRECTABLE_ERRORS1_DAY = "FCHcorrectableErrors1Day"
    _FCHCORRECTABLE_ERRORS1_DAY_H = "FCHcorrectableErrors1DayH"
    _FCHCORRECTABLE_ERRORS1_HOUR = "FCHcorrectableErrors1Hour"
    _FCHCORRECTABLE_ERRORS1_HOUR_H = "FCHcorrectableErrors1HourH"
    _FCHCORRECTABLE_ERRORS1_WEEK = "FCHcorrectableErrors1Week"
    _FCHCORRECTABLE_ERRORS1_WEEK_H = "FCHcorrectableErrors1WeekH"
    _FCHCORRECTABLE_ERRORS2_WEEKS = "FCHcorrectableErrors2Weeks"
    _FCHCORRECTABLE_ERRORS2_WEEKS_H = "FCHcorrectableErrors2WeeksH"
    _FPGAIMAGE_STATUS = "FPGAImageStatus"
    _FAN_MODULE_I2_CERRORS = "FanModuleI2CErrors"
    _FAN_MODULE_I2_CERRORS_AVG = "FanModuleI2CErrorsAvg"
    _FAN_MODULE_I2_CERRORS_MAX = "FanModuleI2CErrorsMax"
    _FAN_MODULE_I2_CERRORS_MIN = "FanModuleI2CErrorsMin"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS = "FloatingPointUnitCorrectableErrors"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS15_MIN = "FloatingPointUnitCorrectableErrors15Min"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS15_MIN_H = "FloatingPointUnitCorrectableErrors15MinH"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS1_DAY = "FloatingPointUnitCorrectableErrors1Day"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS1_DAY_H = "FloatingPointUnitCorrectableErrors1DayH"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS1_HOUR = "FloatingPointUnitCorrectableErrors1Hour"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS1_HOUR_H = "FloatingPointUnitCorrectableErrors1HourH"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS1_WEEK = "FloatingPointUnitCorrectableErrors1Week"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS1_WEEK_H = "FloatingPointUnitCorrectableErrors1WeekH"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS2_WEEKS = "FloatingPointUnitCorrectableErrors2Weeks"
    _FLOATING_POINT_UNIT_CORRECTABLE_ERRORS2_WEEKS_H = "FloatingPointUnitCorrectableErrors2WeeksH"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS = "FloatingPointUnitUncorrectableErrors"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS15_MIN = "FloatingPointUnitUncorrectableErrors15Min"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS15_MIN_H = "FloatingPointUnitUncorrectableErrors15MinH"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS1_DAY = "FloatingPointUnitUncorrectableErrors1Day"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS1_DAY_H = "FloatingPointUnitUncorrectableErrors1DayH"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS1_HOUR = "FloatingPointUnitUncorrectableErrors1Hour"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS1_HOUR_H = "FloatingPointUnitUncorrectableErrors1HourH"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS1_WEEK = "FloatingPointUnitUncorrectableErrors1Week"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS1_WEEK_H = "FloatingPointUnitUncorrectableErrors1WeekH"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS2_WEEKS = "FloatingPointUnitUncorrectableErrors2Weeks"
    _FLOATING_POINT_UNIT_UNCORRECTABLE_ERRORS2_WEEKS_H = "FloatingPointUnitUncorrectableErrors2WeeksH"
    _HDDMON_SUPPORT = "HDDMonSupport"
    _IPV4_ADDRESS = "IPv4Address"
    _ID = "Id"
    _IMAGE_NAME_DN = "ImageNameDn"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS = "InstructionFetchUnitCorrectableErrors"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS15_MIN = "InstructionFetchUnitCorrectableErrors15Min"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS15_MIN_H = "InstructionFetchUnitCorrectableErrors15MinH"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS1_DAY = "InstructionFetchUnitCorrectableErrors1Day"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS1_DAY_H = "InstructionFetchUnitCorrectableErrors1DayH"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS1_HOUR = "InstructionFetchUnitCorrectableErrors1Hour"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS1_HOUR_H = "InstructionFetchUnitCorrectableErrors1HourH"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS1_WEEK = "InstructionFetchUnitCorrectableErrors1Week"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS1_WEEK_H = "InstructionFetchUnitCorrectableErrors1WeekH"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS2_WEEKS = "InstructionFetchUnitCorrectableErrors2Weeks"
    _INSTRUCTION_FETCH_UNIT_CORRECTABLE_ERRORS2_WEEKS_H = "InstructionFetchUnitCorrectableErrors2WeeksH"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS = "InstructionFetchUnitUncorrectableErrors"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS15_MIN = "InstructionFetchUnitUncorrectableErrors15Min"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS15_MIN_H = "InstructionFetchUnitUncorrectableErrors15MinH"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS1_DAY = "InstructionFetchUnitUncorrectableErrors1Day"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS1_DAY_H = "InstructionFetchUnitUncorrectableErrors1DayH"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS1_HOUR = "InstructionFetchUnitUncorrectableErrors1Hour"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS1_HOUR_H = "InstructionFetchUnitUncorrectableErrors1HourH"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS1_WEEK = "InstructionFetchUnitUncorrectableErrors1Week"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS1_WEEK_H = "InstructionFetchUnitUncorrectableErrors1WeekH"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS2_WEEKS = "InstructionFetchUnitUncorrectableErrors2Weeks"
    _INSTRUCTION_FETCH_UNIT_UNCORRECTABLE_ERRORS2_WEEKS_H = "InstructionFetchUnitUncorrectableErrors2WeeksH"
    _IOM_I2_CERRORS = "IomI2CErrors"
    _IOM_I2_CERRORS_AVG = "IomI2CErrorsAvg"
    _IOM_I2_CERRORS_MAX = "IomI2CErrorsMax"
    _IOM_I2_CERRORS_MIN = "IomI2CErrorsMin"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS = "L2CacheUnitCorrectableErrors"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS15_MIN = "L2CacheUnitCorrectableErrors15Min"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS15_MIN_H = "L2CacheUnitCorrectableErrors15MinH"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS1_DAY = "L2CacheUnitCorrectableErrors1Day"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS1_DAY_H = "L2CacheUnitCorrectableErrors1DayH"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS1_HOUR = "L2CacheUnitCorrectableErrors1Hour"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS1_HOUR_H = "L2CacheUnitCorrectableErrors1HourH"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS1_WEEK = "L2CacheUnitCorrectableErrors1Week"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS1_WEEK_H = "L2CacheUnitCorrectableErrors1WeekH"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS2_WEEKS = "L2CacheUnitCorrectableErrors2Weeks"
    _L2_CACHE_UNIT_CORRECTABLE_ERRORS2_WEEKS_H = "L2CacheUnitCorrectableErrors2WeeksH"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS = "L2CacheUnitUncorrectableErrors"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS15_MIN = "L2CacheUnitUncorrectableErrors15Min"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS15_MIN_H = "L2CacheUnitUncorrectableErrors15MinH"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS1_DAY = "L2CacheUnitUncorrectableErrors1Day"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS1_DAY_H = "L2CacheUnitUncorrectableErrors1DayH"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS1_HOUR = "L2CacheUnitUncorrectableErrors1Hour"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS1_HOUR_H = "L2CacheUnitUncorrectableErrors1HourH"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS1_WEEK = "L2CacheUnitUncorrectableErrors1Week"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS1_WEEK_H = "L2CacheUnitUncorrectableErrors1WeekH"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS2_WEEKS = "L2CacheUnitUncorrectableErrors2Weeks"
    _L2_CACHE_UNIT_UNCORRECTABLE_ERRORS2_WEEKS_H = "L2CacheUnitUncorrectableErrors2WeeksH"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS = "L3CacheUnitCorrectableErrors"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS15_MIN = "L3CacheUnitCorrectableErrors15Min"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS15_MIN_H = "L3CacheUnitCorrectableErrors15MinH"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS1_DAY = "L3CacheUnitCorrectableErrors1Day"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS1_DAY_H = "L3CacheUnitCorrectableErrors1DayH"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS1_HOUR = "L3CacheUnitCorrectableErrors1Hour"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS1_HOUR_H = "L3CacheUnitCorrectableErrors1HourH"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS1_WEEK = "L3CacheUnitCorrectableErrors1Week"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS1_WEEK_H = "L3CacheUnitCorrectableErrors1WeekH"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS2_WEEKS = "L3CacheUnitCorrectableErrors2Weeks"
    _L3_CACHE_UNIT_CORRECTABLE_ERRORS2_WEEKS_H = "L3CacheUnitCorrectableErrors2WeeksH"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS = "L3CacheUnitUncorrectableErrors"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS15_MIN = "L3CacheUnitUncorrectableErrors15Min"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS15_MIN_H = "L3CacheUnitUncorrectableErrors15MinH"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS1_DAY = "L3CacheUnitUncorrectableErrors1Day"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS1_DAY_H = "L3CacheUnitUncorrectableErrors1DayH"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS1_HOUR = "L3CacheUnitUncorrectableErrors1Hour"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS1_HOUR_H = "L3CacheUnitUncorrectableErrors1HourH"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS1_WEEK = "L3CacheUnitUncorrectableErrors1Week"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS1_WEEK_H = "L3CacheUnitUncorrectableErrors1WeekH"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS2_WEEKS = "L3CacheUnitUncorrectableErrors2Weeks"
    _L3_CACHE_UNIT_UNCORRECTABLE_ERRORS2_WEEKS_H = "L3CacheUnitUncorrectableErrors2WeeksH"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS = "LoadStoreUnitCorrectableErrors"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS15_MIN = "LoadStoreUnitCorrectableErrors15Min"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS15_MIN_H = "LoadStoreUnitCorrectableErrors15MinH"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS1_DAY = "LoadStoreUnitCorrectableErrors1Day"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS1_DAY_H = "LoadStoreUnitCorrectableErrors1DayH"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS1_HOUR = "LoadStoreUnitCorrectableErrors1Hour"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS1_HOUR_H = "LoadStoreUnitCorrectableErrors1HourH"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS1_WEEK = "LoadStoreUnitCorrectableErrors1Week"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS1_WEEK_H = "LoadStoreUnitCorrectableErrors1WeekH"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS2_WEEKS = "LoadStoreUnitCorrectableErrors2Weeks"
    _LOAD_STORE_UNIT_CORRECTABLE_ERRORS2_WEEKS_H = "LoadStoreUnitCorrectableErrors2WeeksH"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS = "LoadStoreUnitUncorrectableErrors"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS15_MIN = "LoadStoreUnitUncorrectableErrors15Min"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS15_MIN_H = "LoadStoreUnitUncorrectableErrors15MinH"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS1_DAY = "LoadStoreUnitUncorrectableErrors1Day"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS1_DAY_H = "LoadStoreUnitUncorrectableErrors1DayH"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS1_HOUR = "LoadStoreUnitUncorrectableErrors1Hour"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS1_HOUR_H = "LoadStoreUnitUncorrectableErrors1HourH"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS1_WEEK = "LoadStoreUnitUncorrectableErrors1Week"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS1_WEEK_H = "LoadStoreUnitUncorrectableErrors1WeekH"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS2_WEEKS = "LoadStoreUnitUncorrectableErrors2Weeks"
    _LOAD_STORE_UNIT_UNCORRECTABLE_ERRORS2_WEEKS_H = "LoadStoreUnitUncorrectableErrors2WeeksH"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS = "MPMgmntControllerCorrectableErrors"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS15_MIN = "MPMgmntControllerCorrectableErrors15Min"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS15_MIN_H = "MPMgmntControllerCorrectableErrors15MinH"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS1_DAY = "MPMgmntControllerCorrectableErrors1Day"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS1_DAY_H = "MPMgmntControllerCorrectableErrors1DayH"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS1_HOUR = "MPMgmntControllerCorrectableErrors1Hour"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS1_HOUR_H = "MPMgmntControllerCorrectableErrors1HourH"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS1_WEEK = "MPMgmntControllerCorrectableErrors1Week"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS1_WEEK_H = "MPMgmntControllerCorrectableErrors1WeekH"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS2_WEEKS = "MPMgmntControllerCorrectableErrors2Weeks"
    _MPMGMNT_CONTROLLER_CORRECTABLE_ERRORS2_WEEKS_H = "MPMgmntControllerCorrectableErrors2WeeksH"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS = "MPMgmntControllerUncorrectableErrors"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS15_MIN = "MPMgmntControllerUncorrectableErrors15Min"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS15_MIN_H = "MPMgmntControllerUncorrectableErrors15MinH"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS1_DAY = "MPMgmntControllerUncorrectableErrors1Day"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS1_DAY_H = "MPMgmntControllerUncorrectableErrors1DayH"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS1_HOUR = "MPMgmntControllerUncorrectableErrors1Hour"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS1_HOUR_H = "MPMgmntControllerUncorrectableErrors1HourH"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS1_WEEK = "MPMgmntControllerUncorrectableErrors1Week"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS1_WEEK_H = "MPMgmntControllerUncorrectableErrors1WeekH"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS2_WEEKS = "MPMgmntControllerUncorrectableErrors2Weeks"
    _MPMGMNT_CONTROLLER_UNCORRECTABLE_ERRORS2_WEEKS_H = "MPMgmntControllerUncorrectableErrors2WeeksH"
    _MAXIMUM = "Maximum"
    _MEM_TESTCORRECTABLE_ERRORS = "MemTestcorrectableErrors"
    _MEM_TESTCORRECTABLE_ERRORS15_MIN = "MemTestcorrectableErrors15Min"
    _MEM_TESTCORRECTABLE_ERRORS15_MIN_H = "MemTestcorrectableErrors15MinH"
    _MEM_TESTCORRECTABLE_ERRORS1_DAY = "MemTestcorrectableErrors1Day"
    _MEM_TESTCORRECTABLE_ERRORS1_DAY_H = "MemTestcorrectableErrors1DayH"
    _MEM_TESTCORRECTABLE_ERRORS1_HOUR = "MemTestcorrectableErrors1Hour"
    _MEM_TESTCORRECTABLE_ERRORS1_HOUR_H = "MemTestcorrectableErrors1HourH"
    _MEM_TESTCORRECTABLE_ERRORS1_WEEK = "MemTestcorrectableErrors1Week"
    _MEM_TESTCORRECTABLE_ERRORS1_WEEK_H = "MemTestcorrectableErrors1WeekH"
    _MEM_TESTCORRECTABLE_ERRORS2_WEEKS = "MemTestcorrectableErrors2Weeks"
    _MEM_TESTCORRECTABLE_ERRORS2_WEEKS_H = "MemTestcorrectableErrors2WeeksH"
    _MINIMUM = "Minimum"
    _MODULE_POWER = "ModulePower"
    _MODULE_POWER_AVG = "ModulePowerAvg"
    _MODULE_POWER_MAX = "ModulePowerMax"
    _MODULE_POWER_MIN = "ModulePowerMin"
    _NAME = "Name"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS = "NorthBridgeIOCorrectableErrors"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS15_MIN = "NorthBridgeIOCorrectableErrors15Min"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS15_MIN_H = "NorthBridgeIOCorrectableErrors15MinH"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS1_DAY = "NorthBridgeIOCorrectableErrors1Day"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS1_DAY_H = "NorthBridgeIOCorrectableErrors1DayH"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS1_HOUR = "NorthBridgeIOCorrectableErrors1Hour"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS1_HOUR_H = "NorthBridgeIOCorrectableErrors1HourH"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS1_WEEK = "NorthBridgeIOCorrectableErrors1Week"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS1_WEEK_H = "NorthBridgeIOCorrectableErrors1WeekH"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS2_WEEKS = "NorthBridgeIOCorrectableErrors2Weeks"
    _NORTH_BRIDGE_IOCORRECTABLE_ERRORS2_WEEKS_H = "NorthBridgeIOCorrectableErrors2WeeksH"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS = "NorthBridgeIOUncorrectableErrors"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS15_MIN = "NorthBridgeIOUncorrectableErrors15Min"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS15_MIN_H = "NorthBridgeIOUncorrectableErrors15MinH"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS1_DAY = "NorthBridgeIOUncorrectableErrors1Day"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS1_DAY_H = "NorthBridgeIOUncorrectableErrors1DayH"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS1_HOUR = "NorthBridgeIOUncorrectableErrors1Hour"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS1_HOUR_H = "NorthBridgeIOUncorrectableErrors1HourH"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS1_WEEK = "NorthBridgeIOUncorrectableErrors1Week"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS1_WEEK_H = "NorthBridgeIOUncorrectableErrors1WeekH"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS2_WEEKS = "NorthBridgeIOUncorrectableErrors2Weeks"
    _NORTH_BRIDGE_IOUNCORRECTABLE_ERRORS2_WEEKS_H = "NorthBridgeIOUncorrectableErrors2WeeksH"
    _OFFLOAD = "Offload"
    _PCIE_BANK_CORRECTABLE_ERRORS = "PCIeBankCorrectableErrors"
    _PCIE_BANK_CORRECTABLE_ERRORS15_MIN = "PCIeBankCorrectableErrors15Min"
    _PCIE_BANK_CORRECTABLE_ERRORS15_MIN_H = "PCIeBankCorrectableErrors15MinH"
    _PCIE_BANK_CORRECTABLE_ERRORS1_DAY = "PCIeBankCorrectableErrors1Day"
    _PCIE_BANK_CORRECTABLE_ERRORS1_DAY_H = "PCIeBankCorrectableErrors1DayH"
    _PCIE_BANK_CORRECTABLE_ERRORS1_HOUR = "PCIeBankCorrectableErrors1Hour"
    _PCIE_BANK_CORRECTABLE_ERRORS1_HOUR_H = "PCIeBankCorrectableErrors1HourH"
    _PCIE_BANK_CORRECTABLE_ERRORS1_WEEK = "PCIeBankCorrectableErrors1Week"
    _PCIE_BANK_CORRECTABLE_ERRORS1_WEEK_H = "PCIeBankCorrectableErrors1WeekH"
    _PCIE_BANK_CORRECTABLE_ERRORS2_WEEKS = "PCIeBankCorrectableErrors2Weeks"
    _PCIE_BANK_CORRECTABLE_ERRORS2_WEEKS_H = "PCIeBankCorrectableErrors2WeeksH"
    _PCIE_BANK_UNCORRECTABLE_ERRORS = "PCIeBankUncorrectableErrors"
    _PCIE_BANK_UNCORRECTABLE_ERRORS15_MIN = "PCIeBankUncorrectableErrors15Min"
    _PCIE_BANK_UNCORRECTABLE_ERRORS15_MIN_H = "PCIeBankUncorrectableErrors15MinH"
    _PCIE_BANK_UNCORRECTABLE_ERRORS1_DAY = "PCIeBankUncorrectableErrors1Day"
    _PCIE_BANK_UNCORRECTABLE_ERRORS1_DAY_H = "PCIeBankUncorrectableErrors1DayH"
    _PCIE_BANK_UNCORRECTABLE_ERRORS1_HOUR = "PCIeBankUncorrectableErrors1Hour"
    _PCIE_BANK_UNCORRECTABLE_ERRORS1_HOUR_H = "PCIeBankUncorrectableErrors1HourH"
    _PCIE_BANK_UNCORRECTABLE_ERRORS1_WEEK = "PCIeBankUncorrectableErrors1Week"
    _PCIE_BANK_UNCORRECTABLE_ERRORS1_WEEK_H = "PCIeBankUncorrectableErrors1WeekH"
    _PCIE_BANK_UNCORRECTABLE_ERRORS2_WEEKS = "PCIeBankUncorrectableErrors2Weeks"
    _PCIE_BANK_UNCORRECTABLE_ERRORS2_WEEKS_H = "PCIeBankUncorrectableErrors2WeeksH"
    _PSPCORRECTABLE_ERRORS = "PSPCorrectableErrors"
    _PSPCORRECTABLE_ERRORS15_MIN = "PSPCorrectableErrors15Min"
    _PSPCORRECTABLE_ERRORS15_MIN_H = "PSPCorrectableErrors15MinH"
    _PSPCORRECTABLE_ERRORS1_DAY = "PSPCorrectableErrors1Day"
    _PSPCORRECTABLE_ERRORS1_DAY_H = "PSPCorrectableErrors1DayH"
    _PSPCORRECTABLE_ERRORS1_HOUR = "PSPCorrectableErrors1Hour"
    _PSPCORRECTABLE_ERRORS1_HOUR_H = "PSPCorrectableErrors1HourH"
    _PSPCORRECTABLE_ERRORS1_WEEK = "PSPCorrectableErrors1Week"
    _PSPCORRECTABLE_ERRORS1_WEEK_H = "PSPCorrectableErrors1WeekH"
    _PSPCORRECTABLE_ERRORS2_WEEKS = "PSPCorrectableErrors2Weeks"
    _PSPCORRECTABLE_ERRORS2_WEEKS_H = "PSPCorrectableErrors2WeeksH"
    _PSPUNCORRECTABLE_ERRORS = "PSPUncorrectableErrors"
    _PSPUNCORRECTABLE_ERRORS15_MIN = "PSPUncorrectableErrors15Min"
    _PSPUNCORRECTABLE_ERRORS15_MIN_H = "PSPUncorrectableErrors15MinH"
    _PSPUNCORRECTABLE_ERRORS1_DAY = "PSPUncorrectableErrors1Day"
    _PSPUNCORRECTABLE_ERRORS1_DAY_H = "PSPUncorrectableErrors1DayH"
    _PSPUNCORRECTABLE_ERRORS1_HOUR = "PSPUncorrectableErrors1Hour"
    _PSPUNCORRECTABLE_ERRORS1_HOUR_H = "PSPUncorrectableErrors1HourH"
    _PSPUNCORRECTABLE_ERRORS1_WEEK = "PSPUncorrectableErrors1Week"
    _PSPUNCORRECTABLE_ERRORS1_WEEK_H = "PSPUncorrectableErrors1WeekH"
    _PSPUNCORRECTABLE_ERRORS2_WEEKS = "PSPUncorrectableErrors2Weeks"
    _PSPUNCORRECTABLE_ERRORS2_WEEKS_H = "PSPUncorrectableErrors2WeeksH"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS = "ParameterBlockCorrectableErrors"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS15_MIN = "ParameterBlockCorrectableErrors15Min"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS15_MIN_H = "ParameterBlockCorrectableErrors15MinH"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS1_DAY = "ParameterBlockCorrectableErrors1Day"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS1_DAY_H = "ParameterBlockCorrectableErrors1DayH"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS1_HOUR = "ParameterBlockCorrectableErrors1Hour"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS1_HOUR_H = "ParameterBlockCorrectableErrors1HourH"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS1_WEEK = "ParameterBlockCorrectableErrors1Week"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS1_WEEK_H = "ParameterBlockCorrectableErrors1WeekH"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS2_WEEKS = "ParameterBlockCorrectableErrors2Weeks"
    _PARAMETER_BLOCK_CORRECTABLE_ERRORS2_WEEKS_H = "ParameterBlockCorrectableErrors2WeeksH"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS = "ParameterBlockUncorrectableErrors"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS15_MIN = "ParameterBlockUncorrectableErrors15Min"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS15_MIN_H = "ParameterBlockUncorrectableErrors15MinH"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS1_DAY = "ParameterBlockUncorrectableErrors1Day"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS1_DAY_H = "ParameterBlockUncorrectableErrors1DayH"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS1_HOUR = "ParameterBlockUncorrectableErrors1Hour"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS1_HOUR_H = "ParameterBlockUncorrectableErrors1HourH"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS1_WEEK = "ParameterBlockUncorrectableErrors1Week"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS1_WEEK_H = "ParameterBlockUncorrectableErrors1WeekH"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS2_WEEKS = "ParameterBlockUncorrectableErrors2Weeks"
    _PARAMETER_BLOCK_UNCORRECTABLE_ERRORS2_WEEKS_H = "ParameterBlockUncorrectableErrors2WeeksH"
    _PSU_I2_CERRORS = "PsuI2CErrors"
    _PSU_I2_CERRORS_AVG = "PsuI2CErrorsAvg"
    _PSU_I2_CERRORS_MAX = "PsuI2CErrorsMax"
    _PSU_I2_CERRORS_MIN = "PsuI2CErrorsMin"
    _PSU_TYPE = "PsuType"
    _RWTYPE = "RWType"
    _SATAUNCORRECTABLE_ERRORS = "SATAUncorrectableErrors"
    _SATAUNCORRECTABLE_ERRORS15_MIN = "SATAUncorrectableErrors15Min"
    _SATAUNCORRECTABLE_ERRORS15_MIN_H = "SATAUncorrectableErrors15MinH"
    _SATAUNCORRECTABLE_ERRORS1_DAY = "SATAUncorrectableErrors1Day"
    _SATAUNCORRECTABLE_ERRORS1_DAY_H = "SATAUncorrectableErrors1DayH"
    _SATAUNCORRECTABLE_ERRORS1_HOUR = "SATAUncorrectableErrors1Hour"
    _SATAUNCORRECTABLE_ERRORS1_HOUR_H = "SATAUncorrectableErrors1HourH"
    _SATAUNCORRECTABLE_ERRORS1_WEEK = "SATAUncorrectableErrors1Week"
    _SATAUNCORRECTABLE_ERRORS1_WEEK_H = "SATAUncorrectableErrors1WeekH"
    _SATAUNCORRECTABLE_ERRORS2_WEEKS = "SATAUncorrectableErrors2Weeks"
    _SATAUNCORRECTABLE_ERRORS2_WEEKS_H = "SATAUncorrectableErrors2WeeksH"
    _SATACORRECTABLE_ERRORS = "SATAcorrectableErrors"
    _SATACORRECTABLE_ERRORS15_MIN = "SATAcorrectableErrors15Min"
    _SATACORRECTABLE_ERRORS15_MIN_H = "SATAcorrectableErrors15MinH"
    _SATACORRECTABLE_ERRORS1_DAY = "SATAcorrectableErrors1Day"
    _SATACORRECTABLE_ERRORS1_DAY_H = "SATAcorrectableErrors1DayH"
    _SATACORRECTABLE_ERRORS1_HOUR = "SATAcorrectableErrors1Hour"
    _SATACORRECTABLE_ERRORS1_HOUR_H = "SATAcorrectableErrors1HourH"
    _SATACORRECTABLE_ERRORS1_WEEK = "SATAcorrectableErrors1Week"
    _SATACORRECTABLE_ERRORS1_WEEK_H = "SATAcorrectableErrors1WeekH"
    _SATACORRECTABLE_ERRORS2_WEEKS = "SATAcorrectableErrors2Weeks"
    _SATACORRECTABLE_ERRORS2_WEEKS_H = "SATAcorrectableErrors2WeeksH"
    _SMNUNCORRECTABLE_ERRORS = "SMNUncorrectableErrors"
    _SMNUNCORRECTABLE_ERRORS15_MIN = "SMNUncorrectableErrors15Min"
    _SMNUNCORRECTABLE_ERRORS15_MIN_H = "SMNUncorrectableErrors15MinH"
    _SMNUNCORRECTABLE_ERRORS1_DAY = "SMNUncorrectableErrors1Day"
    _SMNUNCORRECTABLE_ERRORS1_DAY_H = "SMNUncorrectableErrors1DayH"
    _SMNUNCORRECTABLE_ERRORS1_HOUR = "SMNUncorrectableErrors1Hour"
    _SMNUNCORRECTABLE_ERRORS1_HOUR_H = "SMNUncorrectableErrors1HourH"
    _SMNUNCORRECTABLE_ERRORS1_WEEK = "SMNUncorrectableErrors1Week"
    _SMNUNCORRECTABLE_ERRORS1_WEEK_H = "SMNUncorrectableErrors1WeekH"
    _SMNUNCORRECTABLE_ERRORS2_WEEKS = "SMNUncorrectableErrors2Weeks"
    _SMNUNCORRECTABLE_ERRORS2_WEEKS_H = "SMNUncorrectableErrors2WeeksH"
    _SMNCORRECTABLE_ERRORS = "SMNcorrectableErrors"
    _SMNCORRECTABLE_ERRORS15_MIN = "SMNcorrectableErrors15Min"
    _SMNCORRECTABLE_ERRORS15_MIN_H = "SMNcorrectableErrors15MinH"
    _SMNCORRECTABLE_ERRORS1_DAY = "SMNcorrectableErrors1Day"
    _SMNCORRECTABLE_ERRORS1_DAY_H = "SMNcorrectableErrors1DayH"
    _SMNCORRECTABLE_ERRORS1_HOUR = "SMNcorrectableErrors1Hour"
    _SMNCORRECTABLE_ERRORS1_HOUR_H = "SMNcorrectableErrors1HourH"
    _SMNCORRECTABLE_ERRORS1_WEEK = "SMNcorrectableErrors1Week"
    _SMNCORRECTABLE_ERRORS1_WEEK_H = "SMNcorrectableErrors1WeekH"
    _SMNCORRECTABLE_ERRORS2_WEEKS = "SMNcorrectableErrors2Weeks"
    _SMNCORRECTABLE_ERRORS2_WEEKS_H = "SMNcorrectableErrors2WeeksH"
    _SQETEST = "SQETest"
    _SQETEST_DELTA = "SQETestDelta"
    _SQETEST_DELTA_AVG = "SQETestDeltaAvg"
    _SQETEST_DELTA_MAX = "SQETestDeltaMax"
    _SQETEST_DELTA_MIN = "SQETestDeltaMin"
    _SECURED = "Secured"
    _SLOT_OUTLET1 = "SlotOutlet1"
    _SLOT_OUTLET1_AVG = "SlotOutlet1Avg"
    _SLOT_OUTLET1_MAX = "SlotOutlet1Max"
    _SLOT_OUTLET1_MIN = "SlotOutlet1Min"
    _SLOT_OUTLET2 = "SlotOutlet2"
    _SLOT_OUTLET2_AVG = "SlotOutlet2Avg"
    _SLOT_OUTLET2_MAX = "SlotOutlet2Max"
    _SLOT_OUTLET2_MIN = "SlotOutlet2Min"
    _SLOT_OUTLET3 = "SlotOutlet3"
    _SLOT_OUTLET3_AVG = "SlotOutlet3Avg"
    _SLOT_OUTLET3_MAX = "SlotOutlet3Max"
    _SLOT_OUTLET3_MIN = "SlotOutlet3Min"
    _STEP = "Step"
    _SWITCH_ID = "SwitchId"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS = "SystemManagementUnitCorrectableErrors"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS15_MIN = "SystemManagementUnitCorrectableErrors15Min"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS15_MIN_H = "SystemManagementUnitCorrectableErrors15MinH"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS1_DAY = "SystemManagementUnitCorrectableErrors1Day"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS1_DAY_H = "SystemManagementUnitCorrectableErrors1DayH"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS1_HOUR = "SystemManagementUnitCorrectableErrors1Hour"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS1_HOUR_H = "SystemManagementUnitCorrectableErrors1HourH"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS1_WEEK = "SystemManagementUnitCorrectableErrors1Week"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS1_WEEK_H = "SystemManagementUnitCorrectableErrors1WeekH"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS2_WEEKS = "SystemManagementUnitCorrectableErrors2Weeks"
    _SYSTEM_MANAGEMENT_UNIT_CORRECTABLE_ERRORS2_WEEKS_H = "SystemManagementUnitCorrectableErrors2WeeksH"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS = "SystemManagementUnitUncorrectableErrors"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS15_MIN = "SystemManagementUnitUncorrectableErrors15Min"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS15_MIN_H = "SystemManagementUnitUncorrectableErrors15MinH"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS1_DAY = "SystemManagementUnitUncorrectableErrors1Day"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS1_DAY_H = "SystemManagementUnitUncorrectableErrors1DayH"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS1_HOUR = "SystemManagementUnitUncorrectableErrors1Hour"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS1_HOUR_H = "SystemManagementUnitUncorrectableErrors1HourH"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS1_WEEK = "SystemManagementUnitUncorrectableErrors1Week"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS1_WEEK_H = "SystemManagementUnitUncorrectableErrors1WeekH"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS2_WEEKS = "SystemManagementUnitUncorrectableErrors2Weeks"
    _SYSTEM_MANAGEMENT_UNIT_UNCORRECTABLE_ERRORS2_WEEKS_H = "SystemManagementUnitUncorrectableErrors2WeeksH"
    _TIMEOUT_ERRORS = "TimeoutErrors"
    _TIMEOUT_ERRORS15_MIN = "TimeoutErrors15Min"
    _TIMEOUT_ERRORS15_MIN_H = "TimeoutErrors15MinH"
    _TIMEOUT_ERRORS1_DAY = "TimeoutErrors1Day"
    _TIMEOUT_ERRORS1_DAY_H = "TimeoutErrors1DayH"
    _TIMEOUT_ERRORS1_HOUR = "TimeoutErrors1Hour"
    _TIMEOUT_ERRORS1_HOUR_H = "TimeoutErrors1HourH"
    _TIMEOUT_ERRORS1_WEEK = "TimeoutErrors1Week"
    _TIMEOUT_ERRORS1_WEEK_H = "TimeoutErrors1WeekH"
    _TIMEOUT_ERRORS2_WEEKS = "TimeoutErrors2Weeks"
    _TIMEOUT_ERRORS2_WEEKS_H = "TimeoutErrors2WeeksH"
    _TYPE = "Type"
    _USBUNCORRECTABLE_ERRORS = "USBUncorrectableErrors"
    _USBUNCORRECTABLE_ERRORS15_MIN = "USBUncorrectableErrors15Min"
    _USBUNCORRECTABLE_ERRORS15_MIN_H = "USBUncorrectableErrors15MinH"
    _USBUNCORRECTABLE_ERRORS1_DAY = "USBUncorrectableErrors1Day"
    _USBUNCORRECTABLE_ERRORS1_DAY_H = "USBUncorrectableErrors1DayH"
    _USBUNCORRECTABLE_ERRORS1_HOUR = "USBUncorrectableErrors1Hour"
    _USBUNCORRECTABLE_ERRORS1_HOUR_H = "USBUncorrectableErrors1HourH"
    _USBUNCORRECTABLE_ERRORS1_WEEK = "USBUncorrectableErrors1Week"
    _USBUNCORRECTABLE_ERRORS1_WEEK_H = "USBUncorrectableErrors1WeekH"
    _USBUNCORRECTABLE_ERRORS2_WEEKS = "USBUncorrectableErrors2Weeks"
    _USBUNCORRECTABLE_ERRORS2_WEEKS_H = "USBUncorrectableErrors2WeeksH"
    _USBCORRECTABLE_ERRORS = "USBcorrectableErrors"
    _USBCORRECTABLE_ERRORS15_MIN = "USBcorrectableErrors15Min"
    _USBCORRECTABLE_ERRORS15_MIN_H = "USBcorrectableErrors15MinH"
    _USBCORRECTABLE_ERRORS1_DAY = "USBcorrectableErrors1Day"
    _USBCORRECTABLE_ERRORS1_DAY_H = "USBcorrectableErrors1DayH"
    _USBCORRECTABLE_ERRORS1_HOUR = "USBcorrectableErrors1Hour"
    _USBCORRECTABLE_ERRORS1_HOUR_H = "USBcorrectableErrors1HourH"
    _USBCORRECTABLE_ERRORS1_WEEK = "USBcorrectableErrors1Week"
    _USBCORRECTABLE_ERRORS1_WEEK_H = "USBcorrectableErrors1WeekH"
    _USBCORRECTABLE_ERRORS2_WEEKS = "USBcorrectableErrors2Weeks"
    _USBCORRECTABLE_ERRORS2_WEEKS_H = "USBcorrectableErrors2WeeksH"
    _UNCORRECTABLE_LINK_CRCERRORS = "UncorrectableLinkCRCErrors"
    _UNCORRECTABLE_LINK_CRCERRORS15_MIN = "UncorrectableLinkCRCErrors15Min"
    _UNCORRECTABLE_LINK_CRCERRORS15_MIN_H = "UncorrectableLinkCRCErrors15MinH"
    _UNCORRECTABLE_LINK_CRCERRORS1_DAY = "UncorrectableLinkCRCErrors1Day"
    _UNCORRECTABLE_LINK_CRCERRORS1_DAY_H = "UncorrectableLinkCRCErrors1DayH"
    _UNCORRECTABLE_LINK_CRCERRORS1_HOUR = "UncorrectableLinkCRCErrors1Hour"
    _UNCORRECTABLE_LINK_CRCERRORS1_HOUR_H = "UncorrectableLinkCRCErrors1HourH"
    _UNCORRECTABLE_LINK_CRCERRORS1_WEEK = "UncorrectableLinkCRCErrors1Week"
    _UNCORRECTABLE_LINK_CRCERRORS1_WEEK_H = "UncorrectableLinkCRCErrors1WeekH"
    _UNCORRECTABLE_LINK_CRCERRORS2_WEEKS = "UncorrectableLinkCRCErrors2Weeks"
    _UNCORRECTABLE_LINK_CRCERRORS2_WEEKS_H = "UncorrectableLinkCRCErrors2WeeksH"
    _UNIT = "Unit"
    _VMMQ_SUB_VNIC_COUNT = "VmmqSubVnicCount"
    A_PARTIAL_ENUM = "aPartialEnum"
    ABITMASK = "abitmask"
    ABS_MIN_POST_POWER = "absMinPostPower"
    ABS_QUANT = "absQuant"
    ACCELARATED_RFS = "accelaratedRFS"
    ACCESS = "access"
    ACCESS_POLICY = "accessPolicy"
    ACCESS_VLAN_PORT_COUNT = "accessVlanPortCount"
    ACCOUNT_STATUS = "accountStatus"
    ACHAR = "achar"
    ACHARBUF = "acharbuf"
    ACK = "ack"
    ACK_ACTION = "ackAction"
    ACK_PROGRESS_INDICATOR = "ackProgressIndicator"
    ACK_STATE = "ackState"
    ACKED = "acked"
    ACKED_BY = "ackedBy"
    ACQTS = "acqts"
    ACS_VIOLATION_ERRORS = "acsViolationErrors"
    ACS_VIOLATION_ERRORS15_MIN = "acsViolationErrors15Min"
    ACS_VIOLATION_ERRORS15_MIN_H = "acsViolationErrors15MinH"
    ACS_VIOLATION_ERRORS1_DAY = "acsViolationErrors1Day"
    ACS_VIOLATION_ERRORS1_DAY_H = "acsViolationErrors1DayH"
    ACS_VIOLATION_ERRORS1_HOUR = "acsViolationErrors1Hour"
    ACS_VIOLATION_ERRORS1_HOUR_H = "acsViolationErrors1HourH"
    ACS_VIOLATION_ERRORS1_WEEK = "acsViolationErrors1Week"
    ACS_VIOLATION_ERRORS1_WEEK_H = "acsViolationErrors1WeekH"
    ACS_VIOLATION_ERRORS2_WEEKS = "acsViolationErrors2Weeks"
    ACS_VIOLATION_ERRORS2_WEEKS_H = "acsViolationErrors2WeeksH"
    ACTION = "action"
    ACTIVE_STATUS = "activeStatus"
    ACTIVE_TIMEOUT = "activeTimeout"
    ACTIVITY_NAME = "activityName"
    ACTIVITY_TRIGGER_TIME = "activityTriggerTime"
    ACTIVITY_TS = "activityTs"
    ACTUAL_COUNT = "actualCount"
    ACTUAL_WRITE_CACHE_POLICY = "actualWriteCachePolicy"
    ADAPTER = "adapter"
    ADAPTER_ID = "adapterId"
    ADAPTOR_EP = "adaptorEp"
    ADAPTOR_FAMILY = "adaptorFamily"
    ADAPTOR_ID = "adaptorId"
    ADAPTOR_MODEL = "adaptorModel"
    ADAPTOR_PROFILE_NAME = "adaptorProfileName"
    ADAPTOR_SLOT_NUMBER = "adaptorSlotNumber"
    ADAPTOR_SLOT_SPAN = "adaptorSlotSpan"
    ADAPTOR_TYPE = "adaptorType"
    ADATE = "adate"
    ADATETIME = "adatetime"
    ADDITIONAL_INFO = "additionalInfo"
    ADDR = "addr"
    ADDRESS = "address"
    ADDRESS_PARITY_ERRORS = "addressParityErrors"
    ADDRESS_PARITY_ERRORS15_MIN = "addressParityErrors15Min"
    ADDRESS_PARITY_ERRORS15_MIN_H = "addressParityErrors15MinH"
    ADDRESS_PARITY_ERRORS1_DAY = "addressParityErrors1Day"
    ADDRESS_PARITY_ERRORS1_DAY_H = "addressParityErrors1DayH"
    ADDRESS_PARITY_ERRORS1_HOUR = "addressParityErrors1Hour"
    ADDRESS_PARITY_ERRORS1_HOUR_H = "addressParityErrors1HourH"
    ADDRESS_PARITY_ERRORS1_WEEK = "addressParityErrors1Week"
    ADDRESS_PARITY_ERRORS1_WEEK_H = "addressParityErrors1WeekH"
    ADDRESS_PARITY_ERRORS2_WEEKS = "addressParityErrors2Weeks"
    ADDRESS_PARITY_ERRORS2_WEEKS_H = "addressParityErrors2WeeksH"
    ADDRESS_PARITY_ERRORS_CORRECTABLE = "addressParityErrorsCorrectable"
    ADDRESS_PARITY_ERRORS_CORRECTABLE15_MIN = "addressParityErrorsCorrectable15Min"
    ADDRESS_PARITY_ERRORS_CORRECTABLE15_MIN_H = "addressParityErrorsCorrectable15MinH"
    ADDRESS_PARITY_ERRORS_CORRECTABLE1_DAY = "addressParityErrorsCorrectable1Day"
    ADDRESS_PARITY_ERRORS_CORRECTABLE1_DAY_H = "addressParityErrorsCorrectable1DayH"
    ADDRESS_PARITY_ERRORS_CORRECTABLE1_HOUR = "addressParityErrorsCorrectable1Hour"
    ADDRESS_PARITY_ERRORS_CORRECTABLE1_HOUR_H = "addressParityErrorsCorrectable1HourH"
    ADDRESS_PARITY_ERRORS_CORRECTABLE1_WEEK = "addressParityErrorsCorrectable1Week"
    ADDRESS_PARITY_ERRORS_CORRECTABLE1_WEEK_H = "addressParityErrorsCorrectable1WeekH"
    ADDRESS_PARITY_ERRORS_CORRECTABLE2_WEEKS = "addressParityErrorsCorrectable2Weeks"
    ADDRESS_PARITY_ERRORS_CORRECTABLE2_WEEKS_H = "addressParityErrorsCorrectable2WeeksH"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE = "addressParityErrorsUnCorrectable"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE15_MIN = "addressParityErrorsUnCorrectable15Min"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE15_MIN_H = "addressParityErrorsUnCorrectable15MinH"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE1_DAY = "addressParityErrorsUnCorrectable1Day"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE1_DAY_H = "addressParityErrorsUnCorrectable1DayH"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE1_HOUR = "addressParityErrorsUnCorrectable1Hour"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE1_HOUR_H = "addressParityErrorsUnCorrectable1HourH"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE1_WEEK = "addressParityErrorsUnCorrectable1Week"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE1_WEEK_H = "addressParityErrorsUnCorrectable1WeekH"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE2_WEEKS = "addressParityErrorsUnCorrectable2Weeks"
    ADDRESS_PARITY_ERRORS_UN_CORRECTABLE2_WEEKS_H = "addressParityErrorsUnCorrectable2WeeksH"
    ADDRESS_WIDTH = "addressWidth"
    ADMIN_ACTION = "adminAction"
    ADMIN_ACTION_TRIGGER = "adminActionTrigger"
    ADMIN_CDN_NAME = "adminCdnName"
    ADMIN_COMMITTED = "adminCommitted"
    ADMIN_EVAC_STATE = "adminEvacState"
    ADMIN_FPLOCK_STATE = "adminFPLockState"
    ADMIN_HOST_PORT = "adminHostPort"
    ADMIN_INBAND_IF_STATE = "adminInbandIfState"
    ADMIN_MEMORY_STATE = "adminMemoryState"
    ADMIN_NAME = "adminName"
    ADMIN_OPERATION = "adminOperation"
    ADMIN_PEAK = "adminPeak"
    ADMIN_PEAK_NEW = "adminPeakNew"
    ADMIN_PEER_POWER_STATE = "adminPeerPowerState"
    ADMIN_POWER = "adminPower"
    ADMIN_POWER_STATE = "adminPowerState"
    ADMIN_PROP_MASK = "adminPropMask"
    ADMIN_SECURITY_KEY = "adminSecurityKey"
    ADMIN_SLOT_NUMBER = "adminSlotNumber"
    ADMIN_SPEED = "adminSpeed"
    ADMIN_STATE = "adminState"
    ADMIN_TRANSPORT = "adminTransport"
    ADMIN_VCON = "adminVcon"
    ADMIN_VIRTUAL_DRIVE_ID = "adminVirtualDriveId"
    ADP_AZURE_QOS = "adpAzureQos"
    ADP_VIF_ID = "adpVifId"
    ADV_BOOT_ORDER_APPLICABLE = "advBootOrderApplicable"
    AFFECTED = "affected"
    AFFECTED_CHASSIS = "affectedChassis"
    AFFECTED_CHASSIS_CNT = "affectedChassisCnt"
    AFFECTED_OBJ = "affectedObj"
    AFFECTED_SERVER = "affectedServer"
    AFFECTED_SERVERS = "affectedServers"
    AFLOAT = "afloat"
    AGENT_POLICY_NAME = "agentPolicyName"
    AGGR_PORT_ID = "aggrPortId"
    AGGREGATION_CAP = "aggregationCap"
    AGGRESSIVE_COOLING = "aggressiveCooling"
    AHCI_SETTING = "ahciSetting"
    AIRFLOW_DIRECTION = "airflowDirection"
    ALARM_DESC = "alarmDesc"
    ALARM_SEVERITY = "alarmSeverity"
    ALARM_TYPE = "alarmType"
    ALERT_GROUPS = "alertGroups"
    ALERT_THROTTLING_ADMIN_STATE = "alertThrottlingAdminState"
    ALIAS = "alias"
    ALIGN = "align"
    ALIGN_DELTA = "alignDelta"
    ALIGN_DELTA_AVG = "alignDeltaAvg"
    ALIGN_DELTA_MAX = "alignDeltaMax"
    ALIGN_DELTA_MIN = "alignDeltaMin"
    ALLOC_STATE = "allocState"
    ALLOC_STATUS = "allocStatus"
    ALLOWED_SSLPROTOCOLS = "allowedSSLProtocols"
    ALLOWED_VNIC_TYPE = "allowedVnicType"
    ALWAYS_USE = "alwaysUse"
    AMAC = "amac"
    AMBIENT_TEMP = "ambientTemp"
    AMBIENT_TEMP_AVG = "ambientTempAvg"
    AMBIENT_TEMP_MAX = "ambientTempMax"
    AMBIENT_TEMP_MIN = "ambientTempMin"
    ANALYZE_IMPACT_CHANGE_DETAILS = "analyzeImpactChangeDetails"
    ANALYZE_IMPACT_CHANGES = "analyzeImpactChanges"
    ANALYZE_IMPACT_EXTD_CHANGE_DETAILS = "analyzeImpactExtdChangeDetails"
    AND_OPERATION = "andOperation"
    ANENUM = "anenum"
    ANIPV4 = "anipv4"
    ANIPV6 = "anipv6"
    ANSBYTE = "ansbyte"
    ANSINT16 = "ansint16"
    ANSINT32 = "ansint32"
    ANSINT64 = "ansint64"
    APASSWORD = "apassword"
    API = "api"
    APP_CONNECTOR_ID = "appConnectorId"
    APP_DIRECT_CAPACITY = "appDirectCapacity"
    APP_TYPE = "appType"
    APPLY = "apply"
    ARANGE = "arange"
    ARCH = "arch"
    ARCSTRING = "arcstring"
    ARRAY = "array"
    ARXSTRING = "arxstring"
    ASIC = "asic"
    ASIC_NUMBER = "asicNumber"
    ASSET_TAG = "assetTag"
    ASSIGN_STATE = "assignState"
    ASSIGNED = "assigned"
    ASSIGNED_TO_DN = "assignedToDn"
    ASSIGNMENT_ORDER = "assignmentOrder"
    ASSOC_PRIMARY_VLAN_STATE = "assocPrimaryVlanState"
    ASSOC_PRIMARY_VLAN_SWITCH_ID = "assocPrimaryVlanSwitchId"
    ASSOC_STATE = "assocState"
    ASSOCIATION = "association"
    ASTRING = "astring"
    ATIME = "atime"
    ATTEMPTED_WITHIN = "attemptedWithin"
    ATTRIBUTE = "attribute"
    AUBYTE = "aubyte"
    AUDITS = "audits"
    AUINT16 = "auint16"
    AUINT32 = "auint32"
    AUINT64 = "auint64"
    AUTH = "auth"
    AUTH_DOMAIN = "authDomain"
    AUTH_OPTION = "authOption"
    AUTH_PORT = "authPort"
    AUTH_PROFILE_NAME = "authProfileName"
    AUTH_USER = "authUser"
    AUTHORIZATION = "authorization"
    AUTO_CONFIG_MODE = "autoConfigMode"
    AUTO_CONFIG_MODE_SUPPORTED = "autoConfigModeSupported"
    AUTO_DELETE = "autoDelete"
    AUTO_DEPLOY = "autoDeploy"
    AUTO_NEGOTIATE = "autoNegotiate"
    AUTO_RECOVERY = "autoRecovery"
    AUTO_RECOVERY_TIME = "autoRecoveryTime"
    AUTO_ZONE_CAUSE = "autoZoneCause"
    AVAILABILITY = "availability"
    AVAILABLE = "available"
    AVAILABLE_AVG = "availableAvg"
    AVAILABLE_MAX = "availableMax"
    AVAILABLE_MEMORY = "availableMemory"
    AVAILABLE_MIN = "availableMin"
    AVAILABLE_POWER = "availablePower"
    AVAILABLE_POWER_AVG = "availablePowerAvg"
    AVAILABLE_POWER_MAX = "availablePowerMax"
    AVAILABLE_POWER_MIN = "availablePowerMin"
    AVAILABLE_SIZE = "availableSize"
    AWWN = "awwn"
    BACK_UP_HOLDER_OPER_STATE = "backUpHolderOperState"
    BACK_UP_HOLDER_PACK_VERSION = "backUpHolderPackVersion"
    BACK_UP_VERSION = "backUpVersion"
    BACKPLANE_PORT_TIMER = "backplanePortTimer"
    BACKPLANE_SPEED_PREF = "backplaneSpeedPref"
    BACKUP_COUNT = "backupCount"
    BACKUP_DATE = "backupDate"
    BACKUP_ISSUE = "backupIssue"
    BACKUPSTATUS = "backupstatus"
    BAD_CRC_PACKETS = "badCrcPackets"
    BAD_CRC_PACKETS_DELTA = "badCrcPacketsDelta"
    BAD_CRC_PACKETS_DELTA_AVG = "badCrcPacketsDeltaAvg"
    BAD_CRC_PACKETS_DELTA_MAX = "badCrcPacketsDeltaMax"
    BAD_CRC_PACKETS_DELTA_MIN = "badCrcPacketsDeltaMin"
    BAD_LENGTH_PACKETS = "badLengthPackets"
    BAD_LENGTH_PACKETS_DELTA = "badLengthPacketsDelta"
    BAD_LENGTH_PACKETS_DELTA_AVG = "badLengthPacketsDeltaAvg"
    BAD_LENGTH_PACKETS_DELTA_MAX = "badLengthPacketsDeltaMax"
    BAD_LENGTH_PACKETS_DELTA_MIN = "badLengthPacketsDeltaMin"
    BANDWIDTH = "bandwidth"
    BANK = "bank"
    BASE_ADDR = "baseAddr"
    BASE_CONTAINER = "baseContainer"
    BASE_MAC = "baseMac"
    BASEDN = "basedn"
    BATTERY_TYPE = "batteryType"
    BBU_STATUS = "bbuStatus"
    BIOS_PROFILE_NAME = "biosProfileName"
    BIOS_RET_SETTING_NAME = "biosRetSettingName"
    BIOS_SETTINGS_SCRUB = "biosSettingsScrub"
    BIOS_TOKEN_ID = "biosTokenId"
    BIOS_TOKEN_NAME = "biosTokenName"
    BIOS_TOKEN_VALUE = "biosTokenValue"
    BIOS_VERSION = "biosVersion"
    BITMASK = "bitmask"
    BLACK_LISTING = "blackListing"
    BLADE_BUNDLE_NAME = "bladeBundleName"
    BLADE_BUNDLE_VERSION = "bladeBundleVersion"
    BLADE_ID = "bladeId"
    BLKSIZE = "blksize"
    BLOCK_LOGIN = "blockLogin"
    BLOCK_SIZE = "blockSize"
    BLOCKS = "blocks"
    BOARD_AGGREGATION_ROLE = "boardAggregationRole"
    BOARD_CONNECTOR_TYPE = "boardConnectorType"
    BOARD_FRU = "boardFru"
    BOARD_MANUFACTURER = "boardManufacturer"
    BOARD_MFG_TIME = "boardMfgTime"
    BOARD_PART_NO = "boardPartNo"
    BOARD_PRODUCT_NAME = "boardProductName"
    BOARD_SERIAL_NO = "boardSerialNo"
    BOARD_TYPE = "boardType"
    BOARD_VID = "boardVid"
    BOOT = "boot"
    BOOT_DESCRIPTION = "bootDescription"
    BOOT_DEV = "bootDev"
    BOOT_DEV_TYPE = "bootDevType"
    BOOT_IP_POLICY_NAME = "bootIpPolicyName"
    BOOT_LOADER_NAME = "bootLoaderName"
    BOOT_LOADER_PATH = "bootLoaderPath"
    BOOT_MODE = "bootMode"
    BOOT_ORDER_TYPE = "bootOrderType"
    BOOT_POLICY_NAME = "bootPolicyName"
    BOOT_POWER = "bootPower"
    BOOT_TO_TARGET = "bootToTarget"
    BOOTABLE = "bootable"
    BORDER_AGGR_PORT_ID = "borderAggrPortId"
    BORDER_PORT_ID = "borderPortId"
    BORDER_SLOT_ID = "borderSlotId"
    BORDER_VFC_ID = "borderVfcId"
    BORDER_VLAN_PORT_COUNT = "borderVlanPortCount"
    BREAKOUT_PORT_SPEED_GB = "breakoutPortSpeedGb"
    BREAKOUT_TYPE = "breakoutType"
    BROADCAST_PACKETS = "broadcastPackets"
    BROADCAST_PACKETS_DELTA = "broadcastPacketsDelta"
    BROADCAST_PACKETS_DELTA_AVG = "broadcastPacketsDeltaAvg"
    BROADCAST_PACKETS_DELTA_MAX = "broadcastPacketsDeltaMax"
    BROADCAST_PACKETS_DELTA_MIN = "broadcastPacketsDeltaMin"
    BUFFER_OVERFLOW_ERRORS = "bufferOverflowErrors"
    BUFFER_OVERFLOW_ERRORS15_MIN = "bufferOverflowErrors15Min"
    BUFFER_OVERFLOW_ERRORS15_MIN_H = "bufferOverflowErrors15MinH"
    BUFFER_OVERFLOW_ERRORS1_DAY = "bufferOverflowErrors1Day"
    BUFFER_OVERFLOW_ERRORS1_DAY_H = "bufferOverflowErrors1DayH"
    BUFFER_OVERFLOW_ERRORS1_HOUR = "bufferOverflowErrors1Hour"
    BUFFER_OVERFLOW_ERRORS1_HOUR_H = "bufferOverflowErrors1HourH"
    BUFFER_OVERFLOW_ERRORS1_WEEK = "bufferOverflowErrors1Week"
    BUFFER_OVERFLOW_ERRORS1_WEEK_H = "bufferOverflowErrors1WeekH"
    BUFFER_OVERFLOW_ERRORS2_WEEKS = "bufferOverflowErrors2Weeks"
    BUFFER_OVERFLOW_ERRORS2_WEEKS_H = "bufferOverflowErrors2WeeksH"
    BULKED = "bulked"
    BUNDLE_NAME = "bundleName"
    BUNDLE_TYPE = "bundleType"
    BUNDLE_VERSION = "bundleVersion"
    BURST = "burst"
    BUS_ADDRESS = "busAddress"
    BW_PERCENT = "bwPercent"
    BYTES_RX = "bytesRx"
    BYTES_RX_DELTA = "bytesRxDelta"
    BYTES_RX_DELTA_AVG = "bytesRxDeltaAvg"
    BYTES_RX_DELTA_MAX = "bytesRxDeltaMax"
    BYTES_RX_DELTA_MIN = "bytesRxDeltaMin"
    BYTES_TX = "bytesTx"
    BYTES_TX_DELTA = "bytesTxDelta"
    BYTES_TX_DELTA_AVG = "bytesTxDeltaAvg"
    BYTES_TX_DELTA_MAX = "bytesTxDeltaMax"
    BYTES_TX_DELTA_MIN = "bytesTxDeltaMin"
    BYTES_EG = "bytes_eg"
    BYTES_IN = "bytes_in"
    C_TYPE = "cType"
    CA_CERTIFICATE = "caCertificate"
    CACHE_SIZE = "cacheSize"
    CACHED = "cached"
    CACHED_AVG = "cachedAvg"
    CACHED_MAX = "cachedMax"
    CACHED_MIN = "cachedMin"
    CACHENOSPC = "cachenospc"
    CAN_BE_FRUED = "canBeFRUed"
    CAP_ACTION = "capAction"
    CAPABILITIES = "capabilities"
    CAPABILITY = "capability"
    CAPACITY = "capacity"
    CAPACITY_PERCENTAGE = "capacityPercentage"
    CAPTION = "caption"
    CARD_HEALTH = "cardHealth"
    CARD_MODE = "cardMode"
    CARD_PARAM_TYPE = "cardParamType"
    CARD_STATE = "cardState"
    CARD_SYNC = "cardSync"
    CARD_TYPE = "cardType"
    CARRIER_SENSE = "carrierSense"
    CARRIER_SENSE_DELTA = "carrierSenseDelta"
    CARRIER_SENSE_DELTA_AVG = "carrierSenseDeltaAvg"
    CARRIER_SENSE_DELTA_MAX = "carrierSenseDeltaMax"
    CARRIER_SENSE_DELTA_MIN = "carrierSenseDeltaMin"
    CARTRIDGE_CIMCID = "cartridgeCIMCId"
    CARTRIDGE_ID = "cartridgeId"
    CATALOG_NAME = "catalogName"
    CATALOG_POWER = "catalogPower"
    CATALOG_VERSION = "catalogVersion"
    CATEGORY = "category"
    CAUSE = "cause"
    CDN_NAME = "cdnName"
    CDN_PROP_IN_SYNC = "cdnPropInSync"
    CDN_SOURCE = "cdnSource"
    CDP = "cdp"
    CDP_LINK_POLICY_NAME = "cdpLinkPolicyName"
    CENTRALE_MO_DN = "centraleMoDn"
    CENTRALE_VNET_EP_DN = "centraleVnetEpDn"
    CERT = "cert"
    CERT_CHAIN = "certChain"
    CERT_CONTENT = "certContent"
    CERT_FILE = "certFile"
    CERT_HASH_KEY = "certHashKey"
    CERT_ID = "certId"
    CERT_SIGN_REQUEST = "certSignRequest"
    CERT_STATUS = "certStatus"
    CERT_TYPE = "certType"
    CERTIFICATE = "certificate"
    CFGD_MEMORY_PERCENTAGE = "cfgdMemoryPercentage"
    CH_RSRVD_POWER = "chRsrvdPower"
    CHANGE_BY = "changeBy"
    CHANGE_COUNT = "changeCount"
    CHANGE_DETAILS = "changeDetails"
    CHANGE_DURING_INTERVAL = "changeDuringInterval"
    CHANGE_ID = "changeId"
    CHANGE_INTERVAL = "changeInterval"
    CHANGE_MODE = "changeMode"
    CHANGE_QUALIFIER = "changeQualifier"
    CHANGE_SET = "changeSet"
    CHANGED_MO_CLASS_ID = "changedMoClassId"
    CHANGES = "changes"
    CHANNEL_STATE = "channelState"
    CHASSIS1 = "chassis1"
    CHASSIS2 = "chassis2"
    CHASSIS3 = "chassis3"
    CHASSIS_BUNDLE_NAME = "chassisBundleName"
    CHASSIS_BUNDLE_VERSION = "chassisBundleVersion"
    CHASSIS_CARTRIDGE_ID = "chassisCartridgeId"
    CHASSIS_CIMC_ID = "chassisCimcId"
    CHASSIS_COMP_IN_ACTIVATION_DN = "chassisCompInActivationDn"
    CHASSIS_COMPONENT = "chassisComponent"
    CHASSIS_CONFIG_ISSUES = "chassisConfigIssues"
    CHASSIS_CONFIG_QUALIFIER = "chassisConfigQualifier"
    CHASSIS_CONFIG_STATE = "chassisConfigState"
    CHASSIS_DEVICE_IO_STATE1 = "chassisDeviceIoState1"
    CHASSIS_DEVICE_IO_STATE2 = "chassisDeviceIoState2"
    CHASSIS_DEVICE_IO_STATE3 = "chassisDeviceIoState3"
    CHASSIS_DN = "chassisDn"
    CHASSIS_FW_POLICY_NAME = "chassisFwPolicyName"
    CHASSIS_ID = "chassisId"
    CHASSIS_IOM_ID = "chassisIomId"
    CHASSIS_MAC = "chassisMac"
    CHASSIS_PART_NO = "chassisPartNo"
    CHASSIS_POOL_DN = "chassisPoolDn"
    CHASSIS_SERIAL_NO = "chassisSerialNo"
    CHECK_APPLY_CONFIG_COOKIE = "checkApplyConfigCookie"
    CHECK_POINT = "checkPoint"
    CHECK_RUNNING_VER = "checkRunningVer"
    CHECKPOINT_TRIG_TS = "checkpointTrigTs"
    CHECKSUM = "checksum"
    CHILD_ACTION = "childAction"
    CHILD_CLASS_ID = "childClassId"
    CIMC_ADAPTER_ID = "cimcAdapterId"
    CIMC_ADDR = "cimcAddr"
    CIMC_IDS = "cimcIds"
    CIMC_VERSION = "cimcVersion"
    CIPHER_SUITE = "cipherSuite"
    CIPHER_SUITE_MODE = "cipherSuiteMode"
    CL_INST_TYPE = "clInstType"
    CLAIM_STATE = "claimState"
    CLASS_NAME = "className"
    CLASS_TYPE = "classType"
    CLEANUP_MODE = "cleanupMode"
    CLEANUP_PARENT_ON_DISCOVERY = "cleanupParentOnDiscovery"
    CLEAR_ACTION = "clearAction"
    CLEAR_INTERVAL = "clearInterval"
    CLEAR_ON_BACKUP = "clearOnBackup"
    CLEAR_PWD_HISTORY = "clearPwdHistory"
    CLEI = "clei"
    CLI_ID = "cliId"
    CLIENT_CONFIG_STATE = "clientConfigState"
    CLIENT_MO_DN = "clientMoDn"
    CLIENT_TYPE = "clientType"
    CLOCK = "clock"
    CLOUD = "cloud"
    CLUSTER_STATE = "clusterState"
    CMC_SUPPORTED_STORAGE_FEATURES = "cmcSupportedStorageFeatures"
    CMC_SUPPORTED_STORAGE_OPS = "cmcSupportedStorageOps"
    CMC_TEMP = "cmcTemp"
    CMC_TEMP_AVG = "cmcTempAvg"
    CMC_TEMP_MAX = "cmcTempMax"
    CMC_TEMP_MIN = "cmcTempMin"
    CMDLINE = "cmdline"
    CMOS_RESET_SUPPORTED = "cmosResetSupported"
    CMOS_VOLTAGE = "cmosVoltage"
    COALESCING_TIME = "coalescingTime"
    COALESCING_TYPE = "coalescingType"
    CODE = "code"
    COLL_INTERVAL = "collInterval"
    COLLECTION_INTERVAL = "collectionInterval"
    COLOR = "color"
    COMM_METHOD = "commMethod"
    COMM_TYPE = "commType"
    COMMAND_OPTIONS = "commandOptions"
    COMMON_NAME = "commonName"
    COMMUNICATION_TYPE = "communicationType"
    COMMUNITY = "community"
    COMP = "comp"
    COMPLETENESS = "completeness"
    COMPLETION = "completion"
    COMPLETION_TIME = "completionTime"
    COMPONENT_ID = "componentId"
    COMPRESSED_OPTIMIZATION_SETS = "compressedOptimizationSets"
    COMPRESSED_VLAN_PORT_COUNT = "compressedVlanPortCount"
    COMPRESSION_TYPE = "compressionType"
    COMPUTE_CONN_POLICY_NAME = "computeConnPolicyName"
    COMPUTE_EP_DN = "computeEpDn"
    COMPUTE_EP_VENDOR = "computeEpVendor"
    CON_LOGIN = "conLogin"
    CON_POLICY_NAME = "conPolicyName"
    CONCUR_CAP = "concurCap"
    CONF = "conf"
    CONF_MODE = "confMode"
    CONF_QUAL = "confQual"
    CONF_STATE = "confState"
    CONFIG = "config"
    CONFIG_CHECK_POINT = "configCheckPoint"
    CONFIG_ERROR_DESC = "configErrorDesc"
    CONFIG_FAIL_REASON = "configFailReason"
    CONFIG_ISSUE = "configIssue"
    CONFIG_ISSUES = "configIssues"
    CONFIG_MESSAGE = "configMessage"
    CONFIG_OVERLAP = "configOverlap"
    CONFIG_PARM_MOD_SUPPORTED = "configParmModSupported"
    CONFIG_QUAL = "configQual"
    CONFIG_QUALIFIER = "configQualifier"
    CONFIG_QUALIFIER_REASON = "configQualifierReason"
    CONFIG_RESULT = "configResult"
    CONFIG_SEQUENCE_NO = "configSequenceNo"
    CONFIG_STATE = "configState"
    CONFIG_STATUS = "configStatus"
    CONFIG_STATUS_MESSAGE = "configStatusMessage"
    CONFIG_WARNINGS = "configWarnings"
    CONFIGURATION = "configuration"
    CONFIGURED_MODE = "configuredMode"
    CONFIGURED_WRITE_CACHE_POLICY = "configuredWriteCachePolicy"
    CONN_PATH = "connPath"
    CONN_PROTOCOL = "connProtocol"
    CONN_STATUS = "connStatus"
    CONNECTED_ADAPTOR_TYPE = "connectedAdaptorType"
    CONNECTION_MANAGEMENT = "connectionManagement"
    CONNECTION_PROTOCOL = "connectionProtocol"
    CONNECTION_SERIAL = "connectionSerial"
    CONNECTION_TIME_OUT = "connectionTimeOut"
    CONS_DN = "consDn"
    CONS_TYPE = "consType"
    CONSTANT_NAME = "constantName"
    CONSTRAINT_TYPE = "constraintType"
    CONSUMED_POWER = "consumedPower"
    CONSUMED_POWER_AVG = "consumedPowerAvg"
    CONSUMED_POWER_MAX = "consumedPowerMax"
    CONSUMED_POWER_MIN = "consumedPowerMin"
    CONT_CLASS_ID = "contClassId"
    CONT_INST_ID = "contInstId"
    CONT_INST_ID_PROP_ID = "contInstIdPropId"
    CONTACT = "contact"
    CONTAINER_ID = "containerId"
    CONTAINMENT_METHOD = "containmentMethod"
    CONTEXT = "context"
    CONTRACT = "contract"
    CONTROL_PLANE_MAC1 = "controlPlaneMac1"
    CONTROL_PLANE_MAC2 = "controlPlaneMac2"
    CONTROL_REQUESTS = "controlRequests"
    CONTROL_REQUESTS_DELTA = "controlRequestsDelta"
    CONTROL_REQUESTS_DELTA_AVG = "controlRequestsDeltaAvg"
    CONTROL_REQUESTS_DELTA_MAX = "controlRequestsDeltaMax"
    CONTROL_REQUESTS_DELTA_MIN = "controlRequestsDeltaMin"
    CONTROLLER_DEF_TYPE = "controllerDefType"
    CONTROLLER_DN = "controllerDn"
    CONTROLLER_FLAGS = "controllerFlags"
    CONTROLLER_HEALTH = "controllerHealth"
    CONTROLLER_ID = "controllerId"
    CONTROLLER_INDEX = "controllerIndex"
    CONTROLLER_MODE = "controllerMode"
    CONTROLLER_OPS = "controllerOps"
    CONTROLLER_REPORTED = "controllerReported"
    CONTROLLER_STATE = "controllerState"
    CONTROLLER_STATUS = "controllerStatus"
    CONTROLLER_SUB_TYPE = "controllerSubType"
    CONTROLLER_TYPE = "controllerType"
    CONTROLLER_VERSION = "controllerVersion"
    CONVERTED_DN = "convertedDn"
    CONVERTED_EP_REF = "convertedEpRef"
    COOKIE = "cookie"
    CORE_PORT_TIMER = "corePortTimer"
    CORES = "cores"
    CORES_ENABLED = "coresEnabled"
    CORRECTABLE_ERRORS = "correctableErrors"
    CORRECTABLE_ERRORS_DELTA = "correctableErrorsDelta"
    CORRECTABLE_ERRORS_DELTA_AVG = "correctableErrorsDeltaAvg"
    CORRECTABLE_ERRORS_DELTA_MAX = "correctableErrorsDeltaMax"
    CORRECTABLE_ERRORS_DELTA_MIN = "correctableErrorsDeltaMin"
    CORRUPTED_COUNT = "corruptedCount"
    COS = "cos"
    COS_VALUE = "cosValue"
    COUNT = "count"
    COUNT_BREAKOUT_PORTS = "countBreakoutPorts"
    COUNTRY = "country"
    COUNTRY_CODE = "countryCode"
    CPU_FILTER = "cpuFilter"
    CPU_ID = "cpuId"
    CPU_TYPE_DESCRIPTION = "cpuTypeDescription"
    CRC = "crc"
    CRC_DELTA = "crcDelta"
    CRC_DELTA_AVG = "crcDeltaAvg"
    CRC_DELTA_MAX = "crcDeltaMax"
    CRC_DELTA_MIN = "crcDeltaMin"
    CRC_RX = "crcRx"
    CRC_RX_DELTA = "crcRxDelta"
    CRC_RX_DELTA_AVG = "crcRxDeltaAvg"
    CRC_RX_DELTA_MAX = "crcRxDeltaMax"
    CRC_RX_DELTA_MIN = "crcRxDeltaMin"
    CREATE_INITIAL_VOLUMES = "createInitialVolumes"
    CREATED = "created"
    CREATION_DATE = "creationDate"
    CREATION_TS = "creationTS"
    CREATION_TIME = "creationTime"
    CTIME = "ctime"
    CTPASSWORD = "ctpassword"
    CUR_REQ_POWER = "curReqPower"
    CURR_CAPACITY = "currCapacity"
    CURRENT = "current"
    CURRENT_AVG = "currentAvg"
    CURRENT_EPFB = "currentEPFB"
    CURRENT_FSM = "currentFsm"
    CURRENT_MAX = "currentMax"
    CURRENT_MIN = "currentMin"
    CURRENT_POWER = "currentPower"
    CURRENT_TIME = "currentTime"
    CURRENT_ZONE_PREFIX = "currentZonePrefix"
    CUSTOM_FACTOR = "customFactor"
    CUSTOM_POLICY = "customPolicy"
    CUSTOMER = "customer"
    DATA = "data"
    DATA_DISR = "dataDisr"
    DATA_PLANE_MAC1 = "dataPlaneMac1"
    DATA_PLANE_MAC2 = "dataPlaneMac2"
    DATA_PLANE_WWN1 = "dataPlaneWwn1"
    DATA_PLANE_WWN2 = "dataPlaneWwn2"
    DATA_SRC_APP_TYPE = "dataSrcAppType"
    DATA_SRC_SYS_ID = "dataSrcSysId"
    DATA_WIDTH = "dataWidth"
    DATABASE_VERSION = "databaseVersion"
    DATE = "date"
    DAY = "day"
    DBTXS = "dbtxs"
    DC_NAME = "dcName"
    DC_ORG = "dcOrg"
    DECISION_TYPE = "decisionType"
    DEEP_CHECKPOINT_TRIG_TS = "deepCheckpointTrigTs"
    DEESCALATING = "deescalating"
    DEF_DN = "defDn"
    DEF_GW = "defGw"
    DEF_INT_ID = "defIntId"
    DEF_LOGIN = "defLogin"
    DEF_QUANT = "defQuant"
    DEF_ROLE_POLICY = "defRolePolicy"
    DEFAULT_FACTOR = "defaultFactor"
    DEFAULT_LEVEL = "defaultLevel"
    DEFAULT_NET = "defaultNet"
    DEFAULT_POLICY = "defaultPolicy"
    DEFAULT_POLICY_NAME = "defaultPolicyName"
    DEFAULT_SIZE = "defaultSize"
    DEFAULT_SP_VERSION = "defaultSpVersion"
    DEFAULT_STRIP_SIZE = "defaultStripSize"
    DEFAULT_THRESHOLDS_ADDED = "defaultThresholdsAdded"
    DEFAULT_VLAN = "defaultVlan"
    DEFAULT_VLAN_NAME = "defaultVlanName"
    DEFAULT_ZONING = "defaultZoning"
    DEFERRED_NAMING = "deferredNaming"
    DEFERRED_TX = "deferredTx"
    DEFERRED_TX_DELTA = "deferredTxDelta"
    DEFERRED_TX_DELTA_AVG = "deferredTxDeltaAvg"
    DEFERRED_TX_DELTA_MAX = "deferredTxDeltaMax"
    DEFERRED_TX_DELTA_MIN = "deferredTxDeltaMin"
    DEFINED_IN_IDM = "definedInIdm"
    DEL_FE_TS = "delFeTs"
    DELETED = "deleted"
    DEPLOY_ACTION = "deployAction"
    DEPLOY_FLAG = "deployFlag"
    DEPLOYED_KEY_FLAG = "deployedKeyFlag"
    DEPLOYED_SECURE_PASSPHRASE = "deployedSecurePassphrase"
    DEPLOYED_SECURITY_KEY = "deployedSecurityKey"
    DEPLOYMENT = "deployment"
    DEPLOYMENT_MODE = "deploymentMode"
    DEPRECATED = "deprecated"
    DEPTH = "depth"
    DERIVED_FROM_ID = "derivedFromId"
    DESCR = "descr"
    DESCRIPTION = "description"
    DESIRED_MAINTENANCE_MODE = "desiredMaintenanceMode"
    DEST_IP = "destIp"
    DESTINATION_IP = "destinationIp"
    DESTINATION_IP_ADDRESS = "destinationIpAddress"
    DESTINATION_NETMASK = "destinationNetmask"
    DESTINATION_PORT = "destinationPort"
    DETAIL = "detail"
    DEV = "dev"
    DEVICE = "device"
    DEVICE_ID = "deviceId"
    DEVICE_NAME = "deviceName"
    DEVICE_RAID_SUPPORT = "deviceRaidSupport"
    DEVICE_SLOT_OFFSET = "deviceSlotOffset"
    DEVICE_TYPE = "deviceType"
    DEVICE_VERSION = "deviceVersion"
    DHCP_TIME_OUT = "dhcpTimeOut"
    DHCP_VENDOR_ID = "dhcpVendorId"
    DIAG_LLDP_TRANSMIT = "diagLldpTransmit"
    DIE1 = "die1"
    DIE1_AVG = "die1Avg"
    DIE1_MAX = "die1Max"
    DIE1_MIN = "die1Min"
    DIFF_MEMORY = "diffMemory"
    DIMM_BLACKLISTING_OPER_STATE = "dimmBlacklistingOperState"
    DIMM_LOCATER_IDS = "dimmLocaterIds"
    DIMM_TEMP = "dimmTemp"
    DIMM_TEMP_AVG = "dimmTempAvg"
    DIMM_TEMP_MAX = "dimmTempMax"
    DIMM_TEMP_MIN = "dimmTempMin"
    DIRECTION = "direction"
    DISASTER_RECOVERY = "disasterRecovery"
    DISC_TRIG_TS = "discTrigTs"
    DISCARD_RX = "discardRx"
    DISCARD_RX_DELTA = "discardRxDelta"
    DISCARD_RX_DELTA_AVG = "discardRxDeltaAvg"
    DISCARD_RX_DELTA_MAX = "discardRxDeltaMax"
    DISCARD_RX_DELTA_MIN = "discardRxDeltaMin"
    DISCARD_TX = "discardTx"
    DISCARD_TX_DELTA = "discardTxDelta"
    DISCARD_TX_DELTA_AVG = "discardTxDeltaAvg"
    DISCARD_TX_DELTA_MAX = "discardTxDeltaMax"
    DISCARD_TX_DELTA_MIN = "discardTxDeltaMin"
    DISCOVERED_PATH = "discoveredPath"
    DISCOVERY = "discovery"
    DISCOVERY_STATE = "discoveryState"
    DISCOVERY_STATUS = "discoveryStatus"
    DISK_BASE_ID = "diskBaseId"
    DISK_DN = "diskDn"
    DISK_OPS = "diskOps"
    DISK_PRESENT = "diskPresent"
    DISK_SCRUB = "diskScrub"
    DISK_SELECTION_ORDER = "diskSelectionOrder"
    DISK_SELECTION_TS = "diskSelectionTs"
    DISK_SHARING_SUPPORTED = "diskSharingSupported"
    DISK_SLOT_RANGE = "diskSlotRange"
    DISK_STATE = "diskState"
    DISK_TYPE = "diskType"
    DISK_VARIANT = "diskVariant"
    DISK_ZONING_POLICY_NAME = "diskZoningPolicyName"
    DISK_ZONING_STATE = "diskZoningState"
    DISKLESS = "diskless"
    DISR = "disr"
    DISTRO = "distro"
    DLLP_ERRORS = "dllpErrors"
    DLLP_ERRORS15_MIN = "dllpErrors15Min"
    DLLP_ERRORS15_MIN_H = "dllpErrors15MinH"
    DLLP_ERRORS1_DAY = "dllpErrors1Day"
    DLLP_ERRORS1_DAY_H = "dllpErrors1DayH"
    DLLP_ERRORS1_HOUR = "dllpErrors1Hour"
    DLLP_ERRORS1_HOUR_H = "dllpErrors1HourH"
    DLLP_ERRORS1_WEEK = "dllpErrors1Week"
    DLLP_ERRORS1_WEEK_H = "dllpErrors1WeekH"
    DLLP_ERRORS2_WEEKS = "dllpErrors2Weeks"
    DLLP_ERRORS2_WEEKS_H = "dllpErrors2WeeksH"
    DN = "dn"
    DNS = "dns"
    DOMAIN = "domain"
    DONNER = "donner"
    DONNER_AVG = "donnerAvg"
    DONNER_MAX = "donnerMax"
    DONNER_MIN = "donnerMin"
    DOWNLOAD_DATE = "downloadDate"
    DRIVE_CACHE = "driveCache"
    DRIVE_COUNT = "driveCount"
    DRIVE_LIFE_USED_PERCENTAGE = "driveLifeUsedPercentage"
    DRIVE_LIFE_USED_PERCENTAGE_AVG = "driveLifeUsedPercentageAvg"
    DRIVE_LIFE_USED_PERCENTAGE_MAX = "driveLifeUsedPercentageMax"
    DRIVE_LIFE_USED_PERCENTAGE_MIN = "driveLifeUsedPercentageMin"
    DRIVE_PATH = "drivePath"
    DRIVE_PERCENTAGE = "drivePercentage"
    DRIVE_PERCENTAGE_AVG = "drivePercentageAvg"
    DRIVE_PERCENTAGE_MAX = "drivePercentageMax"
    DRIVE_PERCENTAGE_MIN = "drivePercentageMin"
    DRIVE_SECURITY = "driveSecurity"
    DRIVE_STATE = "driveState"
    DRIVE_TYPE = "driveType"
    DRIVES_ENABLED = "drivesEnabled"
    DROP = "drop"
    DROP_ACL = "dropAcl"
    DROP_ACL_DELTA = "dropAclDelta"
    DROP_ACL_DELTA_AVG = "dropAclDeltaAvg"
    DROP_ACL_DELTA_MAX = "dropAclDeltaMax"
    DROP_ACL_DELTA_MIN = "dropAclDeltaMin"
    DROP_CMD = "dropCmd"
    DROP_CMD_DELTA = "dropCmdDelta"
    DROP_CMD_DELTA_AVG = "dropCmdDeltaAvg"
    DROP_CMD_DELTA_MAX = "dropCmdDeltaMax"
    DROP_CMD_DELTA_MIN = "dropCmdDeltaMin"
    DROP_FC_LIF_INVALID = "dropFcLifInvalid"
    DROP_FC_LIF_INVALID_DELTA = "dropFcLifInvalidDelta"
    DROP_FC_LIF_INVALID_DELTA_AVG = "dropFcLifInvalidDeltaAvg"
    DROP_FC_LIF_INVALID_DELTA_MAX = "dropFcLifInvalidDeltaMax"
    DROP_FC_LIF_INVALID_DELTA_MIN = "dropFcLifInvalidDeltaMin"
    DROP_FC_MULTICAST = "dropFcMulticast"
    DROP_FC_MULTICAST_DELTA = "dropFcMulticastDelta"
    DROP_FC_MULTICAST_DELTA_AVG = "dropFcMulticastDeltaAvg"
    DROP_FC_MULTICAST_DELTA_MAX = "dropFcMulticastDeltaMax"
    DROP_FC_MULTICAST_DELTA_MIN = "dropFcMulticastDeltaMin"
    DROP_LIF_CFG_INVALID = "dropLifCfgInvalid"
    DROP_LIF_CFG_INVALID_DELTA = "dropLifCfgInvalidDelta"
    DROP_LIF_CFG_INVALID_DELTA_AVG = "dropLifCfgInvalidDeltaAvg"
    DROP_LIF_CFG_INVALID_DELTA_MAX = "dropLifCfgInvalidDeltaMax"
    DROP_LIF_CFG_INVALID_DELTA_MIN = "dropLifCfgInvalidDeltaMin"
    DROP_LIF_MAP_NO_HIT = "dropLifMapNoHit"
    DROP_LIF_MAP_NO_HIT_DELTA = "dropLifMapNoHitDelta"
    DROP_LIF_MAP_NO_HIT_DELTA_AVG = "dropLifMapNoHitDeltaAvg"
    DROP_LIF_MAP_NO_HIT_DELTA_MAX = "dropLifMapNoHitDeltaMax"
    DROP_LIF_MAP_NO_HIT_DELTA_MIN = "dropLifMapNoHitDeltaMin"
    DROP_NULL_PIF = "dropNullPif"
    DROP_NULL_PIF_DELTA = "dropNullPifDelta"
    DROP_NULL_PIF_DELTA_AVG = "dropNullPifDeltaAvg"
    DROP_NULL_PIF_DELTA_MAX = "dropNullPifDeltaMax"
    DROP_NULL_PIF_DELTA_MIN = "dropNullPifDeltaMin"
    DROP_OVERRUN = "dropOverrun"
    DROP_OVERRUN_DELTA = "dropOverrunDelta"
    DROP_OVERRUN_DELTA_AVG = "dropOverrunDeltaAvg"
    DROP_OVERRUN_DELTA_MAX = "dropOverrunDeltaMax"
    DROP_OVERRUN_DELTA_MIN = "dropOverrunDeltaMin"
    DROP_OVERRUN_N0 = "dropOverrunN0"
    DROP_OVERRUN_N0_DELTA = "dropOverrunN0Delta"
    DROP_OVERRUN_N0_DELTA_AVG = "dropOverrunN0DeltaAvg"
    DROP_OVERRUN_N0_DELTA_MAX = "dropOverrunN0DeltaMax"
    DROP_OVERRUN_N0_DELTA_MIN = "dropOverrunN0DeltaMin"
    DROP_OVERRUN_N1 = "dropOverrunN1"
    DROP_OVERRUN_N1_DELTA = "dropOverrunN1Delta"
    DROP_OVERRUN_N1_DELTA_AVG = "dropOverrunN1DeltaAvg"
    DROP_OVERRUN_N1_DELTA_MAX = "dropOverrunN1DeltaMax"
    DROP_OVERRUN_N1_DELTA_MIN = "dropOverrunN1DeltaMin"
    DROP_RUNT = "dropRunt"
    DROP_RUNT_DELTA = "dropRuntDelta"
    DROP_RUNT_DELTA_AVG = "dropRuntDeltaAvg"
    DROP_RUNT_DELTA_MAX = "dropRuntDeltaMax"
    DROP_RUNT_DELTA_MIN = "dropRuntDeltaMin"
    DROP_SRC_BIND = "dropSrcBind"
    DROP_SRC_BIND_DELTA = "dropSrcBindDelta"
    DROP_SRC_BIND_DELTA_AVG = "dropSrcBindDeltaAvg"
    DROP_SRC_BIND_DELTA_MAX = "dropSrcBindDeltaMax"
    DROP_SRC_BIND_DELTA_MIN = "dropSrcBindDeltaMin"
    DROPPED_RX = "droppedRx"
    DROPPED_RX_DELTA = "droppedRxDelta"
    DROPPED_RX_DELTA_AVG = "droppedRxDeltaAvg"
    DROPPED_RX_DELTA_MAX = "droppedRxDeltaMax"
    DROPPED_RX_DELTA_MIN = "droppedRxDeltaMin"
    DROPPED_TX = "droppedTx"
    DROPPED_TX_DELTA = "droppedTxDelta"
    DROPPED_TX_DELTA_AVG = "droppedTxDeltaAvg"
    DROPPED_TX_DELTA_MAX = "droppedTxDeltaMax"
    DROPPED_TX_DELTA_MIN = "droppedTxDeltaMin"
    DROPPED_PKTS_EG = "dropped_pkts_eg"
    DROPPED_PKTS_IN = "dropped_pkts_in"
    DSCP = "dscp"
    DST_DN = "dstDn"
    DUMPED_FRAMES = "dumpedFrames"
    DUMPED_FRAMES_DELTA = "dumpedFramesDelta"
    DUMPED_FRAMES_DELTA_AVG = "dumpedFramesDeltaAvg"
    DUMPED_FRAMES_DELTA_MAX = "dumpedFramesDeltaMax"
    DUMPED_FRAMES_DELTA_MIN = "dumpedFramesDeltaMin"
    DUPLICATE_TARGET = "duplicateTarget"
    DVS_DN = "dvsDn"
    DVS_GEN_PORT_ID = "dvsGenPortId"
    DVS_NAME = "dvsName"
    DVS_PORT_ID = "dvsPortId"
    DVS_SWITCH_ID = "dvsSwitchId"
    DYN_REALLOC = "dynRealloc"
    DYNAMIC_CON_POLICY_NAME = "dynamicConPolicyName"
    DYNAMIC_ETH = "dynamicEth"
    DYNAMIC_ID = "dynamicId"
    DYNAMIC_PARAMS = "dynamicParams"
    DYNAMIC_VIFS_SUPPORTED = "dynamicVifsSupported"
    ECC_MULTIBIT_ERRORS = "eccMultibitErrors"
    ECC_MULTIBIT_ERRORS15_MIN = "eccMultibitErrors15Min"
    ECC_MULTIBIT_ERRORS15_MIN_H = "eccMultibitErrors15MinH"
    ECC_MULTIBIT_ERRORS1_DAY = "eccMultibitErrors1Day"
    ECC_MULTIBIT_ERRORS1_DAY_H = "eccMultibitErrors1DayH"
    ECC_MULTIBIT_ERRORS1_HOUR = "eccMultibitErrors1Hour"
    ECC_MULTIBIT_ERRORS1_HOUR_H = "eccMultibitErrors1HourH"
    ECC_MULTIBIT_ERRORS1_WEEK = "eccMultibitErrors1Week"
    ECC_MULTIBIT_ERRORS1_WEEK_H = "eccMultibitErrors1WeekH"
    ECC_MULTIBIT_ERRORS2_WEEKS = "eccMultibitErrors2Weeks"
    ECC_MULTIBIT_ERRORS2_WEEKS_H = "eccMultibitErrors2WeeksH"
    ECC_SINGLEBIT_ERRORS = "eccSinglebitErrors"
    ECC_SINGLEBIT_ERRORS15_MIN = "eccSinglebitErrors15Min"
    ECC_SINGLEBIT_ERRORS15_MIN_H = "eccSinglebitErrors15MinH"
    ECC_SINGLEBIT_ERRORS1_DAY = "eccSinglebitErrors1Day"
    ECC_SINGLEBIT_ERRORS1_DAY_H = "eccSinglebitErrors1DayH"
    ECC_SINGLEBIT_ERRORS1_HOUR = "eccSinglebitErrors1Hour"
    ECC_SINGLEBIT_ERRORS1_HOUR_H = "eccSinglebitErrors1HourH"
    ECC_SINGLEBIT_ERRORS1_WEEK = "eccSinglebitErrors1Week"
    ECC_SINGLEBIT_ERRORS1_WEEK_H = "eccSinglebitErrors1WeekH"
    ECC_SINGLEBIT_ERRORS2_WEEKS = "eccSinglebitErrors2Weeks"
    ECC_SINGLEBIT_ERRORS2_WEEKS_H = "eccSinglebitErrors2WeeksH"
    ECN_THRESHOLD = "ecnThreshold"
    ECODE = "ecode"
    EDGE_PORT_TIMER = "edgePortTimer"
    ELEMENT_LOAD_FAILURES = "elementLoadFailures"
    ELEMENTS_LOADED = "elementsLoaded"
    ELID = "elid"
    EMAIL = "email"
    EMAIL_ADDR = "emailAddr"
    ENABLE_HAFAILOVER = "enableHAFailover"
    ENABLE_LLDP_TRANSMIT = "enableLldpTransmit"
    ENABLE_NW_STATS_COLLECTION = "enableNwStatsCollection"
    ENABLE_PWDEXPIRY = "enablePWDExpiry"
    ENABLE_SSL = "enableSSL"
    ENABLED_CAPABILITIES = "enabledCapabilities"
    ENABLED_STATUS = "enabledStatus"
    ENACP = "enacp"
    ENC_ASSOCIATION = "encAssociation"
    ENC_ID = "encId"
    ENC_KEY = "encKey"
    ENC_PWD = "encPwd"
    ENC_PWD_SET = "encPwdSet"
    ENC_SECRET = "encSecret"
    ENCAP = "encap"
    ENCLOSURE_ID = "enclosureId"
    END_ID = "endId"
    END_PORT_ID = "endPortId"
    END_PORT_NUMBER = "endPortNumber"
    END_TIME = "endTime"
    END_TS = "endTs"
    END_TS_M = "endTsM"
    ENDPOINT = "endpoint"
    ENDS = "ends"
    ENFORCE_VNIC_NAME = "enforceVnicName"
    ENTITY_TYPE = "entityType"
    EP = "ep"
    EP_CLASS_ID = "epClassId"
    EP_CLOUD_TYPE = "epCloudType"
    EP_DN = "epDn"
    EP_NAME = "epName"
    EQ_TYPE = "eqType"
    EQPT_CLASS_ID = "eqptClassId"
    EQPT_INST_ID = "eqptInstId"
    EQPT_INST_ID_PROP_ID = "eqptInstIdPropId"
    EQUALS64 = "equals64"
    EQUALS64_DELTA = "equals64Delta"
    EQUALS64_DELTA_AVG = "equals64DeltaAvg"
    EQUALS64_DELTA_MAX = "equals64DeltaMax"
    EQUALS64_DELTA_MIN = "equals64DeltaMin"
    EQUIPMENT_DN = "equipmentDn"
    ERR_DESCRIPTION = "errDescription"
    ERR_FATAL_ERRORS = "errFatalErrors"
    ERR_FATAL_ERRORS15_MIN = "errFatalErrors15Min"
    ERR_FATAL_ERRORS15_MIN_H = "errFatalErrors15MinH"
    ERR_FATAL_ERRORS1_DAY = "errFatalErrors1Day"
    ERR_FATAL_ERRORS1_DAY_H = "errFatalErrors1DayH"
    ERR_FATAL_ERRORS1_HOUR = "errFatalErrors1Hour"
    ERR_FATAL_ERRORS1_HOUR_H = "errFatalErrors1HourH"
    ERR_FATAL_ERRORS1_WEEK = "errFatalErrors1Week"
    ERR_FATAL_ERRORS1_WEEK_H = "errFatalErrors1WeekH"
    ERR_FATAL_ERRORS2_WEEKS = "errFatalErrors2Weeks"
    ERR_FATAL_ERRORS2_WEEKS_H = "errFatalErrors2WeeksH"
    ERR_NON_FATAL_ERRORS = "errNonFatalErrors"
    ERR_NON_FATAL_ERRORS15_MIN = "errNonFatalErrors15Min"
    ERR_NON_FATAL_ERRORS15_MIN_H = "errNonFatalErrors15MinH"
    ERR_NON_FATAL_ERRORS1_DAY = "errNonFatalErrors1Day"
    ERR_NON_FATAL_ERRORS1_DAY_H = "errNonFatalErrors1DayH"
    ERR_NON_FATAL_ERRORS1_HOUR = "errNonFatalErrors1Hour"
    ERR_NON_FATAL_ERRORS1_HOUR_H = "errNonFatalErrors1HourH"
    ERR_NON_FATAL_ERRORS1_WEEK = "errNonFatalErrors1Week"
    ERR_NON_FATAL_ERRORS1_WEEK_H = "errNonFatalErrors1WeekH"
    ERR_NON_FATAL_ERRORS2_WEEKS = "errNonFatalErrors2Weeks"
    ERR_NON_FATAL_ERRORS2_WEEKS_H = "errNonFatalErrors2WeeksH"
    ERR_VAL = "errVal"
    ERR_VALUE = "errValue"
    ERROR_CODE = "errorCode"
    ERROR_CORRECTION = "errorCorrection"
    ERROR_DESCR = "errorDescr"
    ERROR_DETECT_TIMEOUT = "errorDetectTimeout"
    ERROR_DISABLE_FI_PORT = "errorDisableFiPort"
    ERROR_FRAMES = "errorFrames"
    ERROR_FRAMES_DELTA = "errorFramesDelta"
    ERROR_FRAMES_DELTA_AVG = "errorFramesDeltaAvg"
    ERROR_FRAMES_DELTA_MAX = "errorFramesDeltaMax"
    ERROR_FRAMES_DELTA_MIN = "errorFramesDeltaMin"
    ERROR_LOCATION = "errorLocation"
    ERROR_TYPE = "errorType"
    ERRORS_RX = "errorsRx"
    ERRORS_RX_DELTA = "errorsRxDelta"
    ERRORS_RX_DELTA_AVG = "errorsRxDeltaAvg"
    ERRORS_RX_DELTA_MAX = "errorsRxDeltaMax"
    ERRORS_RX_DELTA_MIN = "errorsRxDeltaMin"
    ERRORS_TX = "errorsTx"
    ERRORS_TX_DELTA = "errorsTxDelta"
    ERRORS_TX_DELTA_AVG = "errorsTxDeltaAvg"
    ERRORS_TX_DELTA_MAX = "errorsTxDeltaMax"
    ERRORS_TX_DELTA_MIN = "errorsTxDeltaMin"
    ERRORS_EG = "errors_eg"
    ERRORS_IN = "errors_in"
    ESCALATING = "escalating"
    EST_PROG_WEIGHT = "estProgWeight"
    ETH_ADMIN_STATE = "ethAdminState"
    ETH_BREAKOUT_AUTO_DISCOVERY = "ethBreakoutAutoDiscovery"
    ETH_EFIVERSION = "ethEFIVersion"
    ETH_EP_DN = "ethEpDn"
    ETH_LINK_PROFILE_NAME = "ethLinkProfileName"
    ETH_OPTION_ROM_VERSION = "ethOptionRomVersion"
    ETH_SVR_AUTO_DISCOVERY = "ethSvrAutoDiscovery"
    ETHERNET_PORT_SPEED = "ethernetPortSpeed"
    ETIME = "etime"
    EVAC_STATE = "evacState"
    EVACUATE = "evacuate"
    EVALUATION_METHOD = "evaluationMethod"
    EVENT_READING_TYPE = "eventReadingType"
    EVENTS = "events"
    EXCESS_COLLISION = "excessCollision"
    EXCESS_COLLISION_DELTA = "excessCollisionDelta"
    EXCESS_COLLISION_DELTA_AVG = "excessCollisionDeltaAvg"
    EXCESS_COLLISION_DELTA_MAX = "excessCollisionDeltaMax"
    EXCESS_COLLISION_DELTA_MIN = "excessCollisionDeltaMin"
    EXCLUDE_BY_DEFAULT = "excludeByDefault"
    EXIT_SIGNAL = "exitSignal"
    EXP = "exp"
    EXPAND_TO_AVAIL = "expandToAvail"
    EXPANDER_SLOT = "expanderSlot"
    EXPANDER_STATE = "expanderState"
    EXPECTED_MEMORY = "expectedMemory"
    EXPIRATION = "expiration"
    EXPIRATION_PERIOD = "expirationPeriod"
    EXPIRATION_WARN_TIME = "expirationWarnTime"
    EXPIRES = "expires"
    EXPORT_FAILURE_REASON = "exportFailureReason"
    EXPORT_INTERNAL = "exportInternal"
    EXPORT_STATUS = "exportStatus"
    EXPORTER_SOURCE_MAC = "exporterSourceMac"
    EXPORTER_STATS_TIMEOUT = "exporterStatsTimeout"
    EXT_BROADCAST = "extBroadcast"
    EXT_DEP = "extDep"
    EXT_GW = "extGw"
    EXT_IPPOOL_NAME = "extIPPoolName"
    EXT_IPSTATE = "extIPState"
    EXT_IP = "extIp"
    EXT_IP_POOL_NAME = "extIpPoolName"
    EXT_KEY = "extKey"
    EXT_MANAGED = "extManaged"
    EXT_MASK = "extMask"
    EXT_MGMT_IP_ADDR = "extMgmtIpAddr"
    EXT_PHY_PORT_BITMASK = "extPhyPortBitmask"
    EXTD_CHANGE_DETAILS = "extdChangeDetails"
    EXTENDED_CL_ID = "extendedClId"
    EXTERNAL_RESOLVE_NAME = "externalResolveName"
    FAB_EXT_ID = "fabExtId"
    FABRIC = "fabric"
    FABRIC_EP_DN = "fabricEpDn"
    FABRIC_ID = "fabricId"
    FABRIC_MGMT_ADDR = "fabricMgmtAddr"
    FABRIC_NETWORK_NAME = "fabricNetworkName"
    FABRIC_NWWN = "fabricNwwn"
    FABRIC_PATH = "fabricPath"
    FABRIC_PWWN = "fabricPwwn"
    FAIL_REPORT_COUNT = "failReportCount"
    FAILED = "failed"
    FAILED_ATTEMPTS = "failedAttempts"
    FAILOVER = "failover"
    FAILURE_ACTION = "failureAction"
    FALSE_HITS = "falseHits"
    FAN_CAPACITY = "fanCapacity"
    FAN_CTRLR_INLET1 = "fanCtrlrInlet1"
    FAN_CTRLR_INLET1_AVG = "fanCtrlrInlet1Avg"
    FAN_CTRLR_INLET1_MAX = "fanCtrlrInlet1Max"
    FAN_CTRLR_INLET1_MIN = "fanCtrlrInlet1Min"
    FAN_CTRLR_INLET2 = "fanCtrlrInlet2"
    FAN_CTRLR_INLET2_AVG = "fanCtrlrInlet2Avg"
    FAN_CTRLR_INLET2_MAX = "fanCtrlrInlet2Max"
    FAN_CTRLR_INLET2_MIN = "fanCtrlrInlet2Min"
    FAN_CTRLR_INLET3 = "fanCtrlrInlet3"
    FAN_CTRLR_INLET3_AVG = "fanCtrlrInlet3Avg"
    FAN_CTRLR_INLET3_MAX = "fanCtrlrInlet3Max"
    FAN_CTRLR_INLET3_MIN = "fanCtrlrInlet3Min"
    FAN_CTRLR_INLET4 = "fanCtrlrInlet4"
    FAN_CTRLR_INLET4_AVG = "fanCtrlrInlet4Avg"
    FAN_CTRLR_INLET4_MAX = "fanCtrlrInlet4Max"
    FAN_CTRLR_INLET4_MIN = "fanCtrlrInlet4Min"
    FAN_MODULE_NUMBER = "fanModuleNumber"
    FAN_MODULES_SUPPORTED = "fanModulesSupported"
    FAN_SPEED = "fanSpeed"
    FAN_SPEED_CONFIG_STATE = "fanSpeedConfigState"
    FAN_SPEED_CONFIG_STATUS = "fanSpeedConfigStatus"
    FAN_SPEED_POLICY_ADMIN_STATE = "fanSpeedPolicyAdminState"
    FAN_SPEED_POLICY_FAULT = "fanSpeedPolicyFault"
    FAN_SPEED_POLICY_OPER_STATE = "fanSpeedPolicyOperState"
    FAST_TIMER = "fastTimer"
    FAULT_ALERT_SETTING = "faultAlertSetting"
    FAULT_MONITORING = "faultMonitoring"
    FAULT_QUALIFIER = "faultQualifier"
    FAULTS = "faults"
    FC_ADMIN_STATE = "fcAdminState"
    FC_FWVERSION = "fcFWVersion"
    FC_OPTION_ROM_VERSION = "fcOptionRomVersion"
    FC_PORT_TIMER = "fcPortTimer"
    FC_SPEED_CAP = "fcSpeedCap"
    FC_ZONE_SHARING_MODE = "fcZoneSharingMode"
    FCOE = "fcoe"
    FCOE_ID = "fcoeId"
    FCOE_JUMBO_NODROP = "fcoeJumboNodrop"
    FCOE_NORMAL_NODROP = "fcoeNormalNodrop"
    FCOE_STATE = "fcoeState"
    FCOE_STATE_REASON = "fcoeStateReason"
    FCOE_VLAN = "fcoeVlan"
    FCP_ERROR_RECOVERY = "fcpErrorRecovery"
    FCS = "fcs"
    FCS_DELTA = "fcsDelta"
    FCS_DELTA_AVG = "fcsDeltaAvg"
    FCS_DELTA_MAX = "fcsDeltaMax"
    FCS_DELTA_MIN = "fcsDeltaMin"
    FE_OFFLINE_TS = "feOfflineTs"
    FE_READY_TS = "feReadyTs"
    FEATURE = "feature"
    FEATURE_NAME = "featureName"
    FEATURE_STATUS = "featureStatus"
    FEC = "fec"
    FI_ID = "fiId"
    FI_PORT_DN = "fiPortDn"
    FIBRE_CHANNEL_PORT_SPEED = "fibreChannelPortSpeed"
    FILE_DIR = "fileDir"
    FILE_HOST = "fileHost"
    FILE_NAME = "fileName"
    FILE_PARSE_FAILURES = "fileParseFailures"
    FILE_PASSWD = "filePasswd"
    FILE_PATH = "filePath"
    FILE_PORT = "filePort"
    FILE_PROTO = "fileProto"
    FILE_TX_ADMIN_STATE = "fileTxAdminState"
    FILE_USER = "fileUser"
    FILES_PARSED = "filesParsed"
    FILL_PATTERN = "fillPattern"
    FILTER = "filter"
    FILTER_CLASS_ID = "filterClassId"
    FILTER_PROP_ID1 = "filterPropId1"
    FILTER_PROP_ID2 = "filterPropId2"
    FILTER_PROP_ID3 = "filterPropId3"
    FILTER_PROP_VALUE1 = "filterPropValue1"
    FILTER_PROP_VALUE2 = "filterPropValue2"
    FILTER_PROP_VALUE3 = "filterPropValue3"
    FIRMWARE_STATE = "firmwareState"
    FIRMWARE_VERSION = "firmwareVersion"
    FIRST_INDEX = "firstIndex"
    FIRST_NAME = "firstName"
    FLAGS = "flags"
    FLAP_INTERVAL = "flapInterval"
    FLASH_PERCENTAGE = "flashPercentage"
    FLASH_STATUS = "flashStatus"
    FLEX_FLASH_RAIDREPORTING_STATE = "flexFlashRAIDReportingState"
    FLEX_FLASH_REMOVABLE_STATE = "flexFlashRemovableState"
    FLEX_FLASH_SCRUB = "flexFlashScrub"
    FLEX_FLASH_STATE = "flexFlashState"
    FLEX_FLASH_TYPE = "flexFlashType"
    FLEX_STORAGE_SCRUB = "flexStorageScrub"
    FLG_INITIAL_ACTIVE = "flgInitialActive"
    FLOW_CONTROL_ERRORS = "flowControlErrors"
    FLOW_CONTROL_ERRORS15_MIN = "flowControlErrors15Min"
    FLOW_CONTROL_ERRORS15_MIN_H = "flowControlErrors15MinH"
    FLOW_CONTROL_ERRORS1_DAY = "flowControlErrors1Day"
    FLOW_CONTROL_ERRORS1_DAY_H = "flowControlErrors1DayH"
    FLOW_CONTROL_ERRORS1_HOUR = "flowControlErrors1Hour"
    FLOW_CONTROL_ERRORS1_HOUR_H = "flowControlErrors1HourH"
    FLOW_CONTROL_ERRORS1_WEEK = "flowControlErrors1Week"
    FLOW_CONTROL_ERRORS1_WEEK_H = "flowControlErrors1WeekH"
    FLOW_CONTROL_ERRORS2_WEEKS = "flowControlErrors2Weeks"
    FLOW_CONTROL_ERRORS2_WEEKS_H = "flowControlErrors2WeeksH"
    FLOW_CTRL_POLICY = "flowCtrlPolicy"
    FLOW_EXP_PROFILE = "flowExpProfile"
    FLOW_MON_COLLECTOR = "flowMonCollector"
    FLOW_MON_PROTOCOL = "flowMonProtocol"
    FLOW_MON_RECORD_DEF = "flowMonRecordDef"
    FLOW_PROTOCOL = "flowProtocol"
    FLOW_RECORD_DEF_NAME = "flowRecordDefName"
    FLOW_TIMEOUT_POLICY = "flowTimeoutPolicy"
    FLT_AGGR = "fltAggr"
    FM_TEMP_SEN_IO = "fmTempSenIo"
    FM_TEMP_SEN_IO_AVG = "fmTempSenIoAvg"
    FM_TEMP_SEN_IO_MAX = "fmTempSenIoMax"
    FM_TEMP_SEN_IO_MIN = "fmTempSenIoMin"
    FM_TEMP_SEN_REAR = "fmTempSenRear"
    FM_TEMP_SEN_REAR_AVG = "fmTempSenRearAvg"
    FM_TEMP_SEN_REAR_L = "fmTempSenRearL"
    FM_TEMP_SEN_REAR_LAVG = "fmTempSenRearLAvg"
    FM_TEMP_SEN_REAR_LMAX = "fmTempSenRearLMax"
    FM_TEMP_SEN_REAR_LMIN = "fmTempSenRearLMin"
    FM_TEMP_SEN_REAR_MAX = "fmTempSenRearMax"
    FM_TEMP_SEN_REAR_MIN = "fmTempSenRearMin"
    FM_TEMP_SEN_REAR_R = "fmTempSenRearR"
    FM_TEMP_SEN_REAR_RAVG = "fmTempSenRearRAvg"
    FM_TEMP_SEN_REAR_RMAX = "fmTempSenRearRMax"
    FM_TEMP_SEN_REAR_RMIN = "fmTempSenRearRMin"
    FN_DEF_NAME = "fnDefName"
    FN_NAME = "fnName"
    FORCE_CONFIG = "forceConfig"
    FORCE_DEPLOY = "forceDeploy"
    FORCE_EVAC = "forceEvac"
    FORCE_OVERRIDE_ON_LOAD = "forceOverrideOnLoad"
    FORCE_UPDATE_VERSION = "forceUpdateVersion"
    FORGE = "forge"
    FORGE_MAC = "forgeMac"
    FORM = "form"
    FORM_FACTOR = "formFactor"
    FORMAT = "format"
    FORWARDING_FACILITY = "forwardingFacility"
    FP = "fp"
    FRACTIONAL_SIZE = "fractionalSize"
    FRAME_TX = "frameTx"
    FRAME_TX_DELTA = "frameTxDelta"
    FRAME_TX_DELTA_AVG = "frameTxDeltaAvg"
    FRAME_TX_DELTA_MAX = "frameTxDeltaMax"
    FRAME_TX_DELTA_MIN = "frameTxDeltaMin"
    FREE_CAPACITY = "freeCapacity"
    FREQUENCY = "frequency"
    FROM = "from"
    FRONT_DISK_SLOTS = "frontDiskSlots"
    FRONT_TEMP = "frontTemp"
    FRONT_TEMP_AVG = "frontTempAvg"
    FRONT_TEMP_MAX = "frontTempMax"
    FRONT_TEMP_MIN = "frontTempMin"
    FRU_CAP_DN = "fruCapDn"
    FRU_ID = "fruId"
    FRU_IDENT_TRIG_TS = "fruIdentTrigTs"
    FRU_MAJOR_TYPE = "fruMajorType"
    FRU_MINOR_TYPE = "fruMinorType"
    FSM_DESCR = "fsmDescr"
    FSM_FLAGS = "fsmFlags"
    FSM_PREV = "fsmPrev"
    FSM_PROGR = "fsmProgr"
    FSM_RMT_INV_ERR_CODE = "fsmRmtInvErrCode"
    FSM_RMT_INV_ERR_DESCR = "fsmRmtInvErrDescr"
    FSM_RMT_INV_RSLT = "fsmRmtInvRslt"
    FSM_STAGE_DESCR = "fsmStageDescr"
    FSM_STAMP = "fsmStamp"
    FSM_STATUS = "fsmStatus"
    FSM_TRY = "fsmTry"
    FTR_MO_CLASS_NAME = "ftrMoClassName"
    FULL_PATHNAME = "fullPathname"
    FUNCTIONAL_STATE = "functionalState"
    FW_FPGA_REVISION_SUPPORTED = "fwFpgaRevisionSupported"
    FW_REGION_ONE = "fwRegionOne"
    FW_REGION_TWO = "fwRegionTwo"
    FW_RUNNING_REGION = "fwRunningRegion"
    FW_UPDATE_TIMEOUT = "fwUpdateTimeout"
    FW_VERSION_HI = "fwVersionHi"
    FW_VERSION_LO = "fwVersionLo"
    FW_VERSION_OPER = "fwVersionOper"
    FW_VERSION_OPR = "fwVersionOpr"
    FWD_LOOKUP_NO_HIT = "fwdLookupNoHit"
    FWD_LOOKUP_NO_HIT_DELTA = "fwdLookupNoHitDelta"
    FWD_LOOKUP_NO_HIT_DELTA_AVG = "fwdLookupNoHitDeltaAvg"
    FWD_LOOKUP_NO_HIT_DELTA_MAX = "fwdLookupNoHitDeltaMax"
    FWD_LOOKUP_NO_HIT_DELTA_MIN = "fwdLookupNoHitDeltaMin"
    GEN_NUM = "genNum"
    GEN_NUM_SYNC = "genNumSync"
    GENCOUNT = "gencount"
    GENERATION = "generation"
    GIANTS = "giants"
    GIANTS_DELTA = "giantsDelta"
    GIANTS_DELTA_AVG = "giantsDeltaAvg"
    GIANTS_DELTA_MAX = "giantsDeltaMax"
    GIANTS_DELTA_MIN = "giantsDeltaMin"
    GID = "gid"
    GLOBAL = "global"
    GLOBAL_ASSIGNED_CNT = "globalAssignedCnt"
    GLOBAL_DEFINED_CNT = "globalDefinedCnt"
    GLOBAL_ECN = "globalEcn"
    GLOBAL_ID = "globalId"
    GOOD_PACKETS = "goodPackets"
    GOOD_PACKETS_DELTA = "goodPacketsDelta"
    GOOD_PACKETS_DELTA_AVG = "goodPacketsDeltaAvg"
    GOOD_PACKETS_DELTA_MAX = "goodPacketsDeltaMax"
    GOOD_PACKETS_DELTA_MIN = "goodPacketsDeltaMin"
    GRACE_PERIOD = "gracePeriod"
    GRACE_PERIOD_USED = "gracePeriodUsed"
    GRAPHICS_CARD_MODE = "graphicsCardMode"
    GRAPHICS_CARD_POLICY_NAME = "graphicsCardPolicyName"
    GREATER_THAN_OR_EQUAL_TO9216 = "greaterThanOrEqualTo9216"
    GREATER_THAN_OR_EQUAL_TO9216_DELTA = "greaterThanOrEqualTo9216Delta"
    GREATER_THAN_OR_EQUAL_TO9216_DELTA_AVG = "greaterThanOrEqualTo9216DeltaAvg"
    GREATER_THAN_OR_EQUAL_TO9216_DELTA_MAX = "greaterThanOrEqualTo9216DeltaMax"
    GREATER_THAN_OR_EQUAL_TO9216_DELTA_MIN = "greaterThanOrEqualTo9216DeltaMin"
    GROUP = "group"
    GROUP_NAME = "groupName"
    GROUP_POLICY_NAME = "groupPolicyName"
    GUID = "guid"
    GW_ADDR = "gwAddr"
    GW_SUBNET = "gwSubnet"
    HA = "ha"
    HA_FAILURE_REASON = "haFailureReason"
    HA_READINESS = "haReadiness"
    HA_READY = "haReady"
    HAS_ERROR = "hasError"
    HAS_LAST_DEST = "hasLastDest"
    HBA_MODE = "hbaMode"
    HEALTH = "health"
    HEALTH_CHECK_INTERVAL = "healthCheckInterval"
    HEALTH_LED_STATE = "healthLedState"
    HEALTH_LED_STATE_QUALIFIER = "healthLedStateQualifier"
    HEALTH_QUALIFIER = "healthQualifier"
    HEALTH_SEVERITY = "healthSeverity"
    HEALTH_STATE = "healthState"
    HEAP_SIZE = "heapSize"
    HEAP_SIZE16_GB = "heapSize16Gb"
    HEARTBEAT_REQUEST = "heartbeatRequest"
    HEARTBEAT_RESPONSE = "heartbeatResponse"
    HEIGHT = "height"
    HIERARCHICAL = "hierarchical"
    HIGHEST_SEVERITY = "highestSeverity"
    HISTORY_COUNT = "historyCount"
    HORIZONTAL_START_OFFSET = "horizontalStartOffset"
    HOST = "host"
    HOST_CONTROL = "hostControl"
    HOST_FW_POLICY_NAME = "hostFwPolicyName"
    HOST_ID = "hostId"
    HOST_IF_DN = "hostIfDn"
    HOST_NAME = "hostName"
    HOST_NVRAM = "hostNvram"
    HOST_NW_IOPERF = "hostNwIOPerf"
    HOST_PORT = "hostPort"
    HOST_PORT_ID = "hostPortId"
    HOST_REPORTED = "hostReported"
    HOST_VISIBLE = "hostVisible"
    HOSTAG_COMM_METHOD = "hostagCommMethod"
    HOSTNAME = "hostname"
    HOT_PLUG_SUPPORTED = "hotPlugSupported"
    HOUR = "hour"
    HV_DN = "hvDn"
    HV_TYPE = "hvType"
    HV_UUID = "hvUuid"
    HW40_GPCPORT_GROUP_CAP = "hw40GPCPortGroupCap"
    HW40_GPORT_GROUP_CAP = "hw40GPortGroupCap"
    HW_INVENTORY_STATUS = "hwInventoryStatus"
    HW_MODEL = "hwModel"
    HW_REVISION = "hwRevision"
    HW_TYPE = "hwType"
    HW_VENDOR = "hwVendor"
    HW_VERSION = "hwVersion"
    I_SCSIVNIC_NAME = "iSCSIVnicName"
    ID = "id"
    ID_ASSIGNMENT_MODE = "idAssignmentMode"
    ID_COUNT = "idCount"
    IDENT_POOL_NAME = "identPoolName"
    IDENT_TYPE = "identType"
    IDENTITY = "identity"
    IDLE_POWER = "idlePower"
    IF_ROLE = "ifRole"
    IF_TYPE = "ifType"
    IGMP_RESEND_COUNT = "igmpResendCount"
    IGNORE_CAP = "ignoreCap"
    IGNORE_COMP_CHECK = "ignoreCompCheck"
    IMAGE = "image"
    IMAGE_DELETED = "imageDeleted"
    IMAGE_FILE_NAME = "imageFileName"
    IMAGE_NAME = "imageName"
    IMAGE_NAME_VARIABLE = "imageNameVariable"
    IMAGE_PATH = "imagePath"
    IMAGE_PRESENCE = "imagePresence"
    IMAGE_SIZE = "imageSize"
    IMG_LOC = "imgLoc"
    IMG_NAME = "imgName"
    IMG_POLICY_NAME = "imgPolicyName"
    IMG_SEC_POLICY_NAME = "imgSecPolicyName"
    IMPACT_ANALYZER_ID = "impactAnalyzerId"
    IN_PROGRESS = "inProgress"
    IN_RANGE = "inRange"
    IN_RANGE_DELTA = "inRangeDelta"
    IN_RANGE_DELTA_AVG = "inRangeDeltaAvg"
    IN_RANGE_DELTA_MAX = "inRangeDeltaMax"
    IN_RANGE_DELTA_MIN = "inRangeDeltaMin"
    IN_USE = "inUse"
    INACCESSIBLE_CAPACITY = "inaccessibleCapacity"
    INACTIVE_TIMEOUT = "inactiveTimeout"
    INBAND_IF_GW = "inbandIfGw"
    INBAND_IF_IP = "inbandIfIp"
    INBAND_IF_MASK = "inbandIfMask"
    INBAND_IF_VNET = "inbandIfVnet"
    IND = "ind"
    INDEX = "index"
    INFRA_BUNDLE_NAME = "infraBundleName"
    INFRA_BUNDLE_VERSION = "infraBundleVersion"
    INI_NAME = "iniName"
    INIT_NAME_SUFFIX = "initNameSuffix"
    INIT_SEQ = "initSeq"
    INIT_TS = "initTs"
    INITIATOR = "initiator"
    INITIATOR_DN = "initiatorDn"
    INITIATOR_NAME = "initiatorName"
    INITIATOR_POLICY_NAME = "initiatorPolicyName"
    INLET = "inlet"
    INLET1 = "inlet1"
    INLET1_AVG = "inlet1Avg"
    INLET1_MAX = "inlet1Max"
    INLET1_MIN = "inlet1Min"
    INLET_AVG = "inletAvg"
    INLET_MAX = "inletMax"
    INLET_MIN = "inletMin"
    INLINE_GROUP_SEPARATION = "inlineGroupSeparation"
    INLINE_GROUP_SIZE = "inlineGroupSize"
    INLINE_OFFSET = "inlineOffset"
    INO = "ino"
    INPUT210V = "input210v"
    INPUT210V_AVG = "input210vAvg"
    INPUT210V_MAX = "input210vMax"
    INPUT210V_MIN = "input210vMin"
    INPUT_CURRENT = "inputCurrent"
    INPUT_CURRENT_AVG = "inputCurrentAvg"
    INPUT_CURRENT_MAX = "inputCurrentMax"
    INPUT_CURRENT_MIN = "inputCurrentMin"
    INPUT_MEGABYTES = "inputMegabytes"
    INPUT_MEGABYTES_DELTA = "inputMegabytesDelta"
    INPUT_MEGABYTES_DELTA_AVG = "inputMegabytesDeltaAvg"
    INPUT_MEGABYTES_DELTA_MAX = "inputMegabytesDeltaMax"
    INPUT_MEGABYTES_DELTA_MIN = "inputMegabytesDeltaMin"
    INPUT_POWER = "inputPower"
    INPUT_POWER_AVG = "inputPowerAvg"
    INPUT_POWER_MAX = "inputPowerMax"
    INPUT_POWER_MIN = "inputPowerMin"
    INPUT_POWER_STATE = "inputPowerState"
    INPUT_REQUESTS = "inputRequests"
    INPUT_REQUESTS_DELTA = "inputRequestsDelta"
    INPUT_REQUESTS_DELTA_AVG = "inputRequestsDeltaAvg"
    INPUT_REQUESTS_DELTA_MAX = "inputRequestsDeltaMax"
    INPUT_REQUESTS_DELTA_MIN = "inputRequestsDeltaMin"
    INPUT_STATUS = "inputStatus"
    INPUT_VOLTAGE = "inputVoltage"
    INPUT_VOLTAGE_AVG = "inputVoltageAvg"
    INPUT_VOLTAGE_MAX = "inputVoltageMax"
    INPUT_VOLTAGE_MIN = "inputVoltageMin"
    INST = "inst"
    INST_TYPE = "instType"
    INSTALL_PATH = "installPath"
    INSTANCE = "instance"
    INSTANCE_ID = "instanceId"
    INSTANCE_MOD = "instanceMod"
    INT_DEL = "intDel"
    INT_ID = "intId"
    INT_MAC_RX = "intMacRx"
    INT_MAC_RX_DELTA = "intMacRxDelta"
    INT_MAC_RX_DELTA_AVG = "intMacRxDeltaAvg"
    INT_MAC_RX_DELTA_MAX = "intMacRxDeltaMax"
    INT_MAC_RX_DELTA_MIN = "intMacRxDeltaMin"
    INT_MAC_TX = "intMacTx"
    INT_MAC_TX_DELTA = "intMacTxDelta"
    INT_MAC_TX_DELTA_AVG = "intMacTxDeltaAvg"
    INT_MAC_TX_DELTA_MAX = "intMacTxDeltaMax"
    INT_MAC_TX_DELTA_MIN = "intMacTxDeltaMin"
    INT_TYPE = "intType"
    INTEGRATED = "integrated"
    INTENT = "intent"
    INTEREST = "interest"
    INTERFACE_TABLE_TIMEOUT = "interfaceTableTimeout"
    INTERLEAVED_SET_ID = "interleavedSetId"
    INTERNAL_BACKUP_INTERVAL = "internalBackupInterval"
    INTERNALPORTS = "internalports"
    INTERVAL = "interval"
    INTERVAL_DAYS = "intervalDays"
    INTERVALS = "intervals"
    INTF = "intf"
    INTR_COUNT = "intrCount"
    INV_TAG = "invTag"
    INVALID_CRCCOUNT = "invalidCRCCount"
    INVALID_CRCCOUNT_DELTA = "invalidCRCCountDelta"
    INVALID_CRCCOUNT_DELTA_AVG = "invalidCRCCountDeltaAvg"
    INVALID_CRCCOUNT_DELTA_MAX = "invalidCRCCountDeltaMax"
    INVALID_CRCCOUNT_DELTA_MIN = "invalidCRCCountDeltaMin"
    INVENTORY_STATUS = "inventoryStatus"
    INVENTORY_VERSION = "inventoryVersion"
    IO_POLICY = "ioPolicy"
    IO_RETRY_TIMEOUT = "ioRetryTimeout"
    IO_THROTTLE_COUNT = "ioThrottleCount"
    IOCARD_TYPE = "iocardType"
    IOH1_TEMP = "ioh1Temp"
    IOH1_TEMP_AVG = "ioh1TempAvg"
    IOH1_TEMP_MAX = "ioh1TempMax"
    IOH1_TEMP_MIN = "ioh1TempMin"
    IOH2_TEMP = "ioh2Temp"
    IOH2_TEMP_AVG = "ioh2TempAvg"
    IOH2_TEMP_MAX = "ioh2TempMax"
    IOH2_TEMP_MIN = "ioh2TempMin"
    IOM_EP = "iomEp"
    IP = "ip"
    IP_A = "ipA"
    IP_ADDR_TYPE = "ipAddrType"
    IP_ADDRESS = "ipAddress"
    IP_B = "ipB"
    IP_HASH = "ipHash"
    IP_POOL_GUID = "ipPoolGuid"
    IP_POOL_NAME = "ipPoolName"
    IP_POOL_NAME_FABRIC_B = "ipPoolNameFabricB"
    IP_POOL_TYPE = "ipPoolType"
    IP_V4_ADDRESS = "ipV4Address"
    IP_V4_MGMT_ADDRESS = "ipV4MgmtAddress"
    IP_V4_STATE = "ipV4State"
    IP_V6_STATE = "ipV6State"
    IPMI_OVER_LAN = "ipmiOverLan"
    IPV4KEYS = "ipv4keys"
    IPV6 = "ipv6"
    IPV6_A = "ipv6A"
    IPV6_ADDR = "ipv6Addr"
    IPV6_B = "ipv6B"
    IPV6_TARGET1 = "ipv6Target1"
    IPV6_TARGET2 = "ipv6Target2"
    IPV6_TARGET3 = "ipv6Target3"
    IPV6ADDR = "ipv6addr"
    IPV6KEYS = "ipv6keys"
    IQN = "iqn"
    IQN_IDENT_POOL_NAME = "iqnIdentPoolName"
    IQN_POOL_NAME = "iqnPoolName"
    IS_ASSIGNED = "isAssigned"
    IS_ASSIGNED_LOCALLY = "isAssignedLocally"
    IS_BOOTABLE = "isBootable"
    IS_BREAKOUT_XCVR = "isBreakoutXcvr"
    IS_CARD_MISMATCH = "isCardMismatch"
    IS_CHANGED_OBJECT_UPDATE = "isChangedObjectUpdate"
    IS_CONFIG_SUCCESS = "isConfigSuccess"
    IS_DEFAULT = "isDefault"
    IS_DEFAULT_DERIVED = "isDefaultDerived"
    IS_DELETE = "isDelete"
    IS_DELETED = "isDeleted"
    IS_FIRST_SYNC = "isFirstSync"
    IS_FLASH_LIFE_LEFT_SUPPORTED = "isFlashLifeLeftSupported"
    IS_FORMAT_FSMRUNNING = "isFormatFSMRunning"
    IS_HOST_AGENT_PRESENT = "isHostAgentPresent"
    IS_IMPORTABLE = "isImportable"
    IS_LLDP_DISCOVERY_POLICY = "isLldpDiscoveryPolicy"
    IS_MULTI_PORT = "isMultiPort"
    IS_NATIVE = "isNative"
    IS_NET_BIOSENABLED = "isNetBIOSEnabled"
    IS_PASSTHROUGH = "isPassthrough"
    IS_PINNING_CLEARED = "isPinningCleared"
    IS_PORT_CHANNEL_MEMBER = "isPortChannelMember"
    IS_POWER_DEPLOYMENT_NEEDED = "isPowerDeploymentNeeded"
    IS_PRESENT = "isPresent"
    IS_PWD_ENC = "isPwdEnc"
    IS_RACK_PRESENT = "isRackPresent"
    IS_RETIMER_REQUIRED = "isRetimerRequired"
    IS_SEC_FW_UPDATE = "isSecFwUpdate"
    IS_SED_SUPPORTED = "isSedSupported"
    IS_SERVICE_TEMPLATE = "isServiceTemplate"
    IS_SET_SNMP_SECURE = "isSetSnmpSecure"
    IS_SUPPORTED = "isSupported"
    IS_SYNC = "isSync"
    IS_SYNC_ALLOWED = "isSyncAllowed"
    IS_SYSTEM = "isSystem"
    IS_USB_NIC_SUPPORTED = "isUsbNicSupported"
    IS_USER_UPLOADED = "isUserUploaded"
    IS_VALID_CONFIG = "isValidConfig"
    IS_ANALOG = "is_analog"
    ISC_KVMSUPPORTED = "iscKVMSupported"
    ISCSI_CONFIG_ISSUES = "iscsiConfigIssues"
    ISONAME = "isoname"
    ISSUER_COMMON_NAME = "issuerCommonName"
    ISSUER_COUNTRY_CODE = "issuerCountryCode"
    ISSUER_LOCALITY = "issuerLocality"
    ISSUER_ORG_NAME = "issuerOrgName"
    ISSUER_ORG_UNIT_NAME = "issuerOrgUnitName"
    ISSUER_STATE = "issuerState"
    ISSUES = "issues"
    ITEM = "item"
    ITEM_DN = "itemDn"
    JBOD_MODE = "jbodMode"
    JBOD_SHARING_SUPPORTED = "jbodSharingSupported"
    JOB = "job"
    JOB_COUNT = "jobCount"
    JUMBO_BREAKOUT_PORT = "jumboBreakoutPort"
    JUMBO_PACKETS = "jumboPackets"
    JUMBO_PACKETS_DELTA = "jumboPacketsDelta"
    JUMBO_PACKETS_DELTA_AVG = "jumboPacketsDeltaAvg"
    JUMBO_PACKETS_DELTA_MAX = "jumboPacketsDeltaMax"
    JUMBO_PACKETS_DELTA_MIN = "jumboPacketsDeltaMin"
    KERNEL_MEM_FREE = "kernelMemFree"
    KERNEL_MEM_FREE_AVG = "kernelMemFreeAvg"
    KERNEL_MEM_FREE_MAX = "kernelMemFreeMax"
    KERNEL_MEM_FREE_MIN = "kernelMemFreeMin"
    KERNEL_MEM_TOTAL = "kernelMemTotal"
    KERNEL_MEM_TOTAL_AVG = "kernelMemTotalAvg"
    KERNEL_MEM_TOTAL_MAX = "kernelMemTotalMax"
    KERNEL_MEM_TOTAL_MIN = "kernelMemTotalMin"
    KERNEL_NAME = "kernelName"
    KERNEL_RELEASE = "kernelRelease"
    KERNEL_VERSION = "kernelVersion"
    KEY = "key"
    KEY_DESCR = "keyDescr"
    KEY_DN = "keyDn"
    KEY_INST = "keyInst"
    KEY_RING = "keyRing"
    KEY_SET = "keySet"
    KEY_TYPE = "keyType"
    KMIP_FAULT = "kmipFault"
    KMIP_FAULT_DESCRIPTION = "kmipFaultDescription"
    KS_STARTUP_VERSION = "ksStartupVersion"
    KS_VERSION = "ksVersion"
    KVM_MGMT_POLICY_NAME = "kvmMgmtPolicyName"
    KVM_PORT = "kvmPort"
    L2KEYS = "l2keys"
    LABEL = "label"
    LABEL_VERSION = "labelVersion"
    LACP_FAST_TIMER = "lacpFastTimer"
    LACP_POLICY_NAME = "lacpPolicyName"
    LACP_SUSPEND_INDIVIDUAL = "lacpSuspendIndividual"
    LAN_CONN_POLICY_NAME = "lanConnPolicyName"
    LARGE_RECEIVE = "largeReceive"
    LARGETXS = "largetxs"
    LAST_BACKUP = "lastBackup"
    LAST_CMD = "lastCmd"
    LAST_DEADLINE = "lastDeadline"
    LAST_EVT = "lastEvt"
    LAST_EVT_TS = "lastEvtTs"
    LAST_EXIT_CODE = "lastExitCode"
    LAST_INTEGRITY_CHECK_TIME = "lastIntegrityCheckTime"
    LAST_INTERNAL_BACKUP_TIME = "lastInternalBackupTime"
    LAST_KNOWN_STATUS = "lastKnownStatus"
    LAST_NAME = "lastName"
    LAST_OCCURRENCE_TIME = "lastOccurrenceTime"
    LAST_OPER_STATE_REPORT = "lastOperStateReport"
    LAST_OPERATION = "lastOperation"
    LAST_PIN_TIME = "lastPinTime"
    LAST_POLL_TS = "lastPollTs"
    LAST_REBOOT_REASON = "lastRebootReason"
    LAST_TRANSITION = "lastTransition"
    LAST_UPDATE = "lastUpdate"
    LAST_UPDATE_TIME = "lastUpdateTime"
    LAST_UPDATED_TIME = "lastUpdatedTime"
    LAST_VLAN_GRP_COMPUTE_TIME = "lastVlanGrpComputeTime"
    LATE_COLLISION = "lateCollision"
    LATE_COLLISION_DELTA = "lateCollisionDelta"
    LATE_COLLISION_DELTA_AVG = "lateCollisionDeltaAvg"
    LATE_COLLISION_DELTA_MAX = "lateCollisionDeltaMax"
    LATE_COLLISION_DELTA_MIN = "lateCollisionDeltaMin"
    LATENCY = "latency"
    LB_TYPE = "lbType"
    LC = "lc"
    LC_NAME = "lcName"
    LC_TS = "lcTs"
    LEAD_ID_FOR_AUTO_INSTALL = "leadIdForAutoInstall"
    LEADERSHIP = "leadership"
    LEARN_CYCLE_REQUESTED = "learnCycleRequested"
    LEARN_MODE = "learnMode"
    LEARN_REQ_DROP = "learnReqDrop"
    LEARN_REQ_DROP_DELTA = "learnReqDropDelta"
    LEARN_REQ_DROP_DELTA_AVG = "learnReqDropDeltaAvg"
    LEARN_REQ_DROP_DELTA_MAX = "learnReqDropDeltaMax"
    LEARN_REQ_DROP_DELTA_MIN = "learnReqDropDeltaMin"
    LEFT_DATA = "leftData"
    LEFT_INLET_TEMP = "leftInletTemp"
    LEFT_INLET_TEMP_AVG = "leftInletTempAvg"
    LEFT_INLET_TEMP_MAX = "leftInletTempMax"
    LEFT_INLET_TEMP_MIN = "leftInletTempMin"
    LEFT_OUTLET_TEMP = "leftOutletTemp"
    LEFT_OUTLET_TEMP_AVG = "leftOutletTempAvg"
    LEFT_OUTLET_TEMP_MAX = "leftOutletTempMax"
    LEFT_OUTLET_TEMP_MIN = "leftOutletTempMin"
    LEGACY_MAC_OFFSET1 = "legacyMacOffset1"
    LEGACY_MAC_OFFSET2 = "legacyMacOffset2"
    LEGACY_PROP_ID = "legacyPropId"
    LEGACY_PROP_VAL = "legacyPropVal"
    LESS_THAN1024 = "lessThan1024"
    LESS_THAN1024_DELTA = "lessThan1024Delta"
    LESS_THAN1024_DELTA_AVG = "lessThan1024DeltaAvg"
    LESS_THAN1024_DELTA_MAX = "lessThan1024DeltaMax"
    LESS_THAN1024_DELTA_MIN = "lessThan1024DeltaMin"
    LESS_THAN128 = "lessThan128"
    LESS_THAN128_DELTA = "lessThan128Delta"
    LESS_THAN128_DELTA_AVG = "lessThan128DeltaAvg"
    LESS_THAN128_DELTA_MAX = "lessThan128DeltaMax"
    LESS_THAN128_DELTA_MIN = "lessThan128DeltaMin"
    LESS_THAN2048 = "lessThan2048"
    LESS_THAN2048_DELTA = "lessThan2048Delta"
    LESS_THAN2048_DELTA_AVG = "lessThan2048DeltaAvg"
    LESS_THAN2048_DELTA_MAX = "lessThan2048DeltaMax"
    LESS_THAN2048_DELTA_MIN = "lessThan2048DeltaMin"
    LESS_THAN256 = "lessThan256"
    LESS_THAN256_DELTA = "lessThan256Delta"
    LESS_THAN256_DELTA_AVG = "lessThan256DeltaAvg"
    LESS_THAN256_DELTA_MAX = "lessThan256DeltaMax"
    LESS_THAN256_DELTA_MIN = "lessThan256DeltaMin"
    LESS_THAN4096 = "lessThan4096"
    LESS_THAN4096_DELTA = "lessThan4096Delta"
    LESS_THAN4096_DELTA_AVG = "lessThan4096DeltaAvg"
    LESS_THAN4096_DELTA_MAX = "lessThan4096DeltaMax"
    LESS_THAN4096_DELTA_MIN = "lessThan4096DeltaMin"
    LESS_THAN512 = "lessThan512"
    LESS_THAN512_DELTA = "lessThan512Delta"
    LESS_THAN512_DELTA_AVG = "lessThan512DeltaAvg"
    LESS_THAN512_DELTA_MAX = "lessThan512DeltaMax"
    LESS_THAN512_DELTA_MIN = "lessThan512DeltaMin"
    LESS_THAN64 = "lessThan64"
    LESS_THAN64_DELTA = "lessThan64Delta"
    LESS_THAN64_DELTA_AVG = "lessThan64DeltaAvg"
    LESS_THAN64_DELTA_MAX = "lessThan64DeltaMax"
    LESS_THAN64_DELTA_MIN = "lessThan64DeltaMin"
    LESS_THAN8192 = "lessThan8192"
    LESS_THAN8192_DELTA = "lessThan8192Delta"
    LESS_THAN8192_DELTA_AVG = "lessThan8192DeltaAvg"
    LESS_THAN8192_DELTA_MAX = "lessThan8192DeltaMax"
    LESS_THAN8192_DELTA_MIN = "lessThan8192DeltaMin"
    LESS_THAN9216 = "lessThan9216"
    LESS_THAN9216_DELTA = "lessThan9216Delta"
    LESS_THAN9216_DELTA_AVG = "lessThan9216DeltaAvg"
    LESS_THAN9216_DELTA_MAX = "lessThan9216DeltaMax"
    LESS_THAN9216_DELTA_MIN = "lessThan9216DeltaMin"
    LESS_THAN_OR_EQUAL_TO1518 = "lessThanOrEqualTo1518"
    LESS_THAN_OR_EQUAL_TO1518_DELTA = "lessThanOrEqualTo1518Delta"
    LESS_THAN_OR_EQUAL_TO1518_DELTA_AVG = "lessThanOrEqualTo1518DeltaAvg"
    LESS_THAN_OR_EQUAL_TO1518_DELTA_MAX = "lessThanOrEqualTo1518DeltaMax"
    LESS_THAN_OR_EQUAL_TO1518_DELTA_MIN = "lessThanOrEqualTo1518DeltaMin"
    LEVEL = "level"
    LEVEL_FLAG = "levelFlag"
    LIC_GP = "licGP"
    LIC_STATE = "licState"
    LIC_VENDOR = "licVendor"
    LIC_VERSION = "licVersion"
    LIFE_CYCLE = "lifeCycle"
    LIFE_LEFT_IN_DAYS = "lifeLeftInDays"
    LIFE_LEFT_IN_DAYS_AVG = "lifeLeftInDaysAvg"
    LIFE_LEFT_IN_DAYS_MAX = "lifeLeftInDaysMax"
    LIFE_LEFT_IN_DAYS_MIN = "lifeLeftInDaysMin"
    LIMIT = "limit"
    LIMIT_STATUS = "limitStatus"
    LINE = "line"
    LINK_AGGREGATION_PREF = "linkAggregationPref"
    LINK_DESCR = "linkDescr"
    LINK_DOWN_DELAY = "linkDownDelay"
    LINK_DOWN_TIMEOUT = "linkDownTimeout"
    LINK_FAILURE_COUNT = "linkFailureCount"
    LINK_FAILURE_COUNT_DELTA = "linkFailureCountDelta"
    LINK_FAILURE_COUNT_DELTA_AVG = "linkFailureCountDeltaAvg"
    LINK_FAILURE_COUNT_DELTA_MAX = "linkFailureCountDeltaMax"
    LINK_FAILURE_COUNT_DELTA_MIN = "linkFailureCountDeltaMin"
    LINK_FAILURES = "linkFailures"
    LINK_FAILURES_DELTA = "linkFailuresDelta"
    LINK_FAILURES_DELTA_AVG = "linkFailuresDeltaAvg"
    LINK_FAILURES_DELTA_MAX = "linkFailuresDeltaMax"
    LINK_FAILURES_DELTA_MIN = "linkFailuresDeltaMin"
    LINK_GROUPING = "linkGrouping"
    LINK_SPEED = "linkSpeed"
    LINK_STATE = "linkState"
    LINK_STATE_REASON = "linkStateReason"
    LINK_STATUS = "linkStatus"
    LINK_STATUS_QUERY_TYPE = "linkStatusQueryType"
    LINK_UP_DELAY = "linkUpDelay"
    LINK_WIDTH = "linkWidth"
    LIP_COUNT = "lipCount"
    LIP_COUNT_DELTA = "lipCountDelta"
    LIP_COUNT_DELTA_AVG = "lipCountDeltaAvg"
    LIP_COUNT_DELTA_MAX = "lipCountDeltaMax"
    LIP_COUNT_DELTA_MIN = "lipCountDeltaMin"
    LLDP = "lldp"
    LLDP_INIT = "lldpInit"
    LLDP_MAC = "lldpMac"
    LLDP_MAC_OFFSET1 = "lldpMacOffset1"
    LLDP_MAC_OFFSET2 = "lldpMacOffset2"
    LLDP_RECEIVE = "lldpReceive"
    LLDP_TRANSMIT = "lldpTransmit"
    LOAD = "load"
    LOAD_AVG = "loadAvg"
    LOAD_CATALOG = "loadCatalog"
    LOAD_ERRORS = "loadErrors"
    LOAD_MAX = "loadMax"
    LOAD_MIN = "loadMin"
    LOAD_WARNINGS = "loadWarnings"
    LOCAL = "local"
    LOCAL_DIR = "localDir"
    LOCAL_DISK_POLICY_NAME = "localDiskPolicyName"
    LOCAL_HOST = "localHost"
    LOCAL_ID = "localId"
    LOCAL_INTERFACE = "localInterface"
    LOCALE = "locale"
    LOCALES = "locales"
    LOCALITY = "locality"
    LOCATION = "location"
    LOCATION_DN = "locationDn"
    LOCATOR_BEACON_SUPPORTED = "locatorBeaconSupported"
    LOG_DN = "logDn"
    LOGIN_TIME = "loginTime"
    LOOP_COUNT = "loopCount"
    LOSS_OF_SIGNAL_COUNT = "lossOfSignalCount"
    LOSS_OF_SIGNAL_COUNT_DELTA = "lossOfSignalCountDelta"
    LOSS_OF_SIGNAL_COUNT_DELTA_AVG = "lossOfSignalCountDeltaAvg"
    LOSS_OF_SIGNAL_COUNT_DELTA_MAX = "lossOfSignalCountDeltaMax"
    LOSS_OF_SIGNAL_COUNT_DELTA_MIN = "lossOfSignalCountDeltaMin"
    LOSS_OF_SYNC_COUNT = "lossOfSyncCount"
    LOSS_OF_SYNC_COUNT_DELTA = "lossOfSyncCountDelta"
    LOSS_OF_SYNC_COUNT_DELTA_AVG = "lossOfSyncCountDeltaAvg"
    LOSS_OF_SYNC_COUNT_DELTA_MAX = "lossOfSyncCountDeltaMax"
    LOSS_OF_SYNC_COUNT_DELTA_MIN = "lossOfSyncCountDeltaMin"
    LOW_VOLTAGE_MEMORY = "lowVoltageMemory"
    LOWER_LIMIT = "lowerLimit"
    LP_INTERVAL = "lpInterval"
    LS_DN = "lsDn"
    LS_SERVER_NAME = "lsServerName"
    LS_SERVER_TMPL_NAME = "lsServerTmplName"
    LUN = "lun"
    LUN_BUSY_RETRY_COUNT = "lunBusyRetryCount"
    LUN_DN = "lunDn"
    LUN_ID = "lunId"
    LUN_ITEM_DN = "lunItemDn"
    LUN_ITEM_NAME = "lunItemName"
    LUN_MAP_TYPE = "lunMapType"
    LUN_NAME = "lunName"
    LUN_ORDER = "lunOrder"
    LUN_QUEUE_DEPTH = "lunQueueDepth"
    LUN_SET_DISK_SLOT_ID = "lunSetDiskSlotId"
    LUNS_PER_TARGET = "lunsPerTarget"
    M_STATUS = "mStatus"
    M_SWITCH_DRIVE_INDEX = "mSwitchDriveIndex"
    M_SWITCH_SAS_MIXING_SUPPORTED = "mSwitchSasMixingSupported"
    MAC = "mac"
    MAC1 = "mac1"
    MAC2 = "mac2"
    MAC_ADDR = "macAddr"
    MAC_ADDR_TYPE = "macAddrType"
    MAC_ADDRESS = "macAddress"
    MAC_ADDRESS_POLICY = "macAddressPolicy"
    MAC_AGING = "macAging"
    MAC_DISCARDED_PACKETS = "macDiscardedPackets"
    MAC_DISCARDED_PACKETS_DELTA = "macDiscardedPacketsDelta"
    MAC_DISCARDED_PACKETS_DELTA_AVG = "macDiscardedPacketsDeltaAvg"
    MAC_DISCARDED_PACKETS_DELTA_MAX = "macDiscardedPacketsDeltaMax"
    MAC_DISCARDED_PACKETS_DELTA_MIN = "macDiscardedPacketsDeltaMin"
    MAC_LEFT = "macLeft"
    MAC_OF_SHARED_IOMA = "macOfSharedIOMA"
    MAC_OF_SHARED_IOMB = "macOfSharedIOMB"
    MAC_OFFSET = "macOffset"
    MAC_OFFSET1 = "macOffset1"
    MAC_OFFSET2 = "macOffset2"
    MAC_OFFSET_SUB00 = "macOffsetSub00"
    MAC_OFFSET_SUB01 = "macOffsetSub01"
    MAC_OFFSET_SUB02 = "macOffsetSub02"
    MAC_OFFSET_SUB03 = "macOffsetSub03"
    MAC_OFFSET_SUB10 = "macOffsetSub10"
    MAC_OFFSET_SUB11 = "macOffsetSub11"
    MAC_OFFSET_SUB12 = "macOffsetSub12"
    MAC_OFFSET_SUB13 = "macOffsetSub13"
    MAC_OFFSET_VNIC_FROM = "macOffsetVnicFrom"
    MAC_OFFSET_VNIC_TO = "macOffsetVnicTo"
    MAC_POOL_NAME = "macPoolName"
    MAC_REGISTER_MODE = "macRegisterMode"
    MAC_RIGHT = "macRight"
    MAIN_BOARD_OUTLET1 = "mainBoardOutlet1"
    MAIN_BOARD_OUTLET1_AVG = "mainBoardOutlet1Avg"
    MAIN_BOARD_OUTLET1_MAX = "mainBoardOutlet1Max"
    MAIN_BOARD_OUTLET1_MIN = "mainBoardOutlet1Min"
    MAIN_BOARD_OUTLET2 = "mainBoardOutlet2"
    MAIN_BOARD_OUTLET2_AVG = "mainBoardOutlet2Avg"
    MAIN_BOARD_OUTLET2_MAX = "mainBoardOutlet2Max"
    MAIN_BOARD_OUTLET2_MIN = "mainBoardOutlet2Min"
    MAINT_POLICY_DN = "maintPolicyDn"
    MAINT_POLICY_NAME = "maintPolicyName"
    MAJOR_OPT_TYPE = "majorOptType"
    MALFORMED_TLPERRORS = "malformedTLPErrors"
    MALFORMED_TLPERRORS15_MIN = "malformedTLPErrors15Min"
    MALFORMED_TLPERRORS15_MIN_H = "malformedTLPErrors15MinH"
    MALFORMED_TLPERRORS1_DAY = "malformedTLPErrors1Day"
    MALFORMED_TLPERRORS1_DAY_H = "malformedTLPErrors1DayH"
    MALFORMED_TLPERRORS1_HOUR = "malformedTLPErrors1Hour"
    MALFORMED_TLPERRORS1_HOUR_H = "malformedTLPErrors1HourH"
    MALFORMED_TLPERRORS1_WEEK = "malformedTLPErrors1Week"
    MALFORMED_TLPERRORS1_WEEK_H = "malformedTLPErrors1WeekH"
    MALFORMED_TLPERRORS2_WEEKS = "malformedTLPErrors2Weeks"
    MALFORMED_TLPERRORS2_WEEKS_H = "malformedTLPErrors2WeeksH"
    MANAGER = "manager"
    MANAGING_INST = "managingInst"
    MANAGING_INSTANCE = "managingInstance"
    MAPPING_NAME = "mappingName"
    MASK = "mask"
    MASTER_SLOT_ID = "masterSlotId"
    MAX_ACTIVE_SPAN_SESSION_COUNT = "maxActiveSpanSessionCount"
    MAX_APP_POWER = "maxAppPower"
    MAX_BONDS = "maxBonds"
    MAX_BUS_ID_PER_SLOT = "maxBusIdPerSlot"
    MAX_CAP = "maxCap"
    MAX_CAPACITY = "maxCapacity"
    MAX_CORES = "maxCores"
    MAX_DATA_FIELD_SIZE = "maxDataFieldSize"
    MAX_DEADLINE_TIMEOUT = "maxDeadlineTimeout"
    MAX_DERIVABLE_WWPN = "maxDerivableWWPN"
    MAX_DEVICES = "maxDevices"
    MAX_DRIVE_PER_CAGE = "maxDrivePerCage"
    MAX_ETH1G_PORT = "maxEth1gPort"
    MAX_ETH1G_SLOT = "maxEth1gSlot"
    MAX_ETH_PC_MEMBERS = "maxEthPcMembers"
    MAX_ETH_PCS = "maxEthPcs"
    MAX_EVENT_INTERVAL = "maxEventInterval"
    MAX_FAIL_REPORT_COUNT = "maxFailReportCount"
    MAX_FC_PCS = "maxFcPcs"
    MAX_FC_SPEED = "maxFcSpeed"
    MAX_FCOE_PC_MEMBERS = "maxFcoePcMembers"
    MAX_FILES = "maxFiles"
    MAX_HITS = "maxHits"
    MAX_ID = "maxId"
    MAX_LOCAL_DISKS = "maxLocalDisks"
    MAX_LUNS = "maxLuns"
    MAX_LUNS_PER_DG = "maxLunsPerDG"
    MAX_NUMBER_OF_MSWITCH = "maxNumberOfMSwitch"
    MAX_PORT_ID = "maxPortId"
    MAX_PORTS = "maxPorts"
    MAX_PORTS_PER_NODE = "maxPortsPerNode"
    MAX_POST_POWER = "maxPostPower"
    MAX_POWER = "maxPower"
    MAX_PRIMARY_VLAN_COUNT = "maxPrimaryVlanCount"
    MAX_PROCS = "maxProcs"
    MAX_REQ_POWER = "maxReqPower"
    MAX_RETRIES = "maxRetries"
    MAX_RETRY_COUNT = "maxRetryCount"
    MAX_SEC_VLAN_PER_PRIMARY_VLAN_COUNT = "maxSecVlanPerPrimaryVlanCount"
    MAX_SECONDARY_VLAN_COUNT = "maxSecondaryVlanCount"
    MAX_SIZE = "maxSize"
    MAX_SLOT = "maxSlot"
    MAX_SPEED = "maxSpeed"
    MAX_SZ = "maxSz"
    MAX_THREADS = "maxThreads"
    MAX_UPLINK_PORTS = "maxUplinkPorts"
    MAX_VER = "maxVer"
    MAX_VIF_COUNT = "maxVifCount"
    MAX_VIRTUAL_DRIVES_PER_SERVER = "maxVirtualDrivesPerServer"
    MAX_VIRTUAL_ETH_IF_PER_SERVER = "maxVirtualEthIfPerServer"
    MAXIMUM = "maximum"
    MAXIMUM_MR = "maximumMR"
    MAXIMUM_POWER = "maximumPower"
    MAXIMUM_QP = "maximumQP"
    MAXIMUM_RETRY_COUNT = "maximumRetryCount"
    MAXIMUM_TEMPERATURE = "maximumTemperature"
    MCAST_POLICY_NAME = "mcastPolicyName"
    MD5SUM = "md5sum"
    ME4308_SUPPORTED = "me4308Supported"
    MEM_AVAILABLE = "memAvailable"
    MEM_AVAILABLE_AVG = "memAvailableAvg"
    MEM_AVAILABLE_MAX = "memAvailableMax"
    MEM_AVAILABLE_MIN = "memAvailableMin"
    MEM_CACHED = "memCached"
    MEM_CACHED_AVG = "memCachedAvg"
    MEM_CACHED_MAX = "memCachedMax"
    MEM_CACHED_MIN = "memCachedMin"
    MEM_CHUNK_SIZE = "memChunkSize"
    MEM_SIZE = "memSize"
    MEMBER_STATUS = "memberStatus"
    MEMBERSHIP = "membership"
    MEMORY_CAPACITY = "memoryCapacity"
    MEMORY_MODE_PERCENTAGE = "memoryModePercentage"
    MEMORY_REGIONS = "memoryRegions"
    MEMORY_SPEED = "memorySpeed"
    MENLO_ETH_INDEX = "menloEthIndex"
    MENLO_FC_INDEX = "menloFcIndex"
    MENLO_MCPU_INDEX = "menloMcpuIndex"
    MENLO_NET_INDEX = "menloNetIndex"
    MENLO_PORT_INDEX = "menloPortIndex"
    MENLO_QUEUE_COMPONENT = "menloQueueComponent"
    MENLO_QUEUE_INDEX = "menloQueueIndex"
    MESSAGE = "message"
    MESSAGE_SUBTYPE = "messageSubtype"
    MESSAGE_TYPE = "messageType"
    METHOD = "method"
    MEZZ_MAPPING = "mezzMapping"
    MFG_DATE = "mfgDate"
    MFG_ID = "mfgId"
    MFG_MAJOR_REV = "mfgMajorRev"
    MFG_MINOR_REV = "mfgMinorRev"
    MFG_PLATFORM_ID = "mfgPlatformId"
    MFG_TIME = "mfgTime"
    MGMT_ACCESS_POLICY_NAME = "mgmtAccessPolicyName"
    MGMT_DAUGHTER_CARD_SLOT_ID = "mgmtDaughterCardSlotId"
    MGMT_FW_POLICY_NAME = "mgmtFwPolicyName"
    MGMT_IF_IP_ADDR = "mgmtIfIpAddr"
    MGMT_PLANE = "mgmtPlane"
    MGMT_PLANE_VER = "mgmtPlaneVer"
    MGMT_SERVICES_STATE = "mgmtServicesState"
    MGMT_TRANSPORT = "mgmtTransport"
    MID_TEMP = "midTemp"
    MID_TEMP_AVG = "midTempAvg"
    MID_TEMP_MAX = "midTempMax"
    MID_TEMP_MIN = "midTempMin"
    MIN_ACTIVE_FAN = "minActiveFan"
    MIN_APP_POWER = "minAppPower"
    MIN_BIOS_VERSION = "minBiosVersion"
    MIN_BOOT_FW_CIMC_VERSION = "minBootFwCimcVersion"
    MIN_CAP = "minCap"
    MIN_CIMC_VERSION = "minCimcVersion"
    MIN_CMC_VERSION = "minCmcVersion"
    MIN_CORES = "minCores"
    MIN_DRIVE_SIZE = "minDriveSize"
    MIN_ID = "minId"
    MIN_KVM_CERT_SUPPORTED_CIMC_VER = "minKvmCertSupportedCimcVer"
    MIN_NORM_POST_POWER = "minNormPostPower"
    MIN_PASSPHRASE_LEN = "minPassphraseLen"
    MIN_PORT_ID = "minPortId"
    MIN_POST_POWER = "minPostPower"
    MIN_POWER = "minPower"
    MIN_PROCS = "minProcs"
    MIN_REQ_POWER = "minReqPower"
    MIN_SZ = "minSz"
    MIN_THREADS = "minThreads"
    MIN_UCSMVERSION = "minUCSMVersion"
    MIN_VER = "minVer"
    MIN_VER1 = "minVer1"
    MIN_VER2 = "minVer2"
    MIN_VERSION = "minVersion"
    MIN_WEB_UISUPPORTED_CIMC_VER = "minWebUISupportedCimcVer"
    MINIMUM_POWER = "minimumPower"
    MINIMUM_SEND_NOW_INTERVAL_SECONDS = "minimumSendNowIntervalSeconds"
    MINIMUM_TEMPERATURE = "minimumTemperature"
    MINUTE = "minute"
    MIRRORING_INTER_SOCK_ERRORS = "mirroringInterSockErrors"
    MIRRORING_INTER_SOCK_ERRORS15_MIN = "mirroringInterSockErrors15Min"
    MIRRORING_INTER_SOCK_ERRORS15_MIN_H = "mirroringInterSockErrors15MinH"
    MIRRORING_INTER_SOCK_ERRORS1_DAY = "mirroringInterSockErrors1Day"
    MIRRORING_INTER_SOCK_ERRORS1_DAY_H = "mirroringInterSockErrors1DayH"
    MIRRORING_INTER_SOCK_ERRORS1_HOUR = "mirroringInterSockErrors1Hour"
    MIRRORING_INTER_SOCK_ERRORS1_HOUR_H = "mirroringInterSockErrors1HourH"
    MIRRORING_INTER_SOCK_ERRORS1_WEEK = "mirroringInterSockErrors1Week"
    MIRRORING_INTER_SOCK_ERRORS1_WEEK_H = "mirroringInterSockErrors1WeekH"
    MIRRORING_INTER_SOCK_ERRORS2_WEEKS = "mirroringInterSockErrors2Weeks"
    MIRRORING_INTER_SOCK_ERRORS2_WEEKS_H = "mirroringInterSockErrors2WeeksH"
    MIRRORING_INTRA_SOCK_ERRORS = "mirroringIntraSockErrors"
    MIRRORING_INTRA_SOCK_ERRORS15_MIN = "mirroringIntraSockErrors15Min"
    MIRRORING_INTRA_SOCK_ERRORS15_MIN_H = "mirroringIntraSockErrors15MinH"
    MIRRORING_INTRA_SOCK_ERRORS1_DAY = "mirroringIntraSockErrors1Day"
    MIRRORING_INTRA_SOCK_ERRORS1_DAY_H = "mirroringIntraSockErrors1DayH"
    MIRRORING_INTRA_SOCK_ERRORS1_HOUR = "mirroringIntraSockErrors1Hour"
    MIRRORING_INTRA_SOCK_ERRORS1_HOUR_H = "mirroringIntraSockErrors1HourH"
    MIRRORING_INTRA_SOCK_ERRORS1_WEEK = "mirroringIntraSockErrors1Week"
    MIRRORING_INTRA_SOCK_ERRORS1_WEEK_H = "mirroringIntraSockErrors1WeekH"
    MIRRORING_INTRA_SOCK_ERRORS2_WEEKS = "mirroringIntraSockErrors2Weeks"
    MIRRORING_INTRA_SOCK_ERRORS2_WEEKS_H = "mirroringIntraSockErrors2WeeksH"
    MISMATCH_ERRORS = "mismatchErrors"
    MISMATCH_ERRORS15_MIN = "mismatchErrors15Min"
    MISMATCH_ERRORS15_MIN_H = "mismatchErrors15MinH"
    MISMATCH_ERRORS1_DAY = "mismatchErrors1Day"
    MISMATCH_ERRORS1_DAY_H = "mismatchErrors1DayH"
    MISMATCH_ERRORS1_HOUR = "mismatchErrors1Hour"
    MISMATCH_ERRORS1_HOUR_H = "mismatchErrors1HourH"
    MISMATCH_ERRORS1_WEEK = "mismatchErrors1Week"
    MISMATCH_ERRORS1_WEEK_H = "mismatchErrors1WeekH"
    MISMATCH_ERRORS2_WEEKS = "mismatchErrors2Weeks"
    MISMATCH_ERRORS2_WEEKS_H = "mismatchErrors2WeeksH"
    MMU_PERCENT = "mmuPercent"
    MO_CLASS_ID = "moClassId"
    MO_DN = "moDn"
    MO_RN = "moRn"
    MODE = "mode"
    MODE_CHANGE_SUPPORTED = "modeChangeSupported"
    MODE_CONFIG_TOKEN = "modeConfigToken"
    MODEL = "model"
    MODIFIED = "modified"
    MODULE = "module"
    MODULES = "modules"
    MODULUS = "modulus"
    MON_TRAF_DIR = "monTrafDir"
    MONITOR_INTERVAL = "monitorInterval"
    MONITOR_MECHANISM = "monitorMechanism"
    MOST_RECENT = "mostRecent"
    MOUNT_PROTOCOL = "mountProtocol"
    MSG_INTERVAL = "msgInterval"
    MTIME = "mtime"
    MTU = "mtu"
    MULTI_COLLISION = "multiCollision"
    MULTI_COLLISION_DELTA = "multiCollisionDelta"
    MULTI_COLLISION_DELTA_AVG = "multiCollisionDeltaAvg"
    MULTI_COLLISION_DELTA_MAX = "multiCollisionDeltaMax"
    MULTI_COLLISION_DELTA_MIN = "multiCollisionDeltaMin"
    MULTI_PORT_CONNECTION_STATUS = "multiPortConnectionStatus"
    MULTI_QUEUE = "multiQueue"
    MULTICAST_HW_HASH = "multicastHwHash"
    MULTICAST_OPTIMIZE = "multicastOptimize"
    MULTICAST_PACKETS = "multicastPackets"
    MULTICAST_PACKETS_DELTA = "multicastPacketsDelta"
    MULTICAST_PACKETS_DELTA_AVG = "multicastPacketsDeltaAvg"
    MULTICAST_PACKETS_DELTA_MAX = "multicastPacketsDeltaMax"
    MULTICAST_PACKETS_DELTA_MIN = "multicastPacketsDeltaMin"
    MY_NWWN = "myNwwn"
    MY_PWWN = "myPwwn"
    N_OSCOUNT = "nOSCount"
    N_OSCOUNT_DELTA = "nOSCountDelta"
    N_OSCOUNT_DELTA_AVG = "nOSCountDeltaAvg"
    N_OSCOUNT_DELTA_MAX = "nOSCountDeltaMax"
    N_OSCOUNT_DELTA_MIN = "nOSCountDeltaMin"
    NAME = "name"
    NAMING_PREFIX = "namingPrefix"
    NATIVE_NET = "nativeNet"
    NATIVE_NET_DN = "nativeNetDn"
    NATIVE_VLAN = "nativeVlan"
    NEED_RECOVERY = "needRecovery"
    NETFLOW_ACTIVE_TIMEOUT = "netflowActiveTimeout"
    NETFLOW_INACTIVE_TIMEOUT = "netflowInactiveTimeout"
    NETMASK = "netmask"
    NETWORK_CONFIG_ISSUES = "networkConfigIssues"
    NETWORK_TYPE = "networkType"
    NEW_FE_TS = "newFeTs"
    NEXT_DEADLINE = "nextDeadline"
    NEXT_LEARN_CYCLE_TS = "nextLearnCycleTs"
    NEXT_REQ_ID = "nextReqId"
    NF_MON_EXPORTER_NAME = "nfMonExporterName"
    NF_MONITOR_NAME = "nfMonitorName"
    NF_VERSION_LO = "nfVersionLo"
    NIC_DN = "nicDn"
    NLINK = "nlink"
    NO_BREAKDOWN_GREATER_THAN1518 = "noBreakdownGreaterThan1518"
    NO_BREAKDOWN_GREATER_THAN1518_DELTA = "noBreakdownGreaterThan1518Delta"
    NO_BREAKDOWN_GREATER_THAN1518_DELTA_AVG = "noBreakdownGreaterThan1518DeltaAvg"
    NO_BREAKDOWN_GREATER_THAN1518_DELTA_MAX = "noBreakdownGreaterThan1518DeltaMax"
    NO_BREAKDOWN_GREATER_THAN1518_DELTA_MIN = "noBreakdownGreaterThan1518DeltaMin"
    NO_CHANGE_INTERVAL = "noChangeInterval"
    NODE_ADDR = "nodeAddr"
    NODE_WWN = "nodeWwn"
    NOMINAL_POWER = "nominalPower"
    NOMINAL_TEMPERATURE = "nominalTemperature"
    NON_CR4 = "nonCR4"
    NON_COMP_DESCR = "nonCompDescr"
    NON_COMP_DNS = "nonCompDns"
    NONKEYS = "nonkeys"
    NORMAL_VALUE = "normalValue"
    NOTIFICATION_TYPE = "notificationType"
    NS_ADMIN_STATE = "nsAdminState"
    NS_SIZE = "nsSize"
    NUM_ADAPTER_SLOTS = "numAdapterSlots"
    NUM_BREAKOUT_PORT = "numBreakoutPort"
    NUM_CERTS = "numCerts"
    NUM_CONTROLLERS = "numControllers"
    NUM_DCE_PORTS = "numDcePorts"
    NUM_DED_HOT_SPARES = "numDedHotSpares"
    NUM_DRIVES = "numDrives"
    NUM_GLOB_HOT_SPARES = "numGlobHotSpares"
    NUM_GPU = "numGpu"
    NUM_OF40_GADAPTORS_WITH_OLD_FW = "numOf40GAdaptorsWithOldFw"
    NUM_OF40_GADAPTORS_WITH_UNKNOWN_FW = "numOf40GAdaptorsWithUnknownFw"
    NUM_OF_ADAPTORS = "numOfAdaptors"
    NUM_OF_CORES = "numOfCores"
    NUM_OF_CORES_ENABLED = "numOfCoresEnabled"
    NUM_OF_CPU = "numOfCpu"
    NUM_OF_CPUS = "numOfCpus"
    NUM_OF_DIMM = "numOfDimm"
    NUM_OF_DIMMS = "numOfDimms"
    NUM_OF_ETH_HOST_IFS = "numOfEthHostIfs"
    NUM_OF_FC_HOST_IFS = "numOfFcHostIfs"
    NUM_OF_LOCAL_DISK = "numOfLocalDisk"
    NUM_OF_PHYS_SLOTS = "numOfPhysSlots"
    NUM_OF_REGIONS = "numOfRegions"
    NUM_OF_STORAGE_CONTROLLER = "numOfStorageController"
    NUM_OF_THREADS = "numOfThreads"
    NUM_OFADAPTOR = "numOfadaptor"
    NUM_PEER_NOTIFICATIONS = "numPeerNotifications"
    NUM_PORTS = "numPorts"
    NUM_SLOTS = "numSlots"
    NUM_VLAN_LIMIT = "numVlanLimit"
    NUMBER_OF_ARP_REQUESTS = "numberOfArpRequests"
    NUMBER_OF_BLOCKS = "numberOfBlocks"
    NUMBER_OF_FLEX_FLASH_CARDS = "numberOfFlexFlashCards"
    NUMBER_OF_NDISC_REQUESTS = "numberOfNdiscRequests"
    NUMBER_OF_ONBOARD_DISKS = "numberOfOnboardDisks"
    NUMBER_OF_PING_REQUESTS = "numberOfPingRequests"
    NUMBER_OF_PORTS = "numberOfPorts"
    NUMBER_OF_SERVER_UNITS = "numberOfServerUnits"
    NUMBER_OF_SLOTS = "numberOfSlots"
    NUMBER_OF_SLOTS_SPANNED = "numberOfSlotsSpanned"
    NW_CTRL_POLICY_NAME = "nwCtrlPolicyName"
    NW_TEMPL_NAME = "nwTemplName"
    OBJECT_CLASS_NAME = "objectClassName"
    OBSERVED_DN = "observedDn"
    OCCUR = "occur"
    OEM_ID = "oemId"
    OEM_NAME = "oemName"
    OEM_PART_NUMBER = "oemPartNumber"
    OFFLOAD_SUPPORT = "offloadSupport"
    OFFLOAD_TYPE = "offloadType"
    OLD_CENTRALE_MO_DN = "oldCentraleMoDn"
    OLD_CENTRALE_VNET_EP_DN = "oldCentraleVnetEpDn"
    OLD_CHASSIS_DN = "oldChassisDn"
    OLD_INITIATOR_NAME = "oldInitiatorName"
    OLD_IP_V4_ADDR = "oldIpV4Addr"
    OLD_IP_V6_ADDR = "oldIpV6Addr"
    OLD_PN_DN = "oldPnDn"
    OLD_STR_TYPE = "oldStrType"
    OLD_ZONE_PREFIX = "oldZonePrefix"
    OLDADDR = "oldaddr"
    OLDUUID = "olduuid"
    OLDWWNN = "oldwwnn"
    ON_BEHALF_OF_IDENT = "onBehalfOfIdent"
    ON_BEHALF_OF_TYPE = "onBehalfOfType"
    ON_BOARD_MEMORY_CHECK_NEEDED = "onBoardMemoryCheckNeeded"
    ON_BOARD_MEMORY_PRESENT = "onBoardMemoryPresent"
    ON_BOARD_MEMORY_SIZE = "onBoardMemorySize"
    ONBOARD_DISK_BASE_PORT_NO = "onboardDiskBasePortNo"
    ONBOARD_DISK_FIRST_INDEX = "onboardDiskFirstIndex"
    OOB_CONTROLLER_CLASS_IDENTIFIER = "oobControllerClassIdentifier"
    OOB_CONTROLLER_ID = "oobControllerId"
    OOB_IF_GW = "oobIfGw"
    OOB_IF_IP = "oobIfIp"
    OOB_IF_MAC = "oobIfMac"
    OOB_IF_MASK = "oobIfMask"
    OOB_INTERFACE_SUPPORTED = "oobInterfaceSupported"
    OPER_ADAPTOR_PROFILE_NAME = "operAdaptorProfileName"
    OPER_AUTH_PROFILE_NAME = "operAuthProfileName"
    OPER_BIOS_PROFILE_NAME = "operBiosProfileName"
    OPER_BOOT_POLICY_NAME = "operBootPolicyName"
    OPER_BORDER_AGGR_PORT_ID = "operBorderAggrPortId"
    OPER_BORDER_PORT_ID = "operBorderPortId"
    OPER_BORDER_SLOT_ID = "operBorderSlotId"
    OPER_CDN_NAME = "operCdnName"
    OPER_CDP_LINK_POLICY_NAME = "operCdpLinkPolicyName"
    OPER_CHASSIS_FW_POLICY_NAME = "operChassisFwPolicyName"
    OPER_CODE = "operCode"
    OPER_COMMITTED = "operCommitted"
    OPER_COMPUTE_CONN_POLICY_NAME = "operComputeConnPolicyName"
    OPER_CON_POLICY_NAME = "operConPolicyName"
    OPER_CONN = "operConn"
    OPER_DEVICE_ID = "operDeviceId"
    OPER_DISK_ZONING_POLICY_NAME = "operDiskZoningPolicyName"
    OPER_DYNAMIC_CON_POLICY_NAME = "operDynamicConPolicyName"
    OPER_ETH_LINK_PROFILE_NAME = "operEthLinkProfileName"
    OPER_EVAC_STATE = "operEvacState"
    OPER_EXT_IPPOOL_NAME = "operExtIPPoolName"
    OPER_EXT_IP_POOL_NAME = "operExtIpPoolName"
    OPER_FPLOCK_STATE = "operFPLockState"
    OPER_FABRIC_NETWORK_NAME = "operFabricNetworkName"
    OPER_FLOW_EXP_PROFILE = "operFlowExpProfile"
    OPER_FLOW_MON_RECORD_DEF = "operFlowMonRecordDef"
    OPER_FLOW_TIMEOUT_POLICY = "operFlowTimeoutPolicy"
    OPER_FN_DEF_NAME = "operFnDefName"
    OPER_GRAPHICS_CARD_POLICY_NAME = "operGraphicsCardPolicyName"
    OPER_HOST_FW_POLICY_NAME = "operHostFwPolicyName"
    OPER_HOST_PORT = "operHostPort"
    OPER_IDENT_POOL_NAME = "operIdentPoolName"
    OPER_INITIATOR_POLICY_NAME = "operInitiatorPolicyName"
    OPER_IP_POOL_NAME = "operIpPoolName"
    OPER_IP_POOL_NAME_FABRIC_B = "operIpPoolNameFabricB"
    OPER_IQN_IDENT_POOL_NAME = "operIqnIdentPoolName"
    OPER_IQN_POOL_NAME = "operIqnPoolName"
    OPER_KVM_MGMT_POLICY_NAME = "operKvmMgmtPolicyName"
    OPER_LACP_POLICY_NAME = "operLacpPolicyName"
    OPER_LAN_CONN_POLICY_NAME = "operLanConnPolicyName"
    OPER_LOCAL_DISK_POLICY_NAME = "operLocalDiskPolicyName"
    OPER_LUN_ID = "operLunId"
    OPER_LUN_ORDER = "operLunOrder"
    OPER_MAC_POOL_NAME = "operMacPoolName"
    OPER_MAINT_POLICY_NAME = "operMaintPolicyName"
    OPER_MCAST_POLICY_NAME = "operMcastPolicyName"
    OPER_MGMT_ACCESS_POLICY_NAME = "operMgmtAccessPolicyName"
    OPER_MGMT_FW_POLICY_NAME = "operMgmtFwPolicyName"
    OPER_MIN = "operMin"
    OPER_MOUNT_STATUS = "operMountStatus"
    OPER_NAME = "operName"
    OPER_NF_MON_EXPORTER_NAME = "operNfMonExporterName"
    OPER_NF_MONITOR_NAME = "operNfMonitorName"
    OPER_NW_CTRL_POLICY_NAME = "operNwCtrlPolicyName"
    OPER_NW_TEMPL_NAME = "operNwTemplName"
    OPER_ORDER = "operOrder"
    OPER_PEAK = "operPeak"
    OPER_PEER_REDUNDANCY_TEMPL_NAME = "operPeerRedundancyTemplName"
    OPER_PERSISTENT_MEMORY_POLICY_NAME = "operPersistentMemoryPolicyName"
    OPER_PIN_TO_GROUP_NAME = "operPinToGroupName"
    OPER_POOL_NAME = "operPoolName"
    OPER_PORT = "operPort"
    OPER_PORT_MODE = "operPortMode"
    OPER_POWER = "operPower"
    OPER_POWER_POLICY_NAME = "operPowerPolicyName"
    OPER_POWER_REQUIREMENT = "operPowerRequirement"
    OPER_POWER_SYNC_POLICY_NAME = "operPowerSyncPolicyName"
    OPER_PRIMARY_VNET_DN = "operPrimaryVnetDn"
    OPER_PRIMARY_VNET_NAME = "operPrimaryVnetName"
    OPER_PRIO = "operPrio"
    OPER_PROF_METHOD = "operProfMethod"
    OPER_PROP_MASK = "operPropMask"
    OPER_PROTOCOL = "operProtocol"
    OPER_PROVIDER_DN = "operProviderDn"
    OPER_PROVIDER_GROUP = "operProviderGroup"
    OPER_PWR_TRANS_SRC = "operPwrTransSrc"
    OPER_QOS_POLICY_NAME = "operQosPolicyName"
    OPER_QUALIFIER = "operQualifier"
    OPER_QUALIFIER_REASON = "operQualifierReason"
    OPER_REALM = "operRealm"
    OPER_SAN_CONN_POLICY_NAME = "operSanConnPolicyName"
    OPER_SAS_EXPANDER_CONFIG_POLICY_NAME = "operSasExpanderConfigPolicyName"
    OPER_SCHED_NAME = "operSchedName"
    OPER_SCHEDULER = "operScheduler"
    OPER_SCRUB_POLICY_NAME = "operScrubPolicyName"
    OPER_SERVICE_PACK_VERSION = "operServicePackVersion"
    OPER_SOL_POLICY_NAME = "operSolPolicyName"
    OPER_SPDM_CERTIFICATE_POLICY_NAME = "operSpdmCertificatePolicyName"
    OPER_SPEED = "operSpeed"
    OPER_SRC_TEMPL_NAME = "operSrcTemplName"
    OPER_STATE = "operState"
    OPER_STATE_DESC = "operStateDesc"
    OPER_STATE_DESCR = "operStateDescr"
    OPER_STATE_QUAL = "operStateQual"
    OPER_STATE_REASON = "operStateReason"
    OPER_STATS_POLICY_NAME = "operStatsPolicyName"
    OPER_STATUS = "operStatus"
    OPER_STORAGE_CONN_POLICY_NAME = "operStorageConnPolicyName"
    OPER_STORAGE_PROFILE_NAME = "operStorageProfileName"
    OPER_SUPPRESS_POLICY_NAME = "operSuppressPolicyName"
    OPER_TIMEZONE = "operTimezone"
    OPER_UDLD_LINK_POLICY_NAME = "operUdldLinkPolicyName"
    OPER_VCON = "operVcon"
    OPER_VCON_PROFILE_NAME = "operVconProfileName"
    OPER_VERSION = "operVersion"
    OPER_VM_NETWORK_DEF_NAME = "operVmNetworkDefName"
    OPER_VMEDIA_POLICY_NAME = "operVmediaPolicyName"
    OPER_VNET_DN = "operVnetDn"
    OPER_VNET_NAME = "operVnetName"
    OPERABILITY = "operability"
    OPERABILITY_QUALIFIER = "operabilityQualifier"
    OPERABILITY_QUALIFIER_REASON = "operabilityQualifierReason"
    OPERATING_MODE = "operatingMode"
    OPERATING_VOLTAGES = "operatingVoltages"
    OPERATION = "operation"
    OPERATION_REQUEST = "operationRequest"
    OPERATION_STATE = "operationState"
    OPERATION_TIMEOUT = "operationTimeout"
    OPROM_BOOT_STATUS = "opromBootStatus"
    ORDER = "order"
    ORG_DN = "orgDn"
    ORG_NAME = "orgName"
    ORG_PATH = "orgPath"
    ORG_UNIT_NAME = "orgUnitName"
    ORIENTATION = "orientation"
    ORIG_SEVERITY = "origSeverity"
    ORIGINAL_MAC = "originalMac"
    ORIGINAL_NODE_WWN = "originalNodeWwn"
    ORIGINAL_UUID = "originalUuid"
    ORIGINAL_WWN = "originalWwn"
    OUI = "oui"
    OUT = "out"
    OUT_DISCARD = "outDiscard"
    OUT_DISCARD_DELTA = "outDiscardDelta"
    OUT_DISCARD_DELTA_AVG = "outDiscardDeltaAvg"
    OUT_DISCARD_DELTA_MAX = "outDiscardDeltaMax"
    OUT_DISCARD_DELTA_MIN = "outDiscardDeltaMin"
    OUTLET1 = "outlet1"
    OUTLET1_AVG = "outlet1Avg"
    OUTLET1_MAX = "outlet1Max"
    OUTLET1_MIN = "outlet1Min"
    OUTLET2 = "outlet2"
    OUTLET2_AVG = "outlet2Avg"
    OUTLET2_MAX = "outlet2Max"
    OUTLET2_MIN = "outlet2Min"
    OUTPUT12V = "output12v"
    OUTPUT12V_AVG = "output12vAvg"
    OUTPUT12V_MAX = "output12vMax"
    OUTPUT12V_MIN = "output12vMin"
    OUTPUT3V3 = "output3v3"
    OUTPUT3V3_AVG = "output3v3Avg"
    OUTPUT3V3_MAX = "output3v3Max"
    OUTPUT3V3_MIN = "output3v3Min"
    OUTPUT_CURRENT = "outputCurrent"
    OUTPUT_CURRENT_AVG = "outputCurrentAvg"
    OUTPUT_CURRENT_MAX = "outputCurrentMax"
    OUTPUT_CURRENT_MIN = "outputCurrentMin"
    OUTPUT_MEGABYTES = "outputMegabytes"
    OUTPUT_MEGABYTES_DELTA = "outputMegabytesDelta"
    OUTPUT_MEGABYTES_DELTA_AVG = "outputMegabytesDeltaAvg"
    OUTPUT_MEGABYTES_DELTA_MAX = "outputMegabytesDeltaMax"
    OUTPUT_MEGABYTES_DELTA_MIN = "outputMegabytesDeltaMin"
    OUTPUT_POWER = "outputPower"
    OUTPUT_POWER_AVG = "outputPowerAvg"
    OUTPUT_POWER_MAX = "outputPowerMax"
    OUTPUT_POWER_MIN = "outputPowerMin"
    OUTPUT_POWER_STATE = "outputPowerState"
    OUTPUT_REQUESTS = "outputRequests"
    OUTPUT_REQUESTS_DELTA = "outputRequestsDelta"
    OUTPUT_REQUESTS_DELTA_AVG = "outputRequestsDeltaAvg"
    OUTPUT_REQUESTS_DELTA_MAX = "outputRequestsDeltaMax"
    OUTPUT_REQUESTS_DELTA_MIN = "outputRequestsDeltaMin"
    OUTPUT_STATUS = "outputStatus"
    OUTPUT_VOLTAGE = "outputVoltage"
    OUTPUT_VOLTAGE_AVG = "outputVoltageAvg"
    OUTPUT_VOLTAGE_MAX = "outputVoltageMax"
    OUTPUT_VOLTAGE_MIN = "outputVoltageMin"
    OVERALL_PROGRESS = "overallProgress"
    OVERLAP_STATE_FOR_A = "overlapStateForA"
    OVERLAP_STATE_FOR_B = "overlapStateForB"
    OVERLAPPING_VLANS = "overlappingVlans"
    OVERRIDE = "override"
    OVERRIDE_DEFAULT_EXCLUSION = "overrideDefaultExclusion"
    OVERSIZED_BAD_CRC_PACKETS = "oversizedBadCrcPackets"
    OVERSIZED_BAD_CRC_PACKETS_DELTA = "oversizedBadCrcPacketsDelta"
    OVERSIZED_BAD_CRC_PACKETS_DELTA_AVG = "oversizedBadCrcPacketsDeltaAvg"
    OVERSIZED_BAD_CRC_PACKETS_DELTA_MAX = "oversizedBadCrcPacketsDeltaMax"
    OVERSIZED_BAD_CRC_PACKETS_DELTA_MIN = "oversizedBadCrcPacketsDeltaMin"
    OVERSIZED_GOOD_CRC_PACKETS = "oversizedGoodCrcPackets"
    OVERSIZED_GOOD_CRC_PACKETS_DELTA = "oversizedGoodCrcPacketsDelta"
    OVERSIZED_GOOD_CRC_PACKETS_DELTA_AVG = "oversizedGoodCrcPacketsDeltaAvg"
    OVERSIZED_GOOD_CRC_PACKETS_DELTA_MAX = "oversizedGoodCrcPacketsDeltaMax"
    OVERSIZED_GOOD_CRC_PACKETS_DELTA_MIN = "oversizedGoodCrcPacketsDeltaMin"
    OVERSIZED_PACKETS = "oversizedPackets"
    OVERSIZED_PACKETS_DELTA = "oversizedPacketsDelta"
    OVERSIZED_PACKETS_DELTA_AVG = "oversizedPacketsDeltaAvg"
    OVERSIZED_PACKETS_DELTA_MAX = "oversizedPacketsDeltaMax"
    OVERSIZED_PACKETS_DELTA_MIN = "oversizedPacketsDeltaMin"
    OVERWRITE = "overwrite"
    OWN = "own"
    OWNER = "owner"
    OWNER_POLICY = "ownerPolicy"
    OWNERSHIP = "ownership"
    PACKAGE_VERSION = "packageVersion"
    PACKETS_RX = "packetsRx"
    PACKETS_RX_DELTA = "packetsRxDelta"
    PACKETS_RX_DELTA_AVG = "packetsRxDeltaAvg"
    PACKETS_RX_DELTA_MAX = "packetsRxDeltaMax"
    PACKETS_RX_DELTA_MIN = "packetsRxDeltaMin"
    PACKETS_TX = "packetsTx"
    PACKETS_TX_DELTA = "packetsTxDelta"
    PACKETS_TX_DELTA_AVG = "packetsTxDeltaAvg"
    PACKETS_TX_DELTA_MAX = "packetsTxDeltaMax"
    PACKETS_TX_DELTA_MIN = "packetsTxDeltaMin"
    PAK = "pak"
    PARAM_NAME = "paramName"
    PARENT_ADAPTOR_SLOT_NUM = "parentAdaptorSlotNum"
    PARENT_ADMIN_STATE = "parentAdminState"
    PARENT_CONTEXT = "parentContext"
    PARENT_ID = "parentId"
    PARENT_NAME = "parentName"
    PART_NUMBER = "partNumber"
    PARTITION_COUNT = "partitionCount"
    PARTITION_END = "partitionEnd"
    PARTITION_START = "partitionStart"
    PASS_THRU = "passThru"
    PASSWDEXPIRATION = "passwdexpiration"
    PASSWDEXPIRYSTATUS = "passwdexpirystatus"
    PASSWORD = "password"
    PASSWORD_STATE = "passwordState"
    PASSWORDLESS_SSH = "passwordlessSsh"
    PATH = "path"
    PATH_NAME = "pathName"
    PATTERN = "pattern"
    PAUSE_PACKETS = "pausePackets"
    PAUSE_PACKETS_DELTA = "pausePacketsDelta"
    PAUSE_PACKETS_DELTA_AVG = "pausePacketsDeltaAvg"
    PAUSE_PACKETS_DELTA_MAX = "pausePacketsDeltaMax"
    PAUSE_PACKETS_DELTA_MIN = "pausePacketsDeltaMin"
    PC_GLOBAL_ID = "pcGlobalId"
    PC_ID = "pcId"
    PC_LOCAL_ID = "pcLocalId"
    PCI_ADDR = "pciAddr"
    PCI_ADDR_LIST = "pciAddrList"
    PCI_ENUM = "pciEnum"
    PCI_FUNC = "pciFunc"
    PCI_SLOT = "pciSlot"
    PCI_SLOT_RAW_NAME = "pciSlotRawName"
    PCI_SLOTS = "pciSlots"
    PEER_AGGR_PORT_ID = "peerAggrPortId"
    PEER_CHASSIS_ID = "peerChassisId"
    PEER_COMM_STATUS = "peerCommStatus"
    PEER_DN = "peerDn"
    PEER_ENCAP = "peerEncap"
    PEER_ID = "peerId"
    PEER_MAC = "peerMac"
    PEER_PORT_ID = "peerPortId"
    PEER_PRESENCE = "peerPresence"
    PEER_REDUNDANCY_TEMPL_NAME = "peerRedundancyTemplName"
    PEER_REQ_CONFLICT = "peerReqConflict"
    PEER_SLOT_EP_DN = "peerSlotEpDn"
    PEER_SLOT_ID = "peerSlotId"
    PEER_STATE = "peerState"
    PEER_STATUS = "peerStatus"
    PER_DISK_CAP = "perDiskCap"
    PER_PRIORITY_PAUSE_PACKETS = "perPriorityPausePackets"
    PER_PRIORITY_PAUSE_PACKETS_DELTA = "perPriorityPausePacketsDelta"
    PER_PRIORITY_PAUSE_PACKETS_DELTA_AVG = "perPriorityPausePacketsDeltaAvg"
    PER_PRIORITY_PAUSE_PACKETS_DELTA_MAX = "perPriorityPausePacketsDeltaMax"
    PER_PRIORITY_PAUSE_PACKETS_DELTA_MIN = "perPriorityPausePacketsDeltaMin"
    PERCENTAGE_LIFE_LEFT = "percentageLifeLeft"
    PERCENTAGE_LIFE_LEFT_AVG = "percentageLifeLeftAvg"
    PERCENTAGE_LIFE_LEFT_MAX = "percentageLifeLeftMax"
    PERCENTAGE_LIFE_LEFT_MIN = "percentageLifeLeftMin"
    PERF = "perf"
    PERFORMANCE_LEVEL = "performanceLevel"
    PERM_ACCESS = "permAccess"
    PERS_BIND = "persBind"
    PERS_BIND_CLEAR = "persBindClear"
    PERSIST = "persist"
    PERSIST_TIME = "persistTime"
    PERSISTED_EPFB = "persistedEPFB"
    PERSISTENT_MEMORY_CAPACITY = "persistentMemoryCapacity"
    PERSISTENT_MEMORY_POLICY_NAME = "persistentMemoryPolicyName"
    PERSISTENT_MEMORY_SCRUB = "persistentMemoryScrub"
    PERSISTENT_MEMORY_TYPE = "persistentMemoryType"
    PF_DN = "pfDn"
    PG_NAME = "pgName"
    PH_SWITCH_ID = "phSwitchId"
    PHONE = "phone"
    PHS_ACCESS_AGGR_PORT_ID = "phsAccessAggrPortId"
    PHS_ACCESS_CARD_ID = "phsAccessCardId"
    PHS_ACCESS_PORT_ID = "phsAccessPortId"
    PHS_BORDER_AGGR_PORT_ID = "phsBorderAggrPortId"
    PHS_BORDER_CARD_ID = "phsBorderCardId"
    PHS_BORDER_PORT_ID = "phsBorderPortId"
    PHY_ID = "phyId"
    PHY_PORT_BITMASK = "phyPortBitmask"
    PHYS_EP_DN = "physEpDn"
    PHYSICAL_BLOCK_SIZE = "physicalBlockSize"
    PHYSICAL_DRIVE_COUNT = "physicalDriveCount"
    PHYSICAL_SECURITY = "physicalSecurity"
    PID = "pid"
    PIF_ID = "pifId"
    PIN_GROUP_NAME = "pinGroupName"
    PIN_TO_GROUP_NAME = "pinToGroupName"
    PINNED_CACHE_STATUS = "pinnedCacheStatus"
    PINNING_EXPIRATION_INTERVAL = "pinningExpirationInterval"
    PKTS_PER_SLAVE = "pktsPerSlave"
    PKTS_EG = "pkts_eg"
    PKTS_IN = "pkts_in"
    PLACEMENT = "placement"
    PLATFORM = "platform"
    PLATFORM_TYPE = "platformType"
    PLD_VERSION = "pldVersion"
    PN_DN = "pnDn"
    PN_POOL_DN = "pnPoolDn"
    PNUOS_SUPPORTED = "pnuosSupported"
    POISONED_TLPERRORS = "poisonedTLPErrors"
    POISONED_TLPERRORS15_MIN = "poisonedTLPErrors15Min"
    POISONED_TLPERRORS15_MIN_H = "poisonedTLPErrors15MinH"
    POISONED_TLPERRORS1_DAY = "poisonedTLPErrors1Day"
    POISONED_TLPERRORS1_DAY_H = "poisonedTLPErrors1DayH"
    POISONED_TLPERRORS1_HOUR = "poisonedTLPErrors1Hour"
    POISONED_TLPERRORS1_HOUR_H = "poisonedTLPErrors1HourH"
    POISONED_TLPERRORS1_WEEK = "poisonedTLPErrors1Week"
    POISONED_TLPERRORS1_WEEK_H = "poisonedTLPErrors1WeekH"
    POISONED_TLPERRORS2_WEEKS = "poisonedTLPErrors2Weeks"
    POISONED_TLPERRORS2_WEEKS_H = "poisonedTLPErrors2WeeksH"
    POL_DN = "polDn"
    POL_NAME = "polName"
    POLICY_DN = "policyDn"
    POLICY_LEVEL = "policyLevel"
    POLICY_NAME = "policyName"
    POLICY_OPERATION = "policyOperation"
    POLICY_OWNER = "policyOwner"
    POLICY_TYPE = "policyType"
    POLL_INTERVAL = "pollInterval"
    POLL_INTERVAL_SECONDS = "pollIntervalSeconds"
    POOL_DN = "poolDn"
    POOL_NAME = "poolName"
    POOL_ORG_DN = "poolOrgDn"
    POOLABLE_DN = "poolableDn"
    POOLED_ID = "pooledId"
    POOLED_RESOURCES = "pooledResources"
    POP_ERRORS = "popErrors"
    POP_ERRORS_DELTA = "popErrorsDelta"
    POP_ERRORS_DELTA_AVG = "popErrorsDeltaAvg"
    POP_ERRORS_DELTA_MAX = "popErrorsDeltaMax"
    POP_ERRORS_DELTA_MIN = "popErrorsDeltaMin"
    POPULATED = "populated"
    PORT = "port"
    PORT_ATTRIBUTE = "portAttribute"
    PORT_BANDWIDTH = "portBandwidth"
    PORT_CAPABILITY = "portCapability"
    PORT_CAPACITY = "portCapacity"
    PORT_DOWN_IO_RETRY_COUNT = "portDownIoRetryCount"
    PORT_DOWN_TIMEOUT = "portDownTimeout"
    PORT_FAMILY = "portFamily"
    PORT_GROUP_ROLE = "portGroupRole"
    PORT_ID = "portId"
    PORT_MAC = "portMac"
    PORT_MODE = "portMode"
    PORT_MODE_BEACON = "portModeBeacon"
    PORT_NUMBER = "portNumber"
    PORT_PROFILE_UUID = "portProfileUuid"
    PORT_SPEED_GB = "portSpeedGb"
    PORT_VALUE = "portValue"
    PORT_VSAN = "portVsan"
    PORT_VSAN_ID = "portVsanId"
    POST_ACTION = "postAction"
    POWER = "power"
    POWER_AVAIL_STATE = "powerAvailState"
    POWER_AVG = "powerAvg"
    POWER_CAP_SUPPORT_ENABLED = "powerCapSupportEnabled"
    POWER_CYCLE_COUNT = "powerCycleCount"
    POWER_CYCLE_COUNT_AVG = "powerCycleCountAvg"
    POWER_CYCLE_COUNT_MAX = "powerCycleCountMax"
    POWER_CYCLE_COUNT_MIN = "powerCycleCountMin"
    POWER_DEPLOY_STATE = "powerDeployState"
    POWER_FAN_SPEED_POLICY_SUPPORTED = "powerFanSpeedPolicySupported"
    POWER_MAX = "powerMax"
    POWER_MIN = "powerMin"
    POWER_ON_DEPLOY = "powerOnDeploy"
    POWER_ON_HOURS = "powerOnHours"
    POWER_ON_HOURS_AVG = "powerOnHoursAvg"
    POWER_ON_HOURS_MAX = "powerOnHoursMax"
    POWER_ON_HOURS_MIN = "powerOnHoursMin"
    POWER_POLICY_NAME = "powerPolicyName"
    POWER_STATE = "powerState"
    POWER_STATE_QUALIFIER = "powerStateQualifier"
    POWER_SYNC_POLICY_NAME = "powerSyncPolicyName"
    POWER_USAGE = "powerUsage"
    PPP_PACKETS = "pppPackets"
    PPP_PACKETS_DELTA = "pppPacketsDelta"
    PPP_PACKETS_DELTA_AVG = "pppPacketsDeltaAvg"
    PPP_PACKETS_DELTA_MAX = "pppPacketsDeltaMax"
    PPP_PACKETS_DELTA_MIN = "pppPacketsDeltaMin"
    PRE_DISCOVERY_POWER = "preDiscoveryPower"
    PREBOOT = "preboot"
    PREF = "pref"
    PREFIX = "prefix"
    PRESENCE = "presence"
    PRESENCE_PATH = "presencePath"
    PRESERVE_CONFIG = "preserveConfig"
    PRESERVE_POOLED_VALUES = "preservePooledValues"
    PREV_ASSIGNED_TO_DN = "prevAssignedToDn"
    PREV_CMD = "prevCmd"
    PREV_EVT = "prevEvt"
    PREV_OPER_STATE = "prevOperState"
    PREV_SEVERITY = "prevSeverity"
    PREV_VERSION = "prevVersion"
    PRI_CONN_STATUS = "priConnStatus"
    PRIM_DNS = "primDns"
    PRIMARY_SERVER = "primaryServer"
    PRIMARY_SLOT_NUMBER = "primarySlotNumber"
    PRIMARY_VLAN_COUNT = "primaryVlanCount"
    PRIMARY_VLAN_COUNT_STATUS = "primaryVlanCountStatus"
    PRIMARY_VLAN_ID = "primaryVlanId"
    PRIO = "prio"
    PRIO_SHARE = "prioShare"
    PRIORITY = "priority"
    PRIORITY_FLOW_CTRL = "priorityFlowCtrl"
    PRIV = "priv"
    PRIV_PWD_SET = "privPwdSet"
    PRIVPWD = "privpwd"
    PROBLEMS = "problems"
    PROC_BREAK = "procBreak"
    PROC_CAP = "procCap"
    PROC_TEMP = "procTemp"
    PROC_TEMP_AVG = "procTempAvg"
    PROC_TEMP_MAX = "procTempMax"
    PROC_TEMP_MIN = "procTempMin"
    PROCESSOR_THERMAL_STATE = "processorThermalState"
    PRODUCT_ASSET_TAG = "productAssetTag"
    PRODUCT_FRU = "productFru"
    PRODUCT_ID = "productId"
    PRODUCT_MANUFACTURER = "productManufacturer"
    PRODUCT_NAME = "productName"
    PRODUCT_PART_NO = "productPartNo"
    PRODUCT_REVISION = "productRevision"
    PRODUCT_SERIAL_NO = "productSerialNo"
    PRODUCT_VERSION_NO = "productVersionNo"
    PROF_DN = "profDn"
    PROF_METHOD = "profMethod"
    PROFILE_DN = "profileDn"
    PROFILE_ID = "profileId"
    PROFILE_METHOD = "profileMethod"
    PROFILE_NAME = "profileName"
    PROFILE_RUN_TIME = "profileRunTime"
    PROFILE_TYPE = "profileType"
    PROFILED_BOOT = "profiledBoot"
    PROFILED_MAX = "profiledMax"
    PROFILED_MIN = "profiledMin"
    PROFILING = "profiling"
    PROGRESS = "progress"
    PROM_CARD_TYPE = "promCardType"
    PROP_ACL = "propAcl"
    PROP_ID = "propId"
    PROP_TYPE = "propType"
    PROPERTY_NAME = "propertyName"
    PROT = "prot"
    PROT_PEER_ID = "protPeerId"
    PROT_ROLE = "protRole"
    PROT_STATE = "protState"
    PROTECT_CONFIG = "protectConfig"
    PROTECTION = "protection"
    PROTO = "proto"
    PROTOCOL = "protocol"
    PROV_INT_ID = "provIntId"
    PROV_SRV_POLICY_NAME = "provSrvPolicyName"
    PROVIDER = "provider"
    PROVIDER_GROUP = "providerGroup"
    PROVIDER_LOAD_FAILURES = "providerLoadFailures"
    PROVIDERS_LOADED = "providersLoaded"
    PSU_CAPACITY = "psuCapacity"
    PSU_CTRLR_INLET1 = "psuCtrlrInlet1"
    PSU_CTRLR_INLET1_AVG = "psuCtrlrInlet1Avg"
    PSU_CTRLR_INLET1_MAX = "psuCtrlrInlet1Max"
    PSU_CTRLR_INLET1_MIN = "psuCtrlrInlet1Min"
    PSU_CTRLR_INLET2 = "psuCtrlrInlet2"
    PSU_CTRLR_INLET2_AVG = "psuCtrlrInlet2Avg"
    PSU_CTRLR_INLET2_MAX = "psuCtrlrInlet2Max"
    PSU_CTRLR_INLET2_MIN = "psuCtrlrInlet2Min"
    PSU_FIRMWARE_VERSION = "psuFirmwareVersion"
    PSU_INPUT_SRC = "psuInputSrc"
    PSU_LINE_MODE = "psuLineMode"
    PSU_STATE = "psuState"
    PSU_TEMP1 = "psuTemp1"
    PSU_TEMP2 = "psuTemp2"
    PSU_TYPE = "psuType"
    PSU_WATTAGE = "psuWattage"
    PUB_NW_DN = "pubNwDn"
    PUB_NW_ID = "pubNwId"
    PUB_NW_NAME = "pubNwName"
    PURGE_WINDOW = "purgeWindow"
    PURPOSE = "purpose"
    PUSH_ERRORS = "pushErrors"
    PUSH_ERRORS_DELTA = "pushErrorsDelta"
    PUSH_ERRORS_DELTA_AVG = "pushErrorsDeltaAvg"
    PUSH_ERRORS_DELTA_MAX = "pushErrorsDeltaMax"
    PUSH_ERRORS_DELTA_MIN = "pushErrorsDeltaMin"
    PV_SCORE = "pvScore"
    PWD = "pwd"
    PWD_CHANGE_COUNT = "pwdChangeCount"
    PWD_CHANGE_INTERVAL_BEGIN = "pwdChangeIntervalBegin"
    PWD_CHANGED_DATE = "pwdChangedDate"
    PWD_HISTORY = "pwdHistory"
    PWD_SET = "pwdSet"
    PWD_STRENGTH_CHECK = "pwdStrengthCheck"
    PWR_CHANGE_SRC = "pwrChangeSrc"
    QOS_CONTROL = "qosControl"
    QOS_POLICY_DN = "qosPolicyDn"
    QOS_POLICY_ID = "qosPolicyId"
    QOS_POLICY_NAME = "qosPolicyName"
    QUALIFIER = "qualifier"
    QUANT = "quant"
    QUERIER_IP_ADDR = "querierIpAddr"
    QUERIER_IP_ADDR_PEER = "querierIpAddrPeer"
    QUERIER_IP_ADDRS = "querierIpAddrs"
    QUERIER_STATE = "querierState"
    QUEUE_PAIRS = "queuePairs"
    RACK_BUNDLE_NAME = "rackBundleName"
    RACK_BUNDLE_VERSION = "rackBundleVersion"
    RACK_ID = "rackId"
    RACK_SERVER_ADAPTER_ID = "rackServerAdapterId"
    RACK_SERVER_ID = "rackServerId"
    RAID_BATTERY_OPS = "raidBatteryOps"
    RAID_HEALTH = "raidHealth"
    RAID_LEVEL = "raidLevel"
    RAID_MODE = "raidMode"
    RAID_STATE = "raidState"
    RAID_SUPPORT = "raidSupport"
    RAID_SYNC_SUPPORT = "raidSyncSupport"
    RAND_RANGE_END = "randRangeEnd"
    RAND_RANGE_START = "randRangeStart"
    RATE = "rate"
    RAW_SIZE = "rawSize"
    RAW_TYPE_DESC = "rawTypeDesc"
    RCV = "rcv"
    RCV_DELTA = "rcvDelta"
    RCV_DELTA_AVG = "rcvDeltaAvg"
    RCV_DELTA_MAX = "rcvDeltaMax"
    RCV_DELTA_MIN = "rcvDeltaMin"
    RDEV = "rdev"
    RE_INSERT = "reInsert"
    REACHABILITY = "reachability"
    READ_ERROR_THRESHOLD = "readErrorThreshold"
    READ_IOERROR_COUNT = "readIOErrorCount"
    READ_POLICY = "readPolicy"
    REALLOC = "realloc"
    REALM = "realm"
    REAR_DISK_SLOTS = "rearDiskSlots"
    REAR_TEMP = "rearTemp"
    REAR_TEMP_AVG = "rearTempAvg"
    REAR_TEMP_MAX = "rearTempMax"
    REAR_TEMP_MIN = "rearTempMin"
    REBALANCE = "rebalance"
    REBOOT_ACTION_ON_DESTRUCTIVE = "rebootActionOnDestructive"
    REBOOT_ON_UPDATE = "rebootOnUpdate"
    REBOOT_POLICY = "rebootPolicy"
    REBOOT_REQUIRED = "rebootRequired"
    REBUILD_RATE = "rebuildRate"
    RECEIVE_SIDE_SCALING = "receiveSideScaling"
    RECORD_TYPE = "recordType"
    RECOVERABLE = "recoverable"
    RECOVERY_ACTION = "recoveryAction"
    RECURSIVE = "recursive"
    RECV_FLOW_CTRL = "recvFlowCtrl"
    RECV_PAUSE = "recvPause"
    RECV_PAUSE_DELTA = "recvPauseDelta"
    RECV_PAUSE_DELTA_AVG = "recvPauseDeltaAvg"
    RECV_PAUSE_DELTA_MAX = "recvPauseDeltaMax"
    RECV_PAUSE_DELTA_MIN = "recvPauseDeltaMin"
    REDIRECT_STATE = "redirectState"
    REDUNDANCY = "redundancy"
    REDUNDANCY_PAIR_TYPE = "redundancyPairType"
    REDUNDANCY_PEER = "redundancyPeer"
    REF_CONVERTED_DN = "refConvertedDn"
    REF_DN = "refDn"
    REF_LUN_SET = "refLunSet"
    REF_NAME = "refName"
    REF_OBJ_STATUS = "refObjStatus"
    REF_OPER_STATE = "refOperState"
    REF_POLICY_DN = "refPolicyDn"
    REFERENCED_RN = "referencedRn"
    REFRESH_PERIOD = "refreshPeriod"
    REGEN = "regen"
    REGISTRATION_STATE = "registrationState"
    RELATIONSHIP = "relationship"
    REMAP_ON_EJECT = "remapOnEject"
    REMOTE = "remote"
    REMOTE_DIR = "remoteDir"
    REMOTE_EP_REF = "remoteEpRef"
    REMOTE_FILE = "remoteFile"
    REMOTE_HOST = "remoteHost"
    REMOTE_IF_DESC = "remoteIfDesc"
    REMOTE_INTERFACE = "remoteInterface"
    REMOTE_IP_ADDR = "remoteIpAddr"
    REMOTE_IP_ADDRESS = "remoteIpAddress"
    REMOTE_PATH = "remotePath"
    REMOTE_PORT = "remotePort"
    REMOVABLE = "removable"
    REMOVAL_CONDITIONS = "removalConditions"
    REPAIR_STATE = "repairState"
    REPLICATE_IF_NO_CHILD = "replicateIfNoChild"
    REPLY_TO = "replyTo"
    REPORTING_INTERVAL = "reportingInterval"
    REQ = "req"
    REQ_DN = "reqDn"
    REQ_ID = "reqId"
    REQUEST_SIZE = "requestSize"
    REQUEST_TIMEOUT = "requestTimeout"
    REQUESTOR_OWNERSHIP = "requestorOwnership"
    RES_PROB = "resProb"
    RESELECT_POLICY = "reselectPolicy"
    RESERVED = "reserved"
    RESERVED_CAPACITY = "reservedCapacity"
    RESERVED_POWER = "reservedPower"
    RESERVED_POWER_AVG = "reservedPowerAvg"
    RESERVED_POWER_MAX = "reservedPowerMax"
    RESERVED_POWER_MIN = "reservedPowerMin"
    RESET = "reset"
    RESET_CORRUPT_COUNT = "resetCorruptCount"
    RESET_ON = "resetOn"
    RESET_ON_ACTIVATE = "resetOnActivate"
    RESET_TRIGGER = "resetTrigger"
    RESETS = "resets"
    RESETS_DELTA = "resetsDelta"
    RESETS_DELTA_AVG = "resetsDeltaAvg"
    RESETS_DELTA_MAX = "resetsDeltaMax"
    RESETS_DELTA_MIN = "resetsDeltaMin"
    RESOLVE_REMOTE = "resolveRemote"
    RESOLVE_TYPE = "resolveType"
    RESOLVED_CLASS_TYPE = "resolvedClassType"
    RESOURCE_ALLOCATION_TIMEOUT = "resourceAllocationTimeout"
    RESOURCE_GROUPS = "resourceGroups"
    RESTRICT_MIGRATION = "restrictMigration"
    RESULT = "result"
    RET_STATUS = "retStatus"
    RETENTION_INTERVAL = "retentionInterval"
    RETIMER_HIF_PORT_LIST = "retimerHifPortList"
    RETRIED = "retried"
    RETRIES = "retries"
    RETRY = "retry"
    RETRY_COUNT = "retryCount"
    RETRY_DELAY_MINUTES = "retryDelayMinutes"
    RETRY_INTERVAL = "retryInterval"
    RETRY_ON_MOUNT_FAIL = "retryOnMountFail"
    REVERT_TIMEOUT = "revertTimeout"
    REVISION = "revision"
    REVISION_MODIFIER = "revisionModifier"
    RIGHT_DATA = "rightData"
    RIGHT_INLET_TEMP = "rightInletTemp"
    RIGHT_INLET_TEMP_AVG = "rightInletTempAvg"
    RIGHT_INLET_TEMP_MAX = "rightInletTempMax"
    RIGHT_INLET_TEMP_MIN = "rightInletTempMin"
    RIGHT_OUTLET_TEMP = "rightOutletTemp"
    RIGHT_OUTLET_TEMP_AVG = "rightOutletTempAvg"
    RIGHT_OUTLET_TEMP_MAX = "rightOutletTempMax"
    RIGHT_OUTLET_TEMP_MIN = "rightOutletTempMin"
    RIN = "rin"
    RING_SIZE = "ringSize"
    RMT_DISK_CFG_NAME = "rmtDiskCfgName"
    RMT_ERR_CODE = "rmtErrCode"
    RMT_ERR_DESCR = "rmtErrDescr"
    RMT_RSLT = "rmtRslt"
    RN = "rn"
    ROLE = "role"
    ROOTDN = "rootdn"
    ROTATIONAL_SPEED = "rotationalSpeed"
    ROUTE_IP = "routeIP"
    RSLT_STATUS = "rsltStatus"
    RULE = "rule"
    RUN_POLICY_NAME = "runPolicyName"
    RX = "rx"
    RX_BAD_FRAMES = "rxBadFrames"
    RX_BAD_FRAMES_DELTA = "rxBadFramesDelta"
    RX_BAD_FRAMES_DELTA_AVG = "rxBadFramesDeltaAvg"
    RX_BAD_FRAMES_DELTA_MAX = "rxBadFramesDeltaMax"
    RX_BAD_FRAMES_DELTA_MIN = "rxBadFramesDeltaMin"
    RX_BYTES = "rxBytes"
    RX_BYTES_DELTA = "rxBytesDelta"
    RX_BYTES_DELTA_AVG = "rxBytesDeltaAvg"
    RX_BYTES_DELTA_MAX = "rxBytesDeltaMax"
    RX_BYTES_DELTA_MIN = "rxBytesDeltaMin"
    RX_DELTA = "rxDelta"
    RX_DELTA_AVG = "rxDeltaAvg"
    RX_DELTA_MAX = "rxDeltaMax"
    RX_DELTA_MIN = "rxDeltaMin"
    RX_DROPPED = "rxDropped"
    RX_DROPPED_DELTA = "rxDroppedDelta"
    RX_DROPPED_DELTA_AVG = "rxDroppedDeltaAvg"
    RX_DROPPED_DELTA_MAX = "rxDroppedDeltaMax"
    RX_DROPPED_DELTA_MIN = "rxDroppedDeltaMin"
    RX_ERRORS = "rxErrors"
    RX_ERRORS_DELTA = "rxErrorsDelta"
    RX_ERRORS_DELTA_AVG = "rxErrorsDeltaAvg"
    RX_ERRORS_DELTA_MAX = "rxErrorsDeltaMax"
    RX_ERRORS_DELTA_MIN = "rxErrorsDeltaMin"
    RX_FRAMES = "rxFrames"
    RX_FRAMES_DELTA = "rxFramesDelta"
    RX_FRAMES_DELTA_AVG = "rxFramesDeltaAvg"
    RX_FRAMES_DELTA_MAX = "rxFramesDeltaMax"
    RX_FRAMES_DELTA_MIN = "rxFramesDeltaMin"
    RX_PACKETS = "rxPackets"
    RX_PACKETS_DELTA = "rxPacketsDelta"
    RX_PACKETS_DELTA_AVG = "rxPacketsDeltaAvg"
    RX_PACKETS_DELTA_MAX = "rxPacketsDeltaMax"
    RX_PACKETS_DELTA_MIN = "rxPacketsDeltaMin"
    RX_PAUSE_CFC = "rxPauseCFC"
    RX_PAUSE_CFCDELTA = "rxPauseCFCDelta"
    RX_PAUSE_CFCDELTA_AVG = "rxPauseCFCDeltaAvg"
    RX_PAUSE_CFCDELTA_MAX = "rxPauseCFCDeltaMax"
    RX_PAUSE_CFCDELTA_MIN = "rxPauseCFCDeltaMin"
    RX_PAUSE_PFC = "rxPausePFC"
    RX_PAUSE_PFCDELTA = "rxPausePFCDelta"
    RX_PAUSE_PFCDELTA_AVG = "rxPausePFCDeltaAvg"
    RX_PAUSE_PFCDELTA_MAX = "rxPausePFCDeltaMax"
    RX_PAUSE_PFCDELTA_MIN = "rxPausePFCDeltaMin"
    SACL = "sacl"
    SAN_CONN_POLICY_NAME = "sanConnPolicyName"
    SAS_ADDRESS = "sasAddress"
    SAS_EXPANDER_CONFIG_POLICY_NAME = "sasExpanderConfigPolicyName"
    SCALED_MODE = "scaledMode"
    SCALED_WT = "scaledWt"
    SCAN_ORDER = "scanOrder"
    SCHED_NAME = "schedName"
    SCHEDULE = "schedule"
    SCHEDULER = "scheduler"
    SCOPE = "scope"
    SCOPE_STATUS = "scopeStatus"
    SCRUB_POLICY_NAME = "scrubPolicyName"
    SCSI_DISK_STATE = "scsiDiskState"
    SDR_TYPE = "sdr_type"
    SEC_CONN_STATUS = "secConnStatus"
    SEC_DNS = "secDns"
    SEC_VLAN_PER_PRIMARY_VLAN_COUNT = "secVlanPerPrimaryVlanCount"
    SEC_VLAN_PER_PRIMARY_VLAN_COUNT_STATUS = "secVlanPerPrimaryVlanCountStatus"
    SECONDARY_KEY = "secondaryKey"
    SECONDARY_SERVER = "secondaryServer"
    SECONDARY_VLAN_COUNT = "secondaryVlanCount"
    SECONDARY_VLAN_COUNT_STATUS = "secondaryVlanCountStatus"
    SECONDS_SINCE_LAST_RESET = "secondsSinceLastReset"
    SECONDS_SINCE_LAST_RESET_DELTA = "secondsSinceLastResetDelta"
    SECONDS_SINCE_LAST_RESET_DELTA_AVG = "secondsSinceLastResetDeltaAvg"
    SECONDS_SINCE_LAST_RESET_DELTA_MAX = "secondsSinceLastResetDeltaMax"
    SECONDS_SINCE_LAST_RESET_DELTA_MIN = "secondsSinceLastResetDeltaMin"
    SECRET = "secret"
    SECURE_BIOS = "secureBios"
    SECURE_BOOT = "secureBoot"
    SECURE_PASSPHRASE = "securePassphrase"
    SECURITY = "security"
    SECURITY_FLAGS = "securityFlags"
    SECURITY_KEY = "securityKey"
    SECURITY_STATE = "securityState"
    SECURITY_STATUS = "securityStatus"
    SEEK_AVERAGE_READ_WRITE = "seekAverageReadWrite"
    SEEK_TRACK_TO_TRACK_READ_WRITE = "seekTrackToTrackReadWrite"
    SEEPROM_OPER_STATE = "seepromOperState"
    SELECT = "select"
    SELECTED = "selected"
    SELECTOR = "selector"
    SELF_ENCRYPTING_DRIVE = "selfEncryptingDrive"
    SELF_REQ_CONFLICT = "selfReqConflict"
    SEND_FLOW_CTRL = "sendFlowCtrl"
    SEND_NOW = "sendNow"
    SENSITIVITY = "sensitivity"
    SENSOR_ID = "sensorId"
    SENSOR_NAME = "sensorName"
    SENSOR_TYPE = "sensorType"
    SENSOR_TYPE = "sensor_type"
    SEQ_ID = "seqId"
    SEQ_NUM = "seqNum"
    SEQ_PROTOCOL_ERR_COUNT = "seqProtocolErrCount"
    SEQ_PROTOCOL_ERR_COUNT_DELTA = "seqProtocolErrCountDelta"
    SEQ_PROTOCOL_ERR_COUNT_DELTA_AVG = "seqProtocolErrCountDeltaAvg"
    SEQ_PROTOCOL_ERR_COUNT_DELTA_MAX = "seqProtocolErrCountDeltaMax"
    SEQ_PROTOCOL_ERR_COUNT_DELTA_MIN = "seqProtocolErrCountDeltaMin"
    SERENO_NETFLOW_SUPPORTED = "serenoNetflowSupported"
    SERIAL = "serial"
    SERIAL_NUMBER = "serialNumber"
    SERIES = "series"
    SERVER = "server"
    SERVER_CERT = "serverCert"
    SERVER_COMP_IN_ACTIVATION_DN = "serverCompInActivationDn"
    SERVER_COMPONENT = "serverComponent"
    SERVER_CONFIG_ISSUES = "serverConfigIssues"
    SERVER_DN = "serverDn"
    SERVER_EXTD_CONFIG_ISSUES = "serverExtdConfigIssues"
    SERVER_ID = "serverId"
    SERVER_ID_LIST = "serverIdList"
    SERVER_INSTANCE_ID = "serverInstanceId"
    SERVER_MODEL = "serverModel"
    SERVER_SIOC_CONNECTIVITY = "serverSiocConnectivity"
    SERVERS_POWER_STATE = "serversPowerState"
    SERVICE = "service"
    SERVICE_PACK_BUNDLE_NAME = "servicePackBundleName"
    SERVICE_PACK_BUNDLE_VERSION = "servicePackBundleVersion"
    SERVICE_PACK_OPER_STATE = "servicePackOperState"
    SERVICE_PACK_STATE = "servicePackState"
    SERVICE_PACK_VERSION = "servicePackVersion"
    SERVICE_PHILOSOPHY = "servicePhilosophy"
    SERVICE_PROFILE_DN = "serviceProfileDn"
    SERVICE_STATE = "serviceState"
    SESSION = "session"
    SESSION_ID = "sessionId"
    SESSION_TIMEOUT = "sessionTimeout"
    SESSIONS_PER_USER = "sessionsPerUser"
    SET = "set"
    SETTINGS_MO_RN = "settingsMoRn"
    SEVERITY = "severity"
    SHARE = "share"
    SHARING = "sharing"
    SHUTDOWN_FAN_REMOVEAL = "shutdownFanRemoveal"
    SIDE = "side"
    SIG = "sig"
    SIGNAL_LOSSES = "signalLosses"
    SIGNAL_LOSSES_DELTA = "signalLossesDelta"
    SIGNAL_LOSSES_DELTA_AVG = "signalLossesDeltaAvg"
    SIGNAL_LOSSES_DELTA_MAX = "signalLossesDeltaMax"
    SIGNAL_LOSSES_DELTA_MIN = "signalLossesDeltaMin"
    SIGNATURE = "signature"
    SINGLE_COLLISION = "singleCollision"
    SINGLE_COLLISION_DELTA = "singleCollisionDelta"
    SINGLE_COLLISION_DELTA_AVG = "singleCollisionDeltaAvg"
    SINGLE_COLLISION_DELTA_MAX = "singleCollisionDeltaMax"
    SINGLE_COLLISION_DELTA_MIN = "singleCollisionDeltaMin"
    SINGLETON = "singleton"
    SIOC_ID = "siocId"
    SITE = "site"
    SIZE = "size"
    SIZE_LIMIT = "sizeLimit"
    SKIP_POWER_CHECK = "skipPowerCheck"
    SKIP_POWER_DEPLOY_CHECK = "skipPowerDeployCheck"
    SKIP_PROFILING = "skipProfiling"
    SKIP_VALIDATION = "skipValidation"
    SKU = "sku"
    SLAVE_SLOT_ID = "slaveSlotId"
    SLEEP_DELAY = "sleepDelay"
    SLEEP_INTERVAL = "sleepInterval"
    SLOT_ADMIN_STATE = "slotAdminState"
    SLOT_DN = "slotDn"
    SLOT_ID = "slotId"
    SLOT_NAME = "slotName"
    SLOT_NUM = "slotNum"
    SLOT_NUMBER = "slotNumber"
    SLOT_SPAN = "slotSpan"
    SLOT_SPAN_ORIENTATION = "slotSpanOrientation"
    SLOT_STATUS = "slotStatus"
    SLOTS_PER_LINE = "slotsPerLine"
    SLOW_DRAIN_ADMIN_STATE = "slowDrainAdminState"
    SLOW_DRAIN_CORRECTION = "slowDrainCorrection"
    SMBIOS_ID = "smbiosId"
    SMBIOSNAME = "smbiosname"
    SMI_LINK_CORR_ERRORS = "smiLinkCorrErrors"
    SMI_LINK_CORR_ERRORS15_MIN = "smiLinkCorrErrors15Min"
    SMI_LINK_CORR_ERRORS15_MIN_H = "smiLinkCorrErrors15MinH"
    SMI_LINK_CORR_ERRORS1_DAY = "smiLinkCorrErrors1Day"
    SMI_LINK_CORR_ERRORS1_DAY_H = "smiLinkCorrErrors1DayH"
    SMI_LINK_CORR_ERRORS1_HOUR = "smiLinkCorrErrors1Hour"
    SMI_LINK_CORR_ERRORS1_HOUR_H = "smiLinkCorrErrors1HourH"
    SMI_LINK_CORR_ERRORS1_WEEK = "smiLinkCorrErrors1Week"
    SMI_LINK_CORR_ERRORS1_WEEK_H = "smiLinkCorrErrors1WeekH"
    SMI_LINK_CORR_ERRORS2_WEEKS = "smiLinkCorrErrors2Weeks"
    SMI_LINK_CORR_ERRORS2_WEEKS_H = "smiLinkCorrErrors2WeeksH"
    SMI_LINK_UNCORR_ERRORS = "smiLinkUncorrErrors"
    SMI_LINK_UNCORR_ERRORS15_MIN = "smiLinkUncorrErrors15Min"
    SMI_LINK_UNCORR_ERRORS15_MIN_H = "smiLinkUncorrErrors15MinH"
    SMI_LINK_UNCORR_ERRORS1_DAY = "smiLinkUncorrErrors1Day"
    SMI_LINK_UNCORR_ERRORS1_DAY_H = "smiLinkUncorrErrors1DayH"
    SMI_LINK_UNCORR_ERRORS1_HOUR = "smiLinkUncorrErrors1Hour"
    SMI_LINK_UNCORR_ERRORS1_HOUR_H = "smiLinkUncorrErrors1HourH"
    SMI_LINK_UNCORR_ERRORS1_WEEK = "smiLinkUncorrErrors1Week"
    SMI_LINK_UNCORR_ERRORS1_WEEK_H = "smiLinkUncorrErrors1WeekH"
    SMI_LINK_UNCORR_ERRORS2_WEEKS = "smiLinkUncorrErrors2Weeks"
    SMI_LINK_UNCORR_ERRORS2_WEEKS_H = "smiLinkUncorrErrors2WeeksH"
    SND = "snd"
    SNMP_OPER_STATE = "snmpOperState"
    SNOOPING_ENABLED = "snoopingEnabled"
    SNOOPING_STATE = "snoopingState"
    SOAK_INTERVAL = "soakInterval"
    SOAKING_SEVERITY = "soakingSeverity"
    SOCKET_DESIGNATION = "socketDesignation"
    SOCKET_ID = "socketId"
    SOCKET_LOCAL_DIMM_NUMBER = "socketLocalDimmNumber"
    SOFT_SHUTDOWN_TIMER = "softShutdownTimer"
    SOL_POLICY_NAME = "solPolicyName"
    SORT_CLASS = "sortClass"
    SORT_PROP = "sortProp"
    SOURCE = "source"
    SOURCE_ADDR = "sourceAddr"
    SOURCE_CONNECTOR_ID = "sourceConnectorId"
    SOURCE_DME = "sourceDme"
    SOURCE_DN = "sourceDn"
    SOURCE_MO_DN = "sourceMoDn"
    SOURCE_TYPE = "sourceType"
    SOURCE_VLAN = "sourceVlan"
    SOURCE_VLAN_DN = "sourceVlanDn"
    SPAN_CTRL_PKTS = "spanCtrlPkts"
    SPAN_ID = "spanId"
    SPARING_ERRORS = "sparingErrors"
    SPARING_ERRORS15_MIN = "sparingErrors15Min"
    SPARING_ERRORS15_MIN_H = "sparingErrors15MinH"
    SPARING_ERRORS1_DAY = "sparingErrors1Day"
    SPARING_ERRORS1_DAY_H = "sparingErrors1DayH"
    SPARING_ERRORS1_HOUR = "sparingErrors1Hour"
    SPARING_ERRORS1_HOUR_H = "sparingErrors1HourH"
    SPARING_ERRORS1_WEEK = "sparingErrors1Week"
    SPARING_ERRORS1_WEEK_H = "sparingErrors1WeekH"
    SPARING_ERRORS2_WEEKS = "sparingErrors2Weeks"
    SPARING_ERRORS2_WEEKS_H = "sparingErrors2WeeksH"
    SPDM_CERTIFICATE_POLICY_NAME = "spdmCertificatePolicyName"
    SPDM_FAULT = "spdmFault"
    SPDM_FAULT_DESC = "spdmFaultDesc"
    SPEED = "speed"
    SPEED_AVG = "speedAvg"
    SPEED_INFO = "speedInfo"
    SPEED_MAX = "speedMax"
    SPEED_MIN = "speedMin"
    SPURIOUS_RETRIES = "spuriousRetries"
    SRC_FILT_DN = "srcFiltDn"
    SRC_TEMPL_NAME = "srcTemplName"
    SSH_AUTH_KEYS_CSUM = "sshAuthKeysCsum"
    SSH_AUTH_KEYS_SIZE = "sshAuthKeysSize"
    SSH_KEY_STATUS = "sshKeyStatus"
    SSH_ROOT_PUB_KEY_CSUM = "sshRootPubKeyCsum"
    SSH_ROOT_PUB_KEY_SIZE = "sshRootPubKeySize"
    STAGE_SIZE = "stageSize"
    STAGE_STATUS = "stageStatus"
    START_EVENT = "startEvent"
    START_ID = "startId"
    START_PORT_ID = "startPortId"
    START_PORT_NUMBER = "startPortNumber"
    START_SLOT_NUM = "startSlotNum"
    START_TIME = "startTime"
    START_TS = "startTs"
    START_TS_M = "startTsM"
    STARTS = "starts"
    STARTS_WITH = "startsWith"
    STATE = "state"
    STATE_QUAL = "stateQual"
    STATS_CLASS_ID = "statsClassId"
    STATS_POLICY_NAME = "statsPolicyName"
    STATS_PROP_ID = "statsPropId"
    STATS_UPDATE_ID = "statsUpdateId"
    STATUS = "status"
    STATUS_CHANGE_TS = "statusChangeTs"
    STATUS_DESCR = "statusDescr"
    STDBY_VIF_ID = "stdbyVifId"
    STEPPING = "stepping"
    STORAGE_BIOS_MODE = "storageBiosMode"
    STORAGE_CLASS = "storageClass"
    STORAGE_CONFIG_ISSUES = "storageConfigIssues"
    STORAGE_CONN_POLICY_NAME = "storageConnPolicyName"
    STORAGE_JBOD_MODE_SUPPORTED = "storageJbodModeSupported"
    STORAGE_METHOD = "storageMethod"
    STORAGE_OOB_CONFIG_SUPPORTED = "storageOobConfigSupported"
    STORAGE_OOB_INTERFACE_SUPPORTED = "storageOobInterfaceSupported"
    STORAGE_OPER_QUALIFIER = "storageOperQualifier"
    STORAGE_PROFILE_NAME = "storageProfileName"
    STORAGE_SCRUB = "storageScrub"
    STORAGE_SUBSYSTEM_STATE = "storageSubsystemState"
    STORAGEPID = "storagepid"
    STR_TYPE = "strType"
    STRIP_SIZE = "stripSize"
    STYLE = "style"
    SUB_DEVICE_ID = "subDeviceId"
    SUB_OEM_ID = "subOemId"
    SUB_TYPE = "subType"
    SUB_VENDOR_ID = "subVendorId"
    SUBDEVICE = "subdevice"
    SUBJ_NAME = "subjName"
    SUBJECT = "subject"
    SUBNET = "subnet"
    SUBORDINATE_USED_QUANT = "subordinateUsedQuant"
    SUBVENDOR = "subvendor"
    SUCCESS_ACTION = "successAction"
    SUCCESSFULL = "successfull"
    SUFFIX = "suffix"
    SUPORT_TYPE = "suportType"
    SUPPL_ID1 = "supplId1"
    SUPPL_ID2 = "supplId2"
    SUPPL_ID3 = "supplId3"
    SUPPL_ID4 = "supplId4"
    SUPPORT = "support"
    SUPPORTABILITY = "supportability"
    SUPPORTED_ALGORITHM = "supportedAlgorithm"
    SUPPORTED_BY_DEFAULT = "supportedByDefault"
    SUPPORTED_CAPABILITY = "supportedCapability"
    SUPPORTED_STRIP_SIZES = "supportedStripSizes"
    SUPPORTS_DHCP = "supportsDHCP"
    SUPPRESS_POLICY_NAME = "suppressPolicyName"
    SURPRISE_LINK_DOWN_ERRORS = "surpriseLinkDownErrors"
    SURPRISE_LINK_DOWN_ERRORS15_MIN = "surpriseLinkDownErrors15Min"
    SURPRISE_LINK_DOWN_ERRORS15_MIN_H = "surpriseLinkDownErrors15MinH"
    SURPRISE_LINK_DOWN_ERRORS1_DAY = "surpriseLinkDownErrors1Day"
    SURPRISE_LINK_DOWN_ERRORS1_DAY_H = "surpriseLinkDownErrors1DayH"
    SURPRISE_LINK_DOWN_ERRORS1_HOUR = "surpriseLinkDownErrors1Hour"
    SURPRISE_LINK_DOWN_ERRORS1_HOUR_H = "surpriseLinkDownErrors1HourH"
    SURPRISE_LINK_DOWN_ERRORS1_WEEK = "surpriseLinkDownErrors1Week"
    SURPRISE_LINK_DOWN_ERRORS1_WEEK_H = "surpriseLinkDownErrors1WeekH"
    SURPRISE_LINK_DOWN_ERRORS2_WEEKS = "surpriseLinkDownErrors2Weeks"
    SURPRISE_LINK_DOWN_ERRORS2_WEEKS_H = "surpriseLinkDownErrors2WeeksH"
    SUSPECT = "suspect"
    SUSPEND_INDIVIDUAL = "suspendIndividual"
    SUSPEND_STATE = "suspendState"
    SVC_REG_IP = "svcRegIP"
    SVC_REG_NAME = "svcRegName"
    SVNIC_CONFIG = "svnicConfig"
    SW_ABORDER_AGGR_PORT = "swABorderAggrPort"
    SW_ABORDER_PORT = "swABorderPort"
    SW_ABORDER_SLOT = "swABorderSlot"
    SW_BBORDER_AGGR_PORT = "swBBorderAggrPort"
    SW_BBORDER_PORT = "swBBorderPort"
    SW_BBORDER_SLOT = "swBBorderSlot"
    SW_BACKUP_VERSION = "swBackupVersion"
    SW_COMPLEX_CAPACITY = "swComplexCapacity"
    SW_COMPLEX_ID = "swComplexId"
    SW_INT_ID = "swIntId"
    SW_NAME = "swName"
    SW_RAID_SETTING = "swRaidSetting"
    SW_STARTUP_VERSION = "swStartupVersion"
    SW_UUID = "swUuid"
    SW_VERSION = "swVersion"
    SWITCH_ID = "switchId"
    SWITCH_NAME = "switchName"
    SWITCH_PORT_MUX_OFFSET = "switchPortMuxOffset"
    SWITCH_STATUS = "switchStatus"
    SWITCH_TYPE = "switchType"
    SYMBOL = "symbol"
    SYMBOL_DELTA = "symbolDelta"
    SYMBOL_DELTA_AVG = "symbolDeltaAvg"
    SYMBOL_DELTA_MAX = "symbolDeltaMax"
    SYMBOL_DELTA_MIN = "symbolDeltaMin"
    SYNC_LOSSES = "syncLosses"
    SYNC_LOSSES_DELTA = "syncLossesDelta"
    SYNC_LOSSES_DELTA_AVG = "syncLossesDeltaAvg"
    SYNC_LOSSES_DELTA_MAX = "syncLossesDeltaMax"
    SYNC_LOSSES_DELTA_MIN = "syncLossesDeltaMin"
    SYNC_OPTION = "syncOption"
    SYNC_STATE = "syncState"
    SYNC_TRIGGER = "syncTrigger"
    SYS_CONTACT = "sysContact"
    SYS_ID = "sysId"
    SYS_LOCATION = "sysLocation"
    SYS_NAME = "sysName"
    SYS_STARTUP_VERSION = "sysStartupVersion"
    SYS_VERSION = "sysVersion"
    SYSID = "sysid"
    SYSTEM_DESC = "systemDesc"
    SYSTEM_NAME = "systemName"
    SYSTEM_UP_TIME = "systemUpTime"
    TAG = "tag"
    TAGS = "tags"
    TARGET = "target"
    TARGET_ATTR = "targetAttr"
    TARGET_DN = "targetDn"
    TARGET_IP1 = "targetIp1"
    TARGET_IP2 = "targetIp2"
    TARGET_IP3 = "targetIp3"
    TARGET_LUN = "targetLun"
    TARGET_STATUS = "targetStatus"
    TARGET_TOKEN_NAME = "targetTokenName"
    TARGET_TOKEN_VALUE = "targetTokenValue"
    TARGET_WWN = "targetWWN"
    TARGETWWPN = "targetwwpn"
    TCP_HASH = "tcpHash"
    TCP_RX_CHECKSUM = "tcpRxChecksum"
    TCP_SEGMENT = "tcpSegment"
    TCP_TIME_STAMP = "tcpTimeStamp"
    TCP_TX_CHECKSUM = "tcpTxChecksum"
    TD2 = "td2"
    TD2_AVG = "td2Avg"
    TD2_MAX = "td2Max"
    TD2_MIN = "td2Min"
    TECHNOLOGY = "technology"
    TEMP = "temp"
    TEMP_AVG = "tempAvg"
    TEMP_MAX = "tempMax"
    TEMP_MIN = "tempMin"
    TEMPERATURE = "temperature"
    TEMPERATURE_AVG = "temperatureAvg"
    TEMPERATURE_MAX = "temperatureMax"
    TEMPERATURE_MIN = "temperatureMin"
    TEMPL_TYPE = "templType"
    TEMPLATE_DATA_TIMEOUT = "templateDataTimeout"
    TERM = "term"
    TEST_DN = "testDn"
    TEST_TYPE = "testType"
    TFM_SUPPORTED = "tfmSupported"
    TFTP_URI = "tftpUri"
    THERMAL = "thermal"
    THERMAL_STATE_QUALIFIER = "thermalStateQualifier"
    THREADS = "threads"
    THRESHOLD = "threshold"
    THRESHOLD_LC = "thresholdLc"
    THRESHOLD_LNC = "thresholdLnc"
    THRESHOLD_LNR = "thresholdLnr"
    THRESHOLD_UC = "thresholdUc"
    THRESHOLD_UNC = "thresholdUnc"
    THRESHOLD_UNR = "thresholdUnr"
    THRESHOLDED = "thresholded"
    TIBURON = "tiburon"
    TIBURON_AVG = "tiburonAvg"
    TIBURON_MAX = "tiburonMax"
    TIBURON_MIN = "tiburonMin"
    TIME = "time"
    TIME_CAP = "timeCap"
    TIME_CAPPED = "timeCapped"
    TIME_COLLECTED = "timeCollected"
    TIME_OF_DAY_HOUR = "timeOfDayHour"
    TIME_OF_DAY_MINUTE = "timeOfDayMinute"
    TIME_OF_LAST_ATTEMPT = "timeOfLastAttempt"
    TIME_OF_LAST_SUCCESS = "timeOfLastSuccess"
    TIME_STAMP = "timeStamp"
    TIMEOUT = "timeout"
    TIMESTAMP = "timestamp"
    TIMEZONE = "timezone"
    TO = "to"
    TOKEN = "token"
    TOKEN_FEAT_GROUP = "tokenFeatGroup"
    TOO_LONG = "tooLong"
    TOO_LONG_DELTA = "tooLongDelta"
    TOO_LONG_DELTA_AVG = "tooLongDeltaAvg"
    TOO_LONG_DELTA_MAX = "tooLongDeltaMax"
    TOO_LONG_DELTA_MIN = "tooLongDeltaMin"
    TOO_LONG_RX = "tooLongRx"
    TOO_LONG_RX_DELTA = "tooLongRxDelta"
    TOO_LONG_RX_DELTA_AVG = "tooLongRxDeltaAvg"
    TOO_LONG_RX_DELTA_MAX = "tooLongRxDeltaMax"
    TOO_LONG_RX_DELTA_MIN = "tooLongRxDeltaMin"
    TOO_SHORT = "tooShort"
    TOO_SHORT_DELTA = "tooShortDelta"
    TOO_SHORT_DELTA_AVG = "tooShortDeltaAvg"
    TOO_SHORT_DELTA_MAX = "tooShortDeltaMax"
    TOO_SHORT_DELTA_MIN = "tooShortDeltaMin"
    TOO_SHORT_RX = "tooShortRx"
    TOO_SHORT_RX_DELTA = "tooShortRxDelta"
    TOO_SHORT_RX_DELTA_AVG = "tooShortRxDeltaAvg"
    TOO_SHORT_RX_DELTA_MAX = "tooShortRxDeltaMax"
    TOO_SHORT_RX_DELTA_MIN = "tooShortRxDeltaMin"
    TOTAL = "total"
    TOTAL_AVG = "totalAvg"
    TOTAL_BYTES = "totalBytes"
    TOTAL_BYTES_DELTA = "totalBytesDelta"
    TOTAL_BYTES_DELTA_AVG = "totalBytesDeltaAvg"
    TOTAL_BYTES_DELTA_MAX = "totalBytesDeltaMax"
    TOTAL_BYTES_DELTA_MIN = "totalBytesDeltaMin"
    TOTAL_CAPACITY = "totalCapacity"
    TOTAL_FAULTS = "totalFaults"
    TOTAL_MAX = "totalMax"
    TOTAL_MEMORY = "totalMemory"
    TOTAL_MIN = "totalMin"
    TOTAL_OPTIMIZATION_SETS = "totalOptimizationSets"
    TOTAL_PACKETS = "totalPackets"
    TOTAL_PACKETS_DELTA = "totalPacketsDelta"
    TOTAL_PACKETS_DELTA_AVG = "totalPacketsDeltaAvg"
    TOTAL_PACKETS_DELTA_MAX = "totalPacketsDeltaMax"
    TOTAL_PACKETS_DELTA_MIN = "totalPacketsDeltaMin"
    TOTAL_PASSES = "totalPasses"
    TOTAL_POWER = "totalPower"
    TOTAL_POWER_AVG = "totalPowerAvg"
    TOTAL_POWER_MAX = "totalPowerMax"
    TOTAL_POWER_MIN = "totalPowerMin"
    TOTAL_QUANT = "totalQuant"
    TOTAL_SESSIONS = "totalSessions"
    TOTAL_SLOTS = "totalSlots"
    TOTAL_VLAN_PORT_COUNT = "totalVlanPortCount"
    TP = "tp"
    TPM_CONFIG_SUPPORT = "tpmConfigSupport"
    TPM_REVISION = "tpmRevision"
    TR_DN = "trDn"
    TR_ID = "trId"
    TRAFFIC_DIRECTION = "trafficDirection"
    TRANSFER_STATE = "transferState"
    TRANSPORT = "transport"
    TRANSPORT_PROTOCOL = "transportProtocol"
    TRANSVERSE_GROUP_SEPARATION = "transverseGroupSeparation"
    TRANSVERSE_GROUP_SIZE = "transverseGroupSize"
    TRANSVERSE_OFFSET = "transverseOffset"
    TRAVERSAL = "traversal"
    TRAY = "tray"
    TRIG = "trig"
    TRIG_ELECTION_FLAG = "trigElectionFlag"
    TRIG_TIME = "trigTime"
    TRIGGER_CONFIG = "triggerConfig"
    TRIGGER_CONFIG_STATE = "triggerConfigState"
    TRIGGER_HEALTH_CHECK = "triggerHealthCheck"
    TRUE_HITS = "trueHits"
    TRUNCATE_OVERRUN = "truncateOverrun"
    TRUNCATE_OVERRUN_DELTA = "truncateOverrunDelta"
    TRUNCATE_OVERRUN_DELTA_AVG = "truncateOverrunDeltaAvg"
    TRUNCATE_OVERRUN_DELTA_MAX = "truncateOverrunDeltaMax"
    TRUNCATE_OVERRUN_DELTA_MIN = "truncateOverrunDeltaMin"
    TRUNCATE_OVERRUN_N0 = "truncateOverrunN0"
    TRUNCATE_OVERRUN_N0_DELTA = "truncateOverrunN0Delta"
    TRUNCATE_OVERRUN_N0_DELTA_AVG = "truncateOverrunN0DeltaAvg"
    TRUNCATE_OVERRUN_N0_DELTA_MAX = "truncateOverrunN0DeltaMax"
    TRUNCATE_OVERRUN_N0_DELTA_MIN = "truncateOverrunN0DeltaMin"
    TRUNCATE_OVERRUN_N1 = "truncateOverrunN1"
    TRUNCATE_OVERRUN_N1_DELTA = "truncateOverrunN1Delta"
    TRUNCATE_OVERRUN_N1_DELTA_AVG = "truncateOverrunN1DeltaAvg"
    TRUNCATE_OVERRUN_N1_DELTA_MAX = "truncateOverrunN1DeltaMax"
    TRUNCATE_OVERRUN_N1_DELTA_MIN = "truncateOverrunN1DeltaMin"
    TS = "ts"
    TX = "tx"
    TX_BAD_FRAMES = "txBadFrames"
    TX_BAD_FRAMES_DELTA = "txBadFramesDelta"
    TX_BAD_FRAMES_DELTA_AVG = "txBadFramesDeltaAvg"
    TX_BAD_FRAMES_DELTA_MAX = "txBadFramesDeltaMax"
    TX_BAD_FRAMES_DELTA_MIN = "txBadFramesDeltaMin"
    TX_BYTES = "txBytes"
    TX_BYTES_DELTA = "txBytesDelta"
    TX_BYTES_DELTA_AVG = "txBytesDeltaAvg"
    TX_BYTES_DELTA_MAX = "txBytesDeltaMax"
    TX_BYTES_DELTA_MIN = "txBytesDeltaMin"
    TX_DELTA = "txDelta"
    TX_DELTA_AVG = "txDeltaAvg"
    TX_DELTA_MAX = "txDeltaMax"
    TX_DELTA_MIN = "txDeltaMin"
    TX_DROPPED = "txDropped"
    TX_DROPPED_DELTA = "txDroppedDelta"
    TX_DROPPED_DELTA_AVG = "txDroppedDeltaAvg"
    TX_DROPPED_DELTA_MAX = "txDroppedDeltaMax"
    TX_DROPPED_DELTA_MIN = "txDroppedDeltaMin"
    TX_ERRORS = "txErrors"
    TX_ERRORS_DELTA = "txErrorsDelta"
    TX_ERRORS_DELTA_AVG = "txErrorsDeltaAvg"
    TX_ERRORS_DELTA_MAX = "txErrorsDeltaMax"
    TX_ERRORS_DELTA_MIN = "txErrorsDeltaMin"
    TX_FRAMES = "txFrames"
    TX_FRAMES_DELTA = "txFramesDelta"
    TX_FRAMES_DELTA_AVG = "txFramesDeltaAvg"
    TX_FRAMES_DELTA_MAX = "txFramesDeltaMax"
    TX_FRAMES_DELTA_MIN = "txFramesDeltaMin"
    TX_ID = "txId"
    TX_PACKETS = "txPackets"
    TX_PACKETS_DELTA = "txPacketsDelta"
    TX_PACKETS_DELTA_AVG = "txPacketsDeltaAvg"
    TX_PACKETS_DELTA_MAX = "txPacketsDeltaMax"
    TX_PACKETS_DELTA_MIN = "txPacketsDeltaMin"
    TX_PAUSE_CFC = "txPauseCFC"
    TX_PAUSE_CFCDELTA = "txPauseCFCDelta"
    TX_PAUSE_CFCDELTA_AVG = "txPauseCFCDeltaAvg"
    TX_PAUSE_CFCDELTA_MAX = "txPauseCFCDeltaMax"
    TX_PAUSE_CFCDELTA_MIN = "txPauseCFCDeltaMin"
    TX_PAUSE_PFC = "txPausePFC"
    TX_PAUSE_PFCDELTA = "txPausePFCDelta"
    TX_PAUSE_PFCDELTA_AVG = "txPausePFCDeltaAvg"
    TX_PAUSE_PFCDELTA_MAX = "txPausePFCDeltaMax"
    TX_PAUSE_PFCDELTA_MIN = "txPausePFCDeltaMin"
    TYPE = "type"
    UCSC_GENERATION = "ucscGeneration"
    UCSM_MO_DN = "ucsmMoDn"
    UCSM_VNET_EP_DN = "ucsmVnetEpDn"
    UDLD_ADMIN_STATE = "udldAdminState"
    UDLD_LINK_POLICY_NAME = "udldLinkPolicyName"
    UDLD_MODE = "udldMode"
    UDLD_MSG_INTERVAL = "udldMsgInterval"
    UDLD_OPER_STATE = "udldOperState"
    UDLD_RECOVERY_ACTION = "udldRecoveryAction"
    UI = "ui"
    UI_GROUP_NAME = "uiGroupName"
    UID = "uid"
    UMBILICAL_STATE = "umbilicalState"
    UNCOMPRESSED_VLAN_PORT_COUNT = "uncompressedVlanPortCount"
    UNCONFIGURED_CAPACITY = "unconfiguredCapacity"
    UNCORRECTABLE_ERRORS = "uncorrectableErrors"
    UNCORRECTABLE_ERRORS_DELTA = "uncorrectableErrorsDelta"
    UNCORRECTABLE_ERRORS_DELTA_AVG = "uncorrectableErrorsDeltaAvg"
    UNCORRECTABLE_ERRORS_DELTA_MAX = "uncorrectableErrorsDeltaMax"
    UNCORRECTABLE_ERRORS_DELTA_MIN = "uncorrectableErrorsDeltaMin"
    UNDER_SIZE = "underSize"
    UNDER_SIZE_DELTA = "underSizeDelta"
    UNDER_SIZE_DELTA_AVG = "underSizeDeltaAvg"
    UNDER_SIZE_DELTA_MAX = "underSizeDeltaMax"
    UNDER_SIZE_DELTA_MIN = "underSizeDeltaMin"
    UNDERSIZED_BAD_CRC_PACKETS = "undersizedBadCrcPackets"
    UNDERSIZED_BAD_CRC_PACKETS_DELTA = "undersizedBadCrcPacketsDelta"
    UNDERSIZED_BAD_CRC_PACKETS_DELTA_AVG = "undersizedBadCrcPacketsDeltaAvg"
    UNDERSIZED_BAD_CRC_PACKETS_DELTA_MAX = "undersizedBadCrcPacketsDeltaMax"
    UNDERSIZED_BAD_CRC_PACKETS_DELTA_MIN = "undersizedBadCrcPacketsDeltaMin"
    UNDERSIZED_GOOD_CRC_PACKETS = "undersizedGoodCrcPackets"
    UNDERSIZED_GOOD_CRC_PACKETS_DELTA = "undersizedGoodCrcPacketsDelta"
    UNDERSIZED_GOOD_CRC_PACKETS_DELTA_AVG = "undersizedGoodCrcPacketsDeltaAvg"
    UNDERSIZED_GOOD_CRC_PACKETS_DELTA_MAX = "undersizedGoodCrcPacketsDeltaMax"
    UNDERSIZED_GOOD_CRC_PACKETS_DELTA_MIN = "undersizedGoodCrcPacketsDeltaMin"
    UNEXPECTED_ERRORS = "unexpectedErrors"
    UNEXPECTED_ERRORS15_MIN = "unexpectedErrors15Min"
    UNEXPECTED_ERRORS15_MIN_H = "unexpectedErrors15MinH"
    UNEXPECTED_ERRORS1_DAY = "unexpectedErrors1Day"
    UNEXPECTED_ERRORS1_DAY_H = "unexpectedErrors1DayH"
    UNEXPECTED_ERRORS1_HOUR = "unexpectedErrors1Hour"
    UNEXPECTED_ERRORS1_HOUR_H = "unexpectedErrors1HourH"
    UNEXPECTED_ERRORS1_WEEK = "unexpectedErrors1Week"
    UNEXPECTED_ERRORS1_WEEK_H = "unexpectedErrors1WeekH"
    UNEXPECTED_ERRORS2_WEEKS = "unexpectedErrors2Weeks"
    UNEXPECTED_ERRORS2_WEEKS_H = "unexpectedErrors2WeeksH"
    UNICAST_PACKETS = "unicastPackets"
    UNICAST_PACKETS_DELTA = "unicastPacketsDelta"
    UNICAST_PACKETS_DELTA_AVG = "unicastPacketsDeltaAvg"
    UNICAST_PACKETS_DELTA_MAX = "unicastPacketsDeltaMax"
    UNICAST_PACKETS_DELTA_MIN = "unicastPacketsDeltaMin"
    UNIFIED_PORT = "unifiedPort"
    UNITS = "units"
    UNSUPPORTED_REQUEST_ERRORS = "unsupportedRequestErrors"
    UNSUPPORTED_REQUEST_ERRORS15_MIN = "unsupportedRequestErrors15Min"
    UNSUPPORTED_REQUEST_ERRORS15_MIN_H = "unsupportedRequestErrors15MinH"
    UNSUPPORTED_REQUEST_ERRORS1_DAY = "unsupportedRequestErrors1Day"
    UNSUPPORTED_REQUEST_ERRORS1_DAY_H = "unsupportedRequestErrors1DayH"
    UNSUPPORTED_REQUEST_ERRORS1_HOUR = "unsupportedRequestErrors1Hour"
    UNSUPPORTED_REQUEST_ERRORS1_HOUR_H = "unsupportedRequestErrors1HourH"
    UNSUPPORTED_REQUEST_ERRORS1_WEEK = "unsupportedRequestErrors1Week"
    UNSUPPORTED_REQUEST_ERRORS1_WEEK_H = "unsupportedRequestErrors1WeekH"
    UNSUPPORTED_REQUEST_ERRORS2_WEEKS = "unsupportedRequestErrors2Weeks"
    UNSUPPORTED_REQUEST_ERRORS2_WEEKS_H = "unsupportedRequestErrors2WeeksH"
    UPDATE = "update"
    UPDATE_METHOD = "updateMethod"
    UPDATE_TIME = "updateTime"
    UPDATE_TRIGGER = "updateTrigger"
    UPDATE_TS = "updateTs"
    UPDATE_TYPE = "updateType"
    UPGRADE_PRIORITY_INFO = "upgradePriorityInfo"
    UPGRADE_STATUS = "upgradeStatus"
    UPLINK_FAIL_ACTION = "uplinkFailAction"
    UPLINK_ID = "uplinkId"
    UPLINK_PORT_ID = "uplinkPortId"
    UPLINK_PORT_TYPE = "uplinkPortType"
    UPLINK_STATE = "uplinkState"
    UPLINK_STATE_REASON = "uplinkStateReason"
    UPLINK_TRUNKING = "uplinkTrunking"
    UPPER_LIMIT = "upperLimit"
    UPTIME = "uptime"
    UPTIME_DISR = "uptimeDisr"
    URGENCY = "urgency"
    URI = "uri"
    USAGE = "usage"
    USBNIC_CONN_SIDE = "usbnicConnSide"
    USE2_FACTOR = "use2Factor"
    USE_AES = "useAes"
    USE_ALL_ARPTARGETS = "useAllARPTargets"
    USE_JBOD_DISKS = "useJbodDisks"
    USE_PRIMARY_GROUP = "usePrimaryGroup"
    USE_REMAINING_DISKS = "useRemainingDisks"
    USED = "used"
    USED_QUANT = "usedQuant"
    USER = "user"
    USER_ACKNOWLEDGED = "userAcknowledged"
    USER_ID = "userId"
    USER_NAME = "userName"
    USER_RECOVERY_OPERATION = "userRecoveryOperation"
    USER_TYPE = "userType"
    USER_ZONE_ALLOC_STATUS = "userZoneAllocStatus"
    USER_ZONE_COUNT = "userZoneCount"
    USER_ZONE_LIMIT = "userZoneLimit"
    USNIC_COUNT = "usnicCount"
    USR_LBL = "usrLbl"
    UTIL_OSNAME = "utilOSName"
    UUID = "uuid"
    UUID_IDENTITY_STATE = "uuidIdentityState"
    UUID_SUFFIX = "uuidSuffix"
    UUID_SUPPORT_MODE = "uuidSupportMode"
    V1 = "v1"
    V2 = "v2"
    V3_PRIVILEGE = "v3Privilege"
    V4_ASSIGNED = "v4Assigned"
    V4_SIZE = "v4Size"
    V6_ASSIGNED = "v6Assigned"
    V6_SIZE = "v6Size"
    V_STATUS = "vStatus"
    V_SWITCH_ID = "vSwitchId"
    V_SWITCH_NAME = "vSwitchName"
    VALID_FROM = "validFrom"
    VALID_TO = "validTo"
    VALIDATE_STATUS = "validateStatus"
    VALIDITY = "validity"
    VALUE = "value"
    VAR_NAME = "varName"
    VAR_VALUE = "varValue"
    VARIANT_TYPE = "variantType"
    VC_DN = "vcDn"
    VCON_MAP = "vconMap"
    VCON_PROFILE_NAME = "vconProfileName"
    VD_DN = "vdDn"
    VENDOR = "vendor"
    VENDOR_DAEMON_PATH = "vendorDaemonPath"
    VENDOR_EQUIPMENT_TYPE = "vendorEquipmentType"
    VENDOR_ID = "vendorId"
    VENDOR_TYPE = "vendorType"
    VENDOR_UUID = "vendorUuid"
    VER = "ver"
    VER_RAW = "verRaw"
    VERSION = "version"
    VERSION_HOLDER = "versionHolder"
    VERSION_MISMATCH = "versionMismatch"
    VERTICAL_START_OFFSET = "verticalStartOffset"
    VETH_STATUS = "vethStatus"
    VIC_SLOT = "vicSlot"
    VIC_TEMP = "vicTemp"
    VIC_TEMP_AVG = "vicTempAvg"
    VIC_TEMP_MAX = "vicTempMax"
    VIC_TEMP_MIN = "vicTempMin"
    VID = "vid"
    VIF_CAPACITY = "vifCapacity"
    VIF_COUNT = "vifCount"
    VIF_COUNT_STATUS = "vifCountStatus"
    VIF_ID = "vifId"
    VIF_TYPE = "vifType"
    VIRTUAL_DISK_ID = "virtualDiskId"
    VIRTUAL_DRIVE_COUNT = "virtualDriveCount"
    VIRTUAL_DRIVE_OPS = "virtualDriveOps"
    VIRTUALIZATION_PREFERENCE = "virtualizationPreference"
    VISIBILITY = "visibility"
    VISIBLE = "visible"
    VLAN_COMP_OFF_LIMIT = "vlanCompOffLimit"
    VLAN_COMP_ON_LIMIT = "vlanCompOnLimit"
    VLAN_COMPRESSION = "vlanCompression"
    VLAN_FOR_BOOT = "vlanForBoot"
    VLAN_GROUP_UPDATE = "vlanGroupUpdate"
    VLAN_GRP_REQUEST_COMPUTE_TIME = "vlanGrpRequestComputeTime"
    VLAN_ID = "vlanId"
    VLAN_NAME = "vlanName"
    VLAN_PACKETS = "vlanPackets"
    VLAN_PACKETS_DELTA = "vlanPacketsDelta"
    VLAN_PACKETS_DELTA_AVG = "vlanPacketsDeltaAvg"
    VLAN_PACKETS_DELTA_MAX = "vlanPacketsDeltaMax"
    VLAN_PACKETS_DELTA_MIN = "vlanPacketsDeltaMin"
    VLAN_STATUS = "vlanStatus"
    VLAN_TYPE = "vlanType"
    VM_NETWORK_DEF_NAME = "vmNetworkDefName"
    VM_RETENTION = "vmRetention"
    VM_WARE = "vmWare"
    VMEDIA_ENCRYPTION = "vmediaEncryption"
    VMEDIA_POLICY_NAME = "vmediaPolicyName"
    VMMQ_SUB_VNICS = "vmmqSubVnics"
    VMND_GUID = "vmndGuid"
    VMND_NAME = "vmndName"
    VMQ_COUNT = "vmqCount"
    VNET = "vnet"
    VNET_ID = "vnetId"
    VNIC = "vnic"
    VNIC_CONFIG_ISSUES = "vnicConfigIssues"
    VNIC_DEF_TYPE = "vnicDefType"
    VNIC_DN = "vnicDn"
    VNIC_ETHER_DN = "vnicEtherDn"
    VNIC_MAP = "vnicMap"
    VNIC_NAME = "vnicName"
    VNIC_ORDER = "vnicOrder"
    VNIC_RETENTION = "vnicRetention"
    VNTAG = "vntag"
    VOLTAGE = "voltage"
    VOLTAGE_AVG = "voltageAvg"
    VOLTAGE_MAX = "voltageMax"
    VOLTAGE_MIN = "voltageMin"
    VP_ACPI10_SUPPORT = "vpACPI10Support"
    VP_ASPMSUPPORT = "vpASPMSupport"
    VP_ADJACENT_CACHE_LINE_PREFETCHER = "vpAdjacentCacheLinePrefetcher"
    VP_ALL_USBDEVICES = "vpAllUSBDevices"
    VP_ALTITUDE = "vpAltitude"
    VP_ASSERT_NMION_PERR = "vpAssertNMIOnPERR"
    VP_ASSERT_NMION_SERR = "vpAssertNMIOnSERR"
    VP_BMEDMAMITIGATION = "vpBMEDMAMitigation"
    VP_BAUD_RATE = "vpBaudRate"
    VP_BOOT_OPTION_RETRY = "vpBootOptionRetry"
    VP_CDNCONTROL = "vpCDNControl"
    VP_CPUHARDWARE_POWER_MANAGEMENT = "vpCPUHardwarePowerManagement"
    VP_CPUPERFORMANCE = "vpCPUPerformance"
    VP_CHANNEL_INTERLEAVING = "vpChannelInterleaving"
    VP_COM_SPCR_ENABLE = "vpComSpcrEnable"
    VP_COMPRESSION_SUPPORTED = "vpCompressionSupported"
    VP_CONSOLE_REDIRECTION = "vpConsoleRedirection"
    VP_CORE_MULTI_PROCESSING = "vpCoreMultiProcessing"
    VP_DCUIPPREFETCHER = "vpDCUIPPrefetcher"
    VP_DCUSTREAMER_PREFETCH = "vpDCUStreamerPrefetch"
    VP_DDR3_VOLTAGE_SELECTION = "vpDDR3VoltageSelection"
    VP_DRAMCLOCK_THROTTLING = "vpDRAMClockThrottling"
    VP_DEMAND_SCRUB = "vpDemandScrub"
    VP_DIRECT_CACHE_ACCESS = "vpDirectCacheAccess"
    VP_DRAM_REFRESH_RATE = "vpDramRefreshRate"
    VP_ENERGY_PERFORMANCE = "vpEnergyPerformance"
    VP_ENHANCED_INTEL_SPEED_STEP_TECH = "vpEnhancedIntelSpeedStepTech"
    VP_ENHANCED_POWER_CAPPING = "vpEnhancedPowerCapping"
    VP_EXECUTE_DISABLE_BIT = "vpExecuteDisableBit"
    VP_FRB2_TIMER = "vpFRB2Timer"
    VP_FLOW_CONTROL = "vpFlowControl"
    VP_FREQUENCY_FLOOR_OVERRIDE = "vpFrequencyFloorOverride"
    VP_FRONT_PANEL_LOCKOUT = "vpFrontPanelLockout"
    VP_HARDWARE_PREFETCHER = "vpHardwarePrefetcher"
    VP_IOEMEZZ1_OPTION_ROM = "vpIOEMezz1OptionROM"
    VP_IOENVME1_OPTION_ROM = "vpIOENVMe1OptionROM"
    VP_IOENVME2_OPTION_ROM = "vpIOENVMe2OptionROM"
    VP_IOESLOT1_OPTION_ROM = "vpIOESlot1OptionROM"
    VP_IOESLOT2_OPTION_ROM = "vpIOESlot2OptionROM"
    VP_INTEGRATED_GRAPHICS = "vpIntegratedGraphics"
    VP_INTEGRATED_GRAPHICS_APERTURE_SIZE = "vpIntegratedGraphicsApertureSize"
    VP_INTEL_HYPER_THREADING_TECH = "vpIntelHyperThreadingTech"
    VP_INTEL_TRUSTED_EXECUTION_TECHNOLOGY_SUPPORT = "vpIntelTrustedExecutionTechnologySupport"
    VP_INTEL_TURBO_BOOST_TECH = "vpIntelTurboBoostTech"
    VP_INTEL_VTDATSSUPPORT = "vpIntelVTDATSSupport"
    VP_INTEL_VTDCOHERENCY_SUPPORT = "vpIntelVTDCoherencySupport"
    VP_INTEL_VTDINTERRUPT_REMAPPING = "vpIntelVTDInterruptRemapping"
    VP_INTEL_VTDPASS_THROUGH_DMASUPPORT = "vpIntelVTDPassThroughDMASupport"
    VP_INTEL_VTFOR_DIRECTED_IO = "vpIntelVTForDirectedIO"
    VP_INTEL_VIRTUALIZATION_TECHNOLOGY = "vpIntelVirtualizationTechnology"
    VP_LEGACY_OSREDIRECTION = "vpLegacyOSRedirection"
    VP_LEGACY_USBSUPPORT = "vpLegacyUSBSupport"
    VP_LOAD = "vpLoad"
    VP_LOCAL_X2_APIC = "vpLocalX2Apic"
    VP_LV_DDRMODE = "vpLvDDRMode"
    VP_MAKE_DEVICE_NON_BOOTABLE = "vpMakeDeviceNonBootable"
    VP_MAXIMUM_MEMORY_BELOW4_GB = "vpMaximumMemoryBelow4GB"
    VP_MEMORY_INTERLEAVING = "vpMemoryInterleaving"
    VP_MEMORY_MAPPED_IOABOVE4_GB = "vpMemoryMappedIOAbove4GB"
    VP_MIRRORING_MODE = "vpMirroringMode"
    VP_NUMAOPTIMIZED = "vpNUMAOptimized"
    VP_OSBOOT_WATCHDOG_TIMER = "vpOSBootWatchdogTimer"
    VP_OSBOOT_WATCHDOG_TIMER_POLICY = "vpOSBootWatchdogTimerPolicy"
    VP_OSBOOT_WATCHDOG_TIMER_TIMEOUT = "vpOSBootWatchdogTimerTimeout"
    VP_ONBOARD_GRAPHICS = "vpOnboardGraphics"
    VP_ONBOARD_SATACONTROLLER = "vpOnboardSATAController"
    VP_ONBOARD_SCUSTORAGE_SUPPORT = "vpOnboardSCUStorageSupport"
    VP_PCIROMCLP = "vpPCIROMCLP"
    VP_PCIE10_GLOM2_LINK = "vpPCIe10GLOM2Link"
    VP_PCIE_SLOT10_LINK_SPEED = "vpPCIeSlot10LinkSpeed"
    VP_PCIE_SLOT1_LINK_SPEED = "vpPCIeSlot1LinkSpeed"
    VP_PCIE_SLOT2_LINK_SPEED = "vpPCIeSlot2LinkSpeed"
    VP_PCIE_SLOT3_LINK_SPEED = "vpPCIeSlot3LinkSpeed"
    VP_PCIE_SLOT4_LINK_SPEED = "vpPCIeSlot4LinkSpeed"
    VP_PCIE_SLOT5_LINK_SPEED = "vpPCIeSlot5LinkSpeed"
    VP_PCIE_SLOT6_LINK_SPEED = "vpPCIeSlot6LinkSpeed"
    VP_PCIE_SLOT7_LINK_SPEED = "vpPCIeSlot7LinkSpeed"
    VP_PCIE_SLOT8_LINK_SPEED = "vpPCIeSlot8LinkSpeed"
    VP_PCIE_SLOT9_LINK_SPEED = "vpPCIeSlot9LinkSpeed"
    VP_PCIE_SLOT_HBAOPTION_ROM = "vpPCIeSlotHBAOptionROM"
    VP_PCIE_SLOT_MLOMOPTION_ROM = "vpPCIeSlotMLOMOptionROM"
    VP_PCIE_SLOT_N1_OPTION_ROM = "vpPCIeSlotN1OptionROM"
    VP_PCIE_SLOT_N2_OPTION_ROM = "vpPCIeSlotN2OptionROM"
    VP_PCIE_SLOT_SASOPTION_ROM = "vpPCIeSlotSASOptionROM"
    VP_POSTERROR_PAUSE = "vpPOSTErrorPause"
    VP_PSTATECOORDINATION = "vpPSTATECoordination"
    VP_PACKAGE_CSTATE_LIMIT = "vpPackageCStateLimit"
    VP_PANIC_AND_HIGH_WATERMARK = "vpPanicAndHighWatermark"
    VP_PATROL_SCRUB = "vpPatrolScrub"
    VP_PORT6064_EMULATION = "vpPort6064Emulation"
    VP_POWER_TECHNOLOGY = "vpPowerTechnology"
    VP_PROCESSOR_C1_E = "vpProcessorC1E"
    VP_PROCESSOR_C3_REPORT = "vpProcessorC3Report"
    VP_PROCESSOR_C6_REPORT = "vpProcessorC6Report"
    VP_PROCESSOR_C7_REPORT = "vpProcessorC7Report"
    VP_PROCESSOR_CMCI = "vpProcessorCMCI"
    VP_PROCESSOR_CSTATE = "vpProcessorCState"
    VP_PROCESSOR_MTRR = "vpProcessorMtrr"
    VP_PUTTY_KEY_PAD = "vpPuttyKeyPad"
    VP_PWR_PERF_TUNING = "vpPwrPerfTuning"
    VP_QPILINK_FREQUENCY_SELECT = "vpQPILinkFrequencySelect"
    VP_QPISNOOP_MODE = "vpQPISnoopMode"
    VP_QUIET_BOOT = "vpQuietBoot"
    VP_RANK_INTERLEAVING = "vpRankInterleaving"
    VP_REDIRECTION_AFTER_POST = "vpRedirectionAfterPOST"
    VP_RESUME_ON_ACPOWER_LOSS = "vpResumeOnACPowerLoss"
    VP_SASRAID = "vpSASRAID"
    VP_SASRAIDMODULE = "vpSASRAIDModule"
    VP_SATAMODE = "vpSATAMode"
    VP_SBMEZZ1_OPTION_ROM = "vpSBMezz1OptionROM"
    VP_SBNVME1_OPTION_ROM = "vpSBNVMe1OptionROM"
    VP_SIOC1_OPTION_ROM = "vpSIOC1OptionROM"
    VP_SIOC2_OPTION_ROM = "vpSIOC2OptionROM"
    VP_SELECT_MEMORY_RASCONFIGURATION = "vpSelectMemoryRASConfiguration"
    VP_SERIAL_PORT_AENABLE = "vpSerialPortAEnable"
    VP_SLOT10_STATE = "vpSlot10State"
    VP_SLOT1_STATE = "vpSlot1State"
    VP_SLOT2_STATE = "vpSlot2State"
    VP_SLOT3_STATE = "vpSlot3State"
    VP_SLOT4_STATE = "vpSlot4State"
    VP_SLOT5_STATE = "vpSlot5State"
    VP_SLOT6_STATE = "vpSlot6State"
    VP_SLOT7_STATE = "vpSlot7State"
    VP_SLOT8_STATE = "vpSlot8State"
    VP_SLOT9_STATE = "vpSlot9State"
    VP_SLOT_MEZZ_STATE = "vpSlotMezzState"
    VP_SPARING_MODE = "vpSparingMode"
    VP_SRIOV = "vpSriov"
    VP_STATE = "vpState"
    VP_TPMPENDING_OPERATION = "vpTPMPendingOperation"
    VP_TPMSUPPORT = "vpTPMSupport"
    VP_TERMINAL_TYPE = "vpTerminalType"
    VP_TRUSTED_PLATFORM_MODULE_SUPPORT = "vpTrustedPlatformModuleSupport"
    VP_UCSMBOOT_ORDER_RULE = "vpUCSMBootOrderRule"
    VP_UEFIBOOT_MODE = "vpUEFIBootMode"
    VP_UEFIOSUSE_LEGACY_VIDEO = "vpUEFIOSUseLegacyVideo"
    VP_USBFRONT_PANEL_LOCK = "vpUSBFrontPanelLock"
    VP_USBIDLE_POWER_OPTIMIZING = "vpUSBIdlePowerOptimizing"
    VP_USBPORT_FRONT = "vpUSBPortFront"
    VP_USBPORT_INTERNAL = "vpUSBPortInternal"
    VP_USBPORT_KVM = "vpUSBPortKVM"
    VP_USBPORT_REAR = "vpUSBPortRear"
    VP_USBPORT_SDCARD = "vpUSBPortSDCard"
    VP_USBPORT_VMEDIA = "vpUSBPortVMedia"
    VP_VGAPRIORITY = "vpVGAPriority"
    VP_WORKLOAD_CONFIGURATION = "vpWorkloadConfiguration"
    VP_XHCIMODE = "vpXHCIMode"
    VSAN_ID = "vsanId"
    WARNINGS = "warnings"
    WD_ADMIN_STATE = "wdAdminState"
    WD_INTERVAL = "wdInterval"
    WD_SHUTDOWN_MULTIPLIER = "wdShutdownMultiplier"
    WEAR_PERCENTAGE = "wearPercentage"
    WEAR_PERCENTAGE_AVG = "wearPercentageAvg"
    WEAR_PERCENTAGE_MAX = "wearPercentageMax"
    WEAR_PERCENTAGE_MIN = "wearPercentageMin"
    WEAR_STATUS_IN_DAYS = "wearStatusInDays"
    WEAR_STATUS_IN_DAYS_AVG = "wearStatusInDaysAvg"
    WEAR_STATUS_IN_DAYS_MAX = "wearStatusInDaysMax"
    WEAR_STATUS_IN_DAYS_MIN = "wearStatusInDaysMin"
    WEB_UIKVM_CONSOLE_SUPPORTED = "webUIKvmConsoleSupported"
    WEIGHT = "weight"
    WIDTH = "width"
    WINDOW_DN = "windowDn"
    WORKING_DIRECTORY = "workingDirectory"
    WRITABLE = "writable"
    WRITE_CACHE_POLICY = "writeCachePolicy"
    WRITE_ENABLE = "writeEnable"
    WRITE_ERROR_THRESHOLD = "writeErrorThreshold"
    WRITE_IOERROR_COUNT = "writeIOErrorCount"
    WRITE_MODE = "writeMode"
    WWN = "wwn"
    WWN_REVERSE_MASK_A = "wwnReverseMaskA"
    WWN_REVERSE_MASK_B = "wwnReverseMaskB"
    WWNN = "wwnn"
    WWNN_REVERSE_MASK_A = "wwnnReverseMaskA"
    WWNN_REVERSE_MASK_B = "wwnnReverseMaskB"
    WWPN = "wwpn"
    XCVR_TYPE = "xcvrType"
    XMIT = "xmit"
    XMIT_DELTA = "xmitDelta"
    XMIT_DELTA_AVG = "xmitDeltaAvg"
    XMIT_DELTA_MAX = "xmitDeltaMax"
    XMIT_DELTA_MIN = "xmitDeltaMin"
    XMIT_HASH_TYPE = "xmitHashType"
    XMIT_PAUSE = "xmitPause"
    XMIT_PAUSE_DELTA = "xmitPauseDelta"
    XMIT_PAUSE_DELTA_AVG = "xmitPauseDeltaAvg"
    XMIT_PAUSE_DELTA_MAX = "xmitPauseDeltaMax"
    XMIT_PAUSE_DELTA_MIN = "xmitPauseDeltaMin"
    ZONE_COUNT = "zoneCount"
    ZONE_NAME = "zoneName"
    ZONING_STATE = "zoningState"
    ZONING_SUPPORTED = "zoningSupported"
    ZONING_TYPE = "zoningType"


class Status:
    CREATED = "created"
    DELETED = "deleted"
    MODIFIED = "modified"
    REMOVED = "removed"
